/* Generated by Cython 3.0.5 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "unicorn_binance_rest_api.manager",
        "sources": [
            "unicorn_binance_rest_api/manager.py"
        ]
    },
    "module_name": "unicorn_binance_rest_api.manager"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_5" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030005F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info; // borrowed
        #endif
        PyObject *py_minor_version = NULL;
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11; // we don't yet need to distinguish between versions > 11
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        Py_XDECREF(py_minor_version);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);  // we don't have access to __pyx_empty_bytes here
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE(obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__unicorn_binance_rest_api__manager
#define __PYX_HAVE_API__unicorn_binance_rest_api__manager
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else  // Py < 3.12
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "unicorn_binance_rest_api/manager.py",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr;
struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter;
struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator;
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;
struct __pyx_defaults1;
typedef struct __pyx_defaults1 __pyx_defaults1;
struct __pyx_defaults2;
typedef struct __pyx_defaults2 __pyx_defaults2;
struct __pyx_defaults3;
typedef struct __pyx_defaults3 __pyx_defaults3;
struct __pyx_defaults4;
typedef struct __pyx_defaults4 __pyx_defaults4;
struct __pyx_defaults5;
typedef struct __pyx_defaults5 __pyx_defaults5;
struct __pyx_defaults6;
typedef struct __pyx_defaults6 __pyx_defaults6;
struct __pyx_defaults7;
typedef struct __pyx_defaults7 __pyx_defaults7;
struct __pyx_defaults8;
typedef struct __pyx_defaults8 __pyx_defaults8;
struct __pyx_defaults9;
typedef struct __pyx_defaults9 __pyx_defaults9;
struct __pyx_defaults10;
typedef struct __pyx_defaults10 __pyx_defaults10;
struct __pyx_defaults {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults1 {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults2 {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults3 {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults4 {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults5 {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults6 {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults7 {
  PyObject *__pyx_arg_version;
};
struct __pyx_defaults8 {
  PyObject *__pyx_arg_timeInForce;
};
struct __pyx_defaults9 {
  PyObject *__pyx_arg_timeInForce;
};
struct __pyx_defaults10 {
  PyObject *__pyx_arg_timeInForce;
};

/* "unicorn_binance_rest_api/manager.py":525
 *         # if get request assign data array to params value for requests lib
 *         if data and (method == 'get' or force_params):
 *             kwargs['params'] = '&'.join('%s=%s' % (data[0], data[1]) for data in kwargs['data'])             # <<<<<<<<<<<<<<
 *             del(kwargs['data'])
 * 
 */
struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_data;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "unicorn_binance_rest_api/manager.py":1039
 *         return self._get('aggTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def aggregate_trade_iter(self, symbol, start_str=None, last_id=None):             # <<<<<<<<<<<<<<
 *         """
 *         Iterate over aggregate trade data from (start_time or last_id) to
 */
struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter {
  PyObject_HEAD
  PyObject *__pyx_v_end_ts;
  PyObject *__pyx_v_last_id;
  PyObject *__pyx_v_self;
  PyObject *__pyx_v_start_str;
  PyObject *__pyx_v_start_ts;
  PyObject *__pyx_v_symbol;
  PyObject *__pyx_v_t;
  PyObject *__pyx_v_trades;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "unicorn_binance_rest_api/manager.py":1276
 *         return output_data
 * 
 *     def get_historical_klines_generator(self, symbol, interval, start_str, end_str=None):             # <<<<<<<<<<<<<<
 *         """
 *         Get Historical Klines from Binance
 */
struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator {
  PyObject_HEAD
  PyObject *__pyx_v_end_str;
  PyObject *__pyx_v_end_ts;
  PyObject *__pyx_v_first_valid_ts;
  PyObject *__pyx_v_idx;
  PyObject *__pyx_v_interval;
  long __pyx_v_limit;
  PyObject *__pyx_v_o;
  PyObject *__pyx_v_output_data;
  PyObject *__pyx_v_self;
  PyObject *__pyx_v_start_str;
  PyObject *__pyx_v_start_ts;
  PyObject *__pyx_v_symbol;
  PyObject *__pyx_v_timeframe;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};

/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg // no-op
    #define __Pyx_Arg_XDECREF_VARARGS(arg) // no-op - arg is borrowed
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    static CYTHON_UNUSED PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg // no-op, __Pyx_Arg_FASTCALL is direct and this needs
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)  // no-op - arg was returned from array
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_MultiplyObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* MergeKeywords.proto */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_RemainderObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_RemainderObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceRemainder(op1, op2) : PyNumber_Remainder(op1, op2))
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* CoroutineBase.proto */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */

/* Module declarations from "cython" */

/* Module declarations from "unicorn_binance_rest_api.manager" */
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "unicorn_binance_rest_api.manager"
extern int __pyx_module_is_main_unicorn_binance_rest_api__manager;
int __pyx_module_is_main_unicorn_binance_rest_api__manager = 0;

/* Implementation of "unicorn_binance_rest_api.manager" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_reversed;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_ValueError;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = " ";
static const char __pyx_k_M[] = "M";
static const char __pyx_k_T[] = "T";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_o[] = "o";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_q[] = "q";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_1M[] = "1M";
static const char __pyx_k_1d[] = "1d";
static const char __pyx_k_1h[] = "1h";
static const char __pyx_k_1m[] = "1m";
static const char __pyx_k_1s[] = "1s";
static const char __pyx_k_1w[] = "1w";
static const char __pyx_k_22[] = "%22";
static const char __pyx_k_27[] = "%27";
static const char __pyx_k_2h[] = "2h";
static const char __pyx_k_3d[] = "3d";
static const char __pyx_k_3m[] = "3m";
static const char __pyx_k_4h[] = "4h";
static const char __pyx_k_5m[] = "5m";
static const char __pyx_k_6h[] = "6h";
static const char __pyx_k_8h[] = "8h";
static const char __pyx_k__2[] = "`";
static const char __pyx_k__3[] = ":";
static const char __pyx_k__4[] = "@";
static const char __pyx_k__5[] = "_";
static const char __pyx_k__6[] = " - ";
static const char __pyx_k__7[] = "/";
static const char __pyx_k__8[] = "&";
static const char __pyx_k__9[] = "{}={}";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_v1[] = "v1";
static const char __pyx_k_v2[] = "v2";
static const char __pyx_k_v3[] = "v3";
static const char __pyx_k_12h[] = "12h";
static const char __pyx_k_15m[] = "15m";
static const char __pyx_k_30m[] = "30m";
static const char __pyx_k_ACK[] = "ACK";
static const char __pyx_k_BUY[] = "BUY";
static const char __pyx_k_FOK[] = "FOK";
static const char __pyx_k_GTC[] = "GTC";
static const char __pyx_k_IOC[] = "IOC";
static const char __pyx_k_NEW[] = "NEW";
static const char __pyx_k_bal[] = "bal";
static const char __pyx_k_dev[] = ".dev";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_idx[] = "idx";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_llm[] = "llm";
static const char __pyx_k_msg[] = "msg";
static const char __pyx_k_new[] = "new";
static const char __pyx_k_put[] = "put";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_s_s[] = "%s=%s";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_tld[] = "tld";
static const char __pyx_k_uri[] = "uri";
static const char __pyx_k_Date[] = "Date";
static const char __pyx_k_FULL[] = "FULL";
static const char __pyx_k_SELL[] = "SELL";
static const char __pyx_k_SPOT[] = "SPOT";
static const char __pyx_k__184[] = " ...";
static const char __pyx_k__185[] = ".";
static const char __pyx_k__186[] = "*";
static const char __pyx_k__488[] = "?";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_hmac[] = "hmac";
static const char __pyx_k_http[] = "http";
static const char __pyx_k_info[] = "info";
static const char __pyx_k_init[] = "init";
static const char __pyx_k_item[] = "item";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_json[] = "json";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_ping[] = "ping";
static const char __pyx_k_post[] = "post";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_side[] = "side";
static const char __pyx_k_sort[] = "sort";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_2_0_0[] = "2.0.0";
static const char __pyx_k_LIMIT[] = "LIMIT";
static const char __pyx_k_asset[] = "asset";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_depth[] = "depth";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_entry[] = "entry";
static const char __pyx_k_get_2[] = "_get";
static const char __pyx_k_https[] = "https";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_kline[] = "kline";
static const char __pyx_k_limit[] = "limit";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_order[] = "order";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_put_2[] = "_put";
static const char __pyx_k_sleep[] = "sleep";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_tld_2[] = "tld: ";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_AGG_ID[] = "AGG_ID";
static const char __pyx_k_Accept[] = "Accept";
static const char __pyx_k_FILLED[] = "FILLED";
static const char __pyx_k_MARKET[] = "MARKET";
static const char __pyx_k_RESULT[] = "RESULT";
static const char __pyx_k_delete[] = "delete";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_end_ts[] = "end_ts";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_fromId[] = "fromId";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_income[] = "income";
static const char __pyx_k_init_2[] = "__init__";
static const char __pyx_k_klines[] = "klines";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_logger[] = "logger";
static const char __pyx_k_method[] = "method";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_output[] = "output";
static const char __pyx_k_params[] = "params";
static const char __pyx_k_post_2[] = "_post";
static const char __pyx_k_python[] = "-python_";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_sha256[] = "sha256";
static const char __pyx_k_signed[] = "signed";
static const char __pyx_k_socks5[] = "socks5://";
static const char __pyx_k_status[] = "status";
static const char __pyx_k_symbol[] = "symbol";
static const char __pyx_k_system[] = "system";
static const char __pyx_k_trades[] = "trades";
static const char __pyx_k_typing[] = "typing";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_verify[] = "verify";
static const char __pyx_k_weight[] = "weight";
static const char __pyx_k_API_KEY[] = "API_KEY";
static const char __pyx_k_API_URL[] = "API_URL";
static const char __pyx_k_EXPIRED[] = "EXPIRED";
static const char __pyx_k_Release[] = "Release ";
static const char __pyx_k_account[] = "account";
static const char __pyx_k_api_key[] = "api_key";
static const char __pyx_k_balance[] = "balance";
static const char __pyx_k_bnbBurn[] = "bnbBurn";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_endTime[] = "endTime";
static const char __pyx_k_end_str[] = "end_str";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_hashlib[] = "hashlib";
static const char __pyx_k_headers[] = "headers";
static const char __pyx_k_helpers[] = "helpers";
static const char __pyx_k_last_id[] = "last_id";
static const char __pyx_k_logging[] = "logging";
static const char __pyx_k_options[] = "options";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_proxies[] = "proxies";
static const char __pyx_k_release[] = "release";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_request[] = "_request";
static const char __pyx_k_respond[] = "respond";
static const char __pyx_k_session[] = "session";
static const char __pyx_k_started[] = " started ...";
static const char __pyx_k_success[] = "success";
static const char __pyx_k_symbols[] = "symbols";
static const char __pyx_k_timeout[] = "timeout";
static const char __pyx_k_transTo[] = "transTo";
static const char __pyx_k_unknown[] = "unknown";
static const char __pyx_k_version[] = "version";
static const char __pyx_k_warning[] = "warning";
static const char __pyx_k_AGG_TIME[] = "AGG_TIME";
static const char __pyx_k_C2C_MAIN[] = "C2C_MAIN";
static const char __pyx_k_CANCELED[] = "CANCELED";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_MAIN_C2C[] = "MAIN_C2C";
static const char __pyx_k_Optional[] = "Optional";
static const char __pyx_k_REJECTED[] = "REJECTED";
static const char __pyx_k_SIDE_BUY[] = "SIDE_BUY";
static const char __pyx_k_avgPrice[] = "avgPrice";
static const char __pyx_k_balances[] = "balances";
static const char __pyx_k_colorama[] = "colorama";
static const char __pyx_k_critical[] = "critical";
static const char __pyx_k_datetime[] = "datetime";
static const char __pyx_k_delete_2[] = "_delete";
static const char __pyx_k_exc_type[] = "exc_type";
static const char __pyx_k_exchange[] = "exchange";
static const char __pyx_k_interval[] = "interval";
static const char __pyx_k_leverage[] = "leverage";
static const char __pyx_k_myTrades[] = "myTrades";
static const char __pyx_k_operator[] = "operator";
static const char __pyx_k_platform[] = "platform";
static const char __pyx_k_products[] = "products";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_raw_data[] = "raw_data";
static const char __pyx_k_requests[] = "requests";
static const char __pyx_k_response[] = "response";
static const char __pyx_k_reversed[] = "reversed";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_start_ts[] = "start_ts";
static const char __pyx_k_strptime[] = "strptime";
static const char __pyx_k_tag_name[] = "tag_name";
static const char __pyx_k_withdraw[] = "withdraw";
static const char __pyx_k_AGG_PRICE[] = "AGG_PRICE";
static const char __pyx_k_SIDE_SELL[] = "SIDE_SELL";
static const char __pyx_k_STOP_LOSS[] = "STOP_LOSS";
static const char __pyx_k_aggTrades[] = "aggTrades";
static const char __pyx_k_allOrders[] = "allOrders";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_error_msg[] = "error_msg";
static const char __pyx_k_exc_value[] = "exc_value";
static const char __pyx_k_getLogger[] = "getLogger";
static const char __pyx_k_get_order[] = "get_order";
static const char __pyx_k_hexdigest[] = "hexdigest";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_listenKey[] = "listenKey";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_null_args[] = "null_args";
static const char __pyx_k_order_oco[] = "order/oco";
static const char __pyx_k_signature[] = "signature";
static const char __pyx_k_startTime[] = "startTime";
static const char __pyx_k_start_str[] = "start_str";
static const char __pyx_k_temp_data[] = "temp_data";
static const char __pyx_k_timeframe[] = "timeframe";
static const char __pyx_k_timestamp[] = "timestamp";
static const char __pyx_k_transFrom[] = "transFrom";
static const char __pyx_k_urlencode[] = "urlencode";
static const char __pyx_k_version_2[] = "__version__";
static const char __pyx_k_API_SECRET[] = "API_SECRET";
static const char __pyx_k_C2C_MINING[] = "C2C_MINING";
static const char __pyx_k_MINING_C2C[] = "MINING_C2C";
static const char __pyx_k_User_Agent[] = "User-Agent";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_api_secret[] = "api_secret";
static const char __pyx_k_asset_dust[] = "asset/dust";
static const char __pyx_k_binance_us[] = "binance.us";
static const char __pyx_k_exceptions[] = "exceptions";
static const char __pyx_k_exchange_2[] = ", exchange: ";
static const char __pyx_k_get_klines[] = "get_klines";
static const char __pyx_k_get_ticker[] = "get_ticker";
static const char __pyx_k_itemgetter[] = "itemgetter";
static const char __pyx_k_marginType[] = "marginType";
static const char __pyx_k_openOrders[] = "openOrders";
static const char __pyx_k_order_test[] = "order/test";
static const char __pyx_k_serverTime[] = "serverTime";
static const char __pyx_k_update_msg[] = "update_msg";
static const char __pyx_k_userTrades[] = "userTrades";
static const char __pyx_k_user_agent[] = "user_agent";
static const char __pyx_k_FUTURES_URL[] = "FUTURES_URL";
static const char __pyx_k_LIMIT_MAKER[] = "LIMIT_MAKER";
static const char __pyx_k_MAIN_MARGIN[] = "MAIN_MARGIN";
static const char __pyx_k_MAIN_MINING[] = "MAIN_MINING";
static const char __pyx_k_MARGIN_MAIN[] = "MARGIN_MAIN";
static const char __pyx_k_MINING_MAIN[] = "MINING_MAIN";
static const char __pyx_k_TAKE_PROFIT[] = "TAKE_PROFIT";
static const char __pyx_k_WEBSITE_URL[] = "WEBSITE_URL";
static const char __pyx_k_batchOrders[] = "batchOrders";
static const char __pyx_k_binance_com[] = "binance.com";
static const char __pyx_k_compiled_on[] = "-compiled on ";
static const char __pyx_k_fundingRate[] = "fundingRate";
static const char __pyx_k_get_account[] = "get_account";
static const char __pyx_k_get_version[] = "get_version";
static const char __pyx_k_license_ini[] = "license_ini";
static const char __pyx_k_margin_loan[] = "margin/loan";
static const char __pyx_k_margin_pair[] = "margin/pair";
static const char __pyx_k_mro_entries[] = "__mro_entries__";
static const char __pyx_k_order_limit[] = "order_limit";
static const char __pyx_k_output_data[] = "output_data";
static const char __pyx_k_request_api[] = "_request_api";
static const char __pyx_k_status_code[] = "status_code";
static const char __pyx_k_ticker_24hr[] = "ticker/24hr";
static const char __pyx_k_timeInForce[] = "timeInForce";
static const char __pyx_k_withdraw_id[] = "withdraw_id";
static const char __pyx_k_AGG_QUANTITY[] = "AGG_QUANTITY";
static const char __pyx_k_C2C_UMFUTURE[] = "C2C_UMFUTURE";
static const char __pyx_k_FIAT_TO_SPOT[] = "FIAT_TO_SPOT";
static const char __pyx_k_Optional_str[] = "Optional[str]";
static const char __pyx_k_SPOT_TO_FIAT[] = "SPOT_TO_FIAT";
static const char __pyx_k_UMFUTURE_C2C[] = "UMFUTURE_C2C";
static const char __pyx_k_X_MBX_APIKEY[] = "X-MBX-APIKEY";
static const char __pyx_k_cancel_order[] = "cancel_order";
static const char __pyx_k_create_order[] = "create_order";
static const char __pyx_k_exchangeInfo[] = "exchangeInfo";
static const char __pyx_k_for_exchange[] = " for exchange ";
static const char __pyx_k_force_params[] = "force_params";
static const char __pyx_k_futures_ping[] = "futures_ping";
static const char __pyx_k_futures_time[] = "futures_time";
static const char __pyx_k_get_dust_log[] = "get_dust_log";
static const char __pyx_k_get_products[] = "get_products";
static const char __pyx_k_init_session[] = "_init_session";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_margin_asset[] = "margin/asset";
static const char __pyx_k_margin_order[] = "margin/order";
static const char __pyx_k_margin_repay[] = "margin/repay";
static const char __pyx_k_openInterest[] = "openInterest";
static const char __pyx_k_order_market[] = "order_market";
static const char __pyx_k_order_params[] = "_order_params";
static const char __pyx_k_ordered_data[] = "ordered_data";
static const char __pyx_k_positionRisk[] = "positionRisk";
static const char __pyx_k_premiumIndex[] = "premiumIndex";
static const char __pyx_k_program_used[] = "program_used";
static const char __pyx_k_query_string[] = "query_string";
static const char __pyx_k_self_API_URL[] = "\r\nself.API_URL: ";
static const char __pyx_k_stop_manager[] = "stop_manager";
static const char __pyx_k_stream_close[] = "stream_close";
static const char __pyx_k_ticker_price[] = "ticker/price";
static const char __pyx_k_urllib_parse[] = "urllib.parse";
static const char __pyx_k_withdrawList[] = "withdrawList";
static const char __pyx_k_CMFUTURE_MAIN[] = "CMFUTURE_MAIN";
static const char __pyx_k_MAIN_CMFUTURE[] = "MAIN_CMFUTURE";
static const char __pyx_k_MAIN_UMFUTURE[] = "MAIN_UMFUTURE";
static const char __pyx_k_Optional_bool[] = "Optional[bool]";
static const char __pyx_k_UMFUTURE_MAIN[] = "UMFUTURE_MAIN";
static const char __pyx_k_allOpenOrders[] = "allOpenOrders";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_date_time_obj[] = "date_time_obj";
static const char __pyx_k_get_avg_price[] = "get_avg_price";
static const char __pyx_k_get_my_trades[] = "get_my_trades";
static const char __pyx_k_get_trade_fee[] = "get_trade_fee";
static const char __pyx_k_has_signature[] = "has_signature";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_license_token[] = "license_token";
static const char __pyx_k_order_oco_buy[] = "order_oco_buy";
static const char __pyx_k_system_status[] = "system/status";
static const char __pyx_k_transfer_dust[] = "transfer_dust";
static const char __pyx_k_trbinance_com[] = "trbinance.com";
static const char __pyx_k_AGG_BEST_MATCH[] = "AGG_BEST_MATCH";
static const char __pyx_k_FIAT_TO_MINING[] = "FIAT_TO_MINING";
static const char __pyx_k_MARGIN_API_URL[] = "MARGIN_API_URL";
static const char __pyx_k_MINING_TO_FIAT[] = "MINING_TO_FIAT";
static const char __pyx_k_MINING_TO_SPOT[] = "MINING_TO_SPOT";
static const char __pyx_k_PENDING_CANCEL[] = "PENDING_CANCEL";
static const char __pyx_k_SPOT_TO_MINING[] = "SPOT_TO_MINING";
static const char __pyx_k_account_status[] = "account/status";
static const char __pyx_k_allForceOrders[] = "allForceOrders";
static const char __pyx_k_asset_dribblet[] = "asset/dribblet";
static const char __pyx_k_asset_tradeFee[] = "asset/tradeFee";
static const char __pyx_k_asset_transfer[] = "asset/transfer";
static const char __pyx_k_commissionRate[] = "commissionRate";
static const char __pyx_k_create_api_uri[] = "_create_api_uri";
static const char __pyx_k_first_valid_ts[] = "first_valid_ts";
static const char __pyx_k_futures_klines[] = "futures_klines";
static const char __pyx_k_futures_ticker[] = "futures_ticker";
static const char __pyx_k_get_all_orders[] = "get_all_orders";
static const char __pyx_k_get_order_book[] = "get_order_book";
static const char __pyx_k_get_user_agent[] = "get_user_agent";
static const char __pyx_k_margin_account[] = "margin/account";
static const char __pyx_k_order_oco_sell[] = "order_oco_sell";
static const char __pyx_k_positionMargin[] = "positionMargin";
static const char __pyx_k_python_version[] = "python_version";
static const char __pyx_k_userDataStream[] = "userDataStream";
static const char __pyx_k_warn_on_update[] = "warn_on_update";
static const char __pyx_k_AGG_BUYER_MAKES[] = "AGG_BUYER_MAKES";
static const char __pyx_k_ISOLATED_MARGIN[] = "ISOLATED_MARGIN";
static const char __pyx_k_MARGIN_UMFUTURE[] = "MARGIN_UMFUTURE";
static const char __pyx_k_MINING_UMFUTURE[] = "MINING_UMFUTURE";
static const char __pyx_k_New_instance_of[] = "New instance of ";
static const char __pyx_k_STOP_LOSS_LIMIT[] = "STOP_LOSS_LIMIT";
static const char __pyx_k_UMFUTURE_MARGIN[] = "UMFUTURE_MARGIN";
static const char __pyx_k_UnknownExchange[] = "UnknownExchange";
static const char __pyx_k_a_d_b_Y_I_M_S_Z[] = "%a, %d %b %Y %I:%M:%S %Z";
static const char __pyx_k_accountSnapshot[] = "accountSnapshot";
static const char __pyx_k_error_traceback[] = "error_traceback";
static const char __pyx_k_futures_account[] = "futures_account";
static const char __pyx_k_get_all_tickers[] = "get_all_tickers";
static const char __pyx_k_get_open_orders[] = "get_open_orders";
static const char __pyx_k_get_server_time[] = "get_server_time";
static const char __pyx_k_get_symbol_info[] = "get_symbol_info";
static const char __pyx_k_get_used_weight[] = "get_used_weight";
static const char __pyx_k_handle_response[] = "_handle_response";
static const char __pyx_k_leverageBracket[] = "leverageBracket";
static const char __pyx_k_license_profile[] = "license_profile";
static const char __pyx_k_margin_myTrades[] = "margin/myTrades";
static const char __pyx_k_margin_transfer[] = "margin/transfer";
static const char __pyx_k_markPriceKlines[] = "markPriceKlines";
static const char __pyx_k_order_limit_buy[] = "order_limit_buy";
static const char __pyx_k_request_website[] = "_request_website";
static const char __pyx_k_requests_params[] = "requests_params";
static const char __pyx_k_socks_proxy_uri[] = "socks_proxy_uri";
static const char __pyx_k_throw_exception[] = "throw_exception";
static const char __pyx_k_FUTURES_COIN_URL[] = "FUTURES_COIN_URL";
static const char __pyx_k_FUTURES_DATA_URL[] = "FUTURES_DATA_URL";
static const char __pyx_k_ORDER_STATUS_NEW[] = "ORDER_STATUS_NEW";
static const char __pyx_k_ORDER_TYPE_LIMIT[] = "ORDER_TYPE_LIMIT";
static const char __pyx_k_PARTIALLY_FILLED[] = "PARTIALLY_FILLED";
static const char __pyx_k_SYMBOL_TYPE_SPOT[] = "SYMBOL_TYPE_SPOT";
static const char __pyx_k_Unknown_exchange[] = "Unknown exchange '";
static const char __pyx_k_application_json[] = "application/json";
static const char __pyx_k_continuousKlines[] = "continuousKlines";
static const char __pyx_k_create_oco_order[] = "create_oco_order";
static const char __pyx_k_disable_colorama[] = "disable_colorama";
static const char __pyx_k_futures_transfer[] = "futures/transfer";
static const char __pyx_k_get_margin_asset[] = "get_margin_asset";
static const char __pyx_k_get_margin_order[] = "get_margin_order";
static const char __pyx_k_historicalTrades[] = "historicalTrades";
static const char __pyx_k_indexPriceKlines[] = "indexPriceKlines";
static const char __pyx_k_lucit_api_secret[] = "lucit_api_secret";
static const char __pyx_k_make_new_request[] = "make_new_request";
static const char __pyx_k_margin_allOrders[] = "margin/allOrders";
static const char __pyx_k_margin_orderList[] = "margin/orderList";
static const char __pyx_k_margin_order_oco[] = "margin/order/oco";
static const char __pyx_k_openInterestHist[] = "openInterestHist";
static const char __pyx_k_order_limit_sell[] = "order_limit_sell";
static const char __pyx_k_order_market_buy[] = "order_market_buy";
static const char __pyx_k_self_FUTURES_URL[] = "\r\nself.FUTURES_URL: ";
static const char __pyx_k_self_WEBSITE_URL[] = "\r\nself.WEBSITE_URL: ";
static const char __pyx_k_stream_keepalive[] = "stream_keepalive";
static const char __pyx_k_sub_account_list[] = "sub-account/list";
static const char __pyx_k_timestamp_offset[] = "timestamp_offset";
static const char __pyx_k_transfer_history[] = "transfer_history";
static const char __pyx_k_AGG_LAST_TRADE_ID[] = "AGG_LAST_TRADE_ID";
static const char __pyx_k_ORDER_TYPE_MARKET[] = "ORDER_TYPE_MARKET";
static const char __pyx_k_TAKE_PROFIT_LIMIT[] = "TAKE_PROFIT_LIMIT";
static const char __pyx_k_TIME_IN_FORCE_FOK[] = "TIME_IN_FORCE_FOK";
static const char __pyx_k_TIME_IN_FORCE_GTC[] = "TIME_IN_FORCE_GTC";
static const char __pyx_k_TIME_IN_FORCE_IOC[] = "TIME_IN_FORCE_IOC";
static const char __pyx_k_X_MBX_USED_WEIGHT[] = "X-MBX-USED-WEIGHT";
static const char __pyx_k_asset_assetDetail[] = "asset/assetDetail";
static const char __pyx_k_close_api_session[] = "close_api_session";
static const char __pyx_k_create_test_order[] = "create_test_order";
static const char __pyx_k_futures_coin_ping[] = "futures_coin_ping";
static const char __pyx_k_futures_coin_time[] = "futures_coin_time";
static const char __pyx_k_futures_get_order[] = "futures_get_order";
static const char __pyx_k_get_asset_balance[] = "get_asset_balance";
static const char __pyx_k_get_asset_details[] = "get_asset_details";
static const char __pyx_k_get_exchange_info[] = "get_exchange_info";
static const char __pyx_k_get_margin_symbol[] = "get_margin_symbol";
static const char __pyx_k_get_margin_trades[] = "get_margin_trades";
static const char __pyx_k_get_recent_trades[] = "get_recent_trades";
static const char __pyx_k_get_symbol_ticker[] = "get_symbol_ticker";
static const char __pyx_k_get_system_status[] = "get_system_status";
static const char __pyx_k_https_www_binance[] = "https://www.binance.{}";
static const char __pyx_k_installed_version[] = "installed_version";
static const char __pyx_k_lucit_license_ini[] = "lucit_license_ini";
static const char __pyx_k_margin_openOrders[] = "margin/openOrders";
static const char __pyx_k_margin_priceIndex[] = "margin/priceIndex";
static const char __pyx_k_order_market_sell[] = "order_market_sell";
static const char __pyx_k_positionSide_dual[] = "positionSide/dual";
static const char __pyx_k_repay_margin_loan[] = "repay_margin_loan";
static const char __pyx_k_requests_params_2[] = "_requests_params";
static const char __pyx_k_socks5_proxy_pass[] = "socks5_proxy_pass";
static const char __pyx_k_socks5_proxy_port[] = "socks5_proxy_port";
static const char __pyx_k_socks5_proxy_user[] = "socks5_proxy_user";
static const char __pyx_k_ticker_bookTicker[] = "ticker/bookTicker";
static const char __pyx_k_AGG_FIRST_TRADE_ID[] = "AGG_FIRST_TRADE_ID";
static const char __pyx_k_Invalid_Response_s[] = "Invalid Response: %s";
static const char __pyx_k_MARGIN_API_VERSION[] = "MARGIN_API_VERSION";
static const char __pyx_k_PUBLIC_API_VERSION[] = "PUBLIC_API_VERSION";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_binance_api_status[] = "binance_api_status";
static const char __pyx_k_binance_com_margin[] = "binance.com-margin";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_countdownCancelAll[] = "countdownCancelAll";
static const char __pyx_k_create_margin_loan[] = "create_margin_loan";
static const char __pyx_k_create_website_uri[] = "_create_website_uri";
static const char __pyx_k_futures_mark_price[] = "futures_mark_price";
static const char __pyx_k_futures_order_book[] = "futures_order_book";
static const char __pyx_k_generate_signature[] = "_generate_signature";
static const char __pyx_k_get_account_status[] = "get_account_status";
static const char __pyx_k_get_all_coins_info[] = "get_all_coins_info";
static const char __pyx_k_get_latest_version[] = "get_latest_version";
static const char __pyx_k_get_margin_account[] = "get_margin_account";
static const char __pyx_k_is_update_availabe[] = "is_update_availabe";
static const char __pyx_k_request_margin_api[] = "_request_margin_api";
static const char __pyx_k_sub_account_assets[] = "sub-account/assets";
static const char __pyx_k_sub_account_status[] = "sub-account/status";
static const char __pyx_k_universal_transfer[] = "universal_transfer";
static const char __pyx_k_BinanceAPIException[] = "BinanceAPIException";
static const char __pyx_k_COIN_FUTURE_TO_SPOT[] = "COIN_FUTURE_TO_SPOT";
static const char __pyx_k_FIAT_TO_USDT_FUTURE[] = "FIAT_TO_USDT_FUTURE";
static const char __pyx_k_FUTURES_API_VERSION[] = "FUTURES_API_VERSION";
static const char __pyx_k_Initiating_colorama[] = "Initiating `colorama_";
static const char __pyx_k_KLINE_INTERVAL_1DAY[] = "KLINE_INTERVAL_1DAY";
static const char __pyx_k_KLINE_INTERVAL_3DAY[] = "KLINE_INTERVAL_3DAY";
static const char __pyx_k_ORDER_RESP_TYPE_ACK[] = "ORDER_RESP_TYPE_ACK";
static const char __pyx_k_ORDER_STATUS_FILLED[] = "ORDER_STATUS_FILLED";
static const char __pyx_k_PRIVATE_API_VERSION[] = "PRIVATE_API_VERSION";
static const char __pyx_k_SPOT_TO_COIN_FUTURE[] = "SPOT_TO_COIN_FUTURE";
static const char __pyx_k_SPOT_TO_USDT_FUTURE[] = "SPOT_TO_USDT_FUTURE";
static const char __pyx_k_USDT_FUTURE_TO_FIAT[] = "USDT_FUTURE_TO_FIAT";
static const char __pyx_k_USDT_FUTURE_TO_SPOT[] = "USDT_FUTURE_TO_SPOT";
static const char __pyx_k_asset_assetDividend[] = "asset/assetDividend";
static const char __pyx_k_binance_com_futures[] = "binance.com-futures";
static const char __pyx_k_binance_com_testnet[] = "binance.com-testnet";
static const char __pyx_k_cancel_margin_order[] = "cancel_margin_order";
static const char __pyx_k_create_margin_order[] = "create_margin_order";
static const char __pyx_k_futures_coin_klines[] = "futures_coin_klines";
static const char __pyx_k_futures_coin_ticker[] = "futures_coin_ticker";
static const char __pyx_k_get_deposit_address[] = "get_deposit_address";
static const char __pyx_k_get_deposit_history[] = "get_deposit_history";
static const char __pyx_k_get_lending_account[] = "get_lending_account";
static const char __pyx_k_get_max_margin_loan[] = "get_max_margin_loan";
static const char __pyx_k_latest_release_info[] = "latest_release_info";
static const char __pyx_k_lucit_license_token[] = "lucit_license_token";
static const char __pyx_k_margin_allOrderList[] = "margin/allOrderList";
static const char __pyx_k_margin_stream_close[] = "margin_stream_close";
static const char __pyx_k_needed_license_type[] = "needed_license_type";
static const char __pyx_k_request_futures_api[] = "_request_futures_api";
static const char __pyx_k_self_MARGIN_API_URL[] = "\r\nself.MARGIN_API_URL: ";
static const char __pyx_k_socks5_proxy_server[] = "socks5_proxy_server";
static const char __pyx_k_ticker_openInterest[] = "ticker/openInterest";
static const char __pyx_k_FUTURES_API_VERSION2[] = "FUTURES_API_VERSION2";
static const char __pyx_k_KLINE_INTERVAL_1HOUR[] = "KLINE_INTERVAL_1HOUR";
static const char __pyx_k_KLINE_INTERVAL_1WEEK[] = "KLINE_INTERVAL_1WEEK";
static const char __pyx_k_KLINE_INTERVAL_2HOUR[] = "KLINE_INTERVAL_2HOUR";
static const char __pyx_k_KLINE_INTERVAL_4HOUR[] = "KLINE_INTERVAL_4HOUR";
static const char __pyx_k_KLINE_INTERVAL_6HOUR[] = "KLINE_INTERVAL_6HOUR";
static const char __pyx_k_KLINE_INTERVAL_8HOUR[] = "KLINE_INTERVAL_8HOUR";
static const char __pyx_k_Leaving_with_context[] = "Leaving 'with-context' ...";
static const char __pyx_k_MARGIN_CROSS_TO_SPOT[] = "MARGIN_CROSS_TO_SPOT";
static const char __pyx_k_ORDER_RESP_TYPE_FULL[] = "ORDER_RESP_TYPE_FULL";
static const char __pyx_k_ORDER_STATUS_EXPIRED[] = "ORDER_STATUS_EXPIRED";
static const char __pyx_k_ORDER_TYPE_STOP_LOSS[] = "ORDER_TYPE_STOP_LOSS";
static const char __pyx_k_SPOT_TO_MARGIN_CROSS[] = "SPOT_TO_MARGIN_CROSS";
static const char __pyx_k_aggregate_trade_iter[] = "aggregate_trade_iter";
static const char __pyx_k_date_to_milliseconds[] = "date_to_milliseconds";
static const char __pyx_k_futures_cancel_order[] = "futures_cancel_order";
static const char __pyx_k_futures_coin_account[] = "futures_coin_account";
static const char __pyx_k_futures_create_order[] = "futures_create_order";
static const char __pyx_k_futures_funding_rate[] = "futures_funding_rate";
static const char __pyx_k_futures_stream_close[] = "futures_stream_close";
static const char __pyx_k_get_account_snapshot[] = "get_account_snapshot";
static const char __pyx_k_get_aggregate_trades[] = "get_aggregate_trades";
static const char __pyx_k_get_lending_position[] = "get_lending_position";
static const char __pyx_k_get_margin_oco_order[] = "get_margin_oco_order";
static const char __pyx_k_get_orderbook_ticker[] = "get_orderbook_ticker";
static const char __pyx_k_get_sub_account_list[] = "get_sub_account_list";
static const char __pyx_k_get_withdraw_history[] = "get_withdraw_history";
static const char __pyx_k_https_www_binance_us[] = "https://www.binance.us";
static const char __pyx_k_lending_daily_redeem[] = "lending/daily/redeem";
static const char __pyx_k_lending_project_list[] = "lending/project/list";
static const char __pyx_k_margin_isolated_pair[] = "margin/isolated/pair";
static const char __pyx_k_margin_maxBorrowable[] = "margin/maxBorrowable";
static const char __pyx_k_new_transfer_history[] = "new_transfer_history";
static const char __pyx_k_socks5_proxy_address[] = "socks5_proxy_address";
static const char __pyx_k_An_exception_occurred[] = "An exception occurred: ";
static const char __pyx_k_BinanceRestApiManager[] = "BinanceRestApiManager";
static const char __pyx_k_Entering_with_context[] = "Entering 'with-context' ...";
static const char __pyx_k_FUTURES_COIN_DATA_URL[] = "FUTURES_COIN_DATA_URL";
static const char __pyx_k_KLINE_INTERVAL_12HOUR[] = "KLINE_INTERVAL_12HOUR";
static const char __pyx_k_KLINE_INTERVAL_1MONTH[] = "KLINE_INTERVAL_1MONTH";
static const char __pyx_k_LucitLicensingManager[] = "LucitLicensingManager";
static const char __pyx_k_MINING_TO_USDT_FUTURE[] = "MINING_TO_USDT_FUTURE";
static const char __pyx_k_ORDER_STATUS_CANCELED[] = "ORDER_STATUS_CANCELED";
static const char __pyx_k_ORDER_STATUS_REJECTED[] = "ORDER_STATUS_REJECTED";
static const char __pyx_k_UNICORN_BINANCE_SUITE[] = "UNICORN-BINANCE-SUITE";
static const char __pyx_k_capital_config_getall[] = "capital/config/getall";
static const char __pyx_k_create_margin_api_uri[] = "_create_margin_api_uri";
static const char __pyx_k_futures_cancel_orders[] = "futures_cancel_orders";
static const char __pyx_k_futures_exchange_info[] = "futures_exchange_info";
static const char __pyx_k_futures_open_interest[] = "futures_open_interest";
static const char __pyx_k_futures_recent_trades[] = "futures_recent_trades";
static const char __pyx_k_futures_symbol_ticker[] = "futures_symbol_ticker";
static const char __pyx_k_get_all_margin_orders[] = "get_all_margin_orders";
static const char __pyx_k_get_historical_klines[] = "get_historical_klines";
static const char __pyx_k_get_historical_trades[] = "get_historical_trades";
static const char __pyx_k_get_orderbook_tickers[] = "get_orderbook_tickers";
static const char __pyx_k_https_api_binance_api[] = "https://api.binance.{}/api";
static const char __pyx_k_https_www_binance_com[] = "https://www.binance.com";
static const char __pyx_k_lending_union_account[] = "lending/union/account";
static const char __pyx_k_lucit_license_profile[] = "lucit_license_profile";
static const char __pyx_k_self_FUTURES_COIN_URL[] = "\r\nself.FUTURES_COIN_URL: ";
static const char __pyx_k_self_FUTURES_DATA_URL[] = "\r\nself.FUTURES_DATA_URL: ";
static const char __pyx_k_stream_get_listen_key[] = "stream_get_listen_key";
static const char __pyx_k_ticker_allForceOrders[] = "ticker/allForceOrders";
static const char __pyx_k_KLINE_INTERVAL_1MINUTE[] = "KLINE_INTERVAL_1MINUTE";
static const char __pyx_k_KLINE_INTERVAL_1SECOND[] = "KLINE_INTERVAL_1SECOND";
static const char __pyx_k_KLINE_INTERVAL_3MINUTE[] = "KLINE_INTERVAL_3MINUTE";
static const char __pyx_k_KLINE_INTERVAL_5MINUTE[] = "KLINE_INTERVAL_5MINUTE";
static const char __pyx_k_ORDER_RESP_TYPE_RESULT[] = "ORDER_RESP_TYPE_RESULT";
static const char __pyx_k_ORDER_TYPE_LIMIT_MAKER[] = "ORDER_TYPE_LIMIT_MAKER";
static const char __pyx_k_ORDER_TYPE_TAKE_PROFIT[] = "ORDER_TYPE_TAKE_PROFIT";
static const char __pyx_k_cancel_all_open_orders[] = "cancel_all_open_orders";
static const char __pyx_k_capital_deposit_hisrec[] = "capital/deposit/hisrec";
static const char __pyx_k_capital_withdraw_apply[] = "capital/withdraw/apply";
static const char __pyx_k_create_futures_api_uri[] = "_create_futures_api_uri";
static const char __pyx_k_futures_account_trades[] = "futures_account_trades";
static const char __pyx_k_futures_coin_get_order[] = "futures_coin_get_order";
static const char __pyx_k_futures_get_all_orders[] = "futures_get_all_orders";
static const char __pyx_k_futures_income_history[] = "futures_income_history";
static const char __pyx_k_get_margin_price_index[] = "get_margin_price_index";
static const char __pyx_k_get_open_margin_orders[] = "get_open_margin_orders";
static const char __pyx_k_get_sub_account_assets[] = "get_sub_account_assets";
static const char __pyx_k_https_api_binance_sapi[] = "https://api.binance.{}/sapi";
static const char __pyx_k_lending_daily_purchase[] = "lending/daily/purchase";
static const char __pyx_k_margin_isolated_create[] = "margin/isolated/create";
static const char __pyx_k_margin_maxTransferable[] = "margin/maxTransferable";
static const char __pyx_k_positionMargin_history[] = "positionMargin/history";
static const char __pyx_k_redeem_lending_product[] = "redeem_lending_product";
static const char __pyx_k_request_socks5_proxies[] = "request_socks5_proxies";
static const char __pyx_k_BinanceRequestException[] = "BinanceRequestException";
static const char __pyx_k_KLINE_INTERVAL_15MINUTE[] = "KLINE_INTERVAL_15MINUTE";
static const char __pyx_k_KLINE_INTERVAL_30MINUTE[] = "KLINE_INTERVAL_30MINUTE";
static const char __pyx_k_cancel_margin_oco_order[] = "cancel_margin_oco_order";
static const char __pyx_k_capital_deposit_address[] = "capital/deposit/address";
static const char __pyx_k_create_margin_oco_order[] = "create_margin_oco_order";
static const char __pyx_k_futures_account_balance[] = "futures_account_balance";
static const char __pyx_k_futures_change_leverage[] = "futures_change_leverage";
static const char __pyx_k_futures_coin_mark_price[] = "futures_coin_mark_price";
static const char __pyx_k_futures_coin_order_book[] = "futures_coin_order_book";
static const char __pyx_k_futures_commission_rate[] = "futures_commission_rate";
static const char __pyx_k_futures_get_open_orders[] = "futures_get_open_orders";
static const char __pyx_k_get_latest_release_info[] = "get_latest_release_info";
static const char __pyx_k_get_margin_loan_details[] = "get_margin_loan_details";
static const char __pyx_k_get_max_margin_transfer[] = "get_max_margin_transfer";
static const char __pyx_k_get_withdraw_history_id[] = "get_withdraw_history_id";
static const char __pyx_k_https_fapi_binance_fapi[] = "https://fapi.binance.{}/fapi";
static const char __pyx_k_https_www_trbinance_com[] = "https://www.trbinance.com";
static const char __pyx_k_lending_positionChanged[] = "lending/positionChanged";
static const char __pyx_k_make_universal_transfer[] = "make_universal_transfer";
static const char __pyx_k_margin_isolated_account[] = "margin/isolated/account";
static const char __pyx_k_margin_stream_keepalive[] = "margin_stream_keepalive";
static const char __pyx_k_sub_account_spotSummary[] = "sub-account/spotSummary";
static const char __pyx_k_transfer_margin_to_spot[] = "transfer_margin_to_spot";
static const char __pyx_k_transfer_spot_to_margin[] = "transfer_spot_to_margin";
static const char __pyx_k_userDataStream_isolated[] = "userDataStream/isolated";
static const char __pyx_k_BinanceWithdrawException[] = "BinanceWithdrawException";
static const char __pyx_k_Created_SOCKS5_proxy_URI[] = "Created SOCKS5 proxy URI: ";
static const char __pyx_k_account_apiTradingStatus[] = "account/apiTradingStatus";
static const char __pyx_k_binance_com_coin_futures[] = "binance.com-coin-futures";
static const char __pyx_k_capital_withdraw_history[] = "capital/withdraw/history";
static const char __pyx_k_enableFastWithdrawSwitch[] = "enableFastWithdrawSwitch";
static const char __pyx_k_enable_subaccount_margin[] = "enable_subaccount_margin";
static const char __pyx_k_futures_account_transfer[] = "futures_account_transfer";
static const char __pyx_k_futures_aggregate_trades[] = "futures_aggregate_trades";
static const char __pyx_k_futures_leverage_bracket[] = "futures_leverage_bracket";
static const char __pyx_k_futures_orderbook_ticker[] = "futures_orderbook_ticker";
static const char __pyx_k_futures_stream_keepalive[] = "futures_stream_keepalive";
static const char __pyx_k_get_bnb_burn_spot_margin[] = "get_bnb_burn_spot_margin";
static const char __pyx_k_get_lending_product_list[] = "get_lending_product_list";
static const char __pyx_k_get_margin_repay_details[] = "get_margin_repay_details";
static const char __pyx_k_https_api_binance_us_api[] = "https://api.binance.us/api";
static const char __pyx_k_interval_to_milliseconds[] = "interval_to_milliseconds";
static const char __pyx_k_last_update_check_github[] = "last_update_check_github";
static const char __pyx_k_margin_isolated_allPairs[] = "margin/isolated/allPairs";
static const char __pyx_k_margin_isolated_transfer[] = "margin/isolated/transfer";
static const char __pyx_k_parent_shutdown_function[] = "parent_shutdown_function";
static const char __pyx_k_purchase_lending_product[] = "purchase_lending_product";
static const char __pyx_k_request_futures_coin_api[] = "_request_futures_coin_api";
static const char __pyx_k_request_futures_data_api[] = "_request_futures_data_api";
static const char __pyx_k_unicorn_binance_rest_api[] = "unicorn-binance-rest-api";
static const char __pyx_k_capital_deposit_subHisrec[] = "capital/deposit/subHisrec";
static const char __pyx_k_disableFastWithdrawSwitch[] = "disableFastWithdrawSwitch";
static const char __pyx_k_enable_subaccount_futures[] = "enable_subaccount_futures";
static const char __pyx_k_futures_coin_cancel_order[] = "futures_coin_cancel_order";
static const char __pyx_k_futures_coin_create_order[] = "futures_coin_create_order";
static const char __pyx_k_futures_coin_funding_rate[] = "futures_coin_funding_rate";
static const char __pyx_k_futures_coin_stream_close[] = "futures_coin_stream_close";
static const char __pyx_k_futures_get_position_mode[] = "futures_get_position_mode";
static const char __pyx_k_futures_historical_trades[] = "futures_historical_trades";
static const char __pyx_k_futures_place_batch_order[] = "futures_place_batch_order";
static const char __pyx_k_https_api_binance_com_api[] = "https://api.binance.com/api";
static const char __pyx_k_https_api_binance_us_sapi[] = " https://api.binance.us/sapi";
static const char __pyx_k_sub_account_margin_enable[] = "sub-account/margin/enable";
static const char __pyx_k_BinanceRestApiManager__get[] = "BinanceRestApiManager._get";
static const char __pyx_k_BinanceRestApiManager__put[] = "BinanceRestApiManager._put";
static const char __pyx_k_BinanceRestApiManager_ping[] = "BinanceRestApiManager.ping";
static const char __pyx_k_ORDER_TYPE_STOP_LOSS_LIMIT[] = "ORDER_TYPE_STOP_LOSS_LIMIT";
static const char __pyx_k_binance_com_margin_testnet[] = "binance.com-margin-testnet";
static const char __pyx_k_capital_deposit_subAddress[] = "capital/deposit/subAddress";
static const char __pyx_k_futures_change_margin_type[] = "futures_change_margin_type";
static const char __pyx_k_futures_coin_cancel_orders[] = "futures_coin_cancel_orders";
static const char __pyx_k_futures_coin_exchange_info[] = "futures_coin_exchange_info";
static const char __pyx_k_futures_coin_open_interest[] = "futures_coin_open_interest";
static const char __pyx_k_futures_coin_recent_trades[] = "futures_coin_recent_trades";
static const char __pyx_k_futures_coin_symbol_ticker[] = "futures_coin_symbol_ticker";
static const char __pyx_k_futures_liquidation_orders[] = "futures_liquidation_orders";
static const char __pyx_k_futures_open_interest_hist[] = "futures_open_interest_hist";
static const char __pyx_k_get_asset_dividend_history[] = "get_asset_dividend_history";
static const char __pyx_k_get_isolated_margin_symbol[] = "get_isolated_margin_symbol";
static const char __pyx_k_get_open_margin_oco_orders[] = "get_open_margin_oco_orders";
static const char __pyx_k_https_api_binance_com_sapi[] = " https://api.binance.com/sapi";
static const char __pyx_k_https_fapi_binance_us_fapi[] = "https://fapi.binance.us/fapi";
static const char __pyx_k_lending_daily_product_list[] = "lending/daily/product/list";
static const char __pyx_k_self_FUTURES_COIN_DATA_URL[] = "\r\nself.FUTURES_COIN_DATA_URL: ";
static const char __pyx_k_sub_account_futures_enable[] = "sub-account/futures/enable";
static const char __pyx_k_sub_account_margin_account[] = "sub-account/margin/account";
static const char __pyx_k_unicorn_binance_rest_api_2[] = "unicorn_binance_rest_api";
static const char __pyx_k_BinanceRestApiManager__post[] = "BinanceRestApiManager._post";
static const char __pyx_k_MARGIN_CROSS_TO_USDT_FUTURE[] = "MARGIN_CROSS_TO_USDT_FUTURE";
static const char __pyx_k_ORDER_STATUS_PENDING_CANCEL[] = "ORDER_STATUS_PENDING_CANCEL";
static const char __pyx_k_USDT_FUTURE_TO_MARGIN_CROSS[] = "USDT_FUTURE_TO_MARGIN_CROSS";
static const char __pyx_k_binance_com_futures_testnet[] = "binance.com-futures-testnet";
static const char __pyx_k_binance_com_isolated_margin[] = "binance.com-isolated_margin";
static const char __pyx_k_create_futures_coin_api_url[] = "_create_futures_coin_api_url";
static const char __pyx_k_create_futures_data_api_uri[] = "_create_futures_data_api_uri";
static const char __pyx_k_enable_fast_withdraw_switch[] = "enable_fast_withdraw_switch";
static const char __pyx_k_futures_coin_account_trades[] = "futures_coin_account_trades";
static const char __pyx_k_futures_coin_get_all_orders[] = "futures_coin_get_all_orders";
static const char __pyx_k_futures_coin_income_history[] = "futures_coin_income_history";
static const char __pyx_k_get_isolated_margin_account[] = "get_isolated_margin_account";
static const char __pyx_k_https_fapi_binance_com_fapi[] = "https://fapi.binance.com/fapi";
static const char __pyx_k_https_www_trbinance_com_api[] = "https://www.trbinance.com/api";
static const char __pyx_k_lending_daily_userLeftQuota[] = "lending/daily/userLeftQuota";
static const char __pyx_k_sub_account_futures_account[] = "sub-account/futures/account";
static const char __pyx_k_sub_account_margin_transfer[] = "sub-account/margin/transfer";
static const char __pyx_k_toggle_bnb_burn_spot_margin[] = "toggle_bnb_burn_spot_margin";
static const char __pyx_k_BinanceRestApiManager___exit[] = "BinanceRestApiManager.__exit__";
static const char __pyx_k_BinanceRestApiManager___init[] = "BinanceRestApiManager.__init__";
static const char __pyx_k_ORDER_TYPE_TAKE_PROFIT_LIMIT[] = "ORDER_TYPE_TAKE_PROFIT_LIMIT";
static const char __pyx_k_disable_fast_withdraw_switch[] = "disable_fast_withdraw_switch";
static const char __pyx_k_futures_change_position_mode[] = "futures_change_position_mode";
static const char __pyx_k_futures_coin_account_balance[] = "futures_coin_account_balance";
static const char __pyx_k_futures_coin_change_leverage[] = "futures_coin_change_leverage";
static const char __pyx_k_futures_coin_get_open_orders[] = "futures_coin_get_open_orders";
static const char __pyx_k_futures_position_information[] = "futures_position_information";
static const char __pyx_k_get_earliest_valid_timestamp[] = "_get_earliest_valid_timestamp";
static const char __pyx_k_get_lending_daily_quota_left[] = "get_lending_daily_quota_left";
static const char __pyx_k_get_lending_interest_history[] = "get_lending_interest_history";
static const char __pyx_k_get_lending_purchase_history[] = "get_lending_purchase_history";
static const char __pyx_k_https_api_trbinance_com_sapi[] = " https://api.trbinance.com/sapi";
static const char __pyx_k_https_testnet_binance_vision[] = "https://testnet.binance.vision";
static const char __pyx_k_isolated_margin_stream_close[] = "isolated_margin_stream_close";
static const char __pyx_k_lending_daily_token_position[] = "lending/daily/token/position";
static const char __pyx_k_lending_union_purchaseRecord[] = "lending/union/purchaseRecord";
static const char __pyx_k_margin_stream_get_listen_key[] = "margin_stream_get_listen_key";
static const char __pyx_k_sub_account_futures_transfer[] = "sub-account/futures/transfer";
static const char __pyx_k_BinanceRestApiManager___enter[] = "BinanceRestApiManager.__enter__";
static const char __pyx_k_BinanceRestApiManager__delete[] = "BinanceRestApiManager._delete";
static const char __pyx_k_ORDER_STATUS_PARTIALLY_FILLED[] = "ORDER_STATUS_PARTIALLY_FILLED";
static const char __pyx_k_cancel_all_open_margin_orders[] = "cancel_all_open_margin_orders";
static const char __pyx_k_futures_coin_aggregate_trades[] = "futures_coin_aggregate_trades";
static const char __pyx_k_futures_coin_continous_klines[] = "futures_coin_continous_klines";
static const char __pyx_k_futures_coin_leverage_bracket[] = "futures_coin_leverage_bracket";
static const char __pyx_k_futures_coin_orderbook_ticker[] = "futures_coin_orderbook_ticker";
static const char __pyx_k_futures_coin_stream_keepalive[] = "futures_coin_stream_keepalive";
static const char __pyx_k_futures_stream_get_listen_key[] = "futures_stream_get_listen_key";
static const char __pyx_k_get_subaccount_margin_details[] = "get_subaccount_margin_details";
static const char __pyx_k_get_subaccount_margin_summary[] = "get_subaccount_margin_summary";
static const char __pyx_k_https_fapi_trbinance_com_fapi[] = "https://fapi.trbinance.com/fapi";
static const char __pyx_k_lending_union_interestHistory[] = "lending/union/interestHistory";
static const char __pyx_k_query_subaccount_spot_summary[] = "query_subaccount_spot_summary";
static const char __pyx_k_request_futures_coin_data_api[] = "_request_futures_coin_data_api";
static const char __pyx_k_socks5_proxy_ssl_verification[] = "socks5_proxy_ssl_verification";
static const char __pyx_k_sub_account_transfer_subToSub[] = "sub-account/transfer/subToSub";
static const char __pyx_k_sub_account_universalTransfer[] = "sub-account/universalTransfer";
static const char __pyx_k_unicorn_binance_websocket_api[] = "unicorn-binance-websocket-api";
static const char __pyx_k_BinanceRestApiManager__request[] = "BinanceRestApiManager._request";
static const char __pyx_k_BinanceRestApiManager_withdraw[] = "BinanceRestApiManager.withdraw";
static const char __pyx_k_Read_the_docs_to_see_a_list_of[] = "'! Read the docs to see a list of supported exchanges: https://unicorn-binance-rest-api.docs.lucit.tech/unicorn_binance_rest_api.html#module-unicorn_binance_rest_api.unicorn_binance_rest_api_manager";
static const char __pyx_k_create_isolated_margin_account[] = "create_isolated_margin_account";
static const char __pyx_k_futures_cancel_all_open_orders[] = "futures_cancel_all_open_orders";
static const char __pyx_k_futures_change_position_margin[] = "futures_change_position_margin";
static const char __pyx_k_futures_coin_get_position_mode[] = "futures_coin_get_position_mode";
static const char __pyx_k_futures_coin_historical_trades[] = "futures_coin_historical_trades";
static const char __pyx_k_futures_coin_mark_price_klines[] = "futures_coin_mark_price_klines";
static const char __pyx_k_futures_coin_place_batch_order[] = "futures_coin_place_batch_order";
static const char __pyx_k_get_account_api_trading_status[] = "get_account_api_trading_status";
static const char __pyx_k_get_lending_redemption_history[] = "get_lending_redemption_history";
static const char __pyx_k_get_subaccount_deposit_address[] = "get_subaccount_deposit_address";
static const char __pyx_k_get_subaccount_deposit_history[] = "get_subaccount_deposit_history";
static const char __pyx_k_get_subaccount_futures_details[] = "get_subaccount_futures_details";
static const char __pyx_k_get_subaccount_futures_summary[] = "get_subaccount_futures_summary";
static const char __pyx_k_get_universal_transfer_history[] = "get_universal_transfer_history";
static const char __pyx_k_lending_union_redemptionRecord[] = "lending/union/redemptionRecord";
static const char __pyx_k_lucit_licensing_python_manager[] = "lucit_licensing_python.manager";
static const char __pyx_k_An_unofficial_Python_API_to_use[] = "\n    An unofficial Python API to use the Binance REST API`s (com+testnet, com-margin+testnet,\n    com-isolated_margin+testnet, com-futures+testnet, us) in a easy, fast, flexible,\n    robust and fully-featured way.\n\n    Binance.com rest API documentation:\n        -\n    Binance.vision (Testnet) rest API documentation:\n        -\n    Binance.us rest API documentation:\n        -\n    TRBinance.com rest API documentation:\n        - https://www.trbinance.com/apidocs/#api-document-description\n\n    Binance API Client constructor\n\n    :param api_key: Api Key\n    :type api_key: str.\n    :param api_secret: Api Secret\n    :type api_secret: str.\n    :param requests_params: optional - Dictionary of requests params to use for all calls\n    :type requests_params: dict.\n    :param tld: Top Level Domain of the Binance endpoint, Default is False\n    :type tld: str.\n    :param warn_on_update: set to `False` to disable the update warning\n    :type warn_on_update: bool\n    :param exchange: Select binance.com, binance.com-testnet, binance.com-margin, binance.com-margin-testnet,\n             binance.com-isolated_margin, binance.com-isolated_margin-testnet, binance.com-futures,\n             binance.com-futures-testnet, binance.com-coin-futures, binance.us or trbinance.com (default: binance.com)\n             This overrules parameter `tld`.\n    :type exchange: str\n    :param debug: If True the lib adds additional information to logging outputs\n    :type debug:  bool\n    :param disable_colorama: set to True to disable the use of `colorama <https://pypi.org/project/colorama/>`_\n    :type disable_colorama: bool\n    :param socks5_proxy_server: Set this to activate the usage of a socks5 proxy. Example: '127.0.0.1:9050'\n    :type socks5_proxy_server:  str\n    :param socks5_proxy_user: Set this to activate the usage of a socks5 proxy user. Example: 'alice'\n    :type socks5_proxy_user:  str\n    :param socks5_proxy_pass: Set this to activate the usage of a socks5 p""roxy password.\n    :type socks5_proxy_pass:  str\n    :param socks5_proxy_ssl_verification: Set to `False` to disable SSL server verification. Default is `True`.\n    :type socks5_proxy_ssl_verification:  bool\n    :param lucit_api_secret: The `api_secret` of your UNICORN Binance Suite license from\n                             https://shop.lucit.services/software/unicorn-binance-suite\n    :type lucit_api_secret:  str\n    :param lucit_license_ini: Specify the path including filename to the config file (ex: `~/license_a.ini`). If not\n                              provided lucitlicmgr tries to load a `lucit_license.ini` from `/home/oliver/.lucit/`.\n    :type lucit_license_ini:  str\n    :param lucit_license_profile: The license profile to use. Default is 'LUCIT'.\n    :type lucit_license_profile:  str\n    :param lucit_license_token: The `license_token` of your UNICORN Binance Suite license from\n                                https://shop.lucit.services/software/unicorn-binance-suite\n    :type lucit_license_token:  str\n    ";
static const char __pyx_k_BinanceRestApiManager__generate[] = "BinanceRestApiManager._generate_signature";
static const char __pyx_k_BinanceRestApiManager_aggregate[] = "BinanceRestApiManager.aggregate_trade_iter";
static const char __pyx_k_BinanceRestApiManager_get_asset[] = "BinanceRestApiManager.get_asset_balance";
static const char __pyx_k_BinanceRestApiManager_get_fixed[] = "BinanceRestApiManager.get_fixed_activity_project_list";
static const char __pyx_k_BinanceRestApiManager_get_order[] = "BinanceRestApiManager.get_order_book";
static const char __pyx_k_BinanceRestApiManager_get_trade[] = "BinanceRestApiManager.get_trade_fee";
static const char __pyx_k_BinanceRestApiManager_is_update[] = "BinanceRestApiManager.is_update_availabe";
static const char __pyx_k_BinanceRestApiManager_order_oco[] = "BinanceRestApiManager.order_oco_buy";
static const char __pyx_k_BinanceRestApiManager_universal[] = "BinanceRestApiManager.universal_transfer";
static const char __pyx_k_BinanceWebSocketApiManager_stop[] = "BinanceWebSocketApiManager.stop_manager() - Stopping unicorn_binance_rest_api_manager ";
static const char __pyx_k_There_is_no_entry_with_withdraw[] = "There is no entry with withdraw id";
static const char __pyx_k_create_futures_coin_data_api_ur[] = "_create_futures_coin_data_api_url";
static const char __pyx_k_futures_coin_change_margin_type[] = "futures_coin_change_margin_type";
static const char __pyx_k_futures_coin_index_price_klines[] = "futures_coin_index_price_klines";
static const char __pyx_k_futures_coin_liquidation_orders[] = "futures_coin_liquidation_orders";
static const char __pyx_k_futures_coin_open_interest_hist[] = "futures_coin_open_interest_hist";
static const char __pyx_k_futures_position_margin_history[] = "futures_position_margin_history";
static const char __pyx_k_get_all_isolated_margin_symbols[] = "get_all_isolated_margin_symbols";
static const char __pyx_k_get_fixed_activity_project_list[] = "get_fixed_activity_project_list";
static const char __pyx_k_get_historical_klines_generator[] = "get_historical_klines_generator";
static const char __pyx_k_get_open_isolated_margin_orders[] = "get_open_isolated_margin_orders";
static const char __pyx_k_get_subaccount_transfer_history[] = "get_subaccount_transfer_history";
static const char __pyx_k_https_dapi_binance_futures_data[] = "https://dapi.binance.{}/futures/data";
static const char __pyx_k_https_fapi_binance_futures_data[] = "https://fapi.binance.{}/futures/data";
static const char __pyx_k_https_testnet_binancefuture_com[] = "https://testnet.binancefuture.com/fapi";
static const char __pyx_k_is_available_please_consider_up[] = " is available, please consider updating! (Changelog: https://unicorn-binance-rest-api.docs.lucit.tech/changelog.html)";
static const char __pyx_k_make_subaccount_margin_transfer[] = "make_subaccount_margin_transfer";
static const char __pyx_k_BinanceRestApiManager__create_ap[] = "BinanceRestApiManager._create_api_uri";
static const char __pyx_k_BinanceRestApiManager__create_fu[] = "BinanceRestApiManager._create_futures_api_uri";
static const char __pyx_k_BinanceRestApiManager__create_ma[] = "BinanceRestApiManager._create_margin_api_uri";
static const char __pyx_k_BinanceRestApiManager__create_we[] = "BinanceRestApiManager._create_website_uri";
static const char __pyx_k_BinanceRestApiManager__get_earli[] = "BinanceRestApiManager._get_earliest_valid_timestamp";
static const char __pyx_k_BinanceRestApiManager__handle_re[] = "BinanceRestApiManager._handle_response";
static const char __pyx_k_BinanceRestApiManager__init_sess[] = "BinanceRestApiManager._init_session";
static const char __pyx_k_BinanceRestApiManager__order_par[] = "BinanceRestApiManager._order_params";
static const char __pyx_k_BinanceRestApiManager__request_a[] = "BinanceRestApiManager._request_api";
static const char __pyx_k_BinanceRestApiManager__request_f[] = "BinanceRestApiManager._request_futures_api";
static const char __pyx_k_BinanceRestApiManager__request_l[] = "BinanceRestApiManager._request.<locals>.genexpr";
static const char __pyx_k_BinanceRestApiManager__request_m[] = "BinanceRestApiManager._request_margin_api";
static const char __pyx_k_BinanceRestApiManager__request_w[] = "BinanceRestApiManager._request_website";
static const char __pyx_k_BinanceRestApiManager_cancel_all[] = "BinanceRestApiManager.cancel_all_open_orders";
static const char __pyx_k_BinanceRestApiManager_cancel_mar[] = "BinanceRestApiManager.cancel_margin_oco_order";
static const char __pyx_k_BinanceRestApiManager_cancel_ord[] = "BinanceRestApiManager.cancel_order";
static const char __pyx_k_BinanceRestApiManager_change_fix[] = "BinanceRestApiManager.change_fixed_activity_to_daily_position";
static const char __pyx_k_BinanceRestApiManager_create_iso[] = "BinanceRestApiManager.create_isolated_margin_account";
static const char __pyx_k_BinanceRestApiManager_create_mar[] = "BinanceRestApiManager.create_margin_loan";
static const char __pyx_k_BinanceRestApiManager_create_oco[] = "BinanceRestApiManager.create_oco_order";
static const char __pyx_k_BinanceRestApiManager_create_ord[] = "BinanceRestApiManager.create_order";
static const char __pyx_k_BinanceRestApiManager_create_sub[] = "BinanceRestApiManager.create_sub_account_futures_transfer";
static const char __pyx_k_BinanceRestApiManager_create_tes[] = "BinanceRestApiManager.create_test_order";
static const char __pyx_k_BinanceRestApiManager_disable_fa[] = "BinanceRestApiManager.disable_fast_withdraw_switch";
static const char __pyx_k_BinanceRestApiManager_enable_fas[] = "BinanceRestApiManager.enable_fast_withdraw_switch";
static const char __pyx_k_BinanceRestApiManager_enable_sub[] = "BinanceRestApiManager.enable_subaccount_margin";
static const char __pyx_k_BinanceRestApiManager_futures_ac[] = "BinanceRestApiManager.futures_account_transfer";
static const char __pyx_k_BinanceRestApiManager_futures_ag[] = "BinanceRestApiManager.futures_aggregate_trades";
static const char __pyx_k_BinanceRestApiManager_futures_au[] = "BinanceRestApiManager.futures_auto_cancel_all_open_orders";
static const char __pyx_k_BinanceRestApiManager_futures_ca[] = "BinanceRestApiManager.futures_cancel_order";
static const char __pyx_k_BinanceRestApiManager_futures_ch[] = "BinanceRestApiManager.futures_change_leverage";
static const char __pyx_k_BinanceRestApiManager_futures_co[] = "BinanceRestApiManager.futures_commission_rate";
static const char __pyx_k_BinanceRestApiManager_futures_cr[] = "BinanceRestApiManager.futures_create_order";
static const char __pyx_k_BinanceRestApiManager_futures_ex[] = "BinanceRestApiManager.futures_exchange_info";
static const char __pyx_k_BinanceRestApiManager_futures_fu[] = "BinanceRestApiManager.futures_funding_rate";
static const char __pyx_k_BinanceRestApiManager_futures_ge[] = "BinanceRestApiManager.futures_get_order";
static const char __pyx_k_BinanceRestApiManager_futures_hi[] = "BinanceRestApiManager.futures_historical_trades";
static const char __pyx_k_BinanceRestApiManager_futures_in[] = "BinanceRestApiManager.futures_income_history";
static const char __pyx_k_BinanceRestApiManager_futures_kl[] = "BinanceRestApiManager.futures_klines";
static const char __pyx_k_BinanceRestApiManager_futures_le[] = "BinanceRestApiManager.futures_leverage_bracket";
static const char __pyx_k_BinanceRestApiManager_futures_li[] = "BinanceRestApiManager.futures_liquidation_orders";
static const char __pyx_k_BinanceRestApiManager_futures_ma[] = "BinanceRestApiManager.futures_mark_price";
static const char __pyx_k_BinanceRestApiManager_futures_op[] = "BinanceRestApiManager.futures_open_interest";
static const char __pyx_k_BinanceRestApiManager_futures_or[] = "BinanceRestApiManager.futures_order_book";
static const char __pyx_k_BinanceRestApiManager_futures_pi[] = "BinanceRestApiManager.futures_ping";
static const char __pyx_k_BinanceRestApiManager_futures_pl[] = "BinanceRestApiManager.futures_place_batch_order";
static const char __pyx_k_BinanceRestApiManager_futures_po[] = "BinanceRestApiManager.futures_position_margin_history";
static const char __pyx_k_BinanceRestApiManager_futures_re[] = "BinanceRestApiManager.futures_recent_trades";
static const char __pyx_k_BinanceRestApiManager_futures_st[] = "BinanceRestApiManager.futures_stream_get_listen_key";
static const char __pyx_k_BinanceRestApiManager_futures_sy[] = "BinanceRestApiManager.futures_symbol_ticker";
static const char __pyx_k_BinanceRestApiManager_futures_ti[] = "BinanceRestApiManager.futures_time";
static const char __pyx_k_BinanceRestApiManager_get_accoun[] = "BinanceRestApiManager.get_account";
static const char __pyx_k_BinanceRestApiManager_get_aggreg[] = "BinanceRestApiManager.get_aggregate_trades";
static const char __pyx_k_BinanceRestApiManager_get_all_co[] = "BinanceRestApiManager.get_all_coins_info";
static const char __pyx_k_BinanceRestApiManager_get_all_is[] = "BinanceRestApiManager.get_all_isolated_margin_symbols";
static const char __pyx_k_BinanceRestApiManager_get_all_ma[] = "BinanceRestApiManager.get_all_margin_orders";
static const char __pyx_k_BinanceRestApiManager_get_all_or[] = "BinanceRestApiManager.get_all_orders";
static const char __pyx_k_BinanceRestApiManager_get_all_ti[] = "BinanceRestApiManager.get_all_tickers";
static const char __pyx_k_BinanceRestApiManager_get_avg_pr[] = "BinanceRestApiManager.get_avg_price";
static const char __pyx_k_BinanceRestApiManager_get_bnb_bu[] = "BinanceRestApiManager.get_bnb_burn_spot_margin";
static const char __pyx_k_BinanceRestApiManager_get_deposi[] = "BinanceRestApiManager.get_deposit_history";
static const char __pyx_k_BinanceRestApiManager_get_dust_l[] = "BinanceRestApiManager.get_dust_log";
static const char __pyx_k_BinanceRestApiManager_get_exchan[] = "BinanceRestApiManager.get_exchange_info";
static const char __pyx_k_BinanceRestApiManager_get_histor[] = "BinanceRestApiManager.get_historical_klines_generator";
static const char __pyx_k_BinanceRestApiManager_get_isolat[] = "BinanceRestApiManager.get_isolated_margin_account";
static const char __pyx_k_BinanceRestApiManager_get_klines[] = "BinanceRestApiManager.get_klines";
static const char __pyx_k_BinanceRestApiManager_get_latest[] = "BinanceRestApiManager.get_latest_version";
static const char __pyx_k_BinanceRestApiManager_get_lendin[] = "BinanceRestApiManager.get_lending_product_list";
static const char __pyx_k_BinanceRestApiManager_get_margin[] = "BinanceRestApiManager.get_margin_account";
static const char __pyx_k_BinanceRestApiManager_get_max_ma[] = "BinanceRestApiManager.get_max_margin_loan";
static const char __pyx_k_BinanceRestApiManager_get_my_tra[] = "BinanceRestApiManager.get_my_trades";
static const char __pyx_k_BinanceRestApiManager_get_open_i[] = "BinanceRestApiManager.get_open_isolated_margin_orders";
static const char __pyx_k_BinanceRestApiManager_get_open_m[] = "BinanceRestApiManager.get_open_margin_oco_orders";
static const char __pyx_k_BinanceRestApiManager_get_open_o[] = "BinanceRestApiManager.get_open_orders";
static const char __pyx_k_BinanceRestApiManager_get_orderb[] = "BinanceRestApiManager.get_orderbook_tickers";
static const char __pyx_k_BinanceRestApiManager_get_produc[] = "BinanceRestApiManager.get_products";
static const char __pyx_k_BinanceRestApiManager_get_recent[] = "BinanceRestApiManager.get_recent_trades";
static const char __pyx_k_BinanceRestApiManager_get_server[] = "BinanceRestApiManager.get_server_time";
static const char __pyx_k_BinanceRestApiManager_get_sub_ac[] = "BinanceRestApiManager.get_sub_account_list";
static const char __pyx_k_BinanceRestApiManager_get_subacc[] = "BinanceRestApiManager.get_subaccount_deposit_address";
static const char __pyx_k_BinanceRestApiManager_get_symbol[] = "BinanceRestApiManager.get_symbol_info";
static const char __pyx_k_BinanceRestApiManager_get_system[] = "BinanceRestApiManager.get_system_status";
static const char __pyx_k_BinanceRestApiManager_get_ticker[] = "BinanceRestApiManager.get_ticker";
static const char __pyx_k_BinanceRestApiManager_get_univer[] = "BinanceRestApiManager.get_universal_transfer_history";
static const char __pyx_k_BinanceRestApiManager_get_used_w[] = "BinanceRestApiManager.get_used_weight";
static const char __pyx_k_BinanceRestApiManager_get_user_a[] = "BinanceRestApiManager.get_user_agent";
static const char __pyx_k_BinanceRestApiManager_get_versio[] = "BinanceRestApiManager.get_version";
static const char __pyx_k_BinanceRestApiManager_get_withdr[] = "BinanceRestApiManager.get_withdraw_history";
static const char __pyx_k_BinanceRestApiManager_isolated_m[] = "BinanceRestApiManager.isolated_margin_stream_get_listen_key";
static const char __pyx_k_BinanceRestApiManager_make_subac[] = "BinanceRestApiManager.make_subaccount_futures_transfer";
static const char __pyx_k_BinanceRestApiManager_make_unive[] = "BinanceRestApiManager.make_universal_transfer";
static const char __pyx_k_BinanceRestApiManager_margin_str[] = "BinanceRestApiManager.margin_stream_get_listen_key";
static const char __pyx_k_BinanceRestApiManager_new_transf[] = "BinanceRestApiManager.new_transfer_history";
static const char __pyx_k_BinanceRestApiManager_order_limi[] = "BinanceRestApiManager.order_limit";
static const char __pyx_k_BinanceRestApiManager_order_mark[] = "BinanceRestApiManager.order_market";
static const char __pyx_k_BinanceRestApiManager_purchase_l[] = "BinanceRestApiManager.purchase_lending_product";
static const char __pyx_k_BinanceRestApiManager_query_suba[] = "BinanceRestApiManager.query_subaccount_spot_summary";
static const char __pyx_k_BinanceRestApiManager_query_univ[] = "BinanceRestApiManager.query_universal_transfer_history";
static const char __pyx_k_BinanceRestApiManager_redeem_len[] = "BinanceRestApiManager.redeem_lending_product";
static const char __pyx_k_BinanceRestApiManager_repay_marg[] = "BinanceRestApiManager.repay_margin_loan";
static const char __pyx_k_BinanceRestApiManager_stop_manag[] = "BinanceRestApiManager.stop_manager";
static const char __pyx_k_BinanceRestApiManager_stream_clo[] = "BinanceRestApiManager.stream_close";
static const char __pyx_k_BinanceRestApiManager_stream_get[] = "BinanceRestApiManager.stream_get_listen_key";
static const char __pyx_k_BinanceRestApiManager_stream_kee[] = "BinanceRestApiManager.stream_keepalive";
static const char __pyx_k_BinanceRestApiManager_toggle_bnb[] = "BinanceRestApiManager.toggle_bnb_burn_spot_margin";
static const char __pyx_k_BinanceRestApiManager_transfer_d[] = "BinanceRestApiManager.transfer_dust";
static const char __pyx_k_BinanceRestApiManager_transfer_h[] = "BinanceRestApiManager.transfer_history";
static const char __pyx_k_BinanceRestApiManager_transfer_i[] = "BinanceRestApiManager.transfer_isolated_margin_to_spot";
static const char __pyx_k_BinanceRestApiManager_transfer_m[] = "BinanceRestApiManager.transfer_margin_to_spot";
static const char __pyx_k_BinanceRestApiManager_transfer_s[] = "BinanceRestApiManager.transfer_spot_to_margin";
static const char __pyx_k_The_parameter_BinanceRestApiMana[] = "The parameter BinanceRestApiManager(tld=`com`) is obsolete, use parameter `exchange` instead! Attention: parameter `exchange` overrules `tld`!! ";
static const char __pyx_k_binance_com_isolated_margin_test[] = "binance.com-isolated_margin-testnet";
static const char __pyx_k_change_fixed_activity_to_daily_p[] = "change_fixed_activity_to_daily_position";
static const char __pyx_k_create_sub_account_futures_trans[] = "create_sub_account_futures_transfer";
static const char __pyx_k_exchange_api_v1_public_asset_ser[] = "exchange-api/v1/public/asset-service/product/get-products";
static const char __pyx_k_futures_auto_cancel_all_open_ord[] = "futures_auto_cancel_all_open_orders";
static const char __pyx_k_futures_coin_cancel_all_open_ord[] = "futures_coin_cancel_all_open_orders";
static const char __pyx_k_futures_coin_change_position_mar[] = "futures_coin_change_position_margin";
static const char __pyx_k_futures_coin_change_position_mod[] = "futures_coin_change_position_mode";
static const char __pyx_k_futures_coin_position_informatio[] = "futures_coin_position_information";
static const char __pyx_k_futures_coin_position_margin_his[] = "futures_coin_position_margin_history";
static const char __pyx_k_futures_coin_stream_get_listen_k[] = "futures_coin_stream_get_listen_key";
static const char __pyx_k_get_lending_daily_redemption_quo[] = "get_lending_daily_redemption_quota";
static const char __pyx_k_get_sub_account_futures_transfer[] = "get_sub_account_futures_transfer_history";
static const char __pyx_k_get_sub_account_transfer_history[] = "get_sub_account_transfer_history";
static const char __pyx_k_get_subaccount_futures_margin_st[] = "get_subaccount_futures_margin_status";
static const char __pyx_k_get_subaccount_futures_positionr[] = "get_subaccount_futures_positionrisk";
static const char __pyx_k_https_api_github_com_repos_LUCIT[] = "https://api.github.com/repos/LUCIT-Systems-and-Development/unicorn-binance-rest-api/releases/latest";
static const char __pyx_k_https_dapi_binance_com_futures_d[] = "https://dapi.binance.com/futures/data";
static const char __pyx_k_https_dapi_binance_us_futures_da[] = "https://dapi.binance.us/futures/data";
static const char __pyx_k_https_dapi_trbinance_com_futures[] = "https://dapi.trbinance.com/futures/data";
static const char __pyx_k_https_fapi_binance_com_futures_d[] = "https://fapi.binance.com/futures/data";
static const char __pyx_k_https_fapi_binance_us_futures_da[] = "https://fapi.binance.us/futures/data";
static const char __pyx_k_https_fapi_trbinance_com_futures[] = "https://fapi.trbinance.com/futures/data";
static const char __pyx_k_https_testnet_binance_vision_api[] = "https://testnet.binance.vision/api";
static const char __pyx_k_isolated_margin_stream_get_liste[] = "isolated_margin_stream_get_listen_key";
static const char __pyx_k_isolated_margin_stream_keepalive[] = "isolated_margin_stream_keepalive";
static const char __pyx_k_lending_daily_userRedemptionQuot[] = "lending/daily/userRedemptionQuota";
static const char __pyx_k_make_subaccount_futures_transfer[] = "make_subaccount_futures_transfer";
static const char __pyx_k_make_subaccount_to_master_transf[] = "make_subaccount_to_master_transfer";
static const char __pyx_k_make_subaccount_to_subaccount_tr[] = "make_subaccount_to_subaccount_transfer";
static const char __pyx_k_query_universal_transfer_history[] = "query_universal_transfer_history";
static const char __pyx_k_start_time_and_last_id_may_not_b[] = "start_time and last_id may not be simultaneously specified.";
static const char __pyx_k_sub_account_futures_accountSumma[] = "sub-account/futures/accountSummary";
static const char __pyx_k_sub_account_futures_internalTran[] = "sub-account/futures/internalTransfer";
static const char __pyx_k_sub_account_futures_positionRisk[] = "sub-account/futures/positionRisk";
static const char __pyx_k_sub_account_margin_accountSummar[] = "sub-account/margin/accountSummary";
static const char __pyx_k_sub_account_sub_transfer_history[] = "sub-account/sub/transfer/history";
static const char __pyx_k_sub_account_transfer_subToMaster[] = "sub-account/transfer/subToMaster";
static const char __pyx_k_sub_account_transfer_subUserHist[] = "sub-account/transfer/subUserHistory";
static const char __pyx_k_transfer_isolated_margin_to_spot[] = "transfer_isolated_margin_to_spot";
static const char __pyx_k_transfer_spot_to_isolated_margin[] = "transfer_spot_to_isolated_margin";
static const char __pyx_k_unicorn_binance_rest_api_manager[] = "unicorn_binance_rest_api.manager";
static const char __pyx_k_BinanceRestApiManager_get_asset_2[] = "BinanceRestApiManager.get_asset_dividend_history";
static const char __pyx_k_BinanceRestApiManager_get_asset_3[] = "BinanceRestApiManager.get_asset_details";
static const char __pyx_k_BinanceRestApiManager_get_order_2[] = "BinanceRestApiManager.get_order";
static const char __pyx_k_BinanceRestApiManager_order_oco_2[] = "BinanceRestApiManager.order_oco_sell";
static const char __pyx_k_https_testnet_binancefuture_com_2[] = "https://testnet.binancefuture.com/futures/data";
static const char __pyx_k_https_testnet_binancefuture_com_3[] = "https://testnet.binancefuture.com/dapi";
static const char __pyx_k_BinanceRestApiManager__create_fu_2[] = "BinanceRestApiManager._create_futures_data_api_uri";
static const char __pyx_k_BinanceRestApiManager__create_fu_3[] = "BinanceRestApiManager._create_futures_coin_api_url";
static const char __pyx_k_BinanceRestApiManager__create_fu_4[] = "BinanceRestApiManager._create_futures_coin_data_api_url";
static const char __pyx_k_BinanceRestApiManager__request_f_2[] = "BinanceRestApiManager._request_futures_data_api";
static const char __pyx_k_BinanceRestApiManager__request_f_3[] = "BinanceRestApiManager._request_futures_coin_api";
static const char __pyx_k_BinanceRestApiManager__request_f_4[] = "BinanceRestApiManager._request_futures_coin_data_api";
static const char __pyx_k_BinanceRestApiManager_cancel_all_2[] = "BinanceRestApiManager.cancel_all_open_margin_orders";
static const char __pyx_k_BinanceRestApiManager_cancel_mar_2[] = "BinanceRestApiManager.cancel_margin_order";
static const char __pyx_k_BinanceRestApiManager_create_mar_2[] = "BinanceRestApiManager.create_margin_oco_order";
static const char __pyx_k_BinanceRestApiManager_create_mar_3[] = "BinanceRestApiManager.create_margin_order";
static const char __pyx_k_BinanceRestApiManager_enable_sub_2[] = "BinanceRestApiManager.enable_subaccount_futures";
static const char __pyx_k_BinanceRestApiManager_futures_ac_2[] = "BinanceRestApiManager.futures_account_balance";
static const char __pyx_k_BinanceRestApiManager_futures_ac_3[] = "BinanceRestApiManager.futures_account";
static const char __pyx_k_BinanceRestApiManager_futures_ac_4[] = "BinanceRestApiManager.futures_account_trades";
static const char __pyx_k_BinanceRestApiManager_futures_ca_2[] = "BinanceRestApiManager.futures_cancel_all_open_orders";
static const char __pyx_k_BinanceRestApiManager_futures_ca_3[] = "BinanceRestApiManager.futures_cancel_orders";
static const char __pyx_k_BinanceRestApiManager_futures_ch_2[] = "BinanceRestApiManager.futures_change_margin_type";
static const char __pyx_k_BinanceRestApiManager_futures_ch_3[] = "BinanceRestApiManager.futures_change_position_margin";
static const char __pyx_k_BinanceRestApiManager_futures_ch_4[] = "BinanceRestApiManager.futures_change_position_mode";
static const char __pyx_k_BinanceRestApiManager_futures_co_2[] = "BinanceRestApiManager.futures_coin_ping";
static const char __pyx_k_BinanceRestApiManager_futures_co_3[] = "BinanceRestApiManager.futures_coin_time";
static const char __pyx_k_BinanceRestApiManager_futures_co_4[] = "BinanceRestApiManager.futures_coin_exchange_info";
static const char __pyx_k_BinanceRestApiManager_futures_co_5[] = "BinanceRestApiManager.futures_coin_order_book";
static const char __pyx_k_BinanceRestApiManager_futures_co_6[] = "BinanceRestApiManager.futures_coin_recent_trades";
static const char __pyx_k_BinanceRestApiManager_futures_co_7[] = "BinanceRestApiManager.futures_coin_historical_trades";
static const char __pyx_k_BinanceRestApiManager_futures_co_8[] = "BinanceRestApiManager.futures_coin_aggregate_trades";
static const char __pyx_k_BinanceRestApiManager_futures_co_9[] = "BinanceRestApiManager.futures_coin_klines";
static const char __pyx_k_BinanceRestApiManager_futures_ge_2[] = "BinanceRestApiManager.futures_get_open_orders";
static const char __pyx_k_BinanceRestApiManager_futures_ge_3[] = "BinanceRestApiManager.futures_get_all_orders";
static const char __pyx_k_BinanceRestApiManager_futures_ge_4[] = "BinanceRestApiManager.futures_get_position_mode";
static const char __pyx_k_BinanceRestApiManager_futures_op_2[] = "BinanceRestApiManager.futures_open_interest_hist";
static const char __pyx_k_BinanceRestApiManager_futures_or_2[] = "BinanceRestApiManager.futures_orderbook_ticker";
static const char __pyx_k_BinanceRestApiManager_futures_po_2[] = "BinanceRestApiManager.futures_position_information";
static const char __pyx_k_BinanceRestApiManager_futures_st_2[] = "BinanceRestApiManager.futures_stream_keepalive";
static const char __pyx_k_BinanceRestApiManager_futures_st_3[] = "BinanceRestApiManager.futures_stream_close";
static const char __pyx_k_BinanceRestApiManager_futures_ti_2[] = "BinanceRestApiManager.futures_ticker";
static const char __pyx_k_BinanceRestApiManager_get_accoun_2[] = "BinanceRestApiManager.get_account_status";
static const char __pyx_k_BinanceRestApiManager_get_accoun_3[] = "BinanceRestApiManager.get_account_api_trading_status";
static const char __pyx_k_BinanceRestApiManager_get_accoun_4[] = "BinanceRestApiManager.get_account_snapshot";
static const char __pyx_k_BinanceRestApiManager_get_deposi_2[] = "BinanceRestApiManager.get_deposit_address";
static const char __pyx_k_BinanceRestApiManager_get_histor_2[] = "BinanceRestApiManager.get_historical_trades";
static const char __pyx_k_BinanceRestApiManager_get_histor_3[] = "BinanceRestApiManager.get_historical_klines";
static const char __pyx_k_BinanceRestApiManager_get_isolat_2[] = "BinanceRestApiManager.get_isolated_margin_symbol";
static const char __pyx_k_BinanceRestApiManager_get_latest_2[] = "BinanceRestApiManager.get_latest_release_info";
static const char __pyx_k_BinanceRestApiManager_get_lendin_2[] = "BinanceRestApiManager.get_lending_daily_quota_left";
static const char __pyx_k_BinanceRestApiManager_get_lendin_3[] = "BinanceRestApiManager.get_lending_daily_redemption_quota";
static const char __pyx_k_BinanceRestApiManager_get_lendin_4[] = "BinanceRestApiManager.get_lending_position";
static const char __pyx_k_BinanceRestApiManager_get_lendin_5[] = "BinanceRestApiManager.get_lending_account";
static const char __pyx_k_BinanceRestApiManager_get_lendin_6[] = "BinanceRestApiManager.get_lending_purchase_history";
static const char __pyx_k_BinanceRestApiManager_get_lendin_7[] = "BinanceRestApiManager.get_lending_redemption_history";
static const char __pyx_k_BinanceRestApiManager_get_lendin_8[] = "BinanceRestApiManager.get_lending_interest_history";
static const char __pyx_k_BinanceRestApiManager_get_margin_2[] = "BinanceRestApiManager.get_margin_asset";
static const char __pyx_k_BinanceRestApiManager_get_margin_3[] = "BinanceRestApiManager.get_margin_symbol";
static const char __pyx_k_BinanceRestApiManager_get_margin_4[] = "BinanceRestApiManager.get_margin_price_index";
static const char __pyx_k_BinanceRestApiManager_get_margin_5[] = "BinanceRestApiManager.get_margin_oco_order";
static const char __pyx_k_BinanceRestApiManager_get_margin_6[] = "BinanceRestApiManager.get_margin_loan_details";
static const char __pyx_k_BinanceRestApiManager_get_margin_7[] = "BinanceRestApiManager.get_margin_repay_details";
static const char __pyx_k_BinanceRestApiManager_get_margin_8[] = "BinanceRestApiManager.get_margin_order";
static const char __pyx_k_BinanceRestApiManager_get_margin_9[] = "BinanceRestApiManager.get_margin_trades";
static const char __pyx_k_BinanceRestApiManager_get_max_ma_2[] = "BinanceRestApiManager.get_max_margin_transfer";
static const char __pyx_k_BinanceRestApiManager_get_open_m_2[] = "BinanceRestApiManager.get_open_margin_orders";
static const char __pyx_k_BinanceRestApiManager_get_orderb_2[] = "BinanceRestApiManager.get_orderbook_ticker";
static const char __pyx_k_BinanceRestApiManager_get_sub_ac_2[] = "BinanceRestApiManager.get_sub_account_transfer_history";
static const char __pyx_k_BinanceRestApiManager_get_sub_ac_3[] = "BinanceRestApiManager.get_sub_account_futures_transfer_history";
static const char __pyx_k_BinanceRestApiManager_get_sub_ac_4[] = "BinanceRestApiManager.get_sub_account_assets";
static const char __pyx_k_BinanceRestApiManager_get_subacc_2[] = "BinanceRestApiManager.get_subaccount_deposit_history";
static const char __pyx_k_BinanceRestApiManager_get_subacc_3[] = "BinanceRestApiManager.get_subaccount_futures_margin_status";
static const char __pyx_k_BinanceRestApiManager_get_subacc_4[] = "BinanceRestApiManager.get_subaccount_margin_details";
static const char __pyx_k_BinanceRestApiManager_get_subacc_5[] = "BinanceRestApiManager.get_subaccount_margin_summary";
static const char __pyx_k_BinanceRestApiManager_get_subacc_6[] = "BinanceRestApiManager.get_subaccount_futures_details";
static const char __pyx_k_BinanceRestApiManager_get_subacc_7[] = "BinanceRestApiManager.get_subaccount_futures_summary";
static const char __pyx_k_BinanceRestApiManager_get_subacc_8[] = "BinanceRestApiManager.get_subaccount_futures_positionrisk";
static const char __pyx_k_BinanceRestApiManager_get_subacc_9[] = "BinanceRestApiManager.get_subaccount_transfer_history";
static const char __pyx_k_BinanceRestApiManager_get_symbol_2[] = "BinanceRestApiManager.get_symbol_ticker";
static const char __pyx_k_BinanceRestApiManager_get_withdr_2[] = "BinanceRestApiManager.get_withdraw_history_id";
static const char __pyx_k_BinanceRestApiManager_isolated_m_2[] = "BinanceRestApiManager.isolated_margin_stream_keepalive";
static const char __pyx_k_BinanceRestApiManager_isolated_m_3[] = "BinanceRestApiManager.isolated_margin_stream_close";
static const char __pyx_k_BinanceRestApiManager_make_subac_2[] = "BinanceRestApiManager.make_subaccount_margin_transfer";
static const char __pyx_k_BinanceRestApiManager_make_subac_3[] = "BinanceRestApiManager.make_subaccount_to_subaccount_transfer";
static const char __pyx_k_BinanceRestApiManager_make_subac_4[] = "BinanceRestApiManager.make_subaccount_to_master_transfer";
static const char __pyx_k_BinanceRestApiManager_margin_str_2[] = "BinanceRestApiManager.margin_stream_keepalive";
static const char __pyx_k_BinanceRestApiManager_margin_str_3[] = "BinanceRestApiManager.margin_stream_close";
static const char __pyx_k_BinanceRestApiManager_order_limi_2[] = "BinanceRestApiManager.order_limit_buy";
static const char __pyx_k_BinanceRestApiManager_order_limi_3[] = "BinanceRestApiManager.order_limit_sell";
static const char __pyx_k_BinanceRestApiManager_order_mark_2[] = "BinanceRestApiManager.order_market_buy";
static const char __pyx_k_BinanceRestApiManager_order_mark_3[] = "BinanceRestApiManager.order_market_sell";
static const char __pyx_k_BinanceRestApiManager_transfer_s_2[] = "BinanceRestApiManager.transfer_spot_to_isolated_margin";
static const char __pyx_k_unicorn_binance_rest_api_manager_2[] = "unicorn_binance_rest_api/manager.py";
static const char __pyx_k_BinanceRestApiManager_futures_co_10[] = "BinanceRestApiManager.futures_coin_continous_klines";
static const char __pyx_k_BinanceRestApiManager_futures_co_11[] = "BinanceRestApiManager.futures_coin_index_price_klines";
static const char __pyx_k_BinanceRestApiManager_futures_co_12[] = "BinanceRestApiManager.futures_coin_mark_price_klines";
static const char __pyx_k_BinanceRestApiManager_futures_co_13[] = "BinanceRestApiManager.futures_coin_mark_price";
static const char __pyx_k_BinanceRestApiManager_futures_co_14[] = "BinanceRestApiManager.futures_coin_funding_rate";
static const char __pyx_k_BinanceRestApiManager_futures_co_15[] = "BinanceRestApiManager.futures_coin_ticker";
static const char __pyx_k_BinanceRestApiManager_futures_co_16[] = "BinanceRestApiManager.futures_coin_symbol_ticker";
static const char __pyx_k_BinanceRestApiManager_futures_co_17[] = "BinanceRestApiManager.futures_coin_orderbook_ticker";
static const char __pyx_k_BinanceRestApiManager_futures_co_18[] = "BinanceRestApiManager.futures_coin_liquidation_orders";
static const char __pyx_k_BinanceRestApiManager_futures_co_19[] = "BinanceRestApiManager.futures_coin_open_interest";
static const char __pyx_k_BinanceRestApiManager_futures_co_20[] = "BinanceRestApiManager.futures_coin_open_interest_hist";
static const char __pyx_k_BinanceRestApiManager_futures_co_21[] = "BinanceRestApiManager.futures_coin_leverage_bracket";
static const char __pyx_k_BinanceRestApiManager_futures_co_22[] = "BinanceRestApiManager.futures_coin_create_order";
static const char __pyx_k_BinanceRestApiManager_futures_co_23[] = "BinanceRestApiManager.futures_coin_place_batch_order";
static const char __pyx_k_BinanceRestApiManager_futures_co_24[] = "BinanceRestApiManager.futures_coin_get_order";
static const char __pyx_k_BinanceRestApiManager_futures_co_25[] = "BinanceRestApiManager.futures_coin_get_open_orders";
static const char __pyx_k_BinanceRestApiManager_futures_co_26[] = "BinanceRestApiManager.futures_coin_get_all_orders";
static const char __pyx_k_BinanceRestApiManager_futures_co_27[] = "BinanceRestApiManager.futures_coin_cancel_order";
static const char __pyx_k_BinanceRestApiManager_futures_co_28[] = "BinanceRestApiManager.futures_coin_cancel_all_open_orders";
static const char __pyx_k_BinanceRestApiManager_futures_co_29[] = "BinanceRestApiManager.futures_coin_cancel_orders";
static const char __pyx_k_BinanceRestApiManager_futures_co_30[] = "BinanceRestApiManager.futures_coin_account_balance";
static const char __pyx_k_BinanceRestApiManager_futures_co_31[] = "BinanceRestApiManager.futures_coin_account";
static const char __pyx_k_BinanceRestApiManager_futures_co_32[] = "BinanceRestApiManager.futures_coin_change_leverage";
static const char __pyx_k_BinanceRestApiManager_futures_co_33[] = "BinanceRestApiManager.futures_coin_change_margin_type";
static const char __pyx_k_BinanceRestApiManager_futures_co_34[] = "BinanceRestApiManager.futures_coin_change_position_margin";
static const char __pyx_k_BinanceRestApiManager_futures_co_35[] = "BinanceRestApiManager.futures_coin_position_margin_history";
static const char __pyx_k_BinanceRestApiManager_futures_co_36[] = "BinanceRestApiManager.futures_coin_position_information";
static const char __pyx_k_BinanceRestApiManager_futures_co_37[] = "BinanceRestApiManager.futures_coin_account_trades";
static const char __pyx_k_BinanceRestApiManager_futures_co_38[] = "BinanceRestApiManager.futures_coin_income_history";
static const char __pyx_k_BinanceRestApiManager_futures_co_39[] = "BinanceRestApiManager.futures_coin_change_position_mode";
static const char __pyx_k_BinanceRestApiManager_futures_co_40[] = "BinanceRestApiManager.futures_coin_get_position_mode";
static const char __pyx_k_BinanceRestApiManager_futures_co_41[] = "BinanceRestApiManager.futures_coin_stream_get_listen_key";
static const char __pyx_k_BinanceRestApiManager_futures_co_42[] = "BinanceRestApiManager.futures_coin_stream_keepalive";
static const char __pyx_k_BinanceRestApiManager_futures_co_43[] = "BinanceRestApiManager.futures_coin_stream_close";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_api_key, PyObject *__pyx_v_api_secret, PyObject *__pyx_v_requests_params, PyObject *__pyx_v_tld, PyObject *__pyx_v_warn_on_update, PyObject *__pyx_v_exchange, PyObject *__pyx_v_disable_colorama, PyObject *__pyx_v_debug, PyObject *__pyx_v_socks5_proxy_server, PyObject *__pyx_v_socks5_proxy_user, PyObject *__pyx_v_socks5_proxy_pass, PyObject *__pyx_v_socks5_proxy_ssl_verification, PyObject *__pyx_v_lucit_api_secret, PyObject *__pyx_v_lucit_license_ini, PyObject *__pyx_v_lucit_license_profile, PyObject *__pyx_v_lucit_license_token); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_2__enter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_4__exit__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc_type, PyObject *__pyx_v_exc_value, PyObject *__pyx_v_error_traceback); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_6_init_session(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager___defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_create_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_2__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_10_create_margin_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_version); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_12_create_website_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_14_create_futures_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_16_create_futures_data_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_18_create_futures_coin_api_url(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_version); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_20_create_futures_coin_data_api_url(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, CYTHON_UNUSED PyObject *__pyx_v_version); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_22_generate_signature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_24_order_params(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_26_request(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_uri, PyObject *__pyx_v_signed, PyObject *__pyx_v_force_params, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_4__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_28_request_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_6__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_30_request_margin_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_32_request_website(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_34_request_futures_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_36_request_futures_data_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_38_request_futures_coin_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_40_request_futures_coin_data_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_42_handle_response(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_8__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_44_get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_10__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_46_post(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_12__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_48_put(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_14__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_50_delete(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_52is_update_availabe(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_54get_version(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_56get_latest_version(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_58get_latest_release_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_60get_user_agent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_62get_products(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_64get_exchange_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_66get_symbol_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_68ping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_70get_server_time(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_72get_all_tickers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_74get_orderbook_tickers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_76get_order_book(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_78get_recent_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_80get_historical_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_82get_aggregate_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_84aggregate_trade_iter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_start_str, PyObject *__pyx_v_last_id); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_87get_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_89_get_earliest_valid_timestamp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_interval); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_91get_historical_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_interval, PyObject *__pyx_v_start_str, PyObject *__pyx_v_end_str, PyObject *__pyx_v_limit); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_93get_historical_klines_generator(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_interval, PyObject *__pyx_v_start_str, PyObject *__pyx_v_end_str); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_96get_avg_price(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_98get_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_100get_symbol_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_102get_orderbook_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_104create_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_16__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_106order_limit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_timeInForce, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_18__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_108order_limit_buy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_timeInForce, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_20__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_110order_limit_sell(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_timeInForce, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_112order_market(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_114order_market_buy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_116order_market_sell(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_118create_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_120order_oco_buy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_122order_oco_sell(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_124create_test_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_126get_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_128get_all_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_130cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_132cancel_all_open_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_134cancel_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_136get_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_138get_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_140get_asset_balance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_asset, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_142get_my_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_144get_system_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_146get_account_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_148get_account_api_trading_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_150get_dust_log(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_152transfer_dust(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_154get_asset_dividend_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_156query_universal_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_158get_trade_fee(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_160get_asset_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_162withdraw(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_164get_deposit_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_166get_withdraw_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_168get_withdraw_history_id(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_withdraw_id, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_170get_deposit_address(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_172stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_174stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_176stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_178get_margin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_180get_isolated_margin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_182get_margin_asset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_184get_margin_symbol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_186create_isolated_margin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_188get_isolated_margin_symbol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_190get_all_isolated_margin_symbols(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_192toggle_bnb_burn_spot_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_194get_bnb_burn_spot_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_196get_margin_price_index(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_198transfer_margin_to_spot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_200transfer_spot_to_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_202transfer_isolated_margin_to_spot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_204transfer_spot_to_isolated_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_206create_margin_loan(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_208repay_margin_loan(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_210create_margin_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_212cancel_margin_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_214get_margin_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_216get_open_margin_oco_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_218create_margin_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_220cancel_margin_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_222get_margin_loan_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_224get_margin_repay_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_226get_margin_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_228get_open_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_230get_open_isolated_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_232get_all_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_234get_margin_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_236get_max_margin_loan(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_238get_max_margin_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_240margin_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_242margin_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_244margin_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_246isolated_margin_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_248isolated_margin_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_250isolated_margin_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_252get_lending_product_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_254get_lending_daily_quota_left(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_256purchase_lending_product(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_258get_lending_daily_redemption_quota(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_260redeem_lending_product(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_262get_lending_position(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_264get_fixed_activity_project_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_266get_lending_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_268get_lending_purchase_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_270get_lending_redemption_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_272get_lending_interest_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_274change_fixed_activity_to_daily_position(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_276get_sub_account_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_278get_sub_account_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_280get_sub_account_futures_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_282create_sub_account_futures_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_284get_sub_account_assets(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_286query_subaccount_spot_summary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_288get_subaccount_deposit_address(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_290get_subaccount_deposit_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_292get_subaccount_futures_margin_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_294enable_subaccount_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_296get_subaccount_margin_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_298get_subaccount_margin_summary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_300enable_subaccount_futures(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_302get_subaccount_futures_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_304get_subaccount_futures_summary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_306get_subaccount_futures_positionrisk(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_308make_subaccount_futures_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_310make_subaccount_margin_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_312make_subaccount_to_subaccount_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_314make_subaccount_to_master_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_316get_subaccount_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_318make_universal_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_320get_universal_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_322get_used_weight(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_make_new_request); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_324futures_ping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_326futures_time(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_328futures_exchange_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_330futures_order_book(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_332futures_recent_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_334futures_historical_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_336futures_aggregate_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_338futures_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_340futures_mark_price(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_342futures_funding_rate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_344futures_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_346futures_symbol_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_348futures_orderbook_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_350futures_liquidation_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_352futures_open_interest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_354futures_open_interest_hist(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_356futures_leverage_bracket(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_358futures_account_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_360futures_auto_cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_362futures_commission_rate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_364transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_366futures_create_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_368futures_place_batch_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_370futures_get_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_372futures_get_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_374futures_get_all_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_376futures_cancel_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_378futures_cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_380futures_cancel_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_382futures_account_balance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_384futures_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_386futures_change_leverage(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_388futures_change_margin_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_390futures_change_position_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_392futures_position_margin_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_394futures_position_information(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_396futures_account_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_398futures_income_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_400futures_change_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_402futures_get_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_404futures_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_406futures_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_408futures_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_410futures_coin_ping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_412futures_coin_time(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_414futures_coin_exchange_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_416futures_coin_order_book(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_418futures_coin_recent_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_420futures_coin_historical_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_422futures_coin_aggregate_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_424futures_coin_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_426futures_coin_continous_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_428futures_coin_index_price_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_430futures_coin_mark_price_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_432futures_coin_mark_price(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_434futures_coin_funding_rate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_436futures_coin_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_438futures_coin_symbol_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_440futures_coin_orderbook_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_442futures_coin_liquidation_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_444futures_coin_open_interest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_446futures_coin_open_interest_hist(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_448futures_coin_leverage_bracket(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_450new_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_452universal_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_454futures_coin_create_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_456futures_coin_place_batch_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_458futures_coin_get_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_460futures_coin_get_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_462futures_coin_get_all_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_464futures_coin_cancel_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_466futures_coin_cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_468futures_coin_cancel_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_470futures_coin_account_balance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_472futures_coin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_474futures_coin_change_leverage(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_476futures_coin_change_margin_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_478futures_coin_change_position_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_480futures_coin_position_margin_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_482futures_coin_position_information(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_484futures_coin_account_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_486futures_coin_income_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_488futures_coin_change_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_490futures_coin_get_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_492futures_coin_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_494futures_coin_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_496futures_coin_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_498get_all_coins_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_500get_account_snapshot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_502disable_fast_withdraw_switch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_504enable_fast_withdraw_switch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params); /* proto */
static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_506stop_manager(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_close_api_session); /* proto */
static PyObject *__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_update = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyString_Type_split = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr;
  PyObject *__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter;
  PyObject *__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator;
  #endif
  PyTypeObject *__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr;
  PyTypeObject *__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter;
  PyTypeObject *__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator;
  PyObject *__pyx_kp_u_;
  PyObject *__pyx_kp_s_12h;
  PyObject *__pyx_kp_s_15m;
  PyObject *__pyx_kp_s_1M;
  PyObject *__pyx_kp_s_1d;
  PyObject *__pyx_kp_s_1h;
  PyObject *__pyx_kp_s_1m;
  PyObject *__pyx_kp_s_1s;
  PyObject *__pyx_kp_s_1w;
  PyObject *__pyx_kp_s_22;
  PyObject *__pyx_kp_s_27;
  PyObject *__pyx_kp_s_2_0_0;
  PyObject *__pyx_kp_s_2h;
  PyObject *__pyx_kp_s_30m;
  PyObject *__pyx_kp_s_3d;
  PyObject *__pyx_kp_s_3m;
  PyObject *__pyx_kp_s_4h;
  PyObject *__pyx_kp_s_5m;
  PyObject *__pyx_kp_s_6h;
  PyObject *__pyx_kp_s_8h;
  PyObject *__pyx_n_s_ACK;
  PyObject *__pyx_n_s_AGG_BEST_MATCH;
  PyObject *__pyx_n_s_AGG_BUYER_MAKES;
  PyObject *__pyx_n_s_AGG_FIRST_TRADE_ID;
  PyObject *__pyx_n_s_AGG_ID;
  PyObject *__pyx_n_s_AGG_LAST_TRADE_ID;
  PyObject *__pyx_n_s_AGG_PRICE;
  PyObject *__pyx_n_s_AGG_QUANTITY;
  PyObject *__pyx_n_s_AGG_TIME;
  PyObject *__pyx_n_s_API_KEY;
  PyObject *__pyx_n_s_API_SECRET;
  PyObject *__pyx_n_s_API_URL;
  PyObject *__pyx_n_s_Accept;
  PyObject *__pyx_kp_u_An_exception_occurred;
  PyObject *__pyx_kp_s_An_unofficial_Python_API_to_use;
  PyObject *__pyx_n_s_BUY;
  PyObject *__pyx_n_s_BinanceAPIException;
  PyObject *__pyx_n_s_BinanceRequestException;
  PyObject *__pyx_n_s_BinanceRestApiManager;
  PyObject *__pyx_n_s_BinanceRestApiManager___enter;
  PyObject *__pyx_n_s_BinanceRestApiManager___exit;
  PyObject *__pyx_n_s_BinanceRestApiManager___init;
  PyObject *__pyx_n_s_BinanceRestApiManager__create_ap;
  PyObject *__pyx_n_s_BinanceRestApiManager__create_fu;
  PyObject *__pyx_n_s_BinanceRestApiManager__create_fu_2;
  PyObject *__pyx_n_s_BinanceRestApiManager__create_fu_3;
  PyObject *__pyx_n_s_BinanceRestApiManager__create_fu_4;
  PyObject *__pyx_n_s_BinanceRestApiManager__create_ma;
  PyObject *__pyx_n_s_BinanceRestApiManager__create_we;
  PyObject *__pyx_n_s_BinanceRestApiManager__delete;
  PyObject *__pyx_n_s_BinanceRestApiManager__generate;
  PyObject *__pyx_n_s_BinanceRestApiManager__get;
  PyObject *__pyx_n_s_BinanceRestApiManager__get_earli;
  PyObject *__pyx_n_s_BinanceRestApiManager__handle_re;
  PyObject *__pyx_n_s_BinanceRestApiManager__init_sess;
  PyObject *__pyx_n_s_BinanceRestApiManager__order_par;
  PyObject *__pyx_n_s_BinanceRestApiManager__post;
  PyObject *__pyx_n_s_BinanceRestApiManager__put;
  PyObject *__pyx_n_s_BinanceRestApiManager__request;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_a;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_f;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_f_2;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_f_3;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_f_4;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_l;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_m;
  PyObject *__pyx_n_s_BinanceRestApiManager__request_w;
  PyObject *__pyx_n_s_BinanceRestApiManager_aggregate;
  PyObject *__pyx_n_s_BinanceRestApiManager_cancel_all;
  PyObject *__pyx_n_s_BinanceRestApiManager_cancel_all_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_cancel_mar;
  PyObject *__pyx_n_s_BinanceRestApiManager_cancel_mar_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_cancel_ord;
  PyObject *__pyx_n_s_BinanceRestApiManager_change_fix;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_iso;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_mar;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_mar_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_mar_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_oco;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_ord;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_sub;
  PyObject *__pyx_n_s_BinanceRestApiManager_create_tes;
  PyObject *__pyx_n_s_BinanceRestApiManager_disable_fa;
  PyObject *__pyx_n_s_BinanceRestApiManager_enable_fas;
  PyObject *__pyx_n_s_BinanceRestApiManager_enable_sub;
  PyObject *__pyx_n_s_BinanceRestApiManager_enable_sub_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ac;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ac_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ac_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ac_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ag;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_au;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ca;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ca_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ca_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ch;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ch_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ch_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ch_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_10;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_11;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_12;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_13;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_14;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_15;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_16;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_17;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_18;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_19;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_20;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_21;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_22;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_23;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_24;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_25;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_26;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_27;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_28;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_29;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_30;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_31;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_32;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_33;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_34;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_35;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_36;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_37;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_38;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_39;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_40;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_41;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_42;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_43;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_5;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_6;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_7;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_8;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_co_9;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_cr;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ex;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_fu;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ge;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ge_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ge_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ge_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_hi;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_in;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_kl;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_le;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_li;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ma;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_op;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_op_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_or;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_or_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_pi;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_pl;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_po;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_po_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_re;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_st;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_st_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_st_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_sy;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ti;
  PyObject *__pyx_n_s_BinanceRestApiManager_futures_ti_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_accoun;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_accoun_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_accoun_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_accoun_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_aggreg;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_all_co;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_all_is;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_all_ma;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_all_or;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_all_ti;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_asset;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_asset_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_asset_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_avg_pr;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_bnb_bu;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_deposi;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_deposi_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_dust_l;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_exchan;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_fixed;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_histor;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_histor_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_histor_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_isolat;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_isolat_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_klines;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_latest;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_latest_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin_5;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin_6;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin_7;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_lendin_8;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_5;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_6;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_7;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_8;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_margin_9;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_max_ma;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_max_ma_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_my_tra;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_open_i;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_open_m;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_open_m_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_open_o;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_order;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_order_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_orderb;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_orderb_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_produc;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_recent;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_server;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_sub_ac;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_sub_ac_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_sub_ac_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_sub_ac_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_5;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_6;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_7;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_8;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_subacc_9;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_symbol;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_symbol_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_system;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_ticker;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_trade;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_univer;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_used_w;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_user_a;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_versio;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_withdr;
  PyObject *__pyx_n_s_BinanceRestApiManager_get_withdr_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_is_update;
  PyObject *__pyx_n_s_BinanceRestApiManager_isolated_m;
  PyObject *__pyx_n_s_BinanceRestApiManager_isolated_m_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_isolated_m_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_make_subac;
  PyObject *__pyx_n_s_BinanceRestApiManager_make_subac_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_make_subac_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_make_subac_4;
  PyObject *__pyx_n_s_BinanceRestApiManager_make_unive;
  PyObject *__pyx_n_s_BinanceRestApiManager_margin_str;
  PyObject *__pyx_n_s_BinanceRestApiManager_margin_str_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_margin_str_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_new_transf;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_limi;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_limi_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_limi_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_mark;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_mark_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_mark_3;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_oco;
  PyObject *__pyx_n_s_BinanceRestApiManager_order_oco_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_ping;
  PyObject *__pyx_n_s_BinanceRestApiManager_purchase_l;
  PyObject *__pyx_n_s_BinanceRestApiManager_query_suba;
  PyObject *__pyx_n_s_BinanceRestApiManager_query_univ;
  PyObject *__pyx_n_s_BinanceRestApiManager_redeem_len;
  PyObject *__pyx_n_s_BinanceRestApiManager_repay_marg;
  PyObject *__pyx_n_s_BinanceRestApiManager_stop_manag;
  PyObject *__pyx_n_s_BinanceRestApiManager_stream_clo;
  PyObject *__pyx_n_s_BinanceRestApiManager_stream_get;
  PyObject *__pyx_n_s_BinanceRestApiManager_stream_kee;
  PyObject *__pyx_n_s_BinanceRestApiManager_toggle_bnb;
  PyObject *__pyx_n_s_BinanceRestApiManager_transfer_d;
  PyObject *__pyx_n_s_BinanceRestApiManager_transfer_h;
  PyObject *__pyx_n_s_BinanceRestApiManager_transfer_i;
  PyObject *__pyx_n_s_BinanceRestApiManager_transfer_m;
  PyObject *__pyx_n_s_BinanceRestApiManager_transfer_s;
  PyObject *__pyx_n_s_BinanceRestApiManager_transfer_s_2;
  PyObject *__pyx_n_s_BinanceRestApiManager_universal;
  PyObject *__pyx_n_s_BinanceRestApiManager_withdraw;
  PyObject *__pyx_kp_s_BinanceWebSocketApiManager_stop;
  PyObject *__pyx_n_s_BinanceWithdrawException;
  PyObject *__pyx_n_s_C2C_MAIN;
  PyObject *__pyx_n_s_C2C_MINING;
  PyObject *__pyx_n_s_C2C_UMFUTURE;
  PyObject *__pyx_n_s_CANCELED;
  PyObject *__pyx_n_s_CMFUTURE_MAIN;
  PyObject *__pyx_n_s_COIN_FUTURE_TO_SPOT;
  PyObject *__pyx_kp_u_Created_SOCKS5_proxy_URI;
  PyObject *__pyx_n_s_Date;
  PyObject *__pyx_n_s_EXPIRED;
  PyObject *__pyx_kp_u_Entering_with_context;
  PyObject *__pyx_n_s_FIAT_TO_MINING;
  PyObject *__pyx_n_s_FIAT_TO_SPOT;
  PyObject *__pyx_n_s_FIAT_TO_USDT_FUTURE;
  PyObject *__pyx_n_s_FILLED;
  PyObject *__pyx_n_s_FOK;
  PyObject *__pyx_n_s_FULL;
  PyObject *__pyx_n_s_FUTURES_API_VERSION;
  PyObject *__pyx_n_s_FUTURES_API_VERSION2;
  PyObject *__pyx_n_s_FUTURES_COIN_DATA_URL;
  PyObject *__pyx_n_s_FUTURES_COIN_URL;
  PyObject *__pyx_n_s_FUTURES_DATA_URL;
  PyObject *__pyx_n_s_FUTURES_URL;
  PyObject *__pyx_n_s_GTC;
  PyObject *__pyx_n_s_IOC;
  PyObject *__pyx_n_s_ISOLATED_MARGIN;
  PyObject *__pyx_kp_u_Initiating_colorama;
  PyObject *__pyx_kp_s_Invalid_Response_s;
  PyObject *__pyx_n_s_KLINE_INTERVAL_12HOUR;
  PyObject *__pyx_n_s_KLINE_INTERVAL_15MINUTE;
  PyObject *__pyx_n_s_KLINE_INTERVAL_1DAY;
  PyObject *__pyx_n_s_KLINE_INTERVAL_1HOUR;
  PyObject *__pyx_n_s_KLINE_INTERVAL_1MINUTE;
  PyObject *__pyx_n_s_KLINE_INTERVAL_1MONTH;
  PyObject *__pyx_n_s_KLINE_INTERVAL_1SECOND;
  PyObject *__pyx_n_s_KLINE_INTERVAL_1WEEK;
  PyObject *__pyx_n_s_KLINE_INTERVAL_2HOUR;
  PyObject *__pyx_n_s_KLINE_INTERVAL_30MINUTE;
  PyObject *__pyx_n_s_KLINE_INTERVAL_3DAY;
  PyObject *__pyx_n_s_KLINE_INTERVAL_3MINUTE;
  PyObject *__pyx_n_s_KLINE_INTERVAL_4HOUR;
  PyObject *__pyx_n_s_KLINE_INTERVAL_5MINUTE;
  PyObject *__pyx_n_s_KLINE_INTERVAL_6HOUR;
  PyObject *__pyx_n_s_KLINE_INTERVAL_8HOUR;
  PyObject *__pyx_n_s_KeyError;
  PyObject *__pyx_n_s_LIMIT;
  PyObject *__pyx_n_s_LIMIT_MAKER;
  PyObject *__pyx_kp_u_Leaving_with_context;
  PyObject *__pyx_n_s_LucitLicensingManager;
  PyObject *__pyx_n_s_M;
  PyObject *__pyx_n_s_MAIN_C2C;
  PyObject *__pyx_n_s_MAIN_CMFUTURE;
  PyObject *__pyx_n_s_MAIN_MARGIN;
  PyObject *__pyx_n_s_MAIN_MINING;
  PyObject *__pyx_n_s_MAIN_UMFUTURE;
  PyObject *__pyx_n_s_MARGIN_API_URL;
  PyObject *__pyx_n_s_MARGIN_API_VERSION;
  PyObject *__pyx_n_s_MARGIN_CROSS_TO_SPOT;
  PyObject *__pyx_n_s_MARGIN_CROSS_TO_USDT_FUTURE;
  PyObject *__pyx_n_s_MARGIN_MAIN;
  PyObject *__pyx_n_s_MARGIN_UMFUTURE;
  PyObject *__pyx_n_s_MARKET;
  PyObject *__pyx_n_s_MINING_C2C;
  PyObject *__pyx_n_s_MINING_MAIN;
  PyObject *__pyx_n_s_MINING_TO_FIAT;
  PyObject *__pyx_n_s_MINING_TO_SPOT;
  PyObject *__pyx_n_s_MINING_TO_USDT_FUTURE;
  PyObject *__pyx_n_s_MINING_UMFUTURE;
  PyObject *__pyx_n_s_NEW;
  PyObject *__pyx_kp_u_New_instance_of;
  PyObject *__pyx_n_s_ORDER_RESP_TYPE_ACK;
  PyObject *__pyx_n_s_ORDER_RESP_TYPE_FULL;
  PyObject *__pyx_n_s_ORDER_RESP_TYPE_RESULT;
  PyObject *__pyx_n_s_ORDER_STATUS_CANCELED;
  PyObject *__pyx_n_s_ORDER_STATUS_EXPIRED;
  PyObject *__pyx_n_s_ORDER_STATUS_FILLED;
  PyObject *__pyx_n_s_ORDER_STATUS_NEW;
  PyObject *__pyx_n_s_ORDER_STATUS_PARTIALLY_FILLED;
  PyObject *__pyx_n_s_ORDER_STATUS_PENDING_CANCEL;
  PyObject *__pyx_n_s_ORDER_STATUS_REJECTED;
  PyObject *__pyx_n_s_ORDER_TYPE_LIMIT;
  PyObject *__pyx_n_s_ORDER_TYPE_LIMIT_MAKER;
  PyObject *__pyx_n_s_ORDER_TYPE_MARKET;
  PyObject *__pyx_n_s_ORDER_TYPE_STOP_LOSS;
  PyObject *__pyx_n_s_ORDER_TYPE_STOP_LOSS_LIMIT;
  PyObject *__pyx_n_s_ORDER_TYPE_TAKE_PROFIT;
  PyObject *__pyx_n_s_ORDER_TYPE_TAKE_PROFIT_LIMIT;
  PyObject *__pyx_n_s_Optional;
  PyObject *__pyx_kp_s_Optional_bool;
  PyObject *__pyx_kp_s_Optional_str;
  PyObject *__pyx_n_s_PARTIALLY_FILLED;
  PyObject *__pyx_n_s_PENDING_CANCEL;
  PyObject *__pyx_n_s_PRIVATE_API_VERSION;
  PyObject *__pyx_n_s_PUBLIC_API_VERSION;
  PyObject *__pyx_n_s_REJECTED;
  PyObject *__pyx_n_s_RESULT;
  PyObject *__pyx_kp_u_Read_the_docs_to_see_a_list_of;
  PyObject *__pyx_kp_u_Release;
  PyObject *__pyx_n_s_SELL;
  PyObject *__pyx_n_s_SIDE_BUY;
  PyObject *__pyx_n_s_SIDE_SELL;
  PyObject *__pyx_n_s_SPOT;
  PyObject *__pyx_n_s_SPOT_TO_COIN_FUTURE;
  PyObject *__pyx_n_s_SPOT_TO_FIAT;
  PyObject *__pyx_n_s_SPOT_TO_MARGIN_CROSS;
  PyObject *__pyx_n_s_SPOT_TO_MINING;
  PyObject *__pyx_n_s_SPOT_TO_USDT_FUTURE;
  PyObject *__pyx_n_s_STOP_LOSS;
  PyObject *__pyx_n_s_STOP_LOSS_LIMIT;
  PyObject *__pyx_n_s_SYMBOL_TYPE_SPOT;
  PyObject *__pyx_n_s_T;
  PyObject *__pyx_n_s_TAKE_PROFIT;
  PyObject *__pyx_n_s_TAKE_PROFIT_LIMIT;
  PyObject *__pyx_n_s_TIME_IN_FORCE_FOK;
  PyObject *__pyx_n_s_TIME_IN_FORCE_GTC;
  PyObject *__pyx_n_s_TIME_IN_FORCE_IOC;
  PyObject *__pyx_kp_s_The_parameter_BinanceRestApiMana;
  PyObject *__pyx_kp_s_There_is_no_entry_with_withdraw;
  PyObject *__pyx_n_s_UMFUTURE_C2C;
  PyObject *__pyx_n_s_UMFUTURE_MAIN;
  PyObject *__pyx_n_s_UMFUTURE_MARGIN;
  PyObject *__pyx_kp_s_UNICORN_BINANCE_SUITE;
  PyObject *__pyx_n_s_USDT_FUTURE_TO_FIAT;
  PyObject *__pyx_n_s_USDT_FUTURE_TO_MARGIN_CROSS;
  PyObject *__pyx_n_s_USDT_FUTURE_TO_SPOT;
  PyObject *__pyx_n_s_UnknownExchange;
  PyObject *__pyx_kp_u_Unknown_exchange;
  PyObject *__pyx_kp_s_User_Agent;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s_WEBSITE_URL;
  PyObject *__pyx_kp_s_X_MBX_APIKEY;
  PyObject *__pyx_kp_s_X_MBX_USED_WEIGHT;
  PyObject *__pyx_kp_s__184;
  PyObject *__pyx_kp_u__185;
  PyObject *__pyx_n_s__186;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_kp_s__3;
  PyObject *__pyx_kp_u__3;
  PyObject *__pyx_kp_s__4;
  PyObject *__pyx_n_s__488;
  PyObject *__pyx_n_u__5;
  PyObject *__pyx_kp_u__6;
  PyObject *__pyx_kp_s__7;
  PyObject *__pyx_kp_s__8;
  PyObject *__pyx_kp_s__9;
  PyObject *__pyx_n_s_a;
  PyObject *__pyx_kp_s_a_d_b_Y_I_M_S_Z;
  PyObject *__pyx_n_s_account;
  PyObject *__pyx_n_s_accountSnapshot;
  PyObject *__pyx_kp_s_account_apiTradingStatus;
  PyObject *__pyx_kp_s_account_status;
  PyObject *__pyx_n_s_aggTrades;
  PyObject *__pyx_n_s_aggregate_trade_iter;
  PyObject *__pyx_n_s_allForceOrders;
  PyObject *__pyx_n_s_allOpenOrders;
  PyObject *__pyx_n_s_allOrders;
  PyObject *__pyx_n_s_api_key;
  PyObject *__pyx_n_s_api_secret;
  PyObject *__pyx_kp_s_application_json;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_s_asset;
  PyObject *__pyx_kp_s_asset_assetDetail;
  PyObject *__pyx_kp_s_asset_assetDividend;
  PyObject *__pyx_kp_s_asset_dribblet;
  PyObject *__pyx_kp_s_asset_dust;
  PyObject *__pyx_kp_s_asset_tradeFee;
  PyObject *__pyx_kp_s_asset_transfer;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_avgPrice;
  PyObject *__pyx_n_s_bal;
  PyObject *__pyx_n_s_balance;
  PyObject *__pyx_n_s_balances;
  PyObject *__pyx_n_s_batchOrders;
  PyObject *__pyx_n_s_binance_api_status;
  PyObject *__pyx_kp_s_binance_com;
  PyObject *__pyx_kp_s_binance_com_coin_futures;
  PyObject *__pyx_kp_s_binance_com_futures;
  PyObject *__pyx_kp_s_binance_com_futures_testnet;
  PyObject *__pyx_kp_s_binance_com_isolated_margin;
  PyObject *__pyx_kp_s_binance_com_isolated_margin_test;
  PyObject *__pyx_kp_s_binance_com_margin;
  PyObject *__pyx_kp_s_binance_com_margin_testnet;
  PyObject *__pyx_kp_s_binance_com_testnet;
  PyObject *__pyx_kp_s_binance_us;
  PyObject *__pyx_n_s_bnbBurn;
  PyObject *__pyx_n_s_cancel_all_open_margin_orders;
  PyObject *__pyx_n_s_cancel_all_open_orders;
  PyObject *__pyx_n_s_cancel_margin_oco_order;
  PyObject *__pyx_n_s_cancel_margin_order;
  PyObject *__pyx_n_s_cancel_order;
  PyObject *__pyx_kp_s_capital_config_getall;
  PyObject *__pyx_kp_s_capital_deposit_address;
  PyObject *__pyx_kp_s_capital_deposit_hisrec;
  PyObject *__pyx_kp_s_capital_deposit_subAddress;
  PyObject *__pyx_kp_s_capital_deposit_subHisrec;
  PyObject *__pyx_kp_s_capital_withdraw_apply;
  PyObject *__pyx_kp_s_capital_withdraw_history;
  PyObject *__pyx_n_s_change_fixed_activity_to_daily_p;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_close_api_session;
  PyObject *__pyx_n_s_colorama;
  PyObject *__pyx_n_s_commissionRate;
  PyObject *__pyx_kp_u_compiled_on;
  PyObject *__pyx_n_s_continuousKlines;
  PyObject *__pyx_n_s_countdownCancelAll;
  PyObject *__pyx_n_s_create_api_uri;
  PyObject *__pyx_n_s_create_futures_api_uri;
  PyObject *__pyx_n_s_create_futures_coin_api_url;
  PyObject *__pyx_n_s_create_futures_coin_data_api_ur;
  PyObject *__pyx_n_s_create_futures_data_api_uri;
  PyObject *__pyx_n_s_create_isolated_margin_account;
  PyObject *__pyx_n_s_create_margin_api_uri;
  PyObject *__pyx_n_s_create_margin_loan;
  PyObject *__pyx_n_s_create_margin_oco_order;
  PyObject *__pyx_n_s_create_margin_order;
  PyObject *__pyx_n_s_create_oco_order;
  PyObject *__pyx_n_s_create_order;
  PyObject *__pyx_n_s_create_sub_account_futures_trans;
  PyObject *__pyx_n_s_create_test_order;
  PyObject *__pyx_n_s_create_website_uri;
  PyObject *__pyx_n_s_critical;
  PyObject *__pyx_n_s_d;
  PyObject *__pyx_n_s_data;
  PyObject *__pyx_n_s_date_time_obj;
  PyObject *__pyx_n_s_date_to_milliseconds;
  PyObject *__pyx_n_s_datetime;
  PyObject *__pyx_n_s_debug;
  PyObject *__pyx_n_s_delete;
  PyObject *__pyx_n_s_delete_2;
  PyObject *__pyx_n_s_depth;
  PyObject *__pyx_kp_s_dev;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_disableFastWithdrawSwitch;
  PyObject *__pyx_n_s_disable_colorama;
  PyObject *__pyx_n_s_disable_fast_withdraw_switch;
  PyObject *__pyx_n_s_doc;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_enableFastWithdrawSwitch;
  PyObject *__pyx_n_s_enable_fast_withdraw_switch;
  PyObject *__pyx_n_s_enable_subaccount_futures;
  PyObject *__pyx_n_s_enable_subaccount_margin;
  PyObject *__pyx_n_s_encode;
  PyObject *__pyx_n_s_endTime;
  PyObject *__pyx_n_s_end_str;
  PyObject *__pyx_n_s_end_ts;
  PyObject *__pyx_n_s_enter;
  PyObject *__pyx_n_s_entry;
  PyObject *__pyx_n_s_enumerate;
  PyObject *__pyx_n_s_error_msg;
  PyObject *__pyx_n_s_error_traceback;
  PyObject *__pyx_n_s_exc_type;
  PyObject *__pyx_n_s_exc_value;
  PyObject *__pyx_n_s_exceptions;
  PyObject *__pyx_n_s_exchange;
  PyObject *__pyx_n_s_exchangeInfo;
  PyObject *__pyx_kp_u_exchange_2;
  PyObject *__pyx_kp_s_exchange_api_v1_public_asset_ser;
  PyObject *__pyx_n_s_exit;
  PyObject *__pyx_n_s_f;
  PyObject *__pyx_n_s_first_valid_ts;
  PyObject *__pyx_kp_u_for_exchange;
  PyObject *__pyx_n_s_force_params;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_s_fromId;
  PyObject *__pyx_n_s_fundingRate;
  PyObject *__pyx_n_s_futures_account;
  PyObject *__pyx_n_s_futures_account_balance;
  PyObject *__pyx_n_s_futures_account_trades;
  PyObject *__pyx_n_s_futures_account_transfer;
  PyObject *__pyx_n_s_futures_aggregate_trades;
  PyObject *__pyx_n_s_futures_auto_cancel_all_open_ord;
  PyObject *__pyx_n_s_futures_cancel_all_open_orders;
  PyObject *__pyx_n_s_futures_cancel_order;
  PyObject *__pyx_n_s_futures_cancel_orders;
  PyObject *__pyx_n_s_futures_change_leverage;
  PyObject *__pyx_n_s_futures_change_margin_type;
  PyObject *__pyx_n_s_futures_change_position_margin;
  PyObject *__pyx_n_s_futures_change_position_mode;
  PyObject *__pyx_n_s_futures_coin_account;
  PyObject *__pyx_n_s_futures_coin_account_balance;
  PyObject *__pyx_n_s_futures_coin_account_trades;
  PyObject *__pyx_n_s_futures_coin_aggregate_trades;
  PyObject *__pyx_n_s_futures_coin_cancel_all_open_ord;
  PyObject *__pyx_n_s_futures_coin_cancel_order;
  PyObject *__pyx_n_s_futures_coin_cancel_orders;
  PyObject *__pyx_n_s_futures_coin_change_leverage;
  PyObject *__pyx_n_s_futures_coin_change_margin_type;
  PyObject *__pyx_n_s_futures_coin_change_position_mar;
  PyObject *__pyx_n_s_futures_coin_change_position_mod;
  PyObject *__pyx_n_s_futures_coin_continous_klines;
  PyObject *__pyx_n_s_futures_coin_create_order;
  PyObject *__pyx_n_s_futures_coin_exchange_info;
  PyObject *__pyx_n_s_futures_coin_funding_rate;
  PyObject *__pyx_n_s_futures_coin_get_all_orders;
  PyObject *__pyx_n_s_futures_coin_get_open_orders;
  PyObject *__pyx_n_s_futures_coin_get_order;
  PyObject *__pyx_n_s_futures_coin_get_position_mode;
  PyObject *__pyx_n_s_futures_coin_historical_trades;
  PyObject *__pyx_n_s_futures_coin_income_history;
  PyObject *__pyx_n_s_futures_coin_index_price_klines;
  PyObject *__pyx_n_s_futures_coin_klines;
  PyObject *__pyx_n_s_futures_coin_leverage_bracket;
  PyObject *__pyx_n_s_futures_coin_liquidation_orders;
  PyObject *__pyx_n_s_futures_coin_mark_price;
  PyObject *__pyx_n_s_futures_coin_mark_price_klines;
  PyObject *__pyx_n_s_futures_coin_open_interest;
  PyObject *__pyx_n_s_futures_coin_open_interest_hist;
  PyObject *__pyx_n_s_futures_coin_order_book;
  PyObject *__pyx_n_s_futures_coin_orderbook_ticker;
  PyObject *__pyx_n_s_futures_coin_ping;
  PyObject *__pyx_n_s_futures_coin_place_batch_order;
  PyObject *__pyx_n_s_futures_coin_position_informatio;
  PyObject *__pyx_n_s_futures_coin_position_margin_his;
  PyObject *__pyx_n_s_futures_coin_recent_trades;
  PyObject *__pyx_n_s_futures_coin_stream_close;
  PyObject *__pyx_n_s_futures_coin_stream_get_listen_k;
  PyObject *__pyx_n_s_futures_coin_stream_keepalive;
  PyObject *__pyx_n_s_futures_coin_symbol_ticker;
  PyObject *__pyx_n_s_futures_coin_ticker;
  PyObject *__pyx_n_s_futures_coin_time;
  PyObject *__pyx_n_s_futures_commission_rate;
  PyObject *__pyx_n_s_futures_create_order;
  PyObject *__pyx_n_s_futures_exchange_info;
  PyObject *__pyx_n_s_futures_funding_rate;
  PyObject *__pyx_n_s_futures_get_all_orders;
  PyObject *__pyx_n_s_futures_get_open_orders;
  PyObject *__pyx_n_s_futures_get_order;
  PyObject *__pyx_n_s_futures_get_position_mode;
  PyObject *__pyx_n_s_futures_historical_trades;
  PyObject *__pyx_n_s_futures_income_history;
  PyObject *__pyx_n_s_futures_klines;
  PyObject *__pyx_n_s_futures_leverage_bracket;
  PyObject *__pyx_n_s_futures_liquidation_orders;
  PyObject *__pyx_n_s_futures_mark_price;
  PyObject *__pyx_n_s_futures_open_interest;
  PyObject *__pyx_n_s_futures_open_interest_hist;
  PyObject *__pyx_n_s_futures_order_book;
  PyObject *__pyx_n_s_futures_orderbook_ticker;
  PyObject *__pyx_n_s_futures_ping;
  PyObject *__pyx_n_s_futures_place_batch_order;
  PyObject *__pyx_n_s_futures_position_information;
  PyObject *__pyx_n_s_futures_position_margin_history;
  PyObject *__pyx_n_s_futures_recent_trades;
  PyObject *__pyx_n_s_futures_stream_close;
  PyObject *__pyx_n_s_futures_stream_get_listen_key;
  PyObject *__pyx_n_s_futures_stream_keepalive;
  PyObject *__pyx_n_s_futures_symbol_ticker;
  PyObject *__pyx_n_s_futures_ticker;
  PyObject *__pyx_n_s_futures_time;
  PyObject *__pyx_kp_s_futures_transfer;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_generate_signature;
  PyObject *__pyx_n_s_genexpr;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_getLogger;
  PyObject *__pyx_n_s_get_2;
  PyObject *__pyx_n_s_get_account;
  PyObject *__pyx_n_s_get_account_api_trading_status;
  PyObject *__pyx_n_s_get_account_snapshot;
  PyObject *__pyx_n_s_get_account_status;
  PyObject *__pyx_n_s_get_aggregate_trades;
  PyObject *__pyx_n_s_get_all_coins_info;
  PyObject *__pyx_n_s_get_all_isolated_margin_symbols;
  PyObject *__pyx_n_s_get_all_margin_orders;
  PyObject *__pyx_n_s_get_all_orders;
  PyObject *__pyx_n_s_get_all_tickers;
  PyObject *__pyx_n_s_get_asset_balance;
  PyObject *__pyx_n_s_get_asset_details;
  PyObject *__pyx_n_s_get_asset_dividend_history;
  PyObject *__pyx_n_s_get_avg_price;
  PyObject *__pyx_n_s_get_bnb_burn_spot_margin;
  PyObject *__pyx_n_s_get_deposit_address;
  PyObject *__pyx_n_s_get_deposit_history;
  PyObject *__pyx_n_s_get_dust_log;
  PyObject *__pyx_n_s_get_earliest_valid_timestamp;
  PyObject *__pyx_n_s_get_exchange_info;
  PyObject *__pyx_n_s_get_fixed_activity_project_list;
  PyObject *__pyx_n_s_get_historical_klines;
  PyObject *__pyx_n_s_get_historical_klines_generator;
  PyObject *__pyx_n_s_get_historical_trades;
  PyObject *__pyx_n_s_get_isolated_margin_account;
  PyObject *__pyx_n_s_get_isolated_margin_symbol;
  PyObject *__pyx_n_s_get_klines;
  PyObject *__pyx_n_s_get_latest_release_info;
  PyObject *__pyx_n_s_get_latest_version;
  PyObject *__pyx_n_s_get_lending_account;
  PyObject *__pyx_n_s_get_lending_daily_quota_left;
  PyObject *__pyx_n_s_get_lending_daily_redemption_quo;
  PyObject *__pyx_n_s_get_lending_interest_history;
  PyObject *__pyx_n_s_get_lending_position;
  PyObject *__pyx_n_s_get_lending_product_list;
  PyObject *__pyx_n_s_get_lending_purchase_history;
  PyObject *__pyx_n_s_get_lending_redemption_history;
  PyObject *__pyx_n_s_get_margin_account;
  PyObject *__pyx_n_s_get_margin_asset;
  PyObject *__pyx_n_s_get_margin_loan_details;
  PyObject *__pyx_n_s_get_margin_oco_order;
  PyObject *__pyx_n_s_get_margin_order;
  PyObject *__pyx_n_s_get_margin_price_index;
  PyObject *__pyx_n_s_get_margin_repay_details;
  PyObject *__pyx_n_s_get_margin_symbol;
  PyObject *__pyx_n_s_get_margin_trades;
  PyObject *__pyx_n_s_get_max_margin_loan;
  PyObject *__pyx_n_s_get_max_margin_transfer;
  PyObject *__pyx_n_s_get_my_trades;
  PyObject *__pyx_n_s_get_open_isolated_margin_orders;
  PyObject *__pyx_n_s_get_open_margin_oco_orders;
  PyObject *__pyx_n_s_get_open_margin_orders;
  PyObject *__pyx_n_s_get_open_orders;
  PyObject *__pyx_n_s_get_order;
  PyObject *__pyx_n_s_get_order_book;
  PyObject *__pyx_n_s_get_orderbook_ticker;
  PyObject *__pyx_n_s_get_orderbook_tickers;
  PyObject *__pyx_n_s_get_products;
  PyObject *__pyx_n_s_get_recent_trades;
  PyObject *__pyx_n_s_get_server_time;
  PyObject *__pyx_n_s_get_sub_account_assets;
  PyObject *__pyx_n_s_get_sub_account_futures_transfer;
  PyObject *__pyx_n_s_get_sub_account_list;
  PyObject *__pyx_n_s_get_sub_account_transfer_history;
  PyObject *__pyx_n_s_get_subaccount_deposit_address;
  PyObject *__pyx_n_s_get_subaccount_deposit_history;
  PyObject *__pyx_n_s_get_subaccount_futures_details;
  PyObject *__pyx_n_s_get_subaccount_futures_margin_st;
  PyObject *__pyx_n_s_get_subaccount_futures_positionr;
  PyObject *__pyx_n_s_get_subaccount_futures_summary;
  PyObject *__pyx_n_s_get_subaccount_margin_details;
  PyObject *__pyx_n_s_get_subaccount_margin_summary;
  PyObject *__pyx_n_s_get_subaccount_transfer_history;
  PyObject *__pyx_n_s_get_symbol_info;
  PyObject *__pyx_n_s_get_symbol_ticker;
  PyObject *__pyx_n_s_get_system_status;
  PyObject *__pyx_n_s_get_ticker;
  PyObject *__pyx_n_s_get_trade_fee;
  PyObject *__pyx_n_s_get_universal_transfer_history;
  PyObject *__pyx_n_s_get_used_weight;
  PyObject *__pyx_n_s_get_user_agent;
  PyObject *__pyx_n_s_get_version;
  PyObject *__pyx_n_s_get_withdraw_history;
  PyObject *__pyx_n_s_get_withdraw_history_id;
  PyObject *__pyx_n_s_handle_response;
  PyObject *__pyx_n_s_has_signature;
  PyObject *__pyx_n_s_hashlib;
  PyObject *__pyx_n_s_headers;
  PyObject *__pyx_n_s_helpers;
  PyObject *__pyx_n_s_hexdigest;
  PyObject *__pyx_n_s_historicalTrades;
  PyObject *__pyx_n_s_hmac;
  PyObject *__pyx_n_s_http;
  PyObject *__pyx_n_s_https;
  PyObject *__pyx_kp_s_https_api_binance_api;
  PyObject *__pyx_kp_s_https_api_binance_com_api;
  PyObject *__pyx_kp_s_https_api_binance_com_sapi;
  PyObject *__pyx_kp_s_https_api_binance_sapi;
  PyObject *__pyx_kp_s_https_api_binance_us_api;
  PyObject *__pyx_kp_s_https_api_binance_us_sapi;
  PyObject *__pyx_kp_s_https_api_github_com_repos_LUCIT;
  PyObject *__pyx_kp_s_https_api_trbinance_com_sapi;
  PyObject *__pyx_kp_s_https_dapi_binance_com_futures_d;
  PyObject *__pyx_kp_s_https_dapi_binance_futures_data;
  PyObject *__pyx_kp_s_https_dapi_binance_us_futures_da;
  PyObject *__pyx_kp_s_https_dapi_trbinance_com_futures;
  PyObject *__pyx_kp_s_https_fapi_binance_com_fapi;
  PyObject *__pyx_kp_s_https_fapi_binance_com_futures_d;
  PyObject *__pyx_kp_s_https_fapi_binance_fapi;
  PyObject *__pyx_kp_s_https_fapi_binance_futures_data;
  PyObject *__pyx_kp_s_https_fapi_binance_us_fapi;
  PyObject *__pyx_kp_s_https_fapi_binance_us_futures_da;
  PyObject *__pyx_kp_s_https_fapi_trbinance_com_fapi;
  PyObject *__pyx_kp_s_https_fapi_trbinance_com_futures;
  PyObject *__pyx_kp_s_https_testnet_binance_vision;
  PyObject *__pyx_kp_s_https_testnet_binance_vision_api;
  PyObject *__pyx_kp_s_https_testnet_binancefuture_com;
  PyObject *__pyx_kp_s_https_testnet_binancefuture_com_2;
  PyObject *__pyx_kp_s_https_testnet_binancefuture_com_3;
  PyObject *__pyx_kp_s_https_www_binance;
  PyObject *__pyx_kp_s_https_www_binance_com;
  PyObject *__pyx_kp_s_https_www_binance_us;
  PyObject *__pyx_kp_s_https_www_trbinance_com;
  PyObject *__pyx_kp_s_https_www_trbinance_com_api;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_s_id;
  PyObject *__pyx_n_s_idx;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_income;
  PyObject *__pyx_n_s_indexPriceKlines;
  PyObject *__pyx_n_s_info;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_init_2;
  PyObject *__pyx_n_s_init_session;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_installed_version;
  PyObject *__pyx_n_s_interval;
  PyObject *__pyx_n_s_interval_to_milliseconds;
  PyObject *__pyx_kp_u_is_available_please_consider_up;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_n_s_is_update_availabe;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_isolated_margin_stream_close;
  PyObject *__pyx_n_s_isolated_margin_stream_get_liste;
  PyObject *__pyx_n_s_isolated_margin_stream_keepalive;
  PyObject *__pyx_n_s_item;
  PyObject *__pyx_n_s_itemgetter;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_join;
  PyObject *__pyx_n_s_json;
  PyObject *__pyx_n_s_key;
  PyObject *__pyx_n_s_kline;
  PyObject *__pyx_n_s_klines;
  PyObject *__pyx_n_s_kwargs;
  PyObject *__pyx_n_s_l;
  PyObject *__pyx_n_s_last_id;
  PyObject *__pyx_n_s_last_update_check_github;
  PyObject *__pyx_n_s_latest_release_info;
  PyObject *__pyx_kp_s_lending_daily_product_list;
  PyObject *__pyx_kp_s_lending_daily_purchase;
  PyObject *__pyx_kp_s_lending_daily_redeem;
  PyObject *__pyx_kp_s_lending_daily_token_position;
  PyObject *__pyx_kp_s_lending_daily_userLeftQuota;
  PyObject *__pyx_kp_s_lending_daily_userRedemptionQuot;
  PyObject *__pyx_kp_s_lending_positionChanged;
  PyObject *__pyx_kp_s_lending_project_list;
  PyObject *__pyx_kp_s_lending_union_account;
  PyObject *__pyx_kp_s_lending_union_interestHistory;
  PyObject *__pyx_kp_s_lending_union_purchaseRecord;
  PyObject *__pyx_kp_s_lending_union_redemptionRecord;
  PyObject *__pyx_n_s_leverage;
  PyObject *__pyx_n_s_leverageBracket;
  PyObject *__pyx_n_s_license_ini;
  PyObject *__pyx_n_s_license_profile;
  PyObject *__pyx_n_s_license_token;
  PyObject *__pyx_n_s_limit;
  PyObject *__pyx_n_s_listenKey;
  PyObject *__pyx_n_s_llm;
  PyObject *__pyx_n_s_logger;
  PyObject *__pyx_n_s_logging;
  PyObject *__pyx_n_s_lower;
  PyObject *__pyx_n_s_lucit_api_secret;
  PyObject *__pyx_n_s_lucit_license_ini;
  PyObject *__pyx_n_s_lucit_license_profile;
  PyObject *__pyx_n_s_lucit_license_token;
  PyObject *__pyx_n_s_lucit_licensing_python_manager;
  PyObject *__pyx_n_s_m;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_make_new_request;
  PyObject *__pyx_n_s_make_subaccount_futures_transfer;
  PyObject *__pyx_n_s_make_subaccount_margin_transfer;
  PyObject *__pyx_n_s_make_subaccount_to_master_transf;
  PyObject *__pyx_n_s_make_subaccount_to_subaccount_tr;
  PyObject *__pyx_n_s_make_universal_transfer;
  PyObject *__pyx_n_s_marginType;
  PyObject *__pyx_kp_s_margin_account;
  PyObject *__pyx_kp_s_margin_allOrderList;
  PyObject *__pyx_kp_s_margin_allOrders;
  PyObject *__pyx_kp_s_margin_asset;
  PyObject *__pyx_kp_s_margin_isolated_account;
  PyObject *__pyx_kp_s_margin_isolated_allPairs;
  PyObject *__pyx_kp_s_margin_isolated_create;
  PyObject *__pyx_kp_s_margin_isolated_pair;
  PyObject *__pyx_kp_s_margin_isolated_transfer;
  PyObject *__pyx_kp_s_margin_loan;
  PyObject *__pyx_kp_s_margin_maxBorrowable;
  PyObject *__pyx_kp_s_margin_maxTransferable;
  PyObject *__pyx_kp_s_margin_myTrades;
  PyObject *__pyx_kp_s_margin_openOrders;
  PyObject *__pyx_kp_s_margin_order;
  PyObject *__pyx_kp_s_margin_orderList;
  PyObject *__pyx_kp_s_margin_order_oco;
  PyObject *__pyx_kp_s_margin_pair;
  PyObject *__pyx_kp_s_margin_priceIndex;
  PyObject *__pyx_kp_s_margin_repay;
  PyObject *__pyx_n_s_margin_stream_close;
  PyObject *__pyx_n_s_margin_stream_get_listen_key;
  PyObject *__pyx_n_s_margin_stream_keepalive;
  PyObject *__pyx_kp_s_margin_transfer;
  PyObject *__pyx_n_s_markPriceKlines;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_n_s_method;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_n_s_mro_entries;
  PyObject *__pyx_n_s_msg;
  PyObject *__pyx_n_s_myTrades;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_needed_license_type;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_new_transfer_history;
  PyObject *__pyx_n_s_null_args;
  PyObject *__pyx_n_s_o;
  PyObject *__pyx_n_s_object;
  PyObject *__pyx_n_s_openInterest;
  PyObject *__pyx_n_s_openInterestHist;
  PyObject *__pyx_n_s_openOrders;
  PyObject *__pyx_n_s_operator;
  PyObject *__pyx_n_s_options;
  PyObject *__pyx_n_s_order;
  PyObject *__pyx_n_s_order_limit;
  PyObject *__pyx_n_s_order_limit_buy;
  PyObject *__pyx_n_s_order_limit_sell;
  PyObject *__pyx_n_s_order_market;
  PyObject *__pyx_n_s_order_market_buy;
  PyObject *__pyx_n_s_order_market_sell;
  PyObject *__pyx_kp_s_order_oco;
  PyObject *__pyx_n_s_order_oco_buy;
  PyObject *__pyx_n_s_order_oco_sell;
  PyObject *__pyx_n_s_order_params;
  PyObject *__pyx_kp_s_order_test;
  PyObject *__pyx_n_s_ordered_data;
  PyObject *__pyx_n_s_output;
  PyObject *__pyx_n_s_output_data;
  PyObject *__pyx_n_s_p;
  PyObject *__pyx_n_s_params;
  PyObject *__pyx_n_s_parent_shutdown_function;
  PyObject *__pyx_n_s_path;
  PyObject *__pyx_n_s_ping;
  PyObject *__pyx_n_s_platform;
  PyObject *__pyx_n_s_positionMargin;
  PyObject *__pyx_kp_s_positionMargin_history;
  PyObject *__pyx_n_s_positionRisk;
  PyObject *__pyx_kp_s_positionSide_dual;
  PyObject *__pyx_n_s_post;
  PyObject *__pyx_n_s_post_2;
  PyObject *__pyx_n_s_premiumIndex;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_s_print;
  PyObject *__pyx_n_s_products;
  PyObject *__pyx_n_s_program_used;
  PyObject *__pyx_n_s_proxies;
  PyObject *__pyx_n_s_purchase_lending_product;
  PyObject *__pyx_n_s_put;
  PyObject *__pyx_n_s_put_2;
  PyObject *__pyx_kp_u_python;
  PyObject *__pyx_n_s_python_version;
  PyObject *__pyx_n_s_q;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_query_string;
  PyObject *__pyx_n_s_query_subaccount_spot_summary;
  PyObject *__pyx_n_s_query_universal_transfer_history;
  PyObject *__pyx_n_s_raw_data;
  PyObject *__pyx_n_s_redeem_lending_product;
  PyObject *__pyx_n_s_release;
  PyObject *__pyx_n_s_repay_margin_loan;
  PyObject *__pyx_n_s_replace;
  PyObject *__pyx_n_s_request;
  PyObject *__pyx_n_s_request_api;
  PyObject *__pyx_n_s_request_futures_api;
  PyObject *__pyx_n_s_request_futures_coin_api;
  PyObject *__pyx_n_s_request_futures_coin_data_api;
  PyObject *__pyx_n_s_request_futures_data_api;
  PyObject *__pyx_n_s_request_margin_api;
  PyObject *__pyx_n_s_request_socks5_proxies;
  PyObject *__pyx_n_s_request_website;
  PyObject *__pyx_n_s_requests;
  PyObject *__pyx_n_s_requests_params;
  PyObject *__pyx_n_s_requests_params_2;
  PyObject *__pyx_n_s_res;
  PyObject *__pyx_n_s_respond;
  PyObject *__pyx_n_s_response;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_reversed;
  PyObject *__pyx_kp_s_s_s;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_kp_u_self_API_URL;
  PyObject *__pyx_kp_u_self_FUTURES_COIN_DATA_URL;
  PyObject *__pyx_kp_u_self_FUTURES_COIN_URL;
  PyObject *__pyx_kp_u_self_FUTURES_DATA_URL;
  PyObject *__pyx_kp_u_self_FUTURES_URL;
  PyObject *__pyx_kp_u_self_MARGIN_API_URL;
  PyObject *__pyx_kp_u_self_WEBSITE_URL;
  PyObject *__pyx_n_s_send;
  PyObject *__pyx_n_s_serverTime;
  PyObject *__pyx_n_s_session;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_sha256;
  PyObject *__pyx_n_s_side;
  PyObject *__pyx_n_s_signature;
  PyObject *__pyx_n_s_signed;
  PyObject *__pyx_n_s_sleep;
  PyObject *__pyx_kp_s_socks5;
  PyObject *__pyx_n_s_socks5_proxy_address;
  PyObject *__pyx_n_s_socks5_proxy_pass;
  PyObject *__pyx_n_s_socks5_proxy_port;
  PyObject *__pyx_n_s_socks5_proxy_server;
  PyObject *__pyx_n_s_socks5_proxy_ssl_verification;
  PyObject *__pyx_n_s_socks5_proxy_user;
  PyObject *__pyx_n_s_socks_proxy_uri;
  PyObject *__pyx_n_s_sort;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_split;
  PyObject *__pyx_n_s_start;
  PyObject *__pyx_n_s_startTime;
  PyObject *__pyx_n_s_start_str;
  PyObject *__pyx_kp_s_start_time_and_last_id_may_not_b;
  PyObject *__pyx_n_s_start_ts;
  PyObject *__pyx_kp_u_started;
  PyObject *__pyx_n_s_status;
  PyObject *__pyx_n_s_status_code;
  PyObject *__pyx_n_s_stop_manager;
  PyObject *__pyx_n_s_str;
  PyObject *__pyx_n_s_stream_close;
  PyObject *__pyx_n_s_stream_get_listen_key;
  PyObject *__pyx_n_s_stream_keepalive;
  PyObject *__pyx_n_s_strptime;
  PyObject *__pyx_kp_s_sub_account_assets;
  PyObject *__pyx_kp_s_sub_account_futures_account;
  PyObject *__pyx_kp_s_sub_account_futures_accountSumma;
  PyObject *__pyx_kp_s_sub_account_futures_enable;
  PyObject *__pyx_kp_s_sub_account_futures_internalTran;
  PyObject *__pyx_kp_s_sub_account_futures_positionRisk;
  PyObject *__pyx_kp_s_sub_account_futures_transfer;
  PyObject *__pyx_kp_s_sub_account_list;
  PyObject *__pyx_kp_s_sub_account_margin_account;
  PyObject *__pyx_kp_s_sub_account_margin_accountSummar;
  PyObject *__pyx_kp_s_sub_account_margin_enable;
  PyObject *__pyx_kp_s_sub_account_margin_transfer;
  PyObject *__pyx_kp_s_sub_account_spotSummary;
  PyObject *__pyx_kp_s_sub_account_status;
  PyObject *__pyx_kp_s_sub_account_sub_transfer_history;
  PyObject *__pyx_kp_s_sub_account_transfer_subToMaster;
  PyObject *__pyx_kp_s_sub_account_transfer_subToSub;
  PyObject *__pyx_kp_s_sub_account_transfer_subUserHist;
  PyObject *__pyx_kp_s_sub_account_universalTransfer;
  PyObject *__pyx_n_s_success;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_symbol;
  PyObject *__pyx_n_s_symbols;
  PyObject *__pyx_n_s_system;
  PyObject *__pyx_kp_s_system_status;
  PyObject *__pyx_n_s_t;
  PyObject *__pyx_n_s_tag_name;
  PyObject *__pyx_n_s_temp_data;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_text;
  PyObject *__pyx_n_s_throw;
  PyObject *__pyx_n_s_throw_exception;
  PyObject *__pyx_kp_s_ticker_24hr;
  PyObject *__pyx_kp_s_ticker_allForceOrders;
  PyObject *__pyx_kp_s_ticker_bookTicker;
  PyObject *__pyx_kp_s_ticker_openInterest;
  PyObject *__pyx_kp_s_ticker_price;
  PyObject *__pyx_n_s_time;
  PyObject *__pyx_n_s_timeInForce;
  PyObject *__pyx_n_s_timeframe;
  PyObject *__pyx_n_s_timeout;
  PyObject *__pyx_n_s_timestamp;
  PyObject *__pyx_n_s_timestamp_offset;
  PyObject *__pyx_n_s_tld;
  PyObject *__pyx_kp_u_tld_2;
  PyObject *__pyx_n_s_toggle_bnb_burn_spot_margin;
  PyObject *__pyx_n_s_trades;
  PyObject *__pyx_n_s_transFrom;
  PyObject *__pyx_n_s_transTo;
  PyObject *__pyx_n_s_transfer_dust;
  PyObject *__pyx_n_s_transfer_history;
  PyObject *__pyx_n_s_transfer_isolated_margin_to_spot;
  PyObject *__pyx_n_s_transfer_margin_to_spot;
  PyObject *__pyx_n_s_transfer_spot_to_isolated_margin;
  PyObject *__pyx_n_s_transfer_spot_to_margin;
  PyObject *__pyx_kp_s_trbinance_com;
  PyObject *__pyx_n_s_type;
  PyObject *__pyx_n_s_typing;
  PyObject *__pyx_kp_s_unicorn_binance_rest_api;
  PyObject *__pyx_n_s_unicorn_binance_rest_api_2;
  PyObject *__pyx_n_s_unicorn_binance_rest_api_manager;
  PyObject *__pyx_kp_s_unicorn_binance_rest_api_manager_2;
  PyObject *__pyx_kp_s_unicorn_binance_websocket_api;
  PyObject *__pyx_n_s_universal_transfer;
  PyObject *__pyx_n_s_unknown;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_update_msg;
  PyObject *__pyx_n_s_upper;
  PyObject *__pyx_n_s_uri;
  PyObject *__pyx_n_s_urlencode;
  PyObject *__pyx_n_s_urllib_parse;
  PyObject *__pyx_n_s_userDataStream;
  PyObject *__pyx_kp_s_userDataStream_isolated;
  PyObject *__pyx_n_s_userTrades;
  PyObject *__pyx_n_s_user_agent;
  PyObject *__pyx_kp_s_utf_8;
  PyObject *__pyx_n_s_v;
  PyObject *__pyx_n_s_v1;
  PyObject *__pyx_n_s_v2;
  PyObject *__pyx_n_s_v3;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_n_s_verify;
  PyObject *__pyx_n_s_version;
  PyObject *__pyx_n_s_version_2;
  PyObject *__pyx_n_s_warn_on_update;
  PyObject *__pyx_n_s_warning;
  PyObject *__pyx_n_s_weight;
  PyObject *__pyx_n_s_withdraw;
  PyObject *__pyx_n_s_withdrawList;
  PyObject *__pyx_n_s_withdraw_id;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_10;
  PyObject *__pyx_int_12;
  PyObject *__pyx_int_200;
  PyObject *__pyx_int_300;
  PyObject *__pyx_int_500;
  PyObject *__pyx_int_1000;
  PyObject *__pyx_int_3600;
  PyObject *__pyx_int_3600000;
  PyObject *__pyx_int_neg_4;
  PyObject *__pyx_slice__10;
  PyObject *__pyx_slice__24;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__12;
  PyObject *__pyx_tuple__13;
  PyObject *__pyx_tuple__14;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__16;
  PyObject *__pyx_tuple__17;
  PyObject *__pyx_tuple__18;
  PyObject *__pyx_tuple__19;
  PyObject *__pyx_tuple__20;
  PyObject *__pyx_tuple__21;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__25;
  PyObject *__pyx_tuple__27;
  PyObject *__pyx_tuple__28;
  PyObject *__pyx_tuple__29;
  PyObject *__pyx_tuple__30;
  PyObject *__pyx_tuple__31;
  PyObject *__pyx_tuple__32;
  PyObject *__pyx_tuple__33;
  PyObject *__pyx_tuple__34;
  PyObject *__pyx_tuple__35;
  PyObject *__pyx_tuple__36;
  PyObject *__pyx_tuple__37;
  PyObject *__pyx_tuple__38;
  PyObject *__pyx_tuple__39;
  PyObject *__pyx_tuple__40;
  PyObject *__pyx_tuple__41;
  PyObject *__pyx_tuple__42;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__44;
  PyObject *__pyx_tuple__45;
  PyObject *__pyx_tuple__46;
  PyObject *__pyx_tuple__47;
  PyObject *__pyx_tuple__48;
  PyObject *__pyx_tuple__49;
  PyObject *__pyx_tuple__50;
  PyObject *__pyx_tuple__51;
  PyObject *__pyx_tuple__52;
  PyObject *__pyx_tuple__53;
  PyObject *__pyx_tuple__54;
  PyObject *__pyx_tuple__55;
  PyObject *__pyx_tuple__56;
  PyObject *__pyx_tuple__57;
  PyObject *__pyx_tuple__58;
  PyObject *__pyx_tuple__59;
  PyObject *__pyx_tuple__60;
  PyObject *__pyx_tuple__61;
  PyObject *__pyx_tuple__62;
  PyObject *__pyx_tuple__63;
  PyObject *__pyx_tuple__64;
  PyObject *__pyx_tuple__65;
  PyObject *__pyx_tuple__66;
  PyObject *__pyx_tuple__67;
  PyObject *__pyx_tuple__68;
  PyObject *__pyx_tuple__69;
  PyObject *__pyx_tuple__70;
  PyObject *__pyx_tuple__71;
  PyObject *__pyx_tuple__72;
  PyObject *__pyx_tuple__73;
  PyObject *__pyx_tuple__74;
  PyObject *__pyx_tuple__75;
  PyObject *__pyx_tuple__76;
  PyObject *__pyx_tuple__77;
  PyObject *__pyx_tuple__78;
  PyObject *__pyx_tuple__79;
  PyObject *__pyx_tuple__80;
  PyObject *__pyx_tuple__81;
  PyObject *__pyx_tuple__82;
  PyObject *__pyx_tuple__83;
  PyObject *__pyx_tuple__84;
  PyObject *__pyx_tuple__85;
  PyObject *__pyx_tuple__86;
  PyObject *__pyx_tuple__87;
  PyObject *__pyx_tuple__88;
  PyObject *__pyx_tuple__89;
  PyObject *__pyx_tuple__90;
  PyObject *__pyx_tuple__91;
  PyObject *__pyx_tuple__92;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_tuple__94;
  PyObject *__pyx_tuple__95;
  PyObject *__pyx_tuple__96;
  PyObject *__pyx_tuple__97;
  PyObject *__pyx_tuple__98;
  PyObject *__pyx_tuple__99;
  PyObject *__pyx_slice__143;
  PyObject *__pyx_tuple__100;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__102;
  PyObject *__pyx_tuple__103;
  PyObject *__pyx_tuple__104;
  PyObject *__pyx_tuple__105;
  PyObject *__pyx_tuple__106;
  PyObject *__pyx_tuple__107;
  PyObject *__pyx_tuple__108;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_tuple__110;
  PyObject *__pyx_tuple__111;
  PyObject *__pyx_tuple__112;
  PyObject *__pyx_tuple__113;
  PyObject *__pyx_tuple__114;
  PyObject *__pyx_tuple__115;
  PyObject *__pyx_tuple__116;
  PyObject *__pyx_tuple__117;
  PyObject *__pyx_tuple__118;
  PyObject *__pyx_tuple__119;
  PyObject *__pyx_tuple__120;
  PyObject *__pyx_tuple__121;
  PyObject *__pyx_tuple__122;
  PyObject *__pyx_tuple__123;
  PyObject *__pyx_tuple__124;
  PyObject *__pyx_tuple__125;
  PyObject *__pyx_tuple__126;
  PyObject *__pyx_tuple__127;
  PyObject *__pyx_tuple__128;
  PyObject *__pyx_tuple__129;
  PyObject *__pyx_tuple__130;
  PyObject *__pyx_tuple__131;
  PyObject *__pyx_tuple__132;
  PyObject *__pyx_tuple__133;
  PyObject *__pyx_tuple__134;
  PyObject *__pyx_tuple__135;
  PyObject *__pyx_tuple__136;
  PyObject *__pyx_tuple__137;
  PyObject *__pyx_tuple__138;
  PyObject *__pyx_tuple__139;
  PyObject *__pyx_tuple__140;
  PyObject *__pyx_tuple__141;
  PyObject *__pyx_tuple__142;
  PyObject *__pyx_tuple__144;
  PyObject *__pyx_tuple__145;
  PyObject *__pyx_tuple__146;
  PyObject *__pyx_tuple__147;
  PyObject *__pyx_tuple__148;
  PyObject *__pyx_tuple__149;
  PyObject *__pyx_tuple__150;
  PyObject *__pyx_tuple__151;
  PyObject *__pyx_tuple__152;
  PyObject *__pyx_tuple__153;
  PyObject *__pyx_tuple__154;
  PyObject *__pyx_tuple__155;
  PyObject *__pyx_tuple__156;
  PyObject *__pyx_tuple__157;
  PyObject *__pyx_tuple__158;
  PyObject *__pyx_tuple__159;
  PyObject *__pyx_tuple__160;
  PyObject *__pyx_tuple__161;
  PyObject *__pyx_tuple__162;
  PyObject *__pyx_tuple__163;
  PyObject *__pyx_tuple__164;
  PyObject *__pyx_tuple__165;
  PyObject *__pyx_tuple__166;
  PyObject *__pyx_tuple__167;
  PyObject *__pyx_tuple__168;
  PyObject *__pyx_tuple__169;
  PyObject *__pyx_tuple__170;
  PyObject *__pyx_tuple__171;
  PyObject *__pyx_tuple__172;
  PyObject *__pyx_tuple__173;
  PyObject *__pyx_tuple__174;
  PyObject *__pyx_tuple__175;
  PyObject *__pyx_tuple__176;
  PyObject *__pyx_tuple__177;
  PyObject *__pyx_tuple__178;
  PyObject *__pyx_tuple__179;
  PyObject *__pyx_tuple__180;
  PyObject *__pyx_tuple__181;
  PyObject *__pyx_tuple__182;
  PyObject *__pyx_tuple__183;
  PyObject *__pyx_tuple__187;
  PyObject *__pyx_tuple__188;
  PyObject *__pyx_tuple__189;
  PyObject *__pyx_tuple__190;
  PyObject *__pyx_tuple__192;
  PyObject *__pyx_tuple__193;
  PyObject *__pyx_tuple__195;
  PyObject *__pyx_tuple__197;
  PyObject *__pyx_tuple__199;
  PyObject *__pyx_tuple__201;
  PyObject *__pyx_tuple__203;
  PyObject *__pyx_tuple__207;
  PyObject *__pyx_tuple__209;
  PyObject *__pyx_tuple__211;
  PyObject *__pyx_tuple__213;
  PyObject *__pyx_tuple__215;
  PyObject *__pyx_tuple__217;
  PyObject *__pyx_tuple__218;
  PyObject *__pyx_tuple__221;
  PyObject *__pyx_tuple__226;
  PyObject *__pyx_tuple__228;
  PyObject *__pyx_tuple__230;
  PyObject *__pyx_tuple__231;
  PyObject *__pyx_tuple__233;
  PyObject *__pyx_tuple__237;
  PyObject *__pyx_tuple__241;
  PyObject *__pyx_tuple__243;
  PyObject *__pyx_tuple__245;
  PyObject *__pyx_tuple__248;
  PyObject *__pyx_tuple__254;
  PyObject *__pyx_tuple__259;
  PyObject *__pyx_tuple__260;
  PyObject *__pyx_tuple__262;
  PyObject *__pyx_tuple__264;
  PyObject *__pyx_tuple__266;
  PyObject *__pyx_tuple__267;
  PyObject *__pyx_tuple__268;
  PyObject *__pyx_tuple__274;
  PyObject *__pyx_tuple__292;
  PyObject *__pyx_tuple__296;
  PyObject *__pyx_tuple__308;
  PyObject *__pyx_tuple__311;
  PyObject *__pyx_tuple__313;
  PyObject *__pyx_tuple__314;
  PyObject *__pyx_tuple__351;
  PyObject *__pyx_tuple__353;
  PyObject *__pyx_tuple__391;
  PyObject *__pyx_tuple__393;
  PyObject *__pyx_tuple__416;
  PyObject *__pyx_tuple__486;
  PyObject *__pyx_codeobj__22;
  PyObject *__pyx_codeobj__26;
  PyObject *__pyx_codeobj__191;
  PyObject *__pyx_codeobj__194;
  PyObject *__pyx_codeobj__196;
  PyObject *__pyx_codeobj__198;
  PyObject *__pyx_codeobj__200;
  PyObject *__pyx_codeobj__202;
  PyObject *__pyx_codeobj__204;
  PyObject *__pyx_codeobj__205;
  PyObject *__pyx_codeobj__206;
  PyObject *__pyx_codeobj__208;
  PyObject *__pyx_codeobj__210;
  PyObject *__pyx_codeobj__212;
  PyObject *__pyx_codeobj__214;
  PyObject *__pyx_codeobj__216;
  PyObject *__pyx_codeobj__219;
  PyObject *__pyx_codeobj__220;
  PyObject *__pyx_codeobj__222;
  PyObject *__pyx_codeobj__223;
  PyObject *__pyx_codeobj__224;
  PyObject *__pyx_codeobj__225;
  PyObject *__pyx_codeobj__227;
  PyObject *__pyx_codeobj__229;
  PyObject *__pyx_codeobj__232;
  PyObject *__pyx_codeobj__234;
  PyObject *__pyx_codeobj__235;
  PyObject *__pyx_codeobj__236;
  PyObject *__pyx_codeobj__238;
  PyObject *__pyx_codeobj__239;
  PyObject *__pyx_codeobj__240;
  PyObject *__pyx_codeobj__242;
  PyObject *__pyx_codeobj__244;
  PyObject *__pyx_codeobj__246;
  PyObject *__pyx_codeobj__247;
  PyObject *__pyx_codeobj__249;
  PyObject *__pyx_codeobj__250;
  PyObject *__pyx_codeobj__251;
  PyObject *__pyx_codeobj__252;
  PyObject *__pyx_codeobj__253;
  PyObject *__pyx_codeobj__255;
  PyObject *__pyx_codeobj__256;
  PyObject *__pyx_codeobj__257;
  PyObject *__pyx_codeobj__258;
  PyObject *__pyx_codeobj__261;
  PyObject *__pyx_codeobj__263;
  PyObject *__pyx_codeobj__265;
  PyObject *__pyx_codeobj__269;
  PyObject *__pyx_codeobj__270;
  PyObject *__pyx_codeobj__271;
  PyObject *__pyx_codeobj__272;
  PyObject *__pyx_codeobj__273;
  PyObject *__pyx_codeobj__275;
  PyObject *__pyx_codeobj__276;
  PyObject *__pyx_codeobj__277;
  PyObject *__pyx_codeobj__278;
  PyObject *__pyx_codeobj__279;
  PyObject *__pyx_codeobj__280;
  PyObject *__pyx_codeobj__281;
  PyObject *__pyx_codeobj__282;
  PyObject *__pyx_codeobj__283;
  PyObject *__pyx_codeobj__284;
  PyObject *__pyx_codeobj__285;
  PyObject *__pyx_codeobj__286;
  PyObject *__pyx_codeobj__287;
  PyObject *__pyx_codeobj__288;
  PyObject *__pyx_codeobj__289;
  PyObject *__pyx_codeobj__290;
  PyObject *__pyx_codeobj__291;
  PyObject *__pyx_codeobj__293;
  PyObject *__pyx_codeobj__294;
  PyObject *__pyx_codeobj__295;
  PyObject *__pyx_codeobj__297;
  PyObject *__pyx_codeobj__298;
  PyObject *__pyx_codeobj__299;
  PyObject *__pyx_codeobj__300;
  PyObject *__pyx_codeobj__301;
  PyObject *__pyx_codeobj__302;
  PyObject *__pyx_codeobj__303;
  PyObject *__pyx_codeobj__304;
  PyObject *__pyx_codeobj__305;
  PyObject *__pyx_codeobj__306;
  PyObject *__pyx_codeobj__307;
  PyObject *__pyx_codeobj__309;
  PyObject *__pyx_codeobj__310;
  PyObject *__pyx_codeobj__312;
  PyObject *__pyx_codeobj__315;
  PyObject *__pyx_codeobj__316;
  PyObject *__pyx_codeobj__317;
  PyObject *__pyx_codeobj__318;
  PyObject *__pyx_codeobj__319;
  PyObject *__pyx_codeobj__320;
  PyObject *__pyx_codeobj__321;
  PyObject *__pyx_codeobj__322;
  PyObject *__pyx_codeobj__323;
  PyObject *__pyx_codeobj__324;
  PyObject *__pyx_codeobj__325;
  PyObject *__pyx_codeobj__326;
  PyObject *__pyx_codeobj__327;
  PyObject *__pyx_codeobj__328;
  PyObject *__pyx_codeobj__329;
  PyObject *__pyx_codeobj__330;
  PyObject *__pyx_codeobj__331;
  PyObject *__pyx_codeobj__332;
  PyObject *__pyx_codeobj__333;
  PyObject *__pyx_codeobj__334;
  PyObject *__pyx_codeobj__335;
  PyObject *__pyx_codeobj__336;
  PyObject *__pyx_codeobj__337;
  PyObject *__pyx_codeobj__338;
  PyObject *__pyx_codeobj__339;
  PyObject *__pyx_codeobj__340;
  PyObject *__pyx_codeobj__341;
  PyObject *__pyx_codeobj__342;
  PyObject *__pyx_codeobj__343;
  PyObject *__pyx_codeobj__344;
  PyObject *__pyx_codeobj__345;
  PyObject *__pyx_codeobj__346;
  PyObject *__pyx_codeobj__347;
  PyObject *__pyx_codeobj__348;
  PyObject *__pyx_codeobj__349;
  PyObject *__pyx_codeobj__350;
  PyObject *__pyx_codeobj__352;
  PyObject *__pyx_codeobj__354;
  PyObject *__pyx_codeobj__355;
  PyObject *__pyx_codeobj__356;
  PyObject *__pyx_codeobj__357;
  PyObject *__pyx_codeobj__358;
  PyObject *__pyx_codeobj__359;
  PyObject *__pyx_codeobj__360;
  PyObject *__pyx_codeobj__361;
  PyObject *__pyx_codeobj__362;
  PyObject *__pyx_codeobj__363;
  PyObject *__pyx_codeobj__364;
  PyObject *__pyx_codeobj__365;
  PyObject *__pyx_codeobj__366;
  PyObject *__pyx_codeobj__367;
  PyObject *__pyx_codeobj__368;
  PyObject *__pyx_codeobj__369;
  PyObject *__pyx_codeobj__370;
  PyObject *__pyx_codeobj__371;
  PyObject *__pyx_codeobj__372;
  PyObject *__pyx_codeobj__373;
  PyObject *__pyx_codeobj__374;
  PyObject *__pyx_codeobj__375;
  PyObject *__pyx_codeobj__376;
  PyObject *__pyx_codeobj__377;
  PyObject *__pyx_codeobj__378;
  PyObject *__pyx_codeobj__379;
  PyObject *__pyx_codeobj__380;
  PyObject *__pyx_codeobj__381;
  PyObject *__pyx_codeobj__382;
  PyObject *__pyx_codeobj__383;
  PyObject *__pyx_codeobj__384;
  PyObject *__pyx_codeobj__385;
  PyObject *__pyx_codeobj__386;
  PyObject *__pyx_codeobj__387;
  PyObject *__pyx_codeobj__388;
  PyObject *__pyx_codeobj__389;
  PyObject *__pyx_codeobj__390;
  PyObject *__pyx_codeobj__392;
  PyObject *__pyx_codeobj__394;
  PyObject *__pyx_codeobj__395;
  PyObject *__pyx_codeobj__396;
  PyObject *__pyx_codeobj__397;
  PyObject *__pyx_codeobj__398;
  PyObject *__pyx_codeobj__399;
  PyObject *__pyx_codeobj__400;
  PyObject *__pyx_codeobj__401;
  PyObject *__pyx_codeobj__402;
  PyObject *__pyx_codeobj__403;
  PyObject *__pyx_codeobj__404;
  PyObject *__pyx_codeobj__405;
  PyObject *__pyx_codeobj__406;
  PyObject *__pyx_codeobj__407;
  PyObject *__pyx_codeobj__408;
  PyObject *__pyx_codeobj__409;
  PyObject *__pyx_codeobj__410;
  PyObject *__pyx_codeobj__411;
  PyObject *__pyx_codeobj__412;
  PyObject *__pyx_codeobj__413;
  PyObject *__pyx_codeobj__414;
  PyObject *__pyx_codeobj__415;
  PyObject *__pyx_codeobj__417;
  PyObject *__pyx_codeobj__418;
  PyObject *__pyx_codeobj__419;
  PyObject *__pyx_codeobj__420;
  PyObject *__pyx_codeobj__421;
  PyObject *__pyx_codeobj__422;
  PyObject *__pyx_codeobj__423;
  PyObject *__pyx_codeobj__424;
  PyObject *__pyx_codeobj__425;
  PyObject *__pyx_codeobj__426;
  PyObject *__pyx_codeobj__427;
  PyObject *__pyx_codeobj__428;
  PyObject *__pyx_codeobj__429;
  PyObject *__pyx_codeobj__430;
  PyObject *__pyx_codeobj__431;
  PyObject *__pyx_codeobj__432;
  PyObject *__pyx_codeobj__433;
  PyObject *__pyx_codeobj__434;
  PyObject *__pyx_codeobj__435;
  PyObject *__pyx_codeobj__436;
  PyObject *__pyx_codeobj__437;
  PyObject *__pyx_codeobj__438;
  PyObject *__pyx_codeobj__439;
  PyObject *__pyx_codeobj__440;
  PyObject *__pyx_codeobj__441;
  PyObject *__pyx_codeobj__442;
  PyObject *__pyx_codeobj__443;
  PyObject *__pyx_codeobj__444;
  PyObject *__pyx_codeobj__445;
  PyObject *__pyx_codeobj__446;
  PyObject *__pyx_codeobj__447;
  PyObject *__pyx_codeobj__448;
  PyObject *__pyx_codeobj__449;
  PyObject *__pyx_codeobj__450;
  PyObject *__pyx_codeobj__451;
  PyObject *__pyx_codeobj__452;
  PyObject *__pyx_codeobj__453;
  PyObject *__pyx_codeobj__454;
  PyObject *__pyx_codeobj__455;
  PyObject *__pyx_codeobj__456;
  PyObject *__pyx_codeobj__457;
  PyObject *__pyx_codeobj__458;
  PyObject *__pyx_codeobj__459;
  PyObject *__pyx_codeobj__460;
  PyObject *__pyx_codeobj__461;
  PyObject *__pyx_codeobj__462;
  PyObject *__pyx_codeobj__463;
  PyObject *__pyx_codeobj__464;
  PyObject *__pyx_codeobj__465;
  PyObject *__pyx_codeobj__466;
  PyObject *__pyx_codeobj__467;
  PyObject *__pyx_codeobj__468;
  PyObject *__pyx_codeobj__469;
  PyObject *__pyx_codeobj__470;
  PyObject *__pyx_codeobj__471;
  PyObject *__pyx_codeobj__472;
  PyObject *__pyx_codeobj__473;
  PyObject *__pyx_codeobj__474;
  PyObject *__pyx_codeobj__475;
  PyObject *__pyx_codeobj__476;
  PyObject *__pyx_codeobj__477;
  PyObject *__pyx_codeobj__478;
  PyObject *__pyx_codeobj__479;
  PyObject *__pyx_codeobj__480;
  PyObject *__pyx_codeobj__481;
  PyObject *__pyx_codeobj__482;
  PyObject *__pyx_codeobj__483;
  PyObject *__pyx_codeobj__484;
  PyObject *__pyx_codeobj__485;
  PyObject *__pyx_codeobj__487;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter);
  Py_CLEAR(clear_module_state->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter);
  Py_CLEAR(clear_module_state->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator);
  Py_CLEAR(clear_module_state->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator);
  Py_CLEAR(clear_module_state->__pyx_kp_u_);
  Py_CLEAR(clear_module_state->__pyx_kp_s_12h);
  Py_CLEAR(clear_module_state->__pyx_kp_s_15m);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1M);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1h);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1m);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1s);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1w);
  Py_CLEAR(clear_module_state->__pyx_kp_s_22);
  Py_CLEAR(clear_module_state->__pyx_kp_s_27);
  Py_CLEAR(clear_module_state->__pyx_kp_s_2_0_0);
  Py_CLEAR(clear_module_state->__pyx_kp_s_2h);
  Py_CLEAR(clear_module_state->__pyx_kp_s_30m);
  Py_CLEAR(clear_module_state->__pyx_kp_s_3d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_3m);
  Py_CLEAR(clear_module_state->__pyx_kp_s_4h);
  Py_CLEAR(clear_module_state->__pyx_kp_s_5m);
  Py_CLEAR(clear_module_state->__pyx_kp_s_6h);
  Py_CLEAR(clear_module_state->__pyx_kp_s_8h);
  Py_CLEAR(clear_module_state->__pyx_n_s_ACK);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_BEST_MATCH);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_BUYER_MAKES);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_FIRST_TRADE_ID);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_ID);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_LAST_TRADE_ID);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_PRICE);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_QUANTITY);
  Py_CLEAR(clear_module_state->__pyx_n_s_AGG_TIME);
  Py_CLEAR(clear_module_state->__pyx_n_s_API_KEY);
  Py_CLEAR(clear_module_state->__pyx_n_s_API_SECRET);
  Py_CLEAR(clear_module_state->__pyx_n_s_API_URL);
  Py_CLEAR(clear_module_state->__pyx_n_s_Accept);
  Py_CLEAR(clear_module_state->__pyx_kp_u_An_exception_occurred);
  Py_CLEAR(clear_module_state->__pyx_kp_s_An_unofficial_Python_API_to_use);
  Py_CLEAR(clear_module_state->__pyx_n_s_BUY);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceAPIException);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRequestException);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager___enter);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager___exit);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__create_ap);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__create_fu);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__create_fu_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__create_fu_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__create_fu_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__create_ma);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__create_we);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__delete);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__generate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__get);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__get_earli);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__handle_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__init_sess);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__order_par);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__post);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__put);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_f);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_f_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_f_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_f_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager__request_w);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_aggregate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_cancel_all);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_cancel_all_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_cancel_mar);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_cancel_mar_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_cancel_ord);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_change_fix);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_iso);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_mar);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_mar_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_mar_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_oco);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_ord);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_create_tes);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_disable_fa);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_enable_fas);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_enable_sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_enable_sub_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ag);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_au);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ca);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ca_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ca_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_10);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_11);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_12);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_13);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_14);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_15);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_16);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_17);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_18);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_19);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_20);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_21);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_22);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_23);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_24);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_25);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_26);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_27);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_28);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_29);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_30);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_31);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_32);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_33);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_34);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_35);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_36);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_37);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_38);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_39);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_40);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_41);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_42);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_43);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_9);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_cr);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_fu);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_hi);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_kl);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_le);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_li);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ma);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_op);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_op_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_or);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_or_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_pi);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_pl);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_po);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_po_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_st);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_st_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_st_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_sy);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ti);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_futures_ti_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_aggreg);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_all_co);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_all_is);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_all_ma);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_all_or);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_all_ti);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_asset);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_asset_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_asset_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_avg_pr);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_bnb_bu);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_deposi);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_deposi_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_dust_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_exchan);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_fixed);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_histor);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_histor_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_histor_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_isolat);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_isolat_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_latest);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_latest_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_9);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_max_ma);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_max_ma_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_my_tra);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_open_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_open_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_open_m_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_open_o);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_order_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_orderb);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_orderb_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_produc);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_recent);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_server);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_9);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_symbol_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_system);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_trade);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_univer);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_used_w);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_user_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_versio);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_withdr);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_get_withdr_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_is_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_isolated_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_isolated_m_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_isolated_m_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_make_subac);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_make_subac_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_make_subac_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_make_subac_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_make_unive);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_margin_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_margin_str_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_margin_str_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_new_transf);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_limi);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_limi_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_limi_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_mark);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_mark_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_mark_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_oco);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_order_oco_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_ping);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_purchase_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_query_suba);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_query_univ);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_redeem_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_repay_marg);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_stop_manag);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_stream_clo);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_stream_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_stream_kee);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_toggle_bnb);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_transfer_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_transfer_h);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_transfer_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_transfer_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_transfer_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_transfer_s_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_universal);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceRestApiManager_withdraw);
  Py_CLEAR(clear_module_state->__pyx_kp_s_BinanceWebSocketApiManager_stop);
  Py_CLEAR(clear_module_state->__pyx_n_s_BinanceWithdrawException);
  Py_CLEAR(clear_module_state->__pyx_n_s_C2C_MAIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_C2C_MINING);
  Py_CLEAR(clear_module_state->__pyx_n_s_C2C_UMFUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_CANCELED);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMFUTURE_MAIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_COIN_FUTURE_TO_SPOT);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Created_SOCKS5_proxy_URI);
  Py_CLEAR(clear_module_state->__pyx_n_s_Date);
  Py_CLEAR(clear_module_state->__pyx_n_s_EXPIRED);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Entering_with_context);
  Py_CLEAR(clear_module_state->__pyx_n_s_FIAT_TO_MINING);
  Py_CLEAR(clear_module_state->__pyx_n_s_FIAT_TO_SPOT);
  Py_CLEAR(clear_module_state->__pyx_n_s_FIAT_TO_USDT_FUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_FILLED);
  Py_CLEAR(clear_module_state->__pyx_n_s_FOK);
  Py_CLEAR(clear_module_state->__pyx_n_s_FULL);
  Py_CLEAR(clear_module_state->__pyx_n_s_FUTURES_API_VERSION);
  Py_CLEAR(clear_module_state->__pyx_n_s_FUTURES_API_VERSION2);
  Py_CLEAR(clear_module_state->__pyx_n_s_FUTURES_COIN_DATA_URL);
  Py_CLEAR(clear_module_state->__pyx_n_s_FUTURES_COIN_URL);
  Py_CLEAR(clear_module_state->__pyx_n_s_FUTURES_DATA_URL);
  Py_CLEAR(clear_module_state->__pyx_n_s_FUTURES_URL);
  Py_CLEAR(clear_module_state->__pyx_n_s_GTC);
  Py_CLEAR(clear_module_state->__pyx_n_s_IOC);
  Py_CLEAR(clear_module_state->__pyx_n_s_ISOLATED_MARGIN);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Initiating_colorama);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Invalid_Response_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_12HOUR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_15MINUTE);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_1DAY);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_1HOUR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_1MINUTE);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_1MONTH);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_1SECOND);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_1WEEK);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_2HOUR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_30MINUTE);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_3DAY);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_3MINUTE);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_4HOUR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_5MINUTE);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_6HOUR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KLINE_INTERVAL_8HOUR);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyError);
  Py_CLEAR(clear_module_state->__pyx_n_s_LIMIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_LIMIT_MAKER);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Leaving_with_context);
  Py_CLEAR(clear_module_state->__pyx_n_s_LucitLicensingManager);
  Py_CLEAR(clear_module_state->__pyx_n_s_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_MAIN_C2C);
  Py_CLEAR(clear_module_state->__pyx_n_s_MAIN_CMFUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_MAIN_MARGIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_MAIN_MINING);
  Py_CLEAR(clear_module_state->__pyx_n_s_MAIN_UMFUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_MARGIN_API_URL);
  Py_CLEAR(clear_module_state->__pyx_n_s_MARGIN_API_VERSION);
  Py_CLEAR(clear_module_state->__pyx_n_s_MARGIN_CROSS_TO_SPOT);
  Py_CLEAR(clear_module_state->__pyx_n_s_MARGIN_CROSS_TO_USDT_FUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_MARGIN_MAIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_MARGIN_UMFUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_MARKET);
  Py_CLEAR(clear_module_state->__pyx_n_s_MINING_C2C);
  Py_CLEAR(clear_module_state->__pyx_n_s_MINING_MAIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_MINING_TO_FIAT);
  Py_CLEAR(clear_module_state->__pyx_n_s_MINING_TO_SPOT);
  Py_CLEAR(clear_module_state->__pyx_n_s_MINING_TO_USDT_FUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_MINING_UMFUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_NEW);
  Py_CLEAR(clear_module_state->__pyx_kp_u_New_instance_of);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_RESP_TYPE_ACK);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_RESP_TYPE_FULL);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_RESP_TYPE_RESULT);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_STATUS_CANCELED);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_STATUS_EXPIRED);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_STATUS_FILLED);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_STATUS_NEW);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_STATUS_PARTIALLY_FILLED);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_STATUS_PENDING_CANCEL);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_STATUS_REJECTED);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_TYPE_LIMIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_TYPE_LIMIT_MAKER);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_TYPE_MARKET);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_TYPE_STOP_LOSS);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_TYPE_STOP_LOSS_LIMIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_TYPE_TAKE_PROFIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_ORDER_TYPE_TAKE_PROFIT_LIMIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_Optional);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Optional_bool);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Optional_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_PARTIALLY_FILLED);
  Py_CLEAR(clear_module_state->__pyx_n_s_PENDING_CANCEL);
  Py_CLEAR(clear_module_state->__pyx_n_s_PRIVATE_API_VERSION);
  Py_CLEAR(clear_module_state->__pyx_n_s_PUBLIC_API_VERSION);
  Py_CLEAR(clear_module_state->__pyx_n_s_REJECTED);
  Py_CLEAR(clear_module_state->__pyx_n_s_RESULT);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Read_the_docs_to_see_a_list_of);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Release);
  Py_CLEAR(clear_module_state->__pyx_n_s_SELL);
  Py_CLEAR(clear_module_state->__pyx_n_s_SIDE_BUY);
  Py_CLEAR(clear_module_state->__pyx_n_s_SIDE_SELL);
  Py_CLEAR(clear_module_state->__pyx_n_s_SPOT);
  Py_CLEAR(clear_module_state->__pyx_n_s_SPOT_TO_COIN_FUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_SPOT_TO_FIAT);
  Py_CLEAR(clear_module_state->__pyx_n_s_SPOT_TO_MARGIN_CROSS);
  Py_CLEAR(clear_module_state->__pyx_n_s_SPOT_TO_MINING);
  Py_CLEAR(clear_module_state->__pyx_n_s_SPOT_TO_USDT_FUTURE);
  Py_CLEAR(clear_module_state->__pyx_n_s_STOP_LOSS);
  Py_CLEAR(clear_module_state->__pyx_n_s_STOP_LOSS_LIMIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_SYMBOL_TYPE_SPOT);
  Py_CLEAR(clear_module_state->__pyx_n_s_T);
  Py_CLEAR(clear_module_state->__pyx_n_s_TAKE_PROFIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_TAKE_PROFIT_LIMIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_TIME_IN_FORCE_FOK);
  Py_CLEAR(clear_module_state->__pyx_n_s_TIME_IN_FORCE_GTC);
  Py_CLEAR(clear_module_state->__pyx_n_s_TIME_IN_FORCE_IOC);
  Py_CLEAR(clear_module_state->__pyx_kp_s_The_parameter_BinanceRestApiMana);
  Py_CLEAR(clear_module_state->__pyx_kp_s_There_is_no_entry_with_withdraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_UMFUTURE_C2C);
  Py_CLEAR(clear_module_state->__pyx_n_s_UMFUTURE_MAIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_UMFUTURE_MARGIN);
  Py_CLEAR(clear_module_state->__pyx_kp_s_UNICORN_BINANCE_SUITE);
  Py_CLEAR(clear_module_state->__pyx_n_s_USDT_FUTURE_TO_FIAT);
  Py_CLEAR(clear_module_state->__pyx_n_s_USDT_FUTURE_TO_MARGIN_CROSS);
  Py_CLEAR(clear_module_state->__pyx_n_s_USDT_FUTURE_TO_SPOT);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnknownExchange);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unknown_exchange);
  Py_CLEAR(clear_module_state->__pyx_kp_s_User_Agent);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s_WEBSITE_URL);
  Py_CLEAR(clear_module_state->__pyx_kp_s_X_MBX_APIKEY);
  Py_CLEAR(clear_module_state->__pyx_kp_s_X_MBX_USED_WEIGHT);
  Py_CLEAR(clear_module_state->__pyx_kp_s__184);
  Py_CLEAR(clear_module_state->__pyx_kp_u__185);
  Py_CLEAR(clear_module_state->__pyx_n_s__186);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_kp_s__3);
  Py_CLEAR(clear_module_state->__pyx_kp_u__3);
  Py_CLEAR(clear_module_state->__pyx_kp_s__4);
  Py_CLEAR(clear_module_state->__pyx_n_s__488);
  Py_CLEAR(clear_module_state->__pyx_n_u__5);
  Py_CLEAR(clear_module_state->__pyx_kp_u__6);
  Py_CLEAR(clear_module_state->__pyx_kp_s__7);
  Py_CLEAR(clear_module_state->__pyx_kp_s__8);
  Py_CLEAR(clear_module_state->__pyx_kp_s__9);
  Py_CLEAR(clear_module_state->__pyx_n_s_a);
  Py_CLEAR(clear_module_state->__pyx_kp_s_a_d_b_Y_I_M_S_Z);
  Py_CLEAR(clear_module_state->__pyx_n_s_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_accountSnapshot);
  Py_CLEAR(clear_module_state->__pyx_kp_s_account_apiTradingStatus);
  Py_CLEAR(clear_module_state->__pyx_kp_s_account_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_aggTrades);
  Py_CLEAR(clear_module_state->__pyx_n_s_aggregate_trade_iter);
  Py_CLEAR(clear_module_state->__pyx_n_s_allForceOrders);
  Py_CLEAR(clear_module_state->__pyx_n_s_allOpenOrders);
  Py_CLEAR(clear_module_state->__pyx_n_s_allOrders);
  Py_CLEAR(clear_module_state->__pyx_n_s_api_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_api_secret);
  Py_CLEAR(clear_module_state->__pyx_kp_s_application_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_asset);
  Py_CLEAR(clear_module_state->__pyx_kp_s_asset_assetDetail);
  Py_CLEAR(clear_module_state->__pyx_kp_s_asset_assetDividend);
  Py_CLEAR(clear_module_state->__pyx_kp_s_asset_dribblet);
  Py_CLEAR(clear_module_state->__pyx_kp_s_asset_dust);
  Py_CLEAR(clear_module_state->__pyx_kp_s_asset_tradeFee);
  Py_CLEAR(clear_module_state->__pyx_kp_s_asset_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_avgPrice);
  Py_CLEAR(clear_module_state->__pyx_n_s_bal);
  Py_CLEAR(clear_module_state->__pyx_n_s_balance);
  Py_CLEAR(clear_module_state->__pyx_n_s_balances);
  Py_CLEAR(clear_module_state->__pyx_n_s_batchOrders);
  Py_CLEAR(clear_module_state->__pyx_n_s_binance_api_status);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_coin_futures);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_futures);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_futures_testnet);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_isolated_margin);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_isolated_margin_test);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_margin);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_margin_testnet);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_com_testnet);
  Py_CLEAR(clear_module_state->__pyx_kp_s_binance_us);
  Py_CLEAR(clear_module_state->__pyx_n_s_bnbBurn);
  Py_CLEAR(clear_module_state->__pyx_n_s_cancel_all_open_margin_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_cancel_all_open_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_cancel_margin_oco_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_cancel_margin_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_cancel_order);
  Py_CLEAR(clear_module_state->__pyx_kp_s_capital_config_getall);
  Py_CLEAR(clear_module_state->__pyx_kp_s_capital_deposit_address);
  Py_CLEAR(clear_module_state->__pyx_kp_s_capital_deposit_hisrec);
  Py_CLEAR(clear_module_state->__pyx_kp_s_capital_deposit_subAddress);
  Py_CLEAR(clear_module_state->__pyx_kp_s_capital_deposit_subHisrec);
  Py_CLEAR(clear_module_state->__pyx_kp_s_capital_withdraw_apply);
  Py_CLEAR(clear_module_state->__pyx_kp_s_capital_withdraw_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_change_fixed_activity_to_daily_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_close_api_session);
  Py_CLEAR(clear_module_state->__pyx_n_s_colorama);
  Py_CLEAR(clear_module_state->__pyx_n_s_commissionRate);
  Py_CLEAR(clear_module_state->__pyx_kp_u_compiled_on);
  Py_CLEAR(clear_module_state->__pyx_n_s_continuousKlines);
  Py_CLEAR(clear_module_state->__pyx_n_s_countdownCancelAll);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_api_uri);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_futures_api_uri);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_futures_coin_api_url);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_futures_coin_data_api_ur);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_futures_data_api_uri);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_isolated_margin_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_margin_api_uri);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_margin_loan);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_margin_oco_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_margin_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_oco_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_sub_account_futures_trans);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_test_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_create_website_uri);
  Py_CLEAR(clear_module_state->__pyx_n_s_critical);
  Py_CLEAR(clear_module_state->__pyx_n_s_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_date_time_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_date_to_milliseconds);
  Py_CLEAR(clear_module_state->__pyx_n_s_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_debug);
  Py_CLEAR(clear_module_state->__pyx_n_s_delete);
  Py_CLEAR(clear_module_state->__pyx_n_s_delete_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_depth);
  Py_CLEAR(clear_module_state->__pyx_kp_s_dev);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_disableFastWithdrawSwitch);
  Py_CLEAR(clear_module_state->__pyx_n_s_disable_colorama);
  Py_CLEAR(clear_module_state->__pyx_n_s_disable_fast_withdraw_switch);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_enableFastWithdrawSwitch);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_fast_withdraw_switch);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_subaccount_futures);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_subaccount_margin);
  Py_CLEAR(clear_module_state->__pyx_n_s_encode);
  Py_CLEAR(clear_module_state->__pyx_n_s_endTime);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_ts);
  Py_CLEAR(clear_module_state->__pyx_n_s_enter);
  Py_CLEAR(clear_module_state->__pyx_n_s_entry);
  Py_CLEAR(clear_module_state->__pyx_n_s_enumerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_error_msg);
  Py_CLEAR(clear_module_state->__pyx_n_s_error_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_exc_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_exc_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_exceptions);
  Py_CLEAR(clear_module_state->__pyx_n_s_exchange);
  Py_CLEAR(clear_module_state->__pyx_n_s_exchangeInfo);
  Py_CLEAR(clear_module_state->__pyx_kp_u_exchange_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_exchange_api_v1_public_asset_ser);
  Py_CLEAR(clear_module_state->__pyx_n_s_exit);
  Py_CLEAR(clear_module_state->__pyx_n_s_f);
  Py_CLEAR(clear_module_state->__pyx_n_s_first_valid_ts);
  Py_CLEAR(clear_module_state->__pyx_kp_u_for_exchange);
  Py_CLEAR(clear_module_state->__pyx_n_s_force_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_fromId);
  Py_CLEAR(clear_module_state->__pyx_n_s_fundingRate);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_account_balance);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_account_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_account_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_aggregate_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_auto_cancel_all_open_ord);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_cancel_all_open_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_cancel_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_cancel_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_change_leverage);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_change_margin_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_change_position_margin);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_change_position_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_account_balance);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_account_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_aggregate_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_cancel_all_open_ord);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_cancel_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_cancel_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_change_leverage);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_change_margin_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_change_position_mar);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_change_position_mod);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_continous_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_create_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_exchange_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_funding_rate);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_get_all_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_get_open_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_get_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_get_position_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_historical_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_income_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_index_price_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_leverage_bracket);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_liquidation_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_mark_price);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_mark_price_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_open_interest);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_open_interest_hist);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_order_book);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_orderbook_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_ping);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_place_batch_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_position_informatio);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_position_margin_his);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_recent_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_stream_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_stream_get_listen_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_stream_keepalive);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_symbol_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_coin_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_commission_rate);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_create_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_exchange_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_funding_rate);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_get_all_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_get_open_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_get_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_get_position_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_historical_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_income_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_leverage_bracket);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_liquidation_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_mark_price);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_open_interest);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_open_interest_hist);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_order_book);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_orderbook_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_ping);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_place_batch_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_position_information);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_position_margin_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_recent_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_stream_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_stream_get_listen_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_stream_keepalive);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_symbol_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_futures_time);
  Py_CLEAR(clear_module_state->__pyx_kp_s_futures_transfer);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_generate_signature);
  Py_CLEAR(clear_module_state->__pyx_n_s_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_getLogger);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_account_api_trading_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_account_snapshot);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_account_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_aggregate_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_all_coins_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_all_isolated_margin_symbols);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_all_margin_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_all_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_all_tickers);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_asset_balance);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_asset_details);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_asset_dividend_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_avg_price);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_bnb_burn_spot_margin);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_deposit_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_deposit_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dust_log);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_earliest_valid_timestamp);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_exchange_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_fixed_activity_project_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_historical_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_historical_klines_generator);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_historical_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_isolated_margin_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_isolated_margin_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_latest_release_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_latest_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_daily_quota_left);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_daily_redemption_quo);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_interest_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_position);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_product_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_purchase_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lending_redemption_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_account);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_asset);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_loan_details);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_oco_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_price_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_repay_details);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_margin_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_max_margin_loan);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_max_margin_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_my_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_open_isolated_margin_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_open_margin_oco_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_open_margin_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_open_orders);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_order_book);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_orderbook_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_orderbook_tickers);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_products);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_recent_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_server_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_sub_account_assets);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_sub_account_futures_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_sub_account_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_sub_account_transfer_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_deposit_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_deposit_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_futures_details);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_futures_margin_st);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_futures_positionr);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_futures_summary);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_margin_details);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_margin_summary);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_subaccount_transfer_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_symbol_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_symbol_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_system_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_ticker);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_trade_fee);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_universal_transfer_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_used_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_user_agent);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_withdraw_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_withdraw_history_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_handle_response);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_signature);
  Py_CLEAR(clear_module_state->__pyx_n_s_hashlib);
  Py_CLEAR(clear_module_state->__pyx_n_s_headers);
  Py_CLEAR(clear_module_state->__pyx_n_s_helpers);
  Py_CLEAR(clear_module_state->__pyx_n_s_hexdigest);
  Py_CLEAR(clear_module_state->__pyx_n_s_historicalTrades);
  Py_CLEAR(clear_module_state->__pyx_n_s_hmac);
  Py_CLEAR(clear_module_state->__pyx_n_s_http);
  Py_CLEAR(clear_module_state->__pyx_n_s_https);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_binance_api);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_binance_com_api);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_binance_com_sapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_binance_sapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_binance_us_api);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_binance_us_sapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_github_com_repos_LUCIT);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_api_trbinance_com_sapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_dapi_binance_com_futures_d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_dapi_binance_futures_data);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_dapi_binance_us_futures_da);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_dapi_trbinance_com_futures);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_binance_com_fapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_binance_com_futures_d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_binance_fapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_binance_futures_data);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_binance_us_fapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_binance_us_futures_da);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_trbinance_com_fapi);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_fapi_trbinance_com_futures);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_testnet_binance_vision);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_testnet_binance_vision_api);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_testnet_binancefuture_com);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_testnet_binancefuture_com_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_testnet_binancefuture_com_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_www_binance);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_www_binance_com);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_www_binance_us);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_www_trbinance_com);
  Py_CLEAR(clear_module_state->__pyx_kp_s_https_www_trbinance_com_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_idx);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_income);
  Py_CLEAR(clear_module_state->__pyx_n_s_indexPriceKlines);
  Py_CLEAR(clear_module_state->__pyx_n_s_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_session);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_installed_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_interval);
  Py_CLEAR(clear_module_state->__pyx_n_s_interval_to_milliseconds);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_available_please_consider_up);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_update_availabe);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_isolated_margin_stream_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_isolated_margin_stream_get_liste);
  Py_CLEAR(clear_module_state->__pyx_n_s_isolated_margin_stream_keepalive);
  Py_CLEAR(clear_module_state->__pyx_n_s_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_itemgetter);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_join);
  Py_CLEAR(clear_module_state->__pyx_n_s_json);
  Py_CLEAR(clear_module_state->__pyx_n_s_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_kline);
  Py_CLEAR(clear_module_state->__pyx_n_s_klines);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_last_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_last_update_check_github);
  Py_CLEAR(clear_module_state->__pyx_n_s_latest_release_info);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_daily_product_list);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_daily_purchase);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_daily_redeem);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_daily_token_position);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_daily_userLeftQuota);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_daily_userRedemptionQuot);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_positionChanged);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_project_list);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_union_account);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_union_interestHistory);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_union_purchaseRecord);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lending_union_redemptionRecord);
  Py_CLEAR(clear_module_state->__pyx_n_s_leverage);
  Py_CLEAR(clear_module_state->__pyx_n_s_leverageBracket);
  Py_CLEAR(clear_module_state->__pyx_n_s_license_ini);
  Py_CLEAR(clear_module_state->__pyx_n_s_license_profile);
  Py_CLEAR(clear_module_state->__pyx_n_s_license_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_limit);
  Py_CLEAR(clear_module_state->__pyx_n_s_listenKey);
  Py_CLEAR(clear_module_state->__pyx_n_s_llm);
  Py_CLEAR(clear_module_state->__pyx_n_s_logger);
  Py_CLEAR(clear_module_state->__pyx_n_s_logging);
  Py_CLEAR(clear_module_state->__pyx_n_s_lower);
  Py_CLEAR(clear_module_state->__pyx_n_s_lucit_api_secret);
  Py_CLEAR(clear_module_state->__pyx_n_s_lucit_license_ini);
  Py_CLEAR(clear_module_state->__pyx_n_s_lucit_license_profile);
  Py_CLEAR(clear_module_state->__pyx_n_s_lucit_license_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_lucit_licensing_python_manager);
  Py_CLEAR(clear_module_state->__pyx_n_s_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_new_request);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_subaccount_futures_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_subaccount_margin_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_subaccount_to_master_transf);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_subaccount_to_subaccount_tr);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_universal_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_marginType);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_account);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_allOrderList);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_allOrders);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_asset);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_isolated_account);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_isolated_allPairs);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_isolated_create);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_isolated_pair);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_isolated_transfer);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_loan);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_maxBorrowable);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_maxTransferable);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_myTrades);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_openOrders);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_order);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_orderList);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_order_oco);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_pair);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_priceIndex);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_repay);
  Py_CLEAR(clear_module_state->__pyx_n_s_margin_stream_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_margin_stream_get_listen_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_margin_stream_keepalive);
  Py_CLEAR(clear_module_state->__pyx_kp_s_margin_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_markPriceKlines);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_method);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro_entries);
  Py_CLEAR(clear_module_state->__pyx_n_s_msg);
  Py_CLEAR(clear_module_state->__pyx_n_s_myTrades);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_needed_license_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_new_transfer_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_null_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_o);
  Py_CLEAR(clear_module_state->__pyx_n_s_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_openInterest);
  Py_CLEAR(clear_module_state->__pyx_n_s_openInterestHist);
  Py_CLEAR(clear_module_state->__pyx_n_s_openOrders);
  Py_CLEAR(clear_module_state->__pyx_n_s_operator);
  Py_CLEAR(clear_module_state->__pyx_n_s_options);
  Py_CLEAR(clear_module_state->__pyx_n_s_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_limit);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_limit_buy);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_limit_sell);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_market);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_market_buy);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_market_sell);
  Py_CLEAR(clear_module_state->__pyx_kp_s_order_oco);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_oco_buy);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_oco_sell);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_params);
  Py_CLEAR(clear_module_state->__pyx_kp_s_order_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_ordered_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_output);
  Py_CLEAR(clear_module_state->__pyx_n_s_output_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_parent_shutdown_function);
  Py_CLEAR(clear_module_state->__pyx_n_s_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_ping);
  Py_CLEAR(clear_module_state->__pyx_n_s_platform);
  Py_CLEAR(clear_module_state->__pyx_n_s_positionMargin);
  Py_CLEAR(clear_module_state->__pyx_kp_s_positionMargin_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_positionRisk);
  Py_CLEAR(clear_module_state->__pyx_kp_s_positionSide_dual);
  Py_CLEAR(clear_module_state->__pyx_n_s_post);
  Py_CLEAR(clear_module_state->__pyx_n_s_post_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_premiumIndex);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_s_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_products);
  Py_CLEAR(clear_module_state->__pyx_n_s_program_used);
  Py_CLEAR(clear_module_state->__pyx_n_s_proxies);
  Py_CLEAR(clear_module_state->__pyx_n_s_purchase_lending_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_put);
  Py_CLEAR(clear_module_state->__pyx_n_s_put_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_python);
  Py_CLEAR(clear_module_state->__pyx_n_s_python_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_q);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_query_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_query_subaccount_spot_summary);
  Py_CLEAR(clear_module_state->__pyx_n_s_query_universal_transfer_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_raw_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_redeem_lending_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_release);
  Py_CLEAR(clear_module_state->__pyx_n_s_repay_margin_loan);
  Py_CLEAR(clear_module_state->__pyx_n_s_replace);
  Py_CLEAR(clear_module_state->__pyx_n_s_request);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_futures_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_futures_coin_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_futures_coin_data_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_futures_data_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_margin_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_socks5_proxies);
  Py_CLEAR(clear_module_state->__pyx_n_s_request_website);
  Py_CLEAR(clear_module_state->__pyx_n_s_requests);
  Py_CLEAR(clear_module_state->__pyx_n_s_requests_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_requests_params_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_res);
  Py_CLEAR(clear_module_state->__pyx_n_s_respond);
  Py_CLEAR(clear_module_state->__pyx_n_s_response);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_reversed);
  Py_CLEAR(clear_module_state->__pyx_kp_s_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_kp_u_self_API_URL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_self_FUTURES_COIN_DATA_URL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_self_FUTURES_COIN_URL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_self_FUTURES_DATA_URL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_self_FUTURES_URL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_self_MARGIN_API_URL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_self_WEBSITE_URL);
  Py_CLEAR(clear_module_state->__pyx_n_s_send);
  Py_CLEAR(clear_module_state->__pyx_n_s_serverTime);
  Py_CLEAR(clear_module_state->__pyx_n_s_session);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_sha256);
  Py_CLEAR(clear_module_state->__pyx_n_s_side);
  Py_CLEAR(clear_module_state->__pyx_n_s_signature);
  Py_CLEAR(clear_module_state->__pyx_n_s_signed);
  Py_CLEAR(clear_module_state->__pyx_n_s_sleep);
  Py_CLEAR(clear_module_state->__pyx_kp_s_socks5);
  Py_CLEAR(clear_module_state->__pyx_n_s_socks5_proxy_address);
  Py_CLEAR(clear_module_state->__pyx_n_s_socks5_proxy_pass);
  Py_CLEAR(clear_module_state->__pyx_n_s_socks5_proxy_port);
  Py_CLEAR(clear_module_state->__pyx_n_s_socks5_proxy_server);
  Py_CLEAR(clear_module_state->__pyx_n_s_socks5_proxy_ssl_verification);
  Py_CLEAR(clear_module_state->__pyx_n_s_socks5_proxy_user);
  Py_CLEAR(clear_module_state->__pyx_n_s_socks_proxy_uri);
  Py_CLEAR(clear_module_state->__pyx_n_s_sort);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_startTime);
  Py_CLEAR(clear_module_state->__pyx_n_s_start_str);
  Py_CLEAR(clear_module_state->__pyx_kp_s_start_time_and_last_id_may_not_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_start_ts);
  Py_CLEAR(clear_module_state->__pyx_kp_u_started);
  Py_CLEAR(clear_module_state->__pyx_n_s_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_status_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop_manager);
  Py_CLEAR(clear_module_state->__pyx_n_s_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_stream_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_stream_get_listen_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_stream_keepalive);
  Py_CLEAR(clear_module_state->__pyx_n_s_strptime);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_assets);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_futures_account);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_futures_accountSumma);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_futures_enable);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_futures_internalTran);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_futures_positionRisk);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_futures_transfer);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_list);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_margin_account);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_margin_accountSummar);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_margin_enable);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_margin_transfer);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_spotSummary);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_status);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_sub_transfer_history);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_transfer_subToMaster);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_transfer_subToSub);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_transfer_subUserHist);
  Py_CLEAR(clear_module_state->__pyx_kp_s_sub_account_universalTransfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_success);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_symbols);
  Py_CLEAR(clear_module_state->__pyx_n_s_system);
  Py_CLEAR(clear_module_state->__pyx_kp_s_system_status);
  Py_CLEAR(clear_module_state->__pyx_n_s_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_tag_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_temp_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_text);
  Py_CLEAR(clear_module_state->__pyx_n_s_throw);
  Py_CLEAR(clear_module_state->__pyx_n_s_throw_exception);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ticker_24hr);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ticker_allForceOrders);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ticker_bookTicker);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ticker_openInterest);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ticker_price);
  Py_CLEAR(clear_module_state->__pyx_n_s_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_timeInForce);
  Py_CLEAR(clear_module_state->__pyx_n_s_timeframe);
  Py_CLEAR(clear_module_state->__pyx_n_s_timeout);
  Py_CLEAR(clear_module_state->__pyx_n_s_timestamp);
  Py_CLEAR(clear_module_state->__pyx_n_s_timestamp_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_tld);
  Py_CLEAR(clear_module_state->__pyx_kp_u_tld_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_toggle_bnb_burn_spot_margin);
  Py_CLEAR(clear_module_state->__pyx_n_s_trades);
  Py_CLEAR(clear_module_state->__pyx_n_s_transFrom);
  Py_CLEAR(clear_module_state->__pyx_n_s_transTo);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_dust);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_isolated_margin_to_spot);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_margin_to_spot);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_spot_to_isolated_margin);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfer_spot_to_margin);
  Py_CLEAR(clear_module_state->__pyx_kp_s_trbinance_com);
  Py_CLEAR(clear_module_state->__pyx_n_s_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_typing);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unicorn_binance_rest_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicorn_binance_rest_api_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_unicorn_binance_rest_api_manager);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unicorn_binance_rest_api_manager_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unicorn_binance_websocket_api);
  Py_CLEAR(clear_module_state->__pyx_n_s_universal_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_unknown);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_update_msg);
  Py_CLEAR(clear_module_state->__pyx_n_s_upper);
  Py_CLEAR(clear_module_state->__pyx_n_s_uri);
  Py_CLEAR(clear_module_state->__pyx_n_s_urlencode);
  Py_CLEAR(clear_module_state->__pyx_n_s_urllib_parse);
  Py_CLEAR(clear_module_state->__pyx_n_s_userDataStream);
  Py_CLEAR(clear_module_state->__pyx_kp_s_userDataStream_isolated);
  Py_CLEAR(clear_module_state->__pyx_n_s_userTrades);
  Py_CLEAR(clear_module_state->__pyx_n_s_user_agent);
  Py_CLEAR(clear_module_state->__pyx_kp_s_utf_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_v);
  Py_CLEAR(clear_module_state->__pyx_n_s_v1);
  Py_CLEAR(clear_module_state->__pyx_n_s_v2);
  Py_CLEAR(clear_module_state->__pyx_n_s_v3);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_verify);
  Py_CLEAR(clear_module_state->__pyx_n_s_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_warn_on_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_warning);
  Py_CLEAR(clear_module_state->__pyx_n_s_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_withdraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_withdrawList);
  Py_CLEAR(clear_module_state->__pyx_n_s_withdraw_id);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_10);
  Py_CLEAR(clear_module_state->__pyx_int_12);
  Py_CLEAR(clear_module_state->__pyx_int_200);
  Py_CLEAR(clear_module_state->__pyx_int_300);
  Py_CLEAR(clear_module_state->__pyx_int_500);
  Py_CLEAR(clear_module_state->__pyx_int_1000);
  Py_CLEAR(clear_module_state->__pyx_int_3600);
  Py_CLEAR(clear_module_state->__pyx_int_3600000);
  Py_CLEAR(clear_module_state->__pyx_int_neg_4);
  Py_CLEAR(clear_module_state->__pyx_slice__10);
  Py_CLEAR(clear_module_state->__pyx_slice__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__12);
  Py_CLEAR(clear_module_state->__pyx_tuple__13);
  Py_CLEAR(clear_module_state->__pyx_tuple__14);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__16);
  Py_CLEAR(clear_module_state->__pyx_tuple__17);
  Py_CLEAR(clear_module_state->__pyx_tuple__18);
  Py_CLEAR(clear_module_state->__pyx_tuple__19);
  Py_CLEAR(clear_module_state->__pyx_tuple__20);
  Py_CLEAR(clear_module_state->__pyx_tuple__21);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__25);
  Py_CLEAR(clear_module_state->__pyx_tuple__27);
  Py_CLEAR(clear_module_state->__pyx_tuple__28);
  Py_CLEAR(clear_module_state->__pyx_tuple__29);
  Py_CLEAR(clear_module_state->__pyx_tuple__30);
  Py_CLEAR(clear_module_state->__pyx_tuple__31);
  Py_CLEAR(clear_module_state->__pyx_tuple__32);
  Py_CLEAR(clear_module_state->__pyx_tuple__33);
  Py_CLEAR(clear_module_state->__pyx_tuple__34);
  Py_CLEAR(clear_module_state->__pyx_tuple__35);
  Py_CLEAR(clear_module_state->__pyx_tuple__36);
  Py_CLEAR(clear_module_state->__pyx_tuple__37);
  Py_CLEAR(clear_module_state->__pyx_tuple__38);
  Py_CLEAR(clear_module_state->__pyx_tuple__39);
  Py_CLEAR(clear_module_state->__pyx_tuple__40);
  Py_CLEAR(clear_module_state->__pyx_tuple__41);
  Py_CLEAR(clear_module_state->__pyx_tuple__42);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__44);
  Py_CLEAR(clear_module_state->__pyx_tuple__45);
  Py_CLEAR(clear_module_state->__pyx_tuple__46);
  Py_CLEAR(clear_module_state->__pyx_tuple__47);
  Py_CLEAR(clear_module_state->__pyx_tuple__48);
  Py_CLEAR(clear_module_state->__pyx_tuple__49);
  Py_CLEAR(clear_module_state->__pyx_tuple__50);
  Py_CLEAR(clear_module_state->__pyx_tuple__51);
  Py_CLEAR(clear_module_state->__pyx_tuple__52);
  Py_CLEAR(clear_module_state->__pyx_tuple__53);
  Py_CLEAR(clear_module_state->__pyx_tuple__54);
  Py_CLEAR(clear_module_state->__pyx_tuple__55);
  Py_CLEAR(clear_module_state->__pyx_tuple__56);
  Py_CLEAR(clear_module_state->__pyx_tuple__57);
  Py_CLEAR(clear_module_state->__pyx_tuple__58);
  Py_CLEAR(clear_module_state->__pyx_tuple__59);
  Py_CLEAR(clear_module_state->__pyx_tuple__60);
  Py_CLEAR(clear_module_state->__pyx_tuple__61);
  Py_CLEAR(clear_module_state->__pyx_tuple__62);
  Py_CLEAR(clear_module_state->__pyx_tuple__63);
  Py_CLEAR(clear_module_state->__pyx_tuple__64);
  Py_CLEAR(clear_module_state->__pyx_tuple__65);
  Py_CLEAR(clear_module_state->__pyx_tuple__66);
  Py_CLEAR(clear_module_state->__pyx_tuple__67);
  Py_CLEAR(clear_module_state->__pyx_tuple__68);
  Py_CLEAR(clear_module_state->__pyx_tuple__69);
  Py_CLEAR(clear_module_state->__pyx_tuple__70);
  Py_CLEAR(clear_module_state->__pyx_tuple__71);
  Py_CLEAR(clear_module_state->__pyx_tuple__72);
  Py_CLEAR(clear_module_state->__pyx_tuple__73);
  Py_CLEAR(clear_module_state->__pyx_tuple__74);
  Py_CLEAR(clear_module_state->__pyx_tuple__75);
  Py_CLEAR(clear_module_state->__pyx_tuple__76);
  Py_CLEAR(clear_module_state->__pyx_tuple__77);
  Py_CLEAR(clear_module_state->__pyx_tuple__78);
  Py_CLEAR(clear_module_state->__pyx_tuple__79);
  Py_CLEAR(clear_module_state->__pyx_tuple__80);
  Py_CLEAR(clear_module_state->__pyx_tuple__81);
  Py_CLEAR(clear_module_state->__pyx_tuple__82);
  Py_CLEAR(clear_module_state->__pyx_tuple__83);
  Py_CLEAR(clear_module_state->__pyx_tuple__84);
  Py_CLEAR(clear_module_state->__pyx_tuple__85);
  Py_CLEAR(clear_module_state->__pyx_tuple__86);
  Py_CLEAR(clear_module_state->__pyx_tuple__87);
  Py_CLEAR(clear_module_state->__pyx_tuple__88);
  Py_CLEAR(clear_module_state->__pyx_tuple__89);
  Py_CLEAR(clear_module_state->__pyx_tuple__90);
  Py_CLEAR(clear_module_state->__pyx_tuple__91);
  Py_CLEAR(clear_module_state->__pyx_tuple__92);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_tuple__94);
  Py_CLEAR(clear_module_state->__pyx_tuple__95);
  Py_CLEAR(clear_module_state->__pyx_tuple__96);
  Py_CLEAR(clear_module_state->__pyx_tuple__97);
  Py_CLEAR(clear_module_state->__pyx_tuple__98);
  Py_CLEAR(clear_module_state->__pyx_tuple__99);
  Py_CLEAR(clear_module_state->__pyx_slice__143);
  Py_CLEAR(clear_module_state->__pyx_tuple__100);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__102);
  Py_CLEAR(clear_module_state->__pyx_tuple__103);
  Py_CLEAR(clear_module_state->__pyx_tuple__104);
  Py_CLEAR(clear_module_state->__pyx_tuple__105);
  Py_CLEAR(clear_module_state->__pyx_tuple__106);
  Py_CLEAR(clear_module_state->__pyx_tuple__107);
  Py_CLEAR(clear_module_state->__pyx_tuple__108);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_tuple__110);
  Py_CLEAR(clear_module_state->__pyx_tuple__111);
  Py_CLEAR(clear_module_state->__pyx_tuple__112);
  Py_CLEAR(clear_module_state->__pyx_tuple__113);
  Py_CLEAR(clear_module_state->__pyx_tuple__114);
  Py_CLEAR(clear_module_state->__pyx_tuple__115);
  Py_CLEAR(clear_module_state->__pyx_tuple__116);
  Py_CLEAR(clear_module_state->__pyx_tuple__117);
  Py_CLEAR(clear_module_state->__pyx_tuple__118);
  Py_CLEAR(clear_module_state->__pyx_tuple__119);
  Py_CLEAR(clear_module_state->__pyx_tuple__120);
  Py_CLEAR(clear_module_state->__pyx_tuple__121);
  Py_CLEAR(clear_module_state->__pyx_tuple__122);
  Py_CLEAR(clear_module_state->__pyx_tuple__123);
  Py_CLEAR(clear_module_state->__pyx_tuple__124);
  Py_CLEAR(clear_module_state->__pyx_tuple__125);
  Py_CLEAR(clear_module_state->__pyx_tuple__126);
  Py_CLEAR(clear_module_state->__pyx_tuple__127);
  Py_CLEAR(clear_module_state->__pyx_tuple__128);
  Py_CLEAR(clear_module_state->__pyx_tuple__129);
  Py_CLEAR(clear_module_state->__pyx_tuple__130);
  Py_CLEAR(clear_module_state->__pyx_tuple__131);
  Py_CLEAR(clear_module_state->__pyx_tuple__132);
  Py_CLEAR(clear_module_state->__pyx_tuple__133);
  Py_CLEAR(clear_module_state->__pyx_tuple__134);
  Py_CLEAR(clear_module_state->__pyx_tuple__135);
  Py_CLEAR(clear_module_state->__pyx_tuple__136);
  Py_CLEAR(clear_module_state->__pyx_tuple__137);
  Py_CLEAR(clear_module_state->__pyx_tuple__138);
  Py_CLEAR(clear_module_state->__pyx_tuple__139);
  Py_CLEAR(clear_module_state->__pyx_tuple__140);
  Py_CLEAR(clear_module_state->__pyx_tuple__141);
  Py_CLEAR(clear_module_state->__pyx_tuple__142);
  Py_CLEAR(clear_module_state->__pyx_tuple__144);
  Py_CLEAR(clear_module_state->__pyx_tuple__145);
  Py_CLEAR(clear_module_state->__pyx_tuple__146);
  Py_CLEAR(clear_module_state->__pyx_tuple__147);
  Py_CLEAR(clear_module_state->__pyx_tuple__148);
  Py_CLEAR(clear_module_state->__pyx_tuple__149);
  Py_CLEAR(clear_module_state->__pyx_tuple__150);
  Py_CLEAR(clear_module_state->__pyx_tuple__151);
  Py_CLEAR(clear_module_state->__pyx_tuple__152);
  Py_CLEAR(clear_module_state->__pyx_tuple__153);
  Py_CLEAR(clear_module_state->__pyx_tuple__154);
  Py_CLEAR(clear_module_state->__pyx_tuple__155);
  Py_CLEAR(clear_module_state->__pyx_tuple__156);
  Py_CLEAR(clear_module_state->__pyx_tuple__157);
  Py_CLEAR(clear_module_state->__pyx_tuple__158);
  Py_CLEAR(clear_module_state->__pyx_tuple__159);
  Py_CLEAR(clear_module_state->__pyx_tuple__160);
  Py_CLEAR(clear_module_state->__pyx_tuple__161);
  Py_CLEAR(clear_module_state->__pyx_tuple__162);
  Py_CLEAR(clear_module_state->__pyx_tuple__163);
  Py_CLEAR(clear_module_state->__pyx_tuple__164);
  Py_CLEAR(clear_module_state->__pyx_tuple__165);
  Py_CLEAR(clear_module_state->__pyx_tuple__166);
  Py_CLEAR(clear_module_state->__pyx_tuple__167);
  Py_CLEAR(clear_module_state->__pyx_tuple__168);
  Py_CLEAR(clear_module_state->__pyx_tuple__169);
  Py_CLEAR(clear_module_state->__pyx_tuple__170);
  Py_CLEAR(clear_module_state->__pyx_tuple__171);
  Py_CLEAR(clear_module_state->__pyx_tuple__172);
  Py_CLEAR(clear_module_state->__pyx_tuple__173);
  Py_CLEAR(clear_module_state->__pyx_tuple__174);
  Py_CLEAR(clear_module_state->__pyx_tuple__175);
  Py_CLEAR(clear_module_state->__pyx_tuple__176);
  Py_CLEAR(clear_module_state->__pyx_tuple__177);
  Py_CLEAR(clear_module_state->__pyx_tuple__178);
  Py_CLEAR(clear_module_state->__pyx_tuple__179);
  Py_CLEAR(clear_module_state->__pyx_tuple__180);
  Py_CLEAR(clear_module_state->__pyx_tuple__181);
  Py_CLEAR(clear_module_state->__pyx_tuple__182);
  Py_CLEAR(clear_module_state->__pyx_tuple__183);
  Py_CLEAR(clear_module_state->__pyx_tuple__187);
  Py_CLEAR(clear_module_state->__pyx_tuple__188);
  Py_CLEAR(clear_module_state->__pyx_tuple__189);
  Py_CLEAR(clear_module_state->__pyx_tuple__190);
  Py_CLEAR(clear_module_state->__pyx_tuple__192);
  Py_CLEAR(clear_module_state->__pyx_tuple__193);
  Py_CLEAR(clear_module_state->__pyx_tuple__195);
  Py_CLEAR(clear_module_state->__pyx_tuple__197);
  Py_CLEAR(clear_module_state->__pyx_tuple__199);
  Py_CLEAR(clear_module_state->__pyx_tuple__201);
  Py_CLEAR(clear_module_state->__pyx_tuple__203);
  Py_CLEAR(clear_module_state->__pyx_tuple__207);
  Py_CLEAR(clear_module_state->__pyx_tuple__209);
  Py_CLEAR(clear_module_state->__pyx_tuple__211);
  Py_CLEAR(clear_module_state->__pyx_tuple__213);
  Py_CLEAR(clear_module_state->__pyx_tuple__215);
  Py_CLEAR(clear_module_state->__pyx_tuple__217);
  Py_CLEAR(clear_module_state->__pyx_tuple__218);
  Py_CLEAR(clear_module_state->__pyx_tuple__221);
  Py_CLEAR(clear_module_state->__pyx_tuple__226);
  Py_CLEAR(clear_module_state->__pyx_tuple__228);
  Py_CLEAR(clear_module_state->__pyx_tuple__230);
  Py_CLEAR(clear_module_state->__pyx_tuple__231);
  Py_CLEAR(clear_module_state->__pyx_tuple__233);
  Py_CLEAR(clear_module_state->__pyx_tuple__237);
  Py_CLEAR(clear_module_state->__pyx_tuple__241);
  Py_CLEAR(clear_module_state->__pyx_tuple__243);
  Py_CLEAR(clear_module_state->__pyx_tuple__245);
  Py_CLEAR(clear_module_state->__pyx_tuple__248);
  Py_CLEAR(clear_module_state->__pyx_tuple__254);
  Py_CLEAR(clear_module_state->__pyx_tuple__259);
  Py_CLEAR(clear_module_state->__pyx_tuple__260);
  Py_CLEAR(clear_module_state->__pyx_tuple__262);
  Py_CLEAR(clear_module_state->__pyx_tuple__264);
  Py_CLEAR(clear_module_state->__pyx_tuple__266);
  Py_CLEAR(clear_module_state->__pyx_tuple__267);
  Py_CLEAR(clear_module_state->__pyx_tuple__268);
  Py_CLEAR(clear_module_state->__pyx_tuple__274);
  Py_CLEAR(clear_module_state->__pyx_tuple__292);
  Py_CLEAR(clear_module_state->__pyx_tuple__296);
  Py_CLEAR(clear_module_state->__pyx_tuple__308);
  Py_CLEAR(clear_module_state->__pyx_tuple__311);
  Py_CLEAR(clear_module_state->__pyx_tuple__313);
  Py_CLEAR(clear_module_state->__pyx_tuple__314);
  Py_CLEAR(clear_module_state->__pyx_tuple__351);
  Py_CLEAR(clear_module_state->__pyx_tuple__353);
  Py_CLEAR(clear_module_state->__pyx_tuple__391);
  Py_CLEAR(clear_module_state->__pyx_tuple__393);
  Py_CLEAR(clear_module_state->__pyx_tuple__416);
  Py_CLEAR(clear_module_state->__pyx_tuple__486);
  Py_CLEAR(clear_module_state->__pyx_codeobj__22);
  Py_CLEAR(clear_module_state->__pyx_codeobj__26);
  Py_CLEAR(clear_module_state->__pyx_codeobj__191);
  Py_CLEAR(clear_module_state->__pyx_codeobj__194);
  Py_CLEAR(clear_module_state->__pyx_codeobj__196);
  Py_CLEAR(clear_module_state->__pyx_codeobj__198);
  Py_CLEAR(clear_module_state->__pyx_codeobj__200);
  Py_CLEAR(clear_module_state->__pyx_codeobj__202);
  Py_CLEAR(clear_module_state->__pyx_codeobj__204);
  Py_CLEAR(clear_module_state->__pyx_codeobj__205);
  Py_CLEAR(clear_module_state->__pyx_codeobj__206);
  Py_CLEAR(clear_module_state->__pyx_codeobj__208);
  Py_CLEAR(clear_module_state->__pyx_codeobj__210);
  Py_CLEAR(clear_module_state->__pyx_codeobj__212);
  Py_CLEAR(clear_module_state->__pyx_codeobj__214);
  Py_CLEAR(clear_module_state->__pyx_codeobj__216);
  Py_CLEAR(clear_module_state->__pyx_codeobj__219);
  Py_CLEAR(clear_module_state->__pyx_codeobj__220);
  Py_CLEAR(clear_module_state->__pyx_codeobj__222);
  Py_CLEAR(clear_module_state->__pyx_codeobj__223);
  Py_CLEAR(clear_module_state->__pyx_codeobj__224);
  Py_CLEAR(clear_module_state->__pyx_codeobj__225);
  Py_CLEAR(clear_module_state->__pyx_codeobj__227);
  Py_CLEAR(clear_module_state->__pyx_codeobj__229);
  Py_CLEAR(clear_module_state->__pyx_codeobj__232);
  Py_CLEAR(clear_module_state->__pyx_codeobj__234);
  Py_CLEAR(clear_module_state->__pyx_codeobj__235);
  Py_CLEAR(clear_module_state->__pyx_codeobj__236);
  Py_CLEAR(clear_module_state->__pyx_codeobj__238);
  Py_CLEAR(clear_module_state->__pyx_codeobj__239);
  Py_CLEAR(clear_module_state->__pyx_codeobj__240);
  Py_CLEAR(clear_module_state->__pyx_codeobj__242);
  Py_CLEAR(clear_module_state->__pyx_codeobj__244);
  Py_CLEAR(clear_module_state->__pyx_codeobj__246);
  Py_CLEAR(clear_module_state->__pyx_codeobj__247);
  Py_CLEAR(clear_module_state->__pyx_codeobj__249);
  Py_CLEAR(clear_module_state->__pyx_codeobj__250);
  Py_CLEAR(clear_module_state->__pyx_codeobj__251);
  Py_CLEAR(clear_module_state->__pyx_codeobj__252);
  Py_CLEAR(clear_module_state->__pyx_codeobj__253);
  Py_CLEAR(clear_module_state->__pyx_codeobj__255);
  Py_CLEAR(clear_module_state->__pyx_codeobj__256);
  Py_CLEAR(clear_module_state->__pyx_codeobj__257);
  Py_CLEAR(clear_module_state->__pyx_codeobj__258);
  Py_CLEAR(clear_module_state->__pyx_codeobj__261);
  Py_CLEAR(clear_module_state->__pyx_codeobj__263);
  Py_CLEAR(clear_module_state->__pyx_codeobj__265);
  Py_CLEAR(clear_module_state->__pyx_codeobj__269);
  Py_CLEAR(clear_module_state->__pyx_codeobj__270);
  Py_CLEAR(clear_module_state->__pyx_codeobj__271);
  Py_CLEAR(clear_module_state->__pyx_codeobj__272);
  Py_CLEAR(clear_module_state->__pyx_codeobj__273);
  Py_CLEAR(clear_module_state->__pyx_codeobj__275);
  Py_CLEAR(clear_module_state->__pyx_codeobj__276);
  Py_CLEAR(clear_module_state->__pyx_codeobj__277);
  Py_CLEAR(clear_module_state->__pyx_codeobj__278);
  Py_CLEAR(clear_module_state->__pyx_codeobj__279);
  Py_CLEAR(clear_module_state->__pyx_codeobj__280);
  Py_CLEAR(clear_module_state->__pyx_codeobj__281);
  Py_CLEAR(clear_module_state->__pyx_codeobj__282);
  Py_CLEAR(clear_module_state->__pyx_codeobj__283);
  Py_CLEAR(clear_module_state->__pyx_codeobj__284);
  Py_CLEAR(clear_module_state->__pyx_codeobj__285);
  Py_CLEAR(clear_module_state->__pyx_codeobj__286);
  Py_CLEAR(clear_module_state->__pyx_codeobj__287);
  Py_CLEAR(clear_module_state->__pyx_codeobj__288);
  Py_CLEAR(clear_module_state->__pyx_codeobj__289);
  Py_CLEAR(clear_module_state->__pyx_codeobj__290);
  Py_CLEAR(clear_module_state->__pyx_codeobj__291);
  Py_CLEAR(clear_module_state->__pyx_codeobj__293);
  Py_CLEAR(clear_module_state->__pyx_codeobj__294);
  Py_CLEAR(clear_module_state->__pyx_codeobj__295);
  Py_CLEAR(clear_module_state->__pyx_codeobj__297);
  Py_CLEAR(clear_module_state->__pyx_codeobj__298);
  Py_CLEAR(clear_module_state->__pyx_codeobj__299);
  Py_CLEAR(clear_module_state->__pyx_codeobj__300);
  Py_CLEAR(clear_module_state->__pyx_codeobj__301);
  Py_CLEAR(clear_module_state->__pyx_codeobj__302);
  Py_CLEAR(clear_module_state->__pyx_codeobj__303);
  Py_CLEAR(clear_module_state->__pyx_codeobj__304);
  Py_CLEAR(clear_module_state->__pyx_codeobj__305);
  Py_CLEAR(clear_module_state->__pyx_codeobj__306);
  Py_CLEAR(clear_module_state->__pyx_codeobj__307);
  Py_CLEAR(clear_module_state->__pyx_codeobj__309);
  Py_CLEAR(clear_module_state->__pyx_codeobj__310);
  Py_CLEAR(clear_module_state->__pyx_codeobj__312);
  Py_CLEAR(clear_module_state->__pyx_codeobj__315);
  Py_CLEAR(clear_module_state->__pyx_codeobj__316);
  Py_CLEAR(clear_module_state->__pyx_codeobj__317);
  Py_CLEAR(clear_module_state->__pyx_codeobj__318);
  Py_CLEAR(clear_module_state->__pyx_codeobj__319);
  Py_CLEAR(clear_module_state->__pyx_codeobj__320);
  Py_CLEAR(clear_module_state->__pyx_codeobj__321);
  Py_CLEAR(clear_module_state->__pyx_codeobj__322);
  Py_CLEAR(clear_module_state->__pyx_codeobj__323);
  Py_CLEAR(clear_module_state->__pyx_codeobj__324);
  Py_CLEAR(clear_module_state->__pyx_codeobj__325);
  Py_CLEAR(clear_module_state->__pyx_codeobj__326);
  Py_CLEAR(clear_module_state->__pyx_codeobj__327);
  Py_CLEAR(clear_module_state->__pyx_codeobj__328);
  Py_CLEAR(clear_module_state->__pyx_codeobj__329);
  Py_CLEAR(clear_module_state->__pyx_codeobj__330);
  Py_CLEAR(clear_module_state->__pyx_codeobj__331);
  Py_CLEAR(clear_module_state->__pyx_codeobj__332);
  Py_CLEAR(clear_module_state->__pyx_codeobj__333);
  Py_CLEAR(clear_module_state->__pyx_codeobj__334);
  Py_CLEAR(clear_module_state->__pyx_codeobj__335);
  Py_CLEAR(clear_module_state->__pyx_codeobj__336);
  Py_CLEAR(clear_module_state->__pyx_codeobj__337);
  Py_CLEAR(clear_module_state->__pyx_codeobj__338);
  Py_CLEAR(clear_module_state->__pyx_codeobj__339);
  Py_CLEAR(clear_module_state->__pyx_codeobj__340);
  Py_CLEAR(clear_module_state->__pyx_codeobj__341);
  Py_CLEAR(clear_module_state->__pyx_codeobj__342);
  Py_CLEAR(clear_module_state->__pyx_codeobj__343);
  Py_CLEAR(clear_module_state->__pyx_codeobj__344);
  Py_CLEAR(clear_module_state->__pyx_codeobj__345);
  Py_CLEAR(clear_module_state->__pyx_codeobj__346);
  Py_CLEAR(clear_module_state->__pyx_codeobj__347);
  Py_CLEAR(clear_module_state->__pyx_codeobj__348);
  Py_CLEAR(clear_module_state->__pyx_codeobj__349);
  Py_CLEAR(clear_module_state->__pyx_codeobj__350);
  Py_CLEAR(clear_module_state->__pyx_codeobj__352);
  Py_CLEAR(clear_module_state->__pyx_codeobj__354);
  Py_CLEAR(clear_module_state->__pyx_codeobj__355);
  Py_CLEAR(clear_module_state->__pyx_codeobj__356);
  Py_CLEAR(clear_module_state->__pyx_codeobj__357);
  Py_CLEAR(clear_module_state->__pyx_codeobj__358);
  Py_CLEAR(clear_module_state->__pyx_codeobj__359);
  Py_CLEAR(clear_module_state->__pyx_codeobj__360);
  Py_CLEAR(clear_module_state->__pyx_codeobj__361);
  Py_CLEAR(clear_module_state->__pyx_codeobj__362);
  Py_CLEAR(clear_module_state->__pyx_codeobj__363);
  Py_CLEAR(clear_module_state->__pyx_codeobj__364);
  Py_CLEAR(clear_module_state->__pyx_codeobj__365);
  Py_CLEAR(clear_module_state->__pyx_codeobj__366);
  Py_CLEAR(clear_module_state->__pyx_codeobj__367);
  Py_CLEAR(clear_module_state->__pyx_codeobj__368);
  Py_CLEAR(clear_module_state->__pyx_codeobj__369);
  Py_CLEAR(clear_module_state->__pyx_codeobj__370);
  Py_CLEAR(clear_module_state->__pyx_codeobj__371);
  Py_CLEAR(clear_module_state->__pyx_codeobj__372);
  Py_CLEAR(clear_module_state->__pyx_codeobj__373);
  Py_CLEAR(clear_module_state->__pyx_codeobj__374);
  Py_CLEAR(clear_module_state->__pyx_codeobj__375);
  Py_CLEAR(clear_module_state->__pyx_codeobj__376);
  Py_CLEAR(clear_module_state->__pyx_codeobj__377);
  Py_CLEAR(clear_module_state->__pyx_codeobj__378);
  Py_CLEAR(clear_module_state->__pyx_codeobj__379);
  Py_CLEAR(clear_module_state->__pyx_codeobj__380);
  Py_CLEAR(clear_module_state->__pyx_codeobj__381);
  Py_CLEAR(clear_module_state->__pyx_codeobj__382);
  Py_CLEAR(clear_module_state->__pyx_codeobj__383);
  Py_CLEAR(clear_module_state->__pyx_codeobj__384);
  Py_CLEAR(clear_module_state->__pyx_codeobj__385);
  Py_CLEAR(clear_module_state->__pyx_codeobj__386);
  Py_CLEAR(clear_module_state->__pyx_codeobj__387);
  Py_CLEAR(clear_module_state->__pyx_codeobj__388);
  Py_CLEAR(clear_module_state->__pyx_codeobj__389);
  Py_CLEAR(clear_module_state->__pyx_codeobj__390);
  Py_CLEAR(clear_module_state->__pyx_codeobj__392);
  Py_CLEAR(clear_module_state->__pyx_codeobj__394);
  Py_CLEAR(clear_module_state->__pyx_codeobj__395);
  Py_CLEAR(clear_module_state->__pyx_codeobj__396);
  Py_CLEAR(clear_module_state->__pyx_codeobj__397);
  Py_CLEAR(clear_module_state->__pyx_codeobj__398);
  Py_CLEAR(clear_module_state->__pyx_codeobj__399);
  Py_CLEAR(clear_module_state->__pyx_codeobj__400);
  Py_CLEAR(clear_module_state->__pyx_codeobj__401);
  Py_CLEAR(clear_module_state->__pyx_codeobj__402);
  Py_CLEAR(clear_module_state->__pyx_codeobj__403);
  Py_CLEAR(clear_module_state->__pyx_codeobj__404);
  Py_CLEAR(clear_module_state->__pyx_codeobj__405);
  Py_CLEAR(clear_module_state->__pyx_codeobj__406);
  Py_CLEAR(clear_module_state->__pyx_codeobj__407);
  Py_CLEAR(clear_module_state->__pyx_codeobj__408);
  Py_CLEAR(clear_module_state->__pyx_codeobj__409);
  Py_CLEAR(clear_module_state->__pyx_codeobj__410);
  Py_CLEAR(clear_module_state->__pyx_codeobj__411);
  Py_CLEAR(clear_module_state->__pyx_codeobj__412);
  Py_CLEAR(clear_module_state->__pyx_codeobj__413);
  Py_CLEAR(clear_module_state->__pyx_codeobj__414);
  Py_CLEAR(clear_module_state->__pyx_codeobj__415);
  Py_CLEAR(clear_module_state->__pyx_codeobj__417);
  Py_CLEAR(clear_module_state->__pyx_codeobj__418);
  Py_CLEAR(clear_module_state->__pyx_codeobj__419);
  Py_CLEAR(clear_module_state->__pyx_codeobj__420);
  Py_CLEAR(clear_module_state->__pyx_codeobj__421);
  Py_CLEAR(clear_module_state->__pyx_codeobj__422);
  Py_CLEAR(clear_module_state->__pyx_codeobj__423);
  Py_CLEAR(clear_module_state->__pyx_codeobj__424);
  Py_CLEAR(clear_module_state->__pyx_codeobj__425);
  Py_CLEAR(clear_module_state->__pyx_codeobj__426);
  Py_CLEAR(clear_module_state->__pyx_codeobj__427);
  Py_CLEAR(clear_module_state->__pyx_codeobj__428);
  Py_CLEAR(clear_module_state->__pyx_codeobj__429);
  Py_CLEAR(clear_module_state->__pyx_codeobj__430);
  Py_CLEAR(clear_module_state->__pyx_codeobj__431);
  Py_CLEAR(clear_module_state->__pyx_codeobj__432);
  Py_CLEAR(clear_module_state->__pyx_codeobj__433);
  Py_CLEAR(clear_module_state->__pyx_codeobj__434);
  Py_CLEAR(clear_module_state->__pyx_codeobj__435);
  Py_CLEAR(clear_module_state->__pyx_codeobj__436);
  Py_CLEAR(clear_module_state->__pyx_codeobj__437);
  Py_CLEAR(clear_module_state->__pyx_codeobj__438);
  Py_CLEAR(clear_module_state->__pyx_codeobj__439);
  Py_CLEAR(clear_module_state->__pyx_codeobj__440);
  Py_CLEAR(clear_module_state->__pyx_codeobj__441);
  Py_CLEAR(clear_module_state->__pyx_codeobj__442);
  Py_CLEAR(clear_module_state->__pyx_codeobj__443);
  Py_CLEAR(clear_module_state->__pyx_codeobj__444);
  Py_CLEAR(clear_module_state->__pyx_codeobj__445);
  Py_CLEAR(clear_module_state->__pyx_codeobj__446);
  Py_CLEAR(clear_module_state->__pyx_codeobj__447);
  Py_CLEAR(clear_module_state->__pyx_codeobj__448);
  Py_CLEAR(clear_module_state->__pyx_codeobj__449);
  Py_CLEAR(clear_module_state->__pyx_codeobj__450);
  Py_CLEAR(clear_module_state->__pyx_codeobj__451);
  Py_CLEAR(clear_module_state->__pyx_codeobj__452);
  Py_CLEAR(clear_module_state->__pyx_codeobj__453);
  Py_CLEAR(clear_module_state->__pyx_codeobj__454);
  Py_CLEAR(clear_module_state->__pyx_codeobj__455);
  Py_CLEAR(clear_module_state->__pyx_codeobj__456);
  Py_CLEAR(clear_module_state->__pyx_codeobj__457);
  Py_CLEAR(clear_module_state->__pyx_codeobj__458);
  Py_CLEAR(clear_module_state->__pyx_codeobj__459);
  Py_CLEAR(clear_module_state->__pyx_codeobj__460);
  Py_CLEAR(clear_module_state->__pyx_codeobj__461);
  Py_CLEAR(clear_module_state->__pyx_codeobj__462);
  Py_CLEAR(clear_module_state->__pyx_codeobj__463);
  Py_CLEAR(clear_module_state->__pyx_codeobj__464);
  Py_CLEAR(clear_module_state->__pyx_codeobj__465);
  Py_CLEAR(clear_module_state->__pyx_codeobj__466);
  Py_CLEAR(clear_module_state->__pyx_codeobj__467);
  Py_CLEAR(clear_module_state->__pyx_codeobj__468);
  Py_CLEAR(clear_module_state->__pyx_codeobj__469);
  Py_CLEAR(clear_module_state->__pyx_codeobj__470);
  Py_CLEAR(clear_module_state->__pyx_codeobj__471);
  Py_CLEAR(clear_module_state->__pyx_codeobj__472);
  Py_CLEAR(clear_module_state->__pyx_codeobj__473);
  Py_CLEAR(clear_module_state->__pyx_codeobj__474);
  Py_CLEAR(clear_module_state->__pyx_codeobj__475);
  Py_CLEAR(clear_module_state->__pyx_codeobj__476);
  Py_CLEAR(clear_module_state->__pyx_codeobj__477);
  Py_CLEAR(clear_module_state->__pyx_codeobj__478);
  Py_CLEAR(clear_module_state->__pyx_codeobj__479);
  Py_CLEAR(clear_module_state->__pyx_codeobj__480);
  Py_CLEAR(clear_module_state->__pyx_codeobj__481);
  Py_CLEAR(clear_module_state->__pyx_codeobj__482);
  Py_CLEAR(clear_module_state->__pyx_codeobj__483);
  Py_CLEAR(clear_module_state->__pyx_codeobj__484);
  Py_CLEAR(clear_module_state->__pyx_codeobj__485);
  Py_CLEAR(clear_module_state->__pyx_codeobj__487);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter);
  Py_VISIT(traverse_module_state->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter);
  Py_VISIT(traverse_module_state->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator);
  Py_VISIT(traverse_module_state->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator);
  Py_VISIT(traverse_module_state->__pyx_kp_u_);
  Py_VISIT(traverse_module_state->__pyx_kp_s_12h);
  Py_VISIT(traverse_module_state->__pyx_kp_s_15m);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1M);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1h);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1m);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1s);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1w);
  Py_VISIT(traverse_module_state->__pyx_kp_s_22);
  Py_VISIT(traverse_module_state->__pyx_kp_s_27);
  Py_VISIT(traverse_module_state->__pyx_kp_s_2_0_0);
  Py_VISIT(traverse_module_state->__pyx_kp_s_2h);
  Py_VISIT(traverse_module_state->__pyx_kp_s_30m);
  Py_VISIT(traverse_module_state->__pyx_kp_s_3d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_3m);
  Py_VISIT(traverse_module_state->__pyx_kp_s_4h);
  Py_VISIT(traverse_module_state->__pyx_kp_s_5m);
  Py_VISIT(traverse_module_state->__pyx_kp_s_6h);
  Py_VISIT(traverse_module_state->__pyx_kp_s_8h);
  Py_VISIT(traverse_module_state->__pyx_n_s_ACK);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_BEST_MATCH);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_BUYER_MAKES);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_FIRST_TRADE_ID);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_ID);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_LAST_TRADE_ID);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_PRICE);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_QUANTITY);
  Py_VISIT(traverse_module_state->__pyx_n_s_AGG_TIME);
  Py_VISIT(traverse_module_state->__pyx_n_s_API_KEY);
  Py_VISIT(traverse_module_state->__pyx_n_s_API_SECRET);
  Py_VISIT(traverse_module_state->__pyx_n_s_API_URL);
  Py_VISIT(traverse_module_state->__pyx_n_s_Accept);
  Py_VISIT(traverse_module_state->__pyx_kp_u_An_exception_occurred);
  Py_VISIT(traverse_module_state->__pyx_kp_s_An_unofficial_Python_API_to_use);
  Py_VISIT(traverse_module_state->__pyx_n_s_BUY);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceAPIException);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRequestException);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager___enter);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager___exit);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__create_ap);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__create_fu);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__create_fu_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__create_fu_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__create_fu_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__create_ma);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__create_we);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__delete);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__generate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__get);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__get_earli);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__handle_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__init_sess);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__order_par);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__post);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__put);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_f);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_f_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_f_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_f_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager__request_w);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_aggregate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_cancel_all);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_cancel_all_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_cancel_mar);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_cancel_mar_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_cancel_ord);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_change_fix);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_iso);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_mar);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_mar_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_mar_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_oco);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_ord);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_create_tes);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_disable_fa);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_enable_fas);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_enable_sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_enable_sub_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ac_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ag);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_au);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ca);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ca_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ca_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ch_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_10);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_11);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_12);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_13);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_14);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_15);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_16);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_17);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_18);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_19);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_20);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_21);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_22);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_23);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_24);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_25);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_26);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_27);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_28);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_29);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_30);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_31);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_32);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_33);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_34);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_35);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_36);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_37);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_38);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_39);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_40);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_41);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_42);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_43);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_co_9);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_cr);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_fu);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ge_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_hi);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_kl);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_le);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_li);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ma);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_op);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_op_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_or);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_or_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_pi);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_pl);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_po);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_po_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_st);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_st_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_st_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_sy);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ti);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_futures_ti_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_accoun_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_aggreg);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_all_co);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_all_is);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_all_ma);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_all_or);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_all_ti);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_asset);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_asset_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_asset_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_avg_pr);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_bnb_bu);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_deposi);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_deposi_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_dust_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_exchan);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_fixed);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_histor);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_histor_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_histor_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_isolat);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_isolat_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_latest);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_latest_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_lendin_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_margin_9);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_max_ma);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_max_ma_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_my_tra);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_open_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_open_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_open_m_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_open_o);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_order_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_orderb);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_orderb_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_produc);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_recent);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_server);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_sub_ac_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_subacc_9);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_symbol_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_system);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_trade);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_univer);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_used_w);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_user_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_versio);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_withdr);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_get_withdr_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_is_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_isolated_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_isolated_m_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_isolated_m_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_make_subac);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_make_subac_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_make_subac_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_make_subac_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_make_unive);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_margin_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_margin_str_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_margin_str_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_new_transf);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_limi);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_limi_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_limi_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_mark);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_mark_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_mark_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_oco);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_order_oco_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_ping);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_purchase_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_query_suba);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_query_univ);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_redeem_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_repay_marg);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_stop_manag);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_stream_clo);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_stream_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_stream_kee);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_toggle_bnb);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_transfer_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_transfer_h);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_transfer_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_transfer_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_transfer_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_transfer_s_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_universal);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceRestApiManager_withdraw);
  Py_VISIT(traverse_module_state->__pyx_kp_s_BinanceWebSocketApiManager_stop);
  Py_VISIT(traverse_module_state->__pyx_n_s_BinanceWithdrawException);
  Py_VISIT(traverse_module_state->__pyx_n_s_C2C_MAIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_C2C_MINING);
  Py_VISIT(traverse_module_state->__pyx_n_s_C2C_UMFUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_CANCELED);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMFUTURE_MAIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_COIN_FUTURE_TO_SPOT);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Created_SOCKS5_proxy_URI);
  Py_VISIT(traverse_module_state->__pyx_n_s_Date);
  Py_VISIT(traverse_module_state->__pyx_n_s_EXPIRED);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Entering_with_context);
  Py_VISIT(traverse_module_state->__pyx_n_s_FIAT_TO_MINING);
  Py_VISIT(traverse_module_state->__pyx_n_s_FIAT_TO_SPOT);
  Py_VISIT(traverse_module_state->__pyx_n_s_FIAT_TO_USDT_FUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_FILLED);
  Py_VISIT(traverse_module_state->__pyx_n_s_FOK);
  Py_VISIT(traverse_module_state->__pyx_n_s_FULL);
  Py_VISIT(traverse_module_state->__pyx_n_s_FUTURES_API_VERSION);
  Py_VISIT(traverse_module_state->__pyx_n_s_FUTURES_API_VERSION2);
  Py_VISIT(traverse_module_state->__pyx_n_s_FUTURES_COIN_DATA_URL);
  Py_VISIT(traverse_module_state->__pyx_n_s_FUTURES_COIN_URL);
  Py_VISIT(traverse_module_state->__pyx_n_s_FUTURES_DATA_URL);
  Py_VISIT(traverse_module_state->__pyx_n_s_FUTURES_URL);
  Py_VISIT(traverse_module_state->__pyx_n_s_GTC);
  Py_VISIT(traverse_module_state->__pyx_n_s_IOC);
  Py_VISIT(traverse_module_state->__pyx_n_s_ISOLATED_MARGIN);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Initiating_colorama);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Invalid_Response_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_12HOUR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_15MINUTE);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_1DAY);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_1HOUR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_1MINUTE);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_1MONTH);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_1SECOND);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_1WEEK);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_2HOUR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_30MINUTE);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_3DAY);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_3MINUTE);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_4HOUR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_5MINUTE);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_6HOUR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KLINE_INTERVAL_8HOUR);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyError);
  Py_VISIT(traverse_module_state->__pyx_n_s_LIMIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_LIMIT_MAKER);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Leaving_with_context);
  Py_VISIT(traverse_module_state->__pyx_n_s_LucitLicensingManager);
  Py_VISIT(traverse_module_state->__pyx_n_s_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_MAIN_C2C);
  Py_VISIT(traverse_module_state->__pyx_n_s_MAIN_CMFUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_MAIN_MARGIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_MAIN_MINING);
  Py_VISIT(traverse_module_state->__pyx_n_s_MAIN_UMFUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_MARGIN_API_URL);
  Py_VISIT(traverse_module_state->__pyx_n_s_MARGIN_API_VERSION);
  Py_VISIT(traverse_module_state->__pyx_n_s_MARGIN_CROSS_TO_SPOT);
  Py_VISIT(traverse_module_state->__pyx_n_s_MARGIN_CROSS_TO_USDT_FUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_MARGIN_MAIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_MARGIN_UMFUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_MARKET);
  Py_VISIT(traverse_module_state->__pyx_n_s_MINING_C2C);
  Py_VISIT(traverse_module_state->__pyx_n_s_MINING_MAIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_MINING_TO_FIAT);
  Py_VISIT(traverse_module_state->__pyx_n_s_MINING_TO_SPOT);
  Py_VISIT(traverse_module_state->__pyx_n_s_MINING_TO_USDT_FUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_MINING_UMFUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_NEW);
  Py_VISIT(traverse_module_state->__pyx_kp_u_New_instance_of);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_RESP_TYPE_ACK);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_RESP_TYPE_FULL);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_RESP_TYPE_RESULT);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_STATUS_CANCELED);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_STATUS_EXPIRED);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_STATUS_FILLED);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_STATUS_NEW);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_STATUS_PARTIALLY_FILLED);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_STATUS_PENDING_CANCEL);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_STATUS_REJECTED);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_TYPE_LIMIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_TYPE_LIMIT_MAKER);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_TYPE_MARKET);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_TYPE_STOP_LOSS);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_TYPE_STOP_LOSS_LIMIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_TYPE_TAKE_PROFIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_ORDER_TYPE_TAKE_PROFIT_LIMIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_Optional);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Optional_bool);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Optional_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_PARTIALLY_FILLED);
  Py_VISIT(traverse_module_state->__pyx_n_s_PENDING_CANCEL);
  Py_VISIT(traverse_module_state->__pyx_n_s_PRIVATE_API_VERSION);
  Py_VISIT(traverse_module_state->__pyx_n_s_PUBLIC_API_VERSION);
  Py_VISIT(traverse_module_state->__pyx_n_s_REJECTED);
  Py_VISIT(traverse_module_state->__pyx_n_s_RESULT);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Read_the_docs_to_see_a_list_of);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Release);
  Py_VISIT(traverse_module_state->__pyx_n_s_SELL);
  Py_VISIT(traverse_module_state->__pyx_n_s_SIDE_BUY);
  Py_VISIT(traverse_module_state->__pyx_n_s_SIDE_SELL);
  Py_VISIT(traverse_module_state->__pyx_n_s_SPOT);
  Py_VISIT(traverse_module_state->__pyx_n_s_SPOT_TO_COIN_FUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_SPOT_TO_FIAT);
  Py_VISIT(traverse_module_state->__pyx_n_s_SPOT_TO_MARGIN_CROSS);
  Py_VISIT(traverse_module_state->__pyx_n_s_SPOT_TO_MINING);
  Py_VISIT(traverse_module_state->__pyx_n_s_SPOT_TO_USDT_FUTURE);
  Py_VISIT(traverse_module_state->__pyx_n_s_STOP_LOSS);
  Py_VISIT(traverse_module_state->__pyx_n_s_STOP_LOSS_LIMIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_SYMBOL_TYPE_SPOT);
  Py_VISIT(traverse_module_state->__pyx_n_s_T);
  Py_VISIT(traverse_module_state->__pyx_n_s_TAKE_PROFIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_TAKE_PROFIT_LIMIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_TIME_IN_FORCE_FOK);
  Py_VISIT(traverse_module_state->__pyx_n_s_TIME_IN_FORCE_GTC);
  Py_VISIT(traverse_module_state->__pyx_n_s_TIME_IN_FORCE_IOC);
  Py_VISIT(traverse_module_state->__pyx_kp_s_The_parameter_BinanceRestApiMana);
  Py_VISIT(traverse_module_state->__pyx_kp_s_There_is_no_entry_with_withdraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_UMFUTURE_C2C);
  Py_VISIT(traverse_module_state->__pyx_n_s_UMFUTURE_MAIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_UMFUTURE_MARGIN);
  Py_VISIT(traverse_module_state->__pyx_kp_s_UNICORN_BINANCE_SUITE);
  Py_VISIT(traverse_module_state->__pyx_n_s_USDT_FUTURE_TO_FIAT);
  Py_VISIT(traverse_module_state->__pyx_n_s_USDT_FUTURE_TO_MARGIN_CROSS);
  Py_VISIT(traverse_module_state->__pyx_n_s_USDT_FUTURE_TO_SPOT);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnknownExchange);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unknown_exchange);
  Py_VISIT(traverse_module_state->__pyx_kp_s_User_Agent);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s_WEBSITE_URL);
  Py_VISIT(traverse_module_state->__pyx_kp_s_X_MBX_APIKEY);
  Py_VISIT(traverse_module_state->__pyx_kp_s_X_MBX_USED_WEIGHT);
  Py_VISIT(traverse_module_state->__pyx_kp_s__184);
  Py_VISIT(traverse_module_state->__pyx_kp_u__185);
  Py_VISIT(traverse_module_state->__pyx_n_s__186);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_kp_s__3);
  Py_VISIT(traverse_module_state->__pyx_kp_u__3);
  Py_VISIT(traverse_module_state->__pyx_kp_s__4);
  Py_VISIT(traverse_module_state->__pyx_n_s__488);
  Py_VISIT(traverse_module_state->__pyx_n_u__5);
  Py_VISIT(traverse_module_state->__pyx_kp_u__6);
  Py_VISIT(traverse_module_state->__pyx_kp_s__7);
  Py_VISIT(traverse_module_state->__pyx_kp_s__8);
  Py_VISIT(traverse_module_state->__pyx_kp_s__9);
  Py_VISIT(traverse_module_state->__pyx_n_s_a);
  Py_VISIT(traverse_module_state->__pyx_kp_s_a_d_b_Y_I_M_S_Z);
  Py_VISIT(traverse_module_state->__pyx_n_s_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_accountSnapshot);
  Py_VISIT(traverse_module_state->__pyx_kp_s_account_apiTradingStatus);
  Py_VISIT(traverse_module_state->__pyx_kp_s_account_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_aggTrades);
  Py_VISIT(traverse_module_state->__pyx_n_s_aggregate_trade_iter);
  Py_VISIT(traverse_module_state->__pyx_n_s_allForceOrders);
  Py_VISIT(traverse_module_state->__pyx_n_s_allOpenOrders);
  Py_VISIT(traverse_module_state->__pyx_n_s_allOrders);
  Py_VISIT(traverse_module_state->__pyx_n_s_api_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_api_secret);
  Py_VISIT(traverse_module_state->__pyx_kp_s_application_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_asset);
  Py_VISIT(traverse_module_state->__pyx_kp_s_asset_assetDetail);
  Py_VISIT(traverse_module_state->__pyx_kp_s_asset_assetDividend);
  Py_VISIT(traverse_module_state->__pyx_kp_s_asset_dribblet);
  Py_VISIT(traverse_module_state->__pyx_kp_s_asset_dust);
  Py_VISIT(traverse_module_state->__pyx_kp_s_asset_tradeFee);
  Py_VISIT(traverse_module_state->__pyx_kp_s_asset_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_avgPrice);
  Py_VISIT(traverse_module_state->__pyx_n_s_bal);
  Py_VISIT(traverse_module_state->__pyx_n_s_balance);
  Py_VISIT(traverse_module_state->__pyx_n_s_balances);
  Py_VISIT(traverse_module_state->__pyx_n_s_batchOrders);
  Py_VISIT(traverse_module_state->__pyx_n_s_binance_api_status);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_coin_futures);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_futures);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_futures_testnet);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_isolated_margin);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_isolated_margin_test);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_margin);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_margin_testnet);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_com_testnet);
  Py_VISIT(traverse_module_state->__pyx_kp_s_binance_us);
  Py_VISIT(traverse_module_state->__pyx_n_s_bnbBurn);
  Py_VISIT(traverse_module_state->__pyx_n_s_cancel_all_open_margin_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_cancel_all_open_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_cancel_margin_oco_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_cancel_margin_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_cancel_order);
  Py_VISIT(traverse_module_state->__pyx_kp_s_capital_config_getall);
  Py_VISIT(traverse_module_state->__pyx_kp_s_capital_deposit_address);
  Py_VISIT(traverse_module_state->__pyx_kp_s_capital_deposit_hisrec);
  Py_VISIT(traverse_module_state->__pyx_kp_s_capital_deposit_subAddress);
  Py_VISIT(traverse_module_state->__pyx_kp_s_capital_deposit_subHisrec);
  Py_VISIT(traverse_module_state->__pyx_kp_s_capital_withdraw_apply);
  Py_VISIT(traverse_module_state->__pyx_kp_s_capital_withdraw_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_change_fixed_activity_to_daily_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_close_api_session);
  Py_VISIT(traverse_module_state->__pyx_n_s_colorama);
  Py_VISIT(traverse_module_state->__pyx_n_s_commissionRate);
  Py_VISIT(traverse_module_state->__pyx_kp_u_compiled_on);
  Py_VISIT(traverse_module_state->__pyx_n_s_continuousKlines);
  Py_VISIT(traverse_module_state->__pyx_n_s_countdownCancelAll);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_api_uri);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_futures_api_uri);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_futures_coin_api_url);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_futures_coin_data_api_ur);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_futures_data_api_uri);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_isolated_margin_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_margin_api_uri);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_margin_loan);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_margin_oco_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_margin_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_oco_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_sub_account_futures_trans);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_test_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_create_website_uri);
  Py_VISIT(traverse_module_state->__pyx_n_s_critical);
  Py_VISIT(traverse_module_state->__pyx_n_s_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_date_time_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_date_to_milliseconds);
  Py_VISIT(traverse_module_state->__pyx_n_s_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_debug);
  Py_VISIT(traverse_module_state->__pyx_n_s_delete);
  Py_VISIT(traverse_module_state->__pyx_n_s_delete_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_depth);
  Py_VISIT(traverse_module_state->__pyx_kp_s_dev);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_disableFastWithdrawSwitch);
  Py_VISIT(traverse_module_state->__pyx_n_s_disable_colorama);
  Py_VISIT(traverse_module_state->__pyx_n_s_disable_fast_withdraw_switch);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_enableFastWithdrawSwitch);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_fast_withdraw_switch);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_subaccount_futures);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_subaccount_margin);
  Py_VISIT(traverse_module_state->__pyx_n_s_encode);
  Py_VISIT(traverse_module_state->__pyx_n_s_endTime);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_ts);
  Py_VISIT(traverse_module_state->__pyx_n_s_enter);
  Py_VISIT(traverse_module_state->__pyx_n_s_entry);
  Py_VISIT(traverse_module_state->__pyx_n_s_enumerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_error_msg);
  Py_VISIT(traverse_module_state->__pyx_n_s_error_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_exc_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_exc_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_exceptions);
  Py_VISIT(traverse_module_state->__pyx_n_s_exchange);
  Py_VISIT(traverse_module_state->__pyx_n_s_exchangeInfo);
  Py_VISIT(traverse_module_state->__pyx_kp_u_exchange_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_exchange_api_v1_public_asset_ser);
  Py_VISIT(traverse_module_state->__pyx_n_s_exit);
  Py_VISIT(traverse_module_state->__pyx_n_s_f);
  Py_VISIT(traverse_module_state->__pyx_n_s_first_valid_ts);
  Py_VISIT(traverse_module_state->__pyx_kp_u_for_exchange);
  Py_VISIT(traverse_module_state->__pyx_n_s_force_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_fromId);
  Py_VISIT(traverse_module_state->__pyx_n_s_fundingRate);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_account_balance);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_account_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_account_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_aggregate_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_auto_cancel_all_open_ord);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_cancel_all_open_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_cancel_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_cancel_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_change_leverage);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_change_margin_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_change_position_margin);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_change_position_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_account_balance);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_account_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_aggregate_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_cancel_all_open_ord);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_cancel_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_cancel_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_change_leverage);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_change_margin_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_change_position_mar);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_change_position_mod);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_continous_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_create_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_exchange_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_funding_rate);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_get_all_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_get_open_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_get_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_get_position_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_historical_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_income_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_index_price_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_leverage_bracket);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_liquidation_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_mark_price);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_mark_price_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_open_interest);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_open_interest_hist);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_order_book);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_orderbook_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_ping);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_place_batch_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_position_informatio);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_position_margin_his);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_recent_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_stream_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_stream_get_listen_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_stream_keepalive);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_symbol_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_coin_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_commission_rate);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_create_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_exchange_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_funding_rate);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_get_all_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_get_open_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_get_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_get_position_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_historical_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_income_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_leverage_bracket);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_liquidation_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_mark_price);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_open_interest);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_open_interest_hist);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_order_book);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_orderbook_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_ping);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_place_batch_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_position_information);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_position_margin_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_recent_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_stream_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_stream_get_listen_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_stream_keepalive);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_symbol_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_futures_time);
  Py_VISIT(traverse_module_state->__pyx_kp_s_futures_transfer);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_generate_signature);
  Py_VISIT(traverse_module_state->__pyx_n_s_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_getLogger);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_account_api_trading_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_account_snapshot);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_account_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_aggregate_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_all_coins_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_all_isolated_margin_symbols);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_all_margin_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_all_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_all_tickers);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_asset_balance);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_asset_details);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_asset_dividend_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_avg_price);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_bnb_burn_spot_margin);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_deposit_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_deposit_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dust_log);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_earliest_valid_timestamp);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_exchange_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_fixed_activity_project_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_historical_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_historical_klines_generator);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_historical_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_isolated_margin_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_isolated_margin_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_latest_release_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_latest_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_daily_quota_left);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_daily_redemption_quo);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_interest_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_position);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_product_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_purchase_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lending_redemption_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_account);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_asset);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_loan_details);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_oco_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_price_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_repay_details);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_margin_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_max_margin_loan);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_max_margin_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_my_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_open_isolated_margin_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_open_margin_oco_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_open_margin_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_open_orders);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_order_book);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_orderbook_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_orderbook_tickers);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_products);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_recent_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_server_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_sub_account_assets);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_sub_account_futures_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_sub_account_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_sub_account_transfer_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_deposit_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_deposit_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_futures_details);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_futures_margin_st);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_futures_positionr);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_futures_summary);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_margin_details);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_margin_summary);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_subaccount_transfer_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_symbol_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_symbol_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_system_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_ticker);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_trade_fee);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_universal_transfer_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_used_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_user_agent);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_withdraw_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_withdraw_history_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_handle_response);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_signature);
  Py_VISIT(traverse_module_state->__pyx_n_s_hashlib);
  Py_VISIT(traverse_module_state->__pyx_n_s_headers);
  Py_VISIT(traverse_module_state->__pyx_n_s_helpers);
  Py_VISIT(traverse_module_state->__pyx_n_s_hexdigest);
  Py_VISIT(traverse_module_state->__pyx_n_s_historicalTrades);
  Py_VISIT(traverse_module_state->__pyx_n_s_hmac);
  Py_VISIT(traverse_module_state->__pyx_n_s_http);
  Py_VISIT(traverse_module_state->__pyx_n_s_https);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_binance_api);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_binance_com_api);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_binance_com_sapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_binance_sapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_binance_us_api);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_binance_us_sapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_github_com_repos_LUCIT);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_api_trbinance_com_sapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_dapi_binance_com_futures_d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_dapi_binance_futures_data);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_dapi_binance_us_futures_da);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_dapi_trbinance_com_futures);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_binance_com_fapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_binance_com_futures_d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_binance_fapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_binance_futures_data);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_binance_us_fapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_binance_us_futures_da);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_trbinance_com_fapi);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_fapi_trbinance_com_futures);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_testnet_binance_vision);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_testnet_binance_vision_api);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_testnet_binancefuture_com);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_testnet_binancefuture_com_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_testnet_binancefuture_com_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_www_binance);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_www_binance_com);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_www_binance_us);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_www_trbinance_com);
  Py_VISIT(traverse_module_state->__pyx_kp_s_https_www_trbinance_com_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_idx);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_income);
  Py_VISIT(traverse_module_state->__pyx_n_s_indexPriceKlines);
  Py_VISIT(traverse_module_state->__pyx_n_s_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_session);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_installed_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_interval);
  Py_VISIT(traverse_module_state->__pyx_n_s_interval_to_milliseconds);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_available_please_consider_up);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_update_availabe);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_isolated_margin_stream_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_isolated_margin_stream_get_liste);
  Py_VISIT(traverse_module_state->__pyx_n_s_isolated_margin_stream_keepalive);
  Py_VISIT(traverse_module_state->__pyx_n_s_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_itemgetter);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_join);
  Py_VISIT(traverse_module_state->__pyx_n_s_json);
  Py_VISIT(traverse_module_state->__pyx_n_s_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_kline);
  Py_VISIT(traverse_module_state->__pyx_n_s_klines);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_last_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_last_update_check_github);
  Py_VISIT(traverse_module_state->__pyx_n_s_latest_release_info);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_daily_product_list);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_daily_purchase);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_daily_redeem);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_daily_token_position);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_daily_userLeftQuota);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_daily_userRedemptionQuot);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_positionChanged);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_project_list);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_union_account);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_union_interestHistory);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_union_purchaseRecord);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lending_union_redemptionRecord);
  Py_VISIT(traverse_module_state->__pyx_n_s_leverage);
  Py_VISIT(traverse_module_state->__pyx_n_s_leverageBracket);
  Py_VISIT(traverse_module_state->__pyx_n_s_license_ini);
  Py_VISIT(traverse_module_state->__pyx_n_s_license_profile);
  Py_VISIT(traverse_module_state->__pyx_n_s_license_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_limit);
  Py_VISIT(traverse_module_state->__pyx_n_s_listenKey);
  Py_VISIT(traverse_module_state->__pyx_n_s_llm);
  Py_VISIT(traverse_module_state->__pyx_n_s_logger);
  Py_VISIT(traverse_module_state->__pyx_n_s_logging);
  Py_VISIT(traverse_module_state->__pyx_n_s_lower);
  Py_VISIT(traverse_module_state->__pyx_n_s_lucit_api_secret);
  Py_VISIT(traverse_module_state->__pyx_n_s_lucit_license_ini);
  Py_VISIT(traverse_module_state->__pyx_n_s_lucit_license_profile);
  Py_VISIT(traverse_module_state->__pyx_n_s_lucit_license_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_lucit_licensing_python_manager);
  Py_VISIT(traverse_module_state->__pyx_n_s_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_new_request);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_subaccount_futures_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_subaccount_margin_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_subaccount_to_master_transf);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_subaccount_to_subaccount_tr);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_universal_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_marginType);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_account);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_allOrderList);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_allOrders);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_asset);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_isolated_account);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_isolated_allPairs);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_isolated_create);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_isolated_pair);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_isolated_transfer);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_loan);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_maxBorrowable);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_maxTransferable);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_myTrades);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_openOrders);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_order);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_orderList);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_order_oco);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_pair);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_priceIndex);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_repay);
  Py_VISIT(traverse_module_state->__pyx_n_s_margin_stream_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_margin_stream_get_listen_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_margin_stream_keepalive);
  Py_VISIT(traverse_module_state->__pyx_kp_s_margin_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_markPriceKlines);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_method);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro_entries);
  Py_VISIT(traverse_module_state->__pyx_n_s_msg);
  Py_VISIT(traverse_module_state->__pyx_n_s_myTrades);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_needed_license_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_new_transfer_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_null_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_o);
  Py_VISIT(traverse_module_state->__pyx_n_s_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_openInterest);
  Py_VISIT(traverse_module_state->__pyx_n_s_openInterestHist);
  Py_VISIT(traverse_module_state->__pyx_n_s_openOrders);
  Py_VISIT(traverse_module_state->__pyx_n_s_operator);
  Py_VISIT(traverse_module_state->__pyx_n_s_options);
  Py_VISIT(traverse_module_state->__pyx_n_s_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_limit);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_limit_buy);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_limit_sell);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_market);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_market_buy);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_market_sell);
  Py_VISIT(traverse_module_state->__pyx_kp_s_order_oco);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_oco_buy);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_oco_sell);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_params);
  Py_VISIT(traverse_module_state->__pyx_kp_s_order_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_ordered_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_output);
  Py_VISIT(traverse_module_state->__pyx_n_s_output_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_parent_shutdown_function);
  Py_VISIT(traverse_module_state->__pyx_n_s_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_ping);
  Py_VISIT(traverse_module_state->__pyx_n_s_platform);
  Py_VISIT(traverse_module_state->__pyx_n_s_positionMargin);
  Py_VISIT(traverse_module_state->__pyx_kp_s_positionMargin_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_positionRisk);
  Py_VISIT(traverse_module_state->__pyx_kp_s_positionSide_dual);
  Py_VISIT(traverse_module_state->__pyx_n_s_post);
  Py_VISIT(traverse_module_state->__pyx_n_s_post_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_premiumIndex);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_s_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_products);
  Py_VISIT(traverse_module_state->__pyx_n_s_program_used);
  Py_VISIT(traverse_module_state->__pyx_n_s_proxies);
  Py_VISIT(traverse_module_state->__pyx_n_s_purchase_lending_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_put);
  Py_VISIT(traverse_module_state->__pyx_n_s_put_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_python);
  Py_VISIT(traverse_module_state->__pyx_n_s_python_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_q);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_query_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_query_subaccount_spot_summary);
  Py_VISIT(traverse_module_state->__pyx_n_s_query_universal_transfer_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_raw_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_redeem_lending_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_release);
  Py_VISIT(traverse_module_state->__pyx_n_s_repay_margin_loan);
  Py_VISIT(traverse_module_state->__pyx_n_s_replace);
  Py_VISIT(traverse_module_state->__pyx_n_s_request);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_futures_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_futures_coin_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_futures_coin_data_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_futures_data_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_margin_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_socks5_proxies);
  Py_VISIT(traverse_module_state->__pyx_n_s_request_website);
  Py_VISIT(traverse_module_state->__pyx_n_s_requests);
  Py_VISIT(traverse_module_state->__pyx_n_s_requests_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_requests_params_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_res);
  Py_VISIT(traverse_module_state->__pyx_n_s_respond);
  Py_VISIT(traverse_module_state->__pyx_n_s_response);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_reversed);
  Py_VISIT(traverse_module_state->__pyx_kp_s_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_kp_u_self_API_URL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_self_FUTURES_COIN_DATA_URL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_self_FUTURES_COIN_URL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_self_FUTURES_DATA_URL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_self_FUTURES_URL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_self_MARGIN_API_URL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_self_WEBSITE_URL);
  Py_VISIT(traverse_module_state->__pyx_n_s_send);
  Py_VISIT(traverse_module_state->__pyx_n_s_serverTime);
  Py_VISIT(traverse_module_state->__pyx_n_s_session);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_sha256);
  Py_VISIT(traverse_module_state->__pyx_n_s_side);
  Py_VISIT(traverse_module_state->__pyx_n_s_signature);
  Py_VISIT(traverse_module_state->__pyx_n_s_signed);
  Py_VISIT(traverse_module_state->__pyx_n_s_sleep);
  Py_VISIT(traverse_module_state->__pyx_kp_s_socks5);
  Py_VISIT(traverse_module_state->__pyx_n_s_socks5_proxy_address);
  Py_VISIT(traverse_module_state->__pyx_n_s_socks5_proxy_pass);
  Py_VISIT(traverse_module_state->__pyx_n_s_socks5_proxy_port);
  Py_VISIT(traverse_module_state->__pyx_n_s_socks5_proxy_server);
  Py_VISIT(traverse_module_state->__pyx_n_s_socks5_proxy_ssl_verification);
  Py_VISIT(traverse_module_state->__pyx_n_s_socks5_proxy_user);
  Py_VISIT(traverse_module_state->__pyx_n_s_socks_proxy_uri);
  Py_VISIT(traverse_module_state->__pyx_n_s_sort);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_startTime);
  Py_VISIT(traverse_module_state->__pyx_n_s_start_str);
  Py_VISIT(traverse_module_state->__pyx_kp_s_start_time_and_last_id_may_not_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_start_ts);
  Py_VISIT(traverse_module_state->__pyx_kp_u_started);
  Py_VISIT(traverse_module_state->__pyx_n_s_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_status_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop_manager);
  Py_VISIT(traverse_module_state->__pyx_n_s_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_stream_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_stream_get_listen_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_stream_keepalive);
  Py_VISIT(traverse_module_state->__pyx_n_s_strptime);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_assets);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_futures_account);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_futures_accountSumma);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_futures_enable);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_futures_internalTran);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_futures_positionRisk);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_futures_transfer);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_list);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_margin_account);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_margin_accountSummar);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_margin_enable);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_margin_transfer);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_spotSummary);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_status);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_sub_transfer_history);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_transfer_subToMaster);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_transfer_subToSub);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_transfer_subUserHist);
  Py_VISIT(traverse_module_state->__pyx_kp_s_sub_account_universalTransfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_success);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_symbols);
  Py_VISIT(traverse_module_state->__pyx_n_s_system);
  Py_VISIT(traverse_module_state->__pyx_kp_s_system_status);
  Py_VISIT(traverse_module_state->__pyx_n_s_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_tag_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_temp_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_text);
  Py_VISIT(traverse_module_state->__pyx_n_s_throw);
  Py_VISIT(traverse_module_state->__pyx_n_s_throw_exception);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ticker_24hr);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ticker_allForceOrders);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ticker_bookTicker);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ticker_openInterest);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ticker_price);
  Py_VISIT(traverse_module_state->__pyx_n_s_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_timeInForce);
  Py_VISIT(traverse_module_state->__pyx_n_s_timeframe);
  Py_VISIT(traverse_module_state->__pyx_n_s_timeout);
  Py_VISIT(traverse_module_state->__pyx_n_s_timestamp);
  Py_VISIT(traverse_module_state->__pyx_n_s_timestamp_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_tld);
  Py_VISIT(traverse_module_state->__pyx_kp_u_tld_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_toggle_bnb_burn_spot_margin);
  Py_VISIT(traverse_module_state->__pyx_n_s_trades);
  Py_VISIT(traverse_module_state->__pyx_n_s_transFrom);
  Py_VISIT(traverse_module_state->__pyx_n_s_transTo);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_dust);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_isolated_margin_to_spot);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_margin_to_spot);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_spot_to_isolated_margin);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfer_spot_to_margin);
  Py_VISIT(traverse_module_state->__pyx_kp_s_trbinance_com);
  Py_VISIT(traverse_module_state->__pyx_n_s_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_typing);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unicorn_binance_rest_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicorn_binance_rest_api_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_unicorn_binance_rest_api_manager);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unicorn_binance_rest_api_manager_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unicorn_binance_websocket_api);
  Py_VISIT(traverse_module_state->__pyx_n_s_universal_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_unknown);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_update_msg);
  Py_VISIT(traverse_module_state->__pyx_n_s_upper);
  Py_VISIT(traverse_module_state->__pyx_n_s_uri);
  Py_VISIT(traverse_module_state->__pyx_n_s_urlencode);
  Py_VISIT(traverse_module_state->__pyx_n_s_urllib_parse);
  Py_VISIT(traverse_module_state->__pyx_n_s_userDataStream);
  Py_VISIT(traverse_module_state->__pyx_kp_s_userDataStream_isolated);
  Py_VISIT(traverse_module_state->__pyx_n_s_userTrades);
  Py_VISIT(traverse_module_state->__pyx_n_s_user_agent);
  Py_VISIT(traverse_module_state->__pyx_kp_s_utf_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_v);
  Py_VISIT(traverse_module_state->__pyx_n_s_v1);
  Py_VISIT(traverse_module_state->__pyx_n_s_v2);
  Py_VISIT(traverse_module_state->__pyx_n_s_v3);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_verify);
  Py_VISIT(traverse_module_state->__pyx_n_s_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_warn_on_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_warning);
  Py_VISIT(traverse_module_state->__pyx_n_s_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_withdraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_withdrawList);
  Py_VISIT(traverse_module_state->__pyx_n_s_withdraw_id);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_10);
  Py_VISIT(traverse_module_state->__pyx_int_12);
  Py_VISIT(traverse_module_state->__pyx_int_200);
  Py_VISIT(traverse_module_state->__pyx_int_300);
  Py_VISIT(traverse_module_state->__pyx_int_500);
  Py_VISIT(traverse_module_state->__pyx_int_1000);
  Py_VISIT(traverse_module_state->__pyx_int_3600);
  Py_VISIT(traverse_module_state->__pyx_int_3600000);
  Py_VISIT(traverse_module_state->__pyx_int_neg_4);
  Py_VISIT(traverse_module_state->__pyx_slice__10);
  Py_VISIT(traverse_module_state->__pyx_slice__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__12);
  Py_VISIT(traverse_module_state->__pyx_tuple__13);
  Py_VISIT(traverse_module_state->__pyx_tuple__14);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__16);
  Py_VISIT(traverse_module_state->__pyx_tuple__17);
  Py_VISIT(traverse_module_state->__pyx_tuple__18);
  Py_VISIT(traverse_module_state->__pyx_tuple__19);
  Py_VISIT(traverse_module_state->__pyx_tuple__20);
  Py_VISIT(traverse_module_state->__pyx_tuple__21);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__25);
  Py_VISIT(traverse_module_state->__pyx_tuple__27);
  Py_VISIT(traverse_module_state->__pyx_tuple__28);
  Py_VISIT(traverse_module_state->__pyx_tuple__29);
  Py_VISIT(traverse_module_state->__pyx_tuple__30);
  Py_VISIT(traverse_module_state->__pyx_tuple__31);
  Py_VISIT(traverse_module_state->__pyx_tuple__32);
  Py_VISIT(traverse_module_state->__pyx_tuple__33);
  Py_VISIT(traverse_module_state->__pyx_tuple__34);
  Py_VISIT(traverse_module_state->__pyx_tuple__35);
  Py_VISIT(traverse_module_state->__pyx_tuple__36);
  Py_VISIT(traverse_module_state->__pyx_tuple__37);
  Py_VISIT(traverse_module_state->__pyx_tuple__38);
  Py_VISIT(traverse_module_state->__pyx_tuple__39);
  Py_VISIT(traverse_module_state->__pyx_tuple__40);
  Py_VISIT(traverse_module_state->__pyx_tuple__41);
  Py_VISIT(traverse_module_state->__pyx_tuple__42);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__44);
  Py_VISIT(traverse_module_state->__pyx_tuple__45);
  Py_VISIT(traverse_module_state->__pyx_tuple__46);
  Py_VISIT(traverse_module_state->__pyx_tuple__47);
  Py_VISIT(traverse_module_state->__pyx_tuple__48);
  Py_VISIT(traverse_module_state->__pyx_tuple__49);
  Py_VISIT(traverse_module_state->__pyx_tuple__50);
  Py_VISIT(traverse_module_state->__pyx_tuple__51);
  Py_VISIT(traverse_module_state->__pyx_tuple__52);
  Py_VISIT(traverse_module_state->__pyx_tuple__53);
  Py_VISIT(traverse_module_state->__pyx_tuple__54);
  Py_VISIT(traverse_module_state->__pyx_tuple__55);
  Py_VISIT(traverse_module_state->__pyx_tuple__56);
  Py_VISIT(traverse_module_state->__pyx_tuple__57);
  Py_VISIT(traverse_module_state->__pyx_tuple__58);
  Py_VISIT(traverse_module_state->__pyx_tuple__59);
  Py_VISIT(traverse_module_state->__pyx_tuple__60);
  Py_VISIT(traverse_module_state->__pyx_tuple__61);
  Py_VISIT(traverse_module_state->__pyx_tuple__62);
  Py_VISIT(traverse_module_state->__pyx_tuple__63);
  Py_VISIT(traverse_module_state->__pyx_tuple__64);
  Py_VISIT(traverse_module_state->__pyx_tuple__65);
  Py_VISIT(traverse_module_state->__pyx_tuple__66);
  Py_VISIT(traverse_module_state->__pyx_tuple__67);
  Py_VISIT(traverse_module_state->__pyx_tuple__68);
  Py_VISIT(traverse_module_state->__pyx_tuple__69);
  Py_VISIT(traverse_module_state->__pyx_tuple__70);
  Py_VISIT(traverse_module_state->__pyx_tuple__71);
  Py_VISIT(traverse_module_state->__pyx_tuple__72);
  Py_VISIT(traverse_module_state->__pyx_tuple__73);
  Py_VISIT(traverse_module_state->__pyx_tuple__74);
  Py_VISIT(traverse_module_state->__pyx_tuple__75);
  Py_VISIT(traverse_module_state->__pyx_tuple__76);
  Py_VISIT(traverse_module_state->__pyx_tuple__77);
  Py_VISIT(traverse_module_state->__pyx_tuple__78);
  Py_VISIT(traverse_module_state->__pyx_tuple__79);
  Py_VISIT(traverse_module_state->__pyx_tuple__80);
  Py_VISIT(traverse_module_state->__pyx_tuple__81);
  Py_VISIT(traverse_module_state->__pyx_tuple__82);
  Py_VISIT(traverse_module_state->__pyx_tuple__83);
  Py_VISIT(traverse_module_state->__pyx_tuple__84);
  Py_VISIT(traverse_module_state->__pyx_tuple__85);
  Py_VISIT(traverse_module_state->__pyx_tuple__86);
  Py_VISIT(traverse_module_state->__pyx_tuple__87);
  Py_VISIT(traverse_module_state->__pyx_tuple__88);
  Py_VISIT(traverse_module_state->__pyx_tuple__89);
  Py_VISIT(traverse_module_state->__pyx_tuple__90);
  Py_VISIT(traverse_module_state->__pyx_tuple__91);
  Py_VISIT(traverse_module_state->__pyx_tuple__92);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_tuple__94);
  Py_VISIT(traverse_module_state->__pyx_tuple__95);
  Py_VISIT(traverse_module_state->__pyx_tuple__96);
  Py_VISIT(traverse_module_state->__pyx_tuple__97);
  Py_VISIT(traverse_module_state->__pyx_tuple__98);
  Py_VISIT(traverse_module_state->__pyx_tuple__99);
  Py_VISIT(traverse_module_state->__pyx_slice__143);
  Py_VISIT(traverse_module_state->__pyx_tuple__100);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__102);
  Py_VISIT(traverse_module_state->__pyx_tuple__103);
  Py_VISIT(traverse_module_state->__pyx_tuple__104);
  Py_VISIT(traverse_module_state->__pyx_tuple__105);
  Py_VISIT(traverse_module_state->__pyx_tuple__106);
  Py_VISIT(traverse_module_state->__pyx_tuple__107);
  Py_VISIT(traverse_module_state->__pyx_tuple__108);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_tuple__110);
  Py_VISIT(traverse_module_state->__pyx_tuple__111);
  Py_VISIT(traverse_module_state->__pyx_tuple__112);
  Py_VISIT(traverse_module_state->__pyx_tuple__113);
  Py_VISIT(traverse_module_state->__pyx_tuple__114);
  Py_VISIT(traverse_module_state->__pyx_tuple__115);
  Py_VISIT(traverse_module_state->__pyx_tuple__116);
  Py_VISIT(traverse_module_state->__pyx_tuple__117);
  Py_VISIT(traverse_module_state->__pyx_tuple__118);
  Py_VISIT(traverse_module_state->__pyx_tuple__119);
  Py_VISIT(traverse_module_state->__pyx_tuple__120);
  Py_VISIT(traverse_module_state->__pyx_tuple__121);
  Py_VISIT(traverse_module_state->__pyx_tuple__122);
  Py_VISIT(traverse_module_state->__pyx_tuple__123);
  Py_VISIT(traverse_module_state->__pyx_tuple__124);
  Py_VISIT(traverse_module_state->__pyx_tuple__125);
  Py_VISIT(traverse_module_state->__pyx_tuple__126);
  Py_VISIT(traverse_module_state->__pyx_tuple__127);
  Py_VISIT(traverse_module_state->__pyx_tuple__128);
  Py_VISIT(traverse_module_state->__pyx_tuple__129);
  Py_VISIT(traverse_module_state->__pyx_tuple__130);
  Py_VISIT(traverse_module_state->__pyx_tuple__131);
  Py_VISIT(traverse_module_state->__pyx_tuple__132);
  Py_VISIT(traverse_module_state->__pyx_tuple__133);
  Py_VISIT(traverse_module_state->__pyx_tuple__134);
  Py_VISIT(traverse_module_state->__pyx_tuple__135);
  Py_VISIT(traverse_module_state->__pyx_tuple__136);
  Py_VISIT(traverse_module_state->__pyx_tuple__137);
  Py_VISIT(traverse_module_state->__pyx_tuple__138);
  Py_VISIT(traverse_module_state->__pyx_tuple__139);
  Py_VISIT(traverse_module_state->__pyx_tuple__140);
  Py_VISIT(traverse_module_state->__pyx_tuple__141);
  Py_VISIT(traverse_module_state->__pyx_tuple__142);
  Py_VISIT(traverse_module_state->__pyx_tuple__144);
  Py_VISIT(traverse_module_state->__pyx_tuple__145);
  Py_VISIT(traverse_module_state->__pyx_tuple__146);
  Py_VISIT(traverse_module_state->__pyx_tuple__147);
  Py_VISIT(traverse_module_state->__pyx_tuple__148);
  Py_VISIT(traverse_module_state->__pyx_tuple__149);
  Py_VISIT(traverse_module_state->__pyx_tuple__150);
  Py_VISIT(traverse_module_state->__pyx_tuple__151);
  Py_VISIT(traverse_module_state->__pyx_tuple__152);
  Py_VISIT(traverse_module_state->__pyx_tuple__153);
  Py_VISIT(traverse_module_state->__pyx_tuple__154);
  Py_VISIT(traverse_module_state->__pyx_tuple__155);
  Py_VISIT(traverse_module_state->__pyx_tuple__156);
  Py_VISIT(traverse_module_state->__pyx_tuple__157);
  Py_VISIT(traverse_module_state->__pyx_tuple__158);
  Py_VISIT(traverse_module_state->__pyx_tuple__159);
  Py_VISIT(traverse_module_state->__pyx_tuple__160);
  Py_VISIT(traverse_module_state->__pyx_tuple__161);
  Py_VISIT(traverse_module_state->__pyx_tuple__162);
  Py_VISIT(traverse_module_state->__pyx_tuple__163);
  Py_VISIT(traverse_module_state->__pyx_tuple__164);
  Py_VISIT(traverse_module_state->__pyx_tuple__165);
  Py_VISIT(traverse_module_state->__pyx_tuple__166);
  Py_VISIT(traverse_module_state->__pyx_tuple__167);
  Py_VISIT(traverse_module_state->__pyx_tuple__168);
  Py_VISIT(traverse_module_state->__pyx_tuple__169);
  Py_VISIT(traverse_module_state->__pyx_tuple__170);
  Py_VISIT(traverse_module_state->__pyx_tuple__171);
  Py_VISIT(traverse_module_state->__pyx_tuple__172);
  Py_VISIT(traverse_module_state->__pyx_tuple__173);
  Py_VISIT(traverse_module_state->__pyx_tuple__174);
  Py_VISIT(traverse_module_state->__pyx_tuple__175);
  Py_VISIT(traverse_module_state->__pyx_tuple__176);
  Py_VISIT(traverse_module_state->__pyx_tuple__177);
  Py_VISIT(traverse_module_state->__pyx_tuple__178);
  Py_VISIT(traverse_module_state->__pyx_tuple__179);
  Py_VISIT(traverse_module_state->__pyx_tuple__180);
  Py_VISIT(traverse_module_state->__pyx_tuple__181);
  Py_VISIT(traverse_module_state->__pyx_tuple__182);
  Py_VISIT(traverse_module_state->__pyx_tuple__183);
  Py_VISIT(traverse_module_state->__pyx_tuple__187);
  Py_VISIT(traverse_module_state->__pyx_tuple__188);
  Py_VISIT(traverse_module_state->__pyx_tuple__189);
  Py_VISIT(traverse_module_state->__pyx_tuple__190);
  Py_VISIT(traverse_module_state->__pyx_tuple__192);
  Py_VISIT(traverse_module_state->__pyx_tuple__193);
  Py_VISIT(traverse_module_state->__pyx_tuple__195);
  Py_VISIT(traverse_module_state->__pyx_tuple__197);
  Py_VISIT(traverse_module_state->__pyx_tuple__199);
  Py_VISIT(traverse_module_state->__pyx_tuple__201);
  Py_VISIT(traverse_module_state->__pyx_tuple__203);
  Py_VISIT(traverse_module_state->__pyx_tuple__207);
  Py_VISIT(traverse_module_state->__pyx_tuple__209);
  Py_VISIT(traverse_module_state->__pyx_tuple__211);
  Py_VISIT(traverse_module_state->__pyx_tuple__213);
  Py_VISIT(traverse_module_state->__pyx_tuple__215);
  Py_VISIT(traverse_module_state->__pyx_tuple__217);
  Py_VISIT(traverse_module_state->__pyx_tuple__218);
  Py_VISIT(traverse_module_state->__pyx_tuple__221);
  Py_VISIT(traverse_module_state->__pyx_tuple__226);
  Py_VISIT(traverse_module_state->__pyx_tuple__228);
  Py_VISIT(traverse_module_state->__pyx_tuple__230);
  Py_VISIT(traverse_module_state->__pyx_tuple__231);
  Py_VISIT(traverse_module_state->__pyx_tuple__233);
  Py_VISIT(traverse_module_state->__pyx_tuple__237);
  Py_VISIT(traverse_module_state->__pyx_tuple__241);
  Py_VISIT(traverse_module_state->__pyx_tuple__243);
  Py_VISIT(traverse_module_state->__pyx_tuple__245);
  Py_VISIT(traverse_module_state->__pyx_tuple__248);
  Py_VISIT(traverse_module_state->__pyx_tuple__254);
  Py_VISIT(traverse_module_state->__pyx_tuple__259);
  Py_VISIT(traverse_module_state->__pyx_tuple__260);
  Py_VISIT(traverse_module_state->__pyx_tuple__262);
  Py_VISIT(traverse_module_state->__pyx_tuple__264);
  Py_VISIT(traverse_module_state->__pyx_tuple__266);
  Py_VISIT(traverse_module_state->__pyx_tuple__267);
  Py_VISIT(traverse_module_state->__pyx_tuple__268);
  Py_VISIT(traverse_module_state->__pyx_tuple__274);
  Py_VISIT(traverse_module_state->__pyx_tuple__292);
  Py_VISIT(traverse_module_state->__pyx_tuple__296);
  Py_VISIT(traverse_module_state->__pyx_tuple__308);
  Py_VISIT(traverse_module_state->__pyx_tuple__311);
  Py_VISIT(traverse_module_state->__pyx_tuple__313);
  Py_VISIT(traverse_module_state->__pyx_tuple__314);
  Py_VISIT(traverse_module_state->__pyx_tuple__351);
  Py_VISIT(traverse_module_state->__pyx_tuple__353);
  Py_VISIT(traverse_module_state->__pyx_tuple__391);
  Py_VISIT(traverse_module_state->__pyx_tuple__393);
  Py_VISIT(traverse_module_state->__pyx_tuple__416);
  Py_VISIT(traverse_module_state->__pyx_tuple__486);
  Py_VISIT(traverse_module_state->__pyx_codeobj__22);
  Py_VISIT(traverse_module_state->__pyx_codeobj__26);
  Py_VISIT(traverse_module_state->__pyx_codeobj__191);
  Py_VISIT(traverse_module_state->__pyx_codeobj__194);
  Py_VISIT(traverse_module_state->__pyx_codeobj__196);
  Py_VISIT(traverse_module_state->__pyx_codeobj__198);
  Py_VISIT(traverse_module_state->__pyx_codeobj__200);
  Py_VISIT(traverse_module_state->__pyx_codeobj__202);
  Py_VISIT(traverse_module_state->__pyx_codeobj__204);
  Py_VISIT(traverse_module_state->__pyx_codeobj__205);
  Py_VISIT(traverse_module_state->__pyx_codeobj__206);
  Py_VISIT(traverse_module_state->__pyx_codeobj__208);
  Py_VISIT(traverse_module_state->__pyx_codeobj__210);
  Py_VISIT(traverse_module_state->__pyx_codeobj__212);
  Py_VISIT(traverse_module_state->__pyx_codeobj__214);
  Py_VISIT(traverse_module_state->__pyx_codeobj__216);
  Py_VISIT(traverse_module_state->__pyx_codeobj__219);
  Py_VISIT(traverse_module_state->__pyx_codeobj__220);
  Py_VISIT(traverse_module_state->__pyx_codeobj__222);
  Py_VISIT(traverse_module_state->__pyx_codeobj__223);
  Py_VISIT(traverse_module_state->__pyx_codeobj__224);
  Py_VISIT(traverse_module_state->__pyx_codeobj__225);
  Py_VISIT(traverse_module_state->__pyx_codeobj__227);
  Py_VISIT(traverse_module_state->__pyx_codeobj__229);
  Py_VISIT(traverse_module_state->__pyx_codeobj__232);
  Py_VISIT(traverse_module_state->__pyx_codeobj__234);
  Py_VISIT(traverse_module_state->__pyx_codeobj__235);
  Py_VISIT(traverse_module_state->__pyx_codeobj__236);
  Py_VISIT(traverse_module_state->__pyx_codeobj__238);
  Py_VISIT(traverse_module_state->__pyx_codeobj__239);
  Py_VISIT(traverse_module_state->__pyx_codeobj__240);
  Py_VISIT(traverse_module_state->__pyx_codeobj__242);
  Py_VISIT(traverse_module_state->__pyx_codeobj__244);
  Py_VISIT(traverse_module_state->__pyx_codeobj__246);
  Py_VISIT(traverse_module_state->__pyx_codeobj__247);
  Py_VISIT(traverse_module_state->__pyx_codeobj__249);
  Py_VISIT(traverse_module_state->__pyx_codeobj__250);
  Py_VISIT(traverse_module_state->__pyx_codeobj__251);
  Py_VISIT(traverse_module_state->__pyx_codeobj__252);
  Py_VISIT(traverse_module_state->__pyx_codeobj__253);
  Py_VISIT(traverse_module_state->__pyx_codeobj__255);
  Py_VISIT(traverse_module_state->__pyx_codeobj__256);
  Py_VISIT(traverse_module_state->__pyx_codeobj__257);
  Py_VISIT(traverse_module_state->__pyx_codeobj__258);
  Py_VISIT(traverse_module_state->__pyx_codeobj__261);
  Py_VISIT(traverse_module_state->__pyx_codeobj__263);
  Py_VISIT(traverse_module_state->__pyx_codeobj__265);
  Py_VISIT(traverse_module_state->__pyx_codeobj__269);
  Py_VISIT(traverse_module_state->__pyx_codeobj__270);
  Py_VISIT(traverse_module_state->__pyx_codeobj__271);
  Py_VISIT(traverse_module_state->__pyx_codeobj__272);
  Py_VISIT(traverse_module_state->__pyx_codeobj__273);
  Py_VISIT(traverse_module_state->__pyx_codeobj__275);
  Py_VISIT(traverse_module_state->__pyx_codeobj__276);
  Py_VISIT(traverse_module_state->__pyx_codeobj__277);
  Py_VISIT(traverse_module_state->__pyx_codeobj__278);
  Py_VISIT(traverse_module_state->__pyx_codeobj__279);
  Py_VISIT(traverse_module_state->__pyx_codeobj__280);
  Py_VISIT(traverse_module_state->__pyx_codeobj__281);
  Py_VISIT(traverse_module_state->__pyx_codeobj__282);
  Py_VISIT(traverse_module_state->__pyx_codeobj__283);
  Py_VISIT(traverse_module_state->__pyx_codeobj__284);
  Py_VISIT(traverse_module_state->__pyx_codeobj__285);
  Py_VISIT(traverse_module_state->__pyx_codeobj__286);
  Py_VISIT(traverse_module_state->__pyx_codeobj__287);
  Py_VISIT(traverse_module_state->__pyx_codeobj__288);
  Py_VISIT(traverse_module_state->__pyx_codeobj__289);
  Py_VISIT(traverse_module_state->__pyx_codeobj__290);
  Py_VISIT(traverse_module_state->__pyx_codeobj__291);
  Py_VISIT(traverse_module_state->__pyx_codeobj__293);
  Py_VISIT(traverse_module_state->__pyx_codeobj__294);
  Py_VISIT(traverse_module_state->__pyx_codeobj__295);
  Py_VISIT(traverse_module_state->__pyx_codeobj__297);
  Py_VISIT(traverse_module_state->__pyx_codeobj__298);
  Py_VISIT(traverse_module_state->__pyx_codeobj__299);
  Py_VISIT(traverse_module_state->__pyx_codeobj__300);
  Py_VISIT(traverse_module_state->__pyx_codeobj__301);
  Py_VISIT(traverse_module_state->__pyx_codeobj__302);
  Py_VISIT(traverse_module_state->__pyx_codeobj__303);
  Py_VISIT(traverse_module_state->__pyx_codeobj__304);
  Py_VISIT(traverse_module_state->__pyx_codeobj__305);
  Py_VISIT(traverse_module_state->__pyx_codeobj__306);
  Py_VISIT(traverse_module_state->__pyx_codeobj__307);
  Py_VISIT(traverse_module_state->__pyx_codeobj__309);
  Py_VISIT(traverse_module_state->__pyx_codeobj__310);
  Py_VISIT(traverse_module_state->__pyx_codeobj__312);
  Py_VISIT(traverse_module_state->__pyx_codeobj__315);
  Py_VISIT(traverse_module_state->__pyx_codeobj__316);
  Py_VISIT(traverse_module_state->__pyx_codeobj__317);
  Py_VISIT(traverse_module_state->__pyx_codeobj__318);
  Py_VISIT(traverse_module_state->__pyx_codeobj__319);
  Py_VISIT(traverse_module_state->__pyx_codeobj__320);
  Py_VISIT(traverse_module_state->__pyx_codeobj__321);
  Py_VISIT(traverse_module_state->__pyx_codeobj__322);
  Py_VISIT(traverse_module_state->__pyx_codeobj__323);
  Py_VISIT(traverse_module_state->__pyx_codeobj__324);
  Py_VISIT(traverse_module_state->__pyx_codeobj__325);
  Py_VISIT(traverse_module_state->__pyx_codeobj__326);
  Py_VISIT(traverse_module_state->__pyx_codeobj__327);
  Py_VISIT(traverse_module_state->__pyx_codeobj__328);
  Py_VISIT(traverse_module_state->__pyx_codeobj__329);
  Py_VISIT(traverse_module_state->__pyx_codeobj__330);
  Py_VISIT(traverse_module_state->__pyx_codeobj__331);
  Py_VISIT(traverse_module_state->__pyx_codeobj__332);
  Py_VISIT(traverse_module_state->__pyx_codeobj__333);
  Py_VISIT(traverse_module_state->__pyx_codeobj__334);
  Py_VISIT(traverse_module_state->__pyx_codeobj__335);
  Py_VISIT(traverse_module_state->__pyx_codeobj__336);
  Py_VISIT(traverse_module_state->__pyx_codeobj__337);
  Py_VISIT(traverse_module_state->__pyx_codeobj__338);
  Py_VISIT(traverse_module_state->__pyx_codeobj__339);
  Py_VISIT(traverse_module_state->__pyx_codeobj__340);
  Py_VISIT(traverse_module_state->__pyx_codeobj__341);
  Py_VISIT(traverse_module_state->__pyx_codeobj__342);
  Py_VISIT(traverse_module_state->__pyx_codeobj__343);
  Py_VISIT(traverse_module_state->__pyx_codeobj__344);
  Py_VISIT(traverse_module_state->__pyx_codeobj__345);
  Py_VISIT(traverse_module_state->__pyx_codeobj__346);
  Py_VISIT(traverse_module_state->__pyx_codeobj__347);
  Py_VISIT(traverse_module_state->__pyx_codeobj__348);
  Py_VISIT(traverse_module_state->__pyx_codeobj__349);
  Py_VISIT(traverse_module_state->__pyx_codeobj__350);
  Py_VISIT(traverse_module_state->__pyx_codeobj__352);
  Py_VISIT(traverse_module_state->__pyx_codeobj__354);
  Py_VISIT(traverse_module_state->__pyx_codeobj__355);
  Py_VISIT(traverse_module_state->__pyx_codeobj__356);
  Py_VISIT(traverse_module_state->__pyx_codeobj__357);
  Py_VISIT(traverse_module_state->__pyx_codeobj__358);
  Py_VISIT(traverse_module_state->__pyx_codeobj__359);
  Py_VISIT(traverse_module_state->__pyx_codeobj__360);
  Py_VISIT(traverse_module_state->__pyx_codeobj__361);
  Py_VISIT(traverse_module_state->__pyx_codeobj__362);
  Py_VISIT(traverse_module_state->__pyx_codeobj__363);
  Py_VISIT(traverse_module_state->__pyx_codeobj__364);
  Py_VISIT(traverse_module_state->__pyx_codeobj__365);
  Py_VISIT(traverse_module_state->__pyx_codeobj__366);
  Py_VISIT(traverse_module_state->__pyx_codeobj__367);
  Py_VISIT(traverse_module_state->__pyx_codeobj__368);
  Py_VISIT(traverse_module_state->__pyx_codeobj__369);
  Py_VISIT(traverse_module_state->__pyx_codeobj__370);
  Py_VISIT(traverse_module_state->__pyx_codeobj__371);
  Py_VISIT(traverse_module_state->__pyx_codeobj__372);
  Py_VISIT(traverse_module_state->__pyx_codeobj__373);
  Py_VISIT(traverse_module_state->__pyx_codeobj__374);
  Py_VISIT(traverse_module_state->__pyx_codeobj__375);
  Py_VISIT(traverse_module_state->__pyx_codeobj__376);
  Py_VISIT(traverse_module_state->__pyx_codeobj__377);
  Py_VISIT(traverse_module_state->__pyx_codeobj__378);
  Py_VISIT(traverse_module_state->__pyx_codeobj__379);
  Py_VISIT(traverse_module_state->__pyx_codeobj__380);
  Py_VISIT(traverse_module_state->__pyx_codeobj__381);
  Py_VISIT(traverse_module_state->__pyx_codeobj__382);
  Py_VISIT(traverse_module_state->__pyx_codeobj__383);
  Py_VISIT(traverse_module_state->__pyx_codeobj__384);
  Py_VISIT(traverse_module_state->__pyx_codeobj__385);
  Py_VISIT(traverse_module_state->__pyx_codeobj__386);
  Py_VISIT(traverse_module_state->__pyx_codeobj__387);
  Py_VISIT(traverse_module_state->__pyx_codeobj__388);
  Py_VISIT(traverse_module_state->__pyx_codeobj__389);
  Py_VISIT(traverse_module_state->__pyx_codeobj__390);
  Py_VISIT(traverse_module_state->__pyx_codeobj__392);
  Py_VISIT(traverse_module_state->__pyx_codeobj__394);
  Py_VISIT(traverse_module_state->__pyx_codeobj__395);
  Py_VISIT(traverse_module_state->__pyx_codeobj__396);
  Py_VISIT(traverse_module_state->__pyx_codeobj__397);
  Py_VISIT(traverse_module_state->__pyx_codeobj__398);
  Py_VISIT(traverse_module_state->__pyx_codeobj__399);
  Py_VISIT(traverse_module_state->__pyx_codeobj__400);
  Py_VISIT(traverse_module_state->__pyx_codeobj__401);
  Py_VISIT(traverse_module_state->__pyx_codeobj__402);
  Py_VISIT(traverse_module_state->__pyx_codeobj__403);
  Py_VISIT(traverse_module_state->__pyx_codeobj__404);
  Py_VISIT(traverse_module_state->__pyx_codeobj__405);
  Py_VISIT(traverse_module_state->__pyx_codeobj__406);
  Py_VISIT(traverse_module_state->__pyx_codeobj__407);
  Py_VISIT(traverse_module_state->__pyx_codeobj__408);
  Py_VISIT(traverse_module_state->__pyx_codeobj__409);
  Py_VISIT(traverse_module_state->__pyx_codeobj__410);
  Py_VISIT(traverse_module_state->__pyx_codeobj__411);
  Py_VISIT(traverse_module_state->__pyx_codeobj__412);
  Py_VISIT(traverse_module_state->__pyx_codeobj__413);
  Py_VISIT(traverse_module_state->__pyx_codeobj__414);
  Py_VISIT(traverse_module_state->__pyx_codeobj__415);
  Py_VISIT(traverse_module_state->__pyx_codeobj__417);
  Py_VISIT(traverse_module_state->__pyx_codeobj__418);
  Py_VISIT(traverse_module_state->__pyx_codeobj__419);
  Py_VISIT(traverse_module_state->__pyx_codeobj__420);
  Py_VISIT(traverse_module_state->__pyx_codeobj__421);
  Py_VISIT(traverse_module_state->__pyx_codeobj__422);
  Py_VISIT(traverse_module_state->__pyx_codeobj__423);
  Py_VISIT(traverse_module_state->__pyx_codeobj__424);
  Py_VISIT(traverse_module_state->__pyx_codeobj__425);
  Py_VISIT(traverse_module_state->__pyx_codeobj__426);
  Py_VISIT(traverse_module_state->__pyx_codeobj__427);
  Py_VISIT(traverse_module_state->__pyx_codeobj__428);
  Py_VISIT(traverse_module_state->__pyx_codeobj__429);
  Py_VISIT(traverse_module_state->__pyx_codeobj__430);
  Py_VISIT(traverse_module_state->__pyx_codeobj__431);
  Py_VISIT(traverse_module_state->__pyx_codeobj__432);
  Py_VISIT(traverse_module_state->__pyx_codeobj__433);
  Py_VISIT(traverse_module_state->__pyx_codeobj__434);
  Py_VISIT(traverse_module_state->__pyx_codeobj__435);
  Py_VISIT(traverse_module_state->__pyx_codeobj__436);
  Py_VISIT(traverse_module_state->__pyx_codeobj__437);
  Py_VISIT(traverse_module_state->__pyx_codeobj__438);
  Py_VISIT(traverse_module_state->__pyx_codeobj__439);
  Py_VISIT(traverse_module_state->__pyx_codeobj__440);
  Py_VISIT(traverse_module_state->__pyx_codeobj__441);
  Py_VISIT(traverse_module_state->__pyx_codeobj__442);
  Py_VISIT(traverse_module_state->__pyx_codeobj__443);
  Py_VISIT(traverse_module_state->__pyx_codeobj__444);
  Py_VISIT(traverse_module_state->__pyx_codeobj__445);
  Py_VISIT(traverse_module_state->__pyx_codeobj__446);
  Py_VISIT(traverse_module_state->__pyx_codeobj__447);
  Py_VISIT(traverse_module_state->__pyx_codeobj__448);
  Py_VISIT(traverse_module_state->__pyx_codeobj__449);
  Py_VISIT(traverse_module_state->__pyx_codeobj__450);
  Py_VISIT(traverse_module_state->__pyx_codeobj__451);
  Py_VISIT(traverse_module_state->__pyx_codeobj__452);
  Py_VISIT(traverse_module_state->__pyx_codeobj__453);
  Py_VISIT(traverse_module_state->__pyx_codeobj__454);
  Py_VISIT(traverse_module_state->__pyx_codeobj__455);
  Py_VISIT(traverse_module_state->__pyx_codeobj__456);
  Py_VISIT(traverse_module_state->__pyx_codeobj__457);
  Py_VISIT(traverse_module_state->__pyx_codeobj__458);
  Py_VISIT(traverse_module_state->__pyx_codeobj__459);
  Py_VISIT(traverse_module_state->__pyx_codeobj__460);
  Py_VISIT(traverse_module_state->__pyx_codeobj__461);
  Py_VISIT(traverse_module_state->__pyx_codeobj__462);
  Py_VISIT(traverse_module_state->__pyx_codeobj__463);
  Py_VISIT(traverse_module_state->__pyx_codeobj__464);
  Py_VISIT(traverse_module_state->__pyx_codeobj__465);
  Py_VISIT(traverse_module_state->__pyx_codeobj__466);
  Py_VISIT(traverse_module_state->__pyx_codeobj__467);
  Py_VISIT(traverse_module_state->__pyx_codeobj__468);
  Py_VISIT(traverse_module_state->__pyx_codeobj__469);
  Py_VISIT(traverse_module_state->__pyx_codeobj__470);
  Py_VISIT(traverse_module_state->__pyx_codeobj__471);
  Py_VISIT(traverse_module_state->__pyx_codeobj__472);
  Py_VISIT(traverse_module_state->__pyx_codeobj__473);
  Py_VISIT(traverse_module_state->__pyx_codeobj__474);
  Py_VISIT(traverse_module_state->__pyx_codeobj__475);
  Py_VISIT(traverse_module_state->__pyx_codeobj__476);
  Py_VISIT(traverse_module_state->__pyx_codeobj__477);
  Py_VISIT(traverse_module_state->__pyx_codeobj__478);
  Py_VISIT(traverse_module_state->__pyx_codeobj__479);
  Py_VISIT(traverse_module_state->__pyx_codeobj__480);
  Py_VISIT(traverse_module_state->__pyx_codeobj__481);
  Py_VISIT(traverse_module_state->__pyx_codeobj__482);
  Py_VISIT(traverse_module_state->__pyx_codeobj__483);
  Py_VISIT(traverse_module_state->__pyx_codeobj__484);
  Py_VISIT(traverse_module_state->__pyx_codeobj__485);
  Py_VISIT(traverse_module_state->__pyx_codeobj__487);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr __pyx_mstate_global->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr
#define __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter __pyx_mstate_global->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter
#define __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator __pyx_mstate_global->__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator
#endif
#define __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr __pyx_mstate_global->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr
#define __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter __pyx_mstate_global->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter
#define __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator __pyx_mstate_global->__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator
#define __pyx_kp_u_ __pyx_mstate_global->__pyx_kp_u_
#define __pyx_kp_s_12h __pyx_mstate_global->__pyx_kp_s_12h
#define __pyx_kp_s_15m __pyx_mstate_global->__pyx_kp_s_15m
#define __pyx_kp_s_1M __pyx_mstate_global->__pyx_kp_s_1M
#define __pyx_kp_s_1d __pyx_mstate_global->__pyx_kp_s_1d
#define __pyx_kp_s_1h __pyx_mstate_global->__pyx_kp_s_1h
#define __pyx_kp_s_1m __pyx_mstate_global->__pyx_kp_s_1m
#define __pyx_kp_s_1s __pyx_mstate_global->__pyx_kp_s_1s
#define __pyx_kp_s_1w __pyx_mstate_global->__pyx_kp_s_1w
#define __pyx_kp_s_22 __pyx_mstate_global->__pyx_kp_s_22
#define __pyx_kp_s_27 __pyx_mstate_global->__pyx_kp_s_27
#define __pyx_kp_s_2_0_0 __pyx_mstate_global->__pyx_kp_s_2_0_0
#define __pyx_kp_s_2h __pyx_mstate_global->__pyx_kp_s_2h
#define __pyx_kp_s_30m __pyx_mstate_global->__pyx_kp_s_30m
#define __pyx_kp_s_3d __pyx_mstate_global->__pyx_kp_s_3d
#define __pyx_kp_s_3m __pyx_mstate_global->__pyx_kp_s_3m
#define __pyx_kp_s_4h __pyx_mstate_global->__pyx_kp_s_4h
#define __pyx_kp_s_5m __pyx_mstate_global->__pyx_kp_s_5m
#define __pyx_kp_s_6h __pyx_mstate_global->__pyx_kp_s_6h
#define __pyx_kp_s_8h __pyx_mstate_global->__pyx_kp_s_8h
#define __pyx_n_s_ACK __pyx_mstate_global->__pyx_n_s_ACK
#define __pyx_n_s_AGG_BEST_MATCH __pyx_mstate_global->__pyx_n_s_AGG_BEST_MATCH
#define __pyx_n_s_AGG_BUYER_MAKES __pyx_mstate_global->__pyx_n_s_AGG_BUYER_MAKES
#define __pyx_n_s_AGG_FIRST_TRADE_ID __pyx_mstate_global->__pyx_n_s_AGG_FIRST_TRADE_ID
#define __pyx_n_s_AGG_ID __pyx_mstate_global->__pyx_n_s_AGG_ID
#define __pyx_n_s_AGG_LAST_TRADE_ID __pyx_mstate_global->__pyx_n_s_AGG_LAST_TRADE_ID
#define __pyx_n_s_AGG_PRICE __pyx_mstate_global->__pyx_n_s_AGG_PRICE
#define __pyx_n_s_AGG_QUANTITY __pyx_mstate_global->__pyx_n_s_AGG_QUANTITY
#define __pyx_n_s_AGG_TIME __pyx_mstate_global->__pyx_n_s_AGG_TIME
#define __pyx_n_s_API_KEY __pyx_mstate_global->__pyx_n_s_API_KEY
#define __pyx_n_s_API_SECRET __pyx_mstate_global->__pyx_n_s_API_SECRET
#define __pyx_n_s_API_URL __pyx_mstate_global->__pyx_n_s_API_URL
#define __pyx_n_s_Accept __pyx_mstate_global->__pyx_n_s_Accept
#define __pyx_kp_u_An_exception_occurred __pyx_mstate_global->__pyx_kp_u_An_exception_occurred
#define __pyx_kp_s_An_unofficial_Python_API_to_use __pyx_mstate_global->__pyx_kp_s_An_unofficial_Python_API_to_use
#define __pyx_n_s_BUY __pyx_mstate_global->__pyx_n_s_BUY
#define __pyx_n_s_BinanceAPIException __pyx_mstate_global->__pyx_n_s_BinanceAPIException
#define __pyx_n_s_BinanceRequestException __pyx_mstate_global->__pyx_n_s_BinanceRequestException
#define __pyx_n_s_BinanceRestApiManager __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager
#define __pyx_n_s_BinanceRestApiManager___enter __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager___enter
#define __pyx_n_s_BinanceRestApiManager___exit __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager___exit
#define __pyx_n_s_BinanceRestApiManager___init __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager___init
#define __pyx_n_s_BinanceRestApiManager__create_ap __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__create_ap
#define __pyx_n_s_BinanceRestApiManager__create_fu __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__create_fu
#define __pyx_n_s_BinanceRestApiManager__create_fu_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__create_fu_2
#define __pyx_n_s_BinanceRestApiManager__create_fu_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__create_fu_3
#define __pyx_n_s_BinanceRestApiManager__create_fu_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__create_fu_4
#define __pyx_n_s_BinanceRestApiManager__create_ma __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__create_ma
#define __pyx_n_s_BinanceRestApiManager__create_we __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__create_we
#define __pyx_n_s_BinanceRestApiManager__delete __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__delete
#define __pyx_n_s_BinanceRestApiManager__generate __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__generate
#define __pyx_n_s_BinanceRestApiManager__get __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__get
#define __pyx_n_s_BinanceRestApiManager__get_earli __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__get_earli
#define __pyx_n_s_BinanceRestApiManager__handle_re __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__handle_re
#define __pyx_n_s_BinanceRestApiManager__init_sess __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__init_sess
#define __pyx_n_s_BinanceRestApiManager__order_par __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__order_par
#define __pyx_n_s_BinanceRestApiManager__post __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__post
#define __pyx_n_s_BinanceRestApiManager__put __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__put
#define __pyx_n_s_BinanceRestApiManager__request __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request
#define __pyx_n_s_BinanceRestApiManager__request_a __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_a
#define __pyx_n_s_BinanceRestApiManager__request_f __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_f
#define __pyx_n_s_BinanceRestApiManager__request_f_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_f_2
#define __pyx_n_s_BinanceRestApiManager__request_f_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_f_3
#define __pyx_n_s_BinanceRestApiManager__request_f_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_f_4
#define __pyx_n_s_BinanceRestApiManager__request_l __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_l
#define __pyx_n_s_BinanceRestApiManager__request_m __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_m
#define __pyx_n_s_BinanceRestApiManager__request_w __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager__request_w
#define __pyx_n_s_BinanceRestApiManager_aggregate __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_aggregate
#define __pyx_n_s_BinanceRestApiManager_cancel_all __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_cancel_all
#define __pyx_n_s_BinanceRestApiManager_cancel_all_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_cancel_all_2
#define __pyx_n_s_BinanceRestApiManager_cancel_mar __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_cancel_mar
#define __pyx_n_s_BinanceRestApiManager_cancel_mar_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_cancel_mar_2
#define __pyx_n_s_BinanceRestApiManager_cancel_ord __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_cancel_ord
#define __pyx_n_s_BinanceRestApiManager_change_fix __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_change_fix
#define __pyx_n_s_BinanceRestApiManager_create_iso __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_iso
#define __pyx_n_s_BinanceRestApiManager_create_mar __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_mar
#define __pyx_n_s_BinanceRestApiManager_create_mar_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_mar_2
#define __pyx_n_s_BinanceRestApiManager_create_mar_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_mar_3
#define __pyx_n_s_BinanceRestApiManager_create_oco __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_oco
#define __pyx_n_s_BinanceRestApiManager_create_ord __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_ord
#define __pyx_n_s_BinanceRestApiManager_create_sub __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_sub
#define __pyx_n_s_BinanceRestApiManager_create_tes __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_create_tes
#define __pyx_n_s_BinanceRestApiManager_disable_fa __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_disable_fa
#define __pyx_n_s_BinanceRestApiManager_enable_fas __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_enable_fas
#define __pyx_n_s_BinanceRestApiManager_enable_sub __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_enable_sub
#define __pyx_n_s_BinanceRestApiManager_enable_sub_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_enable_sub_2
#define __pyx_n_s_BinanceRestApiManager_futures_ac __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ac
#define __pyx_n_s_BinanceRestApiManager_futures_ac_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ac_2
#define __pyx_n_s_BinanceRestApiManager_futures_ac_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ac_3
#define __pyx_n_s_BinanceRestApiManager_futures_ac_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ac_4
#define __pyx_n_s_BinanceRestApiManager_futures_ag __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ag
#define __pyx_n_s_BinanceRestApiManager_futures_au __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_au
#define __pyx_n_s_BinanceRestApiManager_futures_ca __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ca
#define __pyx_n_s_BinanceRestApiManager_futures_ca_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ca_2
#define __pyx_n_s_BinanceRestApiManager_futures_ca_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ca_3
#define __pyx_n_s_BinanceRestApiManager_futures_ch __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ch
#define __pyx_n_s_BinanceRestApiManager_futures_ch_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ch_2
#define __pyx_n_s_BinanceRestApiManager_futures_ch_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ch_3
#define __pyx_n_s_BinanceRestApiManager_futures_ch_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ch_4
#define __pyx_n_s_BinanceRestApiManager_futures_co __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co
#define __pyx_n_s_BinanceRestApiManager_futures_co_10 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_10
#define __pyx_n_s_BinanceRestApiManager_futures_co_11 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_11
#define __pyx_n_s_BinanceRestApiManager_futures_co_12 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_12
#define __pyx_n_s_BinanceRestApiManager_futures_co_13 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_13
#define __pyx_n_s_BinanceRestApiManager_futures_co_14 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_14
#define __pyx_n_s_BinanceRestApiManager_futures_co_15 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_15
#define __pyx_n_s_BinanceRestApiManager_futures_co_16 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_16
#define __pyx_n_s_BinanceRestApiManager_futures_co_17 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_17
#define __pyx_n_s_BinanceRestApiManager_futures_co_18 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_18
#define __pyx_n_s_BinanceRestApiManager_futures_co_19 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_19
#define __pyx_n_s_BinanceRestApiManager_futures_co_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_2
#define __pyx_n_s_BinanceRestApiManager_futures_co_20 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_20
#define __pyx_n_s_BinanceRestApiManager_futures_co_21 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_21
#define __pyx_n_s_BinanceRestApiManager_futures_co_22 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_22
#define __pyx_n_s_BinanceRestApiManager_futures_co_23 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_23
#define __pyx_n_s_BinanceRestApiManager_futures_co_24 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_24
#define __pyx_n_s_BinanceRestApiManager_futures_co_25 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_25
#define __pyx_n_s_BinanceRestApiManager_futures_co_26 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_26
#define __pyx_n_s_BinanceRestApiManager_futures_co_27 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_27
#define __pyx_n_s_BinanceRestApiManager_futures_co_28 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_28
#define __pyx_n_s_BinanceRestApiManager_futures_co_29 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_29
#define __pyx_n_s_BinanceRestApiManager_futures_co_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_3
#define __pyx_n_s_BinanceRestApiManager_futures_co_30 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_30
#define __pyx_n_s_BinanceRestApiManager_futures_co_31 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_31
#define __pyx_n_s_BinanceRestApiManager_futures_co_32 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_32
#define __pyx_n_s_BinanceRestApiManager_futures_co_33 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_33
#define __pyx_n_s_BinanceRestApiManager_futures_co_34 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_34
#define __pyx_n_s_BinanceRestApiManager_futures_co_35 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_35
#define __pyx_n_s_BinanceRestApiManager_futures_co_36 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_36
#define __pyx_n_s_BinanceRestApiManager_futures_co_37 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_37
#define __pyx_n_s_BinanceRestApiManager_futures_co_38 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_38
#define __pyx_n_s_BinanceRestApiManager_futures_co_39 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_39
#define __pyx_n_s_BinanceRestApiManager_futures_co_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_4
#define __pyx_n_s_BinanceRestApiManager_futures_co_40 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_40
#define __pyx_n_s_BinanceRestApiManager_futures_co_41 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_41
#define __pyx_n_s_BinanceRestApiManager_futures_co_42 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_42
#define __pyx_n_s_BinanceRestApiManager_futures_co_43 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_43
#define __pyx_n_s_BinanceRestApiManager_futures_co_5 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_5
#define __pyx_n_s_BinanceRestApiManager_futures_co_6 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_6
#define __pyx_n_s_BinanceRestApiManager_futures_co_7 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_7
#define __pyx_n_s_BinanceRestApiManager_futures_co_8 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_8
#define __pyx_n_s_BinanceRestApiManager_futures_co_9 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_co_9
#define __pyx_n_s_BinanceRestApiManager_futures_cr __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_cr
#define __pyx_n_s_BinanceRestApiManager_futures_ex __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ex
#define __pyx_n_s_BinanceRestApiManager_futures_fu __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_fu
#define __pyx_n_s_BinanceRestApiManager_futures_ge __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ge
#define __pyx_n_s_BinanceRestApiManager_futures_ge_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ge_2
#define __pyx_n_s_BinanceRestApiManager_futures_ge_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ge_3
#define __pyx_n_s_BinanceRestApiManager_futures_ge_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ge_4
#define __pyx_n_s_BinanceRestApiManager_futures_hi __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_hi
#define __pyx_n_s_BinanceRestApiManager_futures_in __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_in
#define __pyx_n_s_BinanceRestApiManager_futures_kl __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_kl
#define __pyx_n_s_BinanceRestApiManager_futures_le __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_le
#define __pyx_n_s_BinanceRestApiManager_futures_li __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_li
#define __pyx_n_s_BinanceRestApiManager_futures_ma __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ma
#define __pyx_n_s_BinanceRestApiManager_futures_op __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_op
#define __pyx_n_s_BinanceRestApiManager_futures_op_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_op_2
#define __pyx_n_s_BinanceRestApiManager_futures_or __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_or
#define __pyx_n_s_BinanceRestApiManager_futures_or_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_or_2
#define __pyx_n_s_BinanceRestApiManager_futures_pi __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_pi
#define __pyx_n_s_BinanceRestApiManager_futures_pl __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_pl
#define __pyx_n_s_BinanceRestApiManager_futures_po __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_po
#define __pyx_n_s_BinanceRestApiManager_futures_po_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_po_2
#define __pyx_n_s_BinanceRestApiManager_futures_re __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_re
#define __pyx_n_s_BinanceRestApiManager_futures_st __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_st
#define __pyx_n_s_BinanceRestApiManager_futures_st_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_st_2
#define __pyx_n_s_BinanceRestApiManager_futures_st_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_st_3
#define __pyx_n_s_BinanceRestApiManager_futures_sy __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_sy
#define __pyx_n_s_BinanceRestApiManager_futures_ti __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ti
#define __pyx_n_s_BinanceRestApiManager_futures_ti_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_futures_ti_2
#define __pyx_n_s_BinanceRestApiManager_get_accoun __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_accoun
#define __pyx_n_s_BinanceRestApiManager_get_accoun_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_accoun_2
#define __pyx_n_s_BinanceRestApiManager_get_accoun_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_accoun_3
#define __pyx_n_s_BinanceRestApiManager_get_accoun_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_accoun_4
#define __pyx_n_s_BinanceRestApiManager_get_aggreg __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_aggreg
#define __pyx_n_s_BinanceRestApiManager_get_all_co __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_all_co
#define __pyx_n_s_BinanceRestApiManager_get_all_is __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_all_is
#define __pyx_n_s_BinanceRestApiManager_get_all_ma __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_all_ma
#define __pyx_n_s_BinanceRestApiManager_get_all_or __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_all_or
#define __pyx_n_s_BinanceRestApiManager_get_all_ti __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_all_ti
#define __pyx_n_s_BinanceRestApiManager_get_asset __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_asset
#define __pyx_n_s_BinanceRestApiManager_get_asset_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_asset_2
#define __pyx_n_s_BinanceRestApiManager_get_asset_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_asset_3
#define __pyx_n_s_BinanceRestApiManager_get_avg_pr __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_avg_pr
#define __pyx_n_s_BinanceRestApiManager_get_bnb_bu __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_bnb_bu
#define __pyx_n_s_BinanceRestApiManager_get_deposi __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_deposi
#define __pyx_n_s_BinanceRestApiManager_get_deposi_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_deposi_2
#define __pyx_n_s_BinanceRestApiManager_get_dust_l __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_dust_l
#define __pyx_n_s_BinanceRestApiManager_get_exchan __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_exchan
#define __pyx_n_s_BinanceRestApiManager_get_fixed __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_fixed
#define __pyx_n_s_BinanceRestApiManager_get_histor __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_histor
#define __pyx_n_s_BinanceRestApiManager_get_histor_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_histor_2
#define __pyx_n_s_BinanceRestApiManager_get_histor_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_histor_3
#define __pyx_n_s_BinanceRestApiManager_get_isolat __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_isolat
#define __pyx_n_s_BinanceRestApiManager_get_isolat_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_isolat_2
#define __pyx_n_s_BinanceRestApiManager_get_klines __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_klines
#define __pyx_n_s_BinanceRestApiManager_get_latest __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_latest
#define __pyx_n_s_BinanceRestApiManager_get_latest_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_latest_2
#define __pyx_n_s_BinanceRestApiManager_get_lendin __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin
#define __pyx_n_s_BinanceRestApiManager_get_lendin_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin_2
#define __pyx_n_s_BinanceRestApiManager_get_lendin_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin_3
#define __pyx_n_s_BinanceRestApiManager_get_lendin_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin_4
#define __pyx_n_s_BinanceRestApiManager_get_lendin_5 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin_5
#define __pyx_n_s_BinanceRestApiManager_get_lendin_6 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin_6
#define __pyx_n_s_BinanceRestApiManager_get_lendin_7 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin_7
#define __pyx_n_s_BinanceRestApiManager_get_lendin_8 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_lendin_8
#define __pyx_n_s_BinanceRestApiManager_get_margin __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin
#define __pyx_n_s_BinanceRestApiManager_get_margin_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_2
#define __pyx_n_s_BinanceRestApiManager_get_margin_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_3
#define __pyx_n_s_BinanceRestApiManager_get_margin_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_4
#define __pyx_n_s_BinanceRestApiManager_get_margin_5 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_5
#define __pyx_n_s_BinanceRestApiManager_get_margin_6 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_6
#define __pyx_n_s_BinanceRestApiManager_get_margin_7 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_7
#define __pyx_n_s_BinanceRestApiManager_get_margin_8 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_8
#define __pyx_n_s_BinanceRestApiManager_get_margin_9 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_margin_9
#define __pyx_n_s_BinanceRestApiManager_get_max_ma __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_max_ma
#define __pyx_n_s_BinanceRestApiManager_get_max_ma_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_max_ma_2
#define __pyx_n_s_BinanceRestApiManager_get_my_tra __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_my_tra
#define __pyx_n_s_BinanceRestApiManager_get_open_i __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_open_i
#define __pyx_n_s_BinanceRestApiManager_get_open_m __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_open_m
#define __pyx_n_s_BinanceRestApiManager_get_open_m_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_open_m_2
#define __pyx_n_s_BinanceRestApiManager_get_open_o __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_open_o
#define __pyx_n_s_BinanceRestApiManager_get_order __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_order
#define __pyx_n_s_BinanceRestApiManager_get_order_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_order_2
#define __pyx_n_s_BinanceRestApiManager_get_orderb __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_orderb
#define __pyx_n_s_BinanceRestApiManager_get_orderb_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_orderb_2
#define __pyx_n_s_BinanceRestApiManager_get_produc __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_produc
#define __pyx_n_s_BinanceRestApiManager_get_recent __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_recent
#define __pyx_n_s_BinanceRestApiManager_get_server __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_server
#define __pyx_n_s_BinanceRestApiManager_get_sub_ac __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_sub_ac
#define __pyx_n_s_BinanceRestApiManager_get_sub_ac_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_sub_ac_2
#define __pyx_n_s_BinanceRestApiManager_get_sub_ac_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_sub_ac_3
#define __pyx_n_s_BinanceRestApiManager_get_sub_ac_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_sub_ac_4
#define __pyx_n_s_BinanceRestApiManager_get_subacc __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc
#define __pyx_n_s_BinanceRestApiManager_get_subacc_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_2
#define __pyx_n_s_BinanceRestApiManager_get_subacc_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_3
#define __pyx_n_s_BinanceRestApiManager_get_subacc_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_4
#define __pyx_n_s_BinanceRestApiManager_get_subacc_5 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_5
#define __pyx_n_s_BinanceRestApiManager_get_subacc_6 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_6
#define __pyx_n_s_BinanceRestApiManager_get_subacc_7 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_7
#define __pyx_n_s_BinanceRestApiManager_get_subacc_8 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_8
#define __pyx_n_s_BinanceRestApiManager_get_subacc_9 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_subacc_9
#define __pyx_n_s_BinanceRestApiManager_get_symbol __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_symbol
#define __pyx_n_s_BinanceRestApiManager_get_symbol_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_symbol_2
#define __pyx_n_s_BinanceRestApiManager_get_system __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_system
#define __pyx_n_s_BinanceRestApiManager_get_ticker __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_ticker
#define __pyx_n_s_BinanceRestApiManager_get_trade __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_trade
#define __pyx_n_s_BinanceRestApiManager_get_univer __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_univer
#define __pyx_n_s_BinanceRestApiManager_get_used_w __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_used_w
#define __pyx_n_s_BinanceRestApiManager_get_user_a __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_user_a
#define __pyx_n_s_BinanceRestApiManager_get_versio __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_versio
#define __pyx_n_s_BinanceRestApiManager_get_withdr __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_withdr
#define __pyx_n_s_BinanceRestApiManager_get_withdr_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_get_withdr_2
#define __pyx_n_s_BinanceRestApiManager_is_update __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_is_update
#define __pyx_n_s_BinanceRestApiManager_isolated_m __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_isolated_m
#define __pyx_n_s_BinanceRestApiManager_isolated_m_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_isolated_m_2
#define __pyx_n_s_BinanceRestApiManager_isolated_m_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_isolated_m_3
#define __pyx_n_s_BinanceRestApiManager_make_subac __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_make_subac
#define __pyx_n_s_BinanceRestApiManager_make_subac_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_make_subac_2
#define __pyx_n_s_BinanceRestApiManager_make_subac_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_make_subac_3
#define __pyx_n_s_BinanceRestApiManager_make_subac_4 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_make_subac_4
#define __pyx_n_s_BinanceRestApiManager_make_unive __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_make_unive
#define __pyx_n_s_BinanceRestApiManager_margin_str __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_margin_str
#define __pyx_n_s_BinanceRestApiManager_margin_str_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_margin_str_2
#define __pyx_n_s_BinanceRestApiManager_margin_str_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_margin_str_3
#define __pyx_n_s_BinanceRestApiManager_new_transf __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_new_transf
#define __pyx_n_s_BinanceRestApiManager_order_limi __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_limi
#define __pyx_n_s_BinanceRestApiManager_order_limi_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_limi_2
#define __pyx_n_s_BinanceRestApiManager_order_limi_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_limi_3
#define __pyx_n_s_BinanceRestApiManager_order_mark __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_mark
#define __pyx_n_s_BinanceRestApiManager_order_mark_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_mark_2
#define __pyx_n_s_BinanceRestApiManager_order_mark_3 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_mark_3
#define __pyx_n_s_BinanceRestApiManager_order_oco __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_oco
#define __pyx_n_s_BinanceRestApiManager_order_oco_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_order_oco_2
#define __pyx_n_s_BinanceRestApiManager_ping __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_ping
#define __pyx_n_s_BinanceRestApiManager_purchase_l __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_purchase_l
#define __pyx_n_s_BinanceRestApiManager_query_suba __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_query_suba
#define __pyx_n_s_BinanceRestApiManager_query_univ __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_query_univ
#define __pyx_n_s_BinanceRestApiManager_redeem_len __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_redeem_len
#define __pyx_n_s_BinanceRestApiManager_repay_marg __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_repay_marg
#define __pyx_n_s_BinanceRestApiManager_stop_manag __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_stop_manag
#define __pyx_n_s_BinanceRestApiManager_stream_clo __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_stream_clo
#define __pyx_n_s_BinanceRestApiManager_stream_get __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_stream_get
#define __pyx_n_s_BinanceRestApiManager_stream_kee __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_stream_kee
#define __pyx_n_s_BinanceRestApiManager_toggle_bnb __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_toggle_bnb
#define __pyx_n_s_BinanceRestApiManager_transfer_d __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_transfer_d
#define __pyx_n_s_BinanceRestApiManager_transfer_h __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_transfer_h
#define __pyx_n_s_BinanceRestApiManager_transfer_i __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_transfer_i
#define __pyx_n_s_BinanceRestApiManager_transfer_m __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_transfer_m
#define __pyx_n_s_BinanceRestApiManager_transfer_s __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_transfer_s
#define __pyx_n_s_BinanceRestApiManager_transfer_s_2 __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_transfer_s_2
#define __pyx_n_s_BinanceRestApiManager_universal __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_universal
#define __pyx_n_s_BinanceRestApiManager_withdraw __pyx_mstate_global->__pyx_n_s_BinanceRestApiManager_withdraw
#define __pyx_kp_s_BinanceWebSocketApiManager_stop __pyx_mstate_global->__pyx_kp_s_BinanceWebSocketApiManager_stop
#define __pyx_n_s_BinanceWithdrawException __pyx_mstate_global->__pyx_n_s_BinanceWithdrawException
#define __pyx_n_s_C2C_MAIN __pyx_mstate_global->__pyx_n_s_C2C_MAIN
#define __pyx_n_s_C2C_MINING __pyx_mstate_global->__pyx_n_s_C2C_MINING
#define __pyx_n_s_C2C_UMFUTURE __pyx_mstate_global->__pyx_n_s_C2C_UMFUTURE
#define __pyx_n_s_CANCELED __pyx_mstate_global->__pyx_n_s_CANCELED
#define __pyx_n_s_CMFUTURE_MAIN __pyx_mstate_global->__pyx_n_s_CMFUTURE_MAIN
#define __pyx_n_s_COIN_FUTURE_TO_SPOT __pyx_mstate_global->__pyx_n_s_COIN_FUTURE_TO_SPOT
#define __pyx_kp_u_Created_SOCKS5_proxy_URI __pyx_mstate_global->__pyx_kp_u_Created_SOCKS5_proxy_URI
#define __pyx_n_s_Date __pyx_mstate_global->__pyx_n_s_Date
#define __pyx_n_s_EXPIRED __pyx_mstate_global->__pyx_n_s_EXPIRED
#define __pyx_kp_u_Entering_with_context __pyx_mstate_global->__pyx_kp_u_Entering_with_context
#define __pyx_n_s_FIAT_TO_MINING __pyx_mstate_global->__pyx_n_s_FIAT_TO_MINING
#define __pyx_n_s_FIAT_TO_SPOT __pyx_mstate_global->__pyx_n_s_FIAT_TO_SPOT
#define __pyx_n_s_FIAT_TO_USDT_FUTURE __pyx_mstate_global->__pyx_n_s_FIAT_TO_USDT_FUTURE
#define __pyx_n_s_FILLED __pyx_mstate_global->__pyx_n_s_FILLED
#define __pyx_n_s_FOK __pyx_mstate_global->__pyx_n_s_FOK
#define __pyx_n_s_FULL __pyx_mstate_global->__pyx_n_s_FULL
#define __pyx_n_s_FUTURES_API_VERSION __pyx_mstate_global->__pyx_n_s_FUTURES_API_VERSION
#define __pyx_n_s_FUTURES_API_VERSION2 __pyx_mstate_global->__pyx_n_s_FUTURES_API_VERSION2
#define __pyx_n_s_FUTURES_COIN_DATA_URL __pyx_mstate_global->__pyx_n_s_FUTURES_COIN_DATA_URL
#define __pyx_n_s_FUTURES_COIN_URL __pyx_mstate_global->__pyx_n_s_FUTURES_COIN_URL
#define __pyx_n_s_FUTURES_DATA_URL __pyx_mstate_global->__pyx_n_s_FUTURES_DATA_URL
#define __pyx_n_s_FUTURES_URL __pyx_mstate_global->__pyx_n_s_FUTURES_URL
#define __pyx_n_s_GTC __pyx_mstate_global->__pyx_n_s_GTC
#define __pyx_n_s_IOC __pyx_mstate_global->__pyx_n_s_IOC
#define __pyx_n_s_ISOLATED_MARGIN __pyx_mstate_global->__pyx_n_s_ISOLATED_MARGIN
#define __pyx_kp_u_Initiating_colorama __pyx_mstate_global->__pyx_kp_u_Initiating_colorama
#define __pyx_kp_s_Invalid_Response_s __pyx_mstate_global->__pyx_kp_s_Invalid_Response_s
#define __pyx_n_s_KLINE_INTERVAL_12HOUR __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_12HOUR
#define __pyx_n_s_KLINE_INTERVAL_15MINUTE __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_15MINUTE
#define __pyx_n_s_KLINE_INTERVAL_1DAY __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_1DAY
#define __pyx_n_s_KLINE_INTERVAL_1HOUR __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_1HOUR
#define __pyx_n_s_KLINE_INTERVAL_1MINUTE __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_1MINUTE
#define __pyx_n_s_KLINE_INTERVAL_1MONTH __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_1MONTH
#define __pyx_n_s_KLINE_INTERVAL_1SECOND __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_1SECOND
#define __pyx_n_s_KLINE_INTERVAL_1WEEK __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_1WEEK
#define __pyx_n_s_KLINE_INTERVAL_2HOUR __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_2HOUR
#define __pyx_n_s_KLINE_INTERVAL_30MINUTE __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_30MINUTE
#define __pyx_n_s_KLINE_INTERVAL_3DAY __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_3DAY
#define __pyx_n_s_KLINE_INTERVAL_3MINUTE __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_3MINUTE
#define __pyx_n_s_KLINE_INTERVAL_4HOUR __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_4HOUR
#define __pyx_n_s_KLINE_INTERVAL_5MINUTE __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_5MINUTE
#define __pyx_n_s_KLINE_INTERVAL_6HOUR __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_6HOUR
#define __pyx_n_s_KLINE_INTERVAL_8HOUR __pyx_mstate_global->__pyx_n_s_KLINE_INTERVAL_8HOUR
#define __pyx_n_s_KeyError __pyx_mstate_global->__pyx_n_s_KeyError
#define __pyx_n_s_LIMIT __pyx_mstate_global->__pyx_n_s_LIMIT
#define __pyx_n_s_LIMIT_MAKER __pyx_mstate_global->__pyx_n_s_LIMIT_MAKER
#define __pyx_kp_u_Leaving_with_context __pyx_mstate_global->__pyx_kp_u_Leaving_with_context
#define __pyx_n_s_LucitLicensingManager __pyx_mstate_global->__pyx_n_s_LucitLicensingManager
#define __pyx_n_s_M __pyx_mstate_global->__pyx_n_s_M
#define __pyx_n_s_MAIN_C2C __pyx_mstate_global->__pyx_n_s_MAIN_C2C
#define __pyx_n_s_MAIN_CMFUTURE __pyx_mstate_global->__pyx_n_s_MAIN_CMFUTURE
#define __pyx_n_s_MAIN_MARGIN __pyx_mstate_global->__pyx_n_s_MAIN_MARGIN
#define __pyx_n_s_MAIN_MINING __pyx_mstate_global->__pyx_n_s_MAIN_MINING
#define __pyx_n_s_MAIN_UMFUTURE __pyx_mstate_global->__pyx_n_s_MAIN_UMFUTURE
#define __pyx_n_s_MARGIN_API_URL __pyx_mstate_global->__pyx_n_s_MARGIN_API_URL
#define __pyx_n_s_MARGIN_API_VERSION __pyx_mstate_global->__pyx_n_s_MARGIN_API_VERSION
#define __pyx_n_s_MARGIN_CROSS_TO_SPOT __pyx_mstate_global->__pyx_n_s_MARGIN_CROSS_TO_SPOT
#define __pyx_n_s_MARGIN_CROSS_TO_USDT_FUTURE __pyx_mstate_global->__pyx_n_s_MARGIN_CROSS_TO_USDT_FUTURE
#define __pyx_n_s_MARGIN_MAIN __pyx_mstate_global->__pyx_n_s_MARGIN_MAIN
#define __pyx_n_s_MARGIN_UMFUTURE __pyx_mstate_global->__pyx_n_s_MARGIN_UMFUTURE
#define __pyx_n_s_MARKET __pyx_mstate_global->__pyx_n_s_MARKET
#define __pyx_n_s_MINING_C2C __pyx_mstate_global->__pyx_n_s_MINING_C2C
#define __pyx_n_s_MINING_MAIN __pyx_mstate_global->__pyx_n_s_MINING_MAIN
#define __pyx_n_s_MINING_TO_FIAT __pyx_mstate_global->__pyx_n_s_MINING_TO_FIAT
#define __pyx_n_s_MINING_TO_SPOT __pyx_mstate_global->__pyx_n_s_MINING_TO_SPOT
#define __pyx_n_s_MINING_TO_USDT_FUTURE __pyx_mstate_global->__pyx_n_s_MINING_TO_USDT_FUTURE
#define __pyx_n_s_MINING_UMFUTURE __pyx_mstate_global->__pyx_n_s_MINING_UMFUTURE
#define __pyx_n_s_NEW __pyx_mstate_global->__pyx_n_s_NEW
#define __pyx_kp_u_New_instance_of __pyx_mstate_global->__pyx_kp_u_New_instance_of
#define __pyx_n_s_ORDER_RESP_TYPE_ACK __pyx_mstate_global->__pyx_n_s_ORDER_RESP_TYPE_ACK
#define __pyx_n_s_ORDER_RESP_TYPE_FULL __pyx_mstate_global->__pyx_n_s_ORDER_RESP_TYPE_FULL
#define __pyx_n_s_ORDER_RESP_TYPE_RESULT __pyx_mstate_global->__pyx_n_s_ORDER_RESP_TYPE_RESULT
#define __pyx_n_s_ORDER_STATUS_CANCELED __pyx_mstate_global->__pyx_n_s_ORDER_STATUS_CANCELED
#define __pyx_n_s_ORDER_STATUS_EXPIRED __pyx_mstate_global->__pyx_n_s_ORDER_STATUS_EXPIRED
#define __pyx_n_s_ORDER_STATUS_FILLED __pyx_mstate_global->__pyx_n_s_ORDER_STATUS_FILLED
#define __pyx_n_s_ORDER_STATUS_NEW __pyx_mstate_global->__pyx_n_s_ORDER_STATUS_NEW
#define __pyx_n_s_ORDER_STATUS_PARTIALLY_FILLED __pyx_mstate_global->__pyx_n_s_ORDER_STATUS_PARTIALLY_FILLED
#define __pyx_n_s_ORDER_STATUS_PENDING_CANCEL __pyx_mstate_global->__pyx_n_s_ORDER_STATUS_PENDING_CANCEL
#define __pyx_n_s_ORDER_STATUS_REJECTED __pyx_mstate_global->__pyx_n_s_ORDER_STATUS_REJECTED
#define __pyx_n_s_ORDER_TYPE_LIMIT __pyx_mstate_global->__pyx_n_s_ORDER_TYPE_LIMIT
#define __pyx_n_s_ORDER_TYPE_LIMIT_MAKER __pyx_mstate_global->__pyx_n_s_ORDER_TYPE_LIMIT_MAKER
#define __pyx_n_s_ORDER_TYPE_MARKET __pyx_mstate_global->__pyx_n_s_ORDER_TYPE_MARKET
#define __pyx_n_s_ORDER_TYPE_STOP_LOSS __pyx_mstate_global->__pyx_n_s_ORDER_TYPE_STOP_LOSS
#define __pyx_n_s_ORDER_TYPE_STOP_LOSS_LIMIT __pyx_mstate_global->__pyx_n_s_ORDER_TYPE_STOP_LOSS_LIMIT
#define __pyx_n_s_ORDER_TYPE_TAKE_PROFIT __pyx_mstate_global->__pyx_n_s_ORDER_TYPE_TAKE_PROFIT
#define __pyx_n_s_ORDER_TYPE_TAKE_PROFIT_LIMIT __pyx_mstate_global->__pyx_n_s_ORDER_TYPE_TAKE_PROFIT_LIMIT
#define __pyx_n_s_Optional __pyx_mstate_global->__pyx_n_s_Optional
#define __pyx_kp_s_Optional_bool __pyx_mstate_global->__pyx_kp_s_Optional_bool
#define __pyx_kp_s_Optional_str __pyx_mstate_global->__pyx_kp_s_Optional_str
#define __pyx_n_s_PARTIALLY_FILLED __pyx_mstate_global->__pyx_n_s_PARTIALLY_FILLED
#define __pyx_n_s_PENDING_CANCEL __pyx_mstate_global->__pyx_n_s_PENDING_CANCEL
#define __pyx_n_s_PRIVATE_API_VERSION __pyx_mstate_global->__pyx_n_s_PRIVATE_API_VERSION
#define __pyx_n_s_PUBLIC_API_VERSION __pyx_mstate_global->__pyx_n_s_PUBLIC_API_VERSION
#define __pyx_n_s_REJECTED __pyx_mstate_global->__pyx_n_s_REJECTED
#define __pyx_n_s_RESULT __pyx_mstate_global->__pyx_n_s_RESULT
#define __pyx_kp_u_Read_the_docs_to_see_a_list_of __pyx_mstate_global->__pyx_kp_u_Read_the_docs_to_see_a_list_of
#define __pyx_kp_u_Release __pyx_mstate_global->__pyx_kp_u_Release
#define __pyx_n_s_SELL __pyx_mstate_global->__pyx_n_s_SELL
#define __pyx_n_s_SIDE_BUY __pyx_mstate_global->__pyx_n_s_SIDE_BUY
#define __pyx_n_s_SIDE_SELL __pyx_mstate_global->__pyx_n_s_SIDE_SELL
#define __pyx_n_s_SPOT __pyx_mstate_global->__pyx_n_s_SPOT
#define __pyx_n_s_SPOT_TO_COIN_FUTURE __pyx_mstate_global->__pyx_n_s_SPOT_TO_COIN_FUTURE
#define __pyx_n_s_SPOT_TO_FIAT __pyx_mstate_global->__pyx_n_s_SPOT_TO_FIAT
#define __pyx_n_s_SPOT_TO_MARGIN_CROSS __pyx_mstate_global->__pyx_n_s_SPOT_TO_MARGIN_CROSS
#define __pyx_n_s_SPOT_TO_MINING __pyx_mstate_global->__pyx_n_s_SPOT_TO_MINING
#define __pyx_n_s_SPOT_TO_USDT_FUTURE __pyx_mstate_global->__pyx_n_s_SPOT_TO_USDT_FUTURE
#define __pyx_n_s_STOP_LOSS __pyx_mstate_global->__pyx_n_s_STOP_LOSS
#define __pyx_n_s_STOP_LOSS_LIMIT __pyx_mstate_global->__pyx_n_s_STOP_LOSS_LIMIT
#define __pyx_n_s_SYMBOL_TYPE_SPOT __pyx_mstate_global->__pyx_n_s_SYMBOL_TYPE_SPOT
#define __pyx_n_s_T __pyx_mstate_global->__pyx_n_s_T
#define __pyx_n_s_TAKE_PROFIT __pyx_mstate_global->__pyx_n_s_TAKE_PROFIT
#define __pyx_n_s_TAKE_PROFIT_LIMIT __pyx_mstate_global->__pyx_n_s_TAKE_PROFIT_LIMIT
#define __pyx_n_s_TIME_IN_FORCE_FOK __pyx_mstate_global->__pyx_n_s_TIME_IN_FORCE_FOK
#define __pyx_n_s_TIME_IN_FORCE_GTC __pyx_mstate_global->__pyx_n_s_TIME_IN_FORCE_GTC
#define __pyx_n_s_TIME_IN_FORCE_IOC __pyx_mstate_global->__pyx_n_s_TIME_IN_FORCE_IOC
#define __pyx_kp_s_The_parameter_BinanceRestApiMana __pyx_mstate_global->__pyx_kp_s_The_parameter_BinanceRestApiMana
#define __pyx_kp_s_There_is_no_entry_with_withdraw __pyx_mstate_global->__pyx_kp_s_There_is_no_entry_with_withdraw
#define __pyx_n_s_UMFUTURE_C2C __pyx_mstate_global->__pyx_n_s_UMFUTURE_C2C
#define __pyx_n_s_UMFUTURE_MAIN __pyx_mstate_global->__pyx_n_s_UMFUTURE_MAIN
#define __pyx_n_s_UMFUTURE_MARGIN __pyx_mstate_global->__pyx_n_s_UMFUTURE_MARGIN
#define __pyx_kp_s_UNICORN_BINANCE_SUITE __pyx_mstate_global->__pyx_kp_s_UNICORN_BINANCE_SUITE
#define __pyx_n_s_USDT_FUTURE_TO_FIAT __pyx_mstate_global->__pyx_n_s_USDT_FUTURE_TO_FIAT
#define __pyx_n_s_USDT_FUTURE_TO_MARGIN_CROSS __pyx_mstate_global->__pyx_n_s_USDT_FUTURE_TO_MARGIN_CROSS
#define __pyx_n_s_USDT_FUTURE_TO_SPOT __pyx_mstate_global->__pyx_n_s_USDT_FUTURE_TO_SPOT
#define __pyx_n_s_UnknownExchange __pyx_mstate_global->__pyx_n_s_UnknownExchange
#define __pyx_kp_u_Unknown_exchange __pyx_mstate_global->__pyx_kp_u_Unknown_exchange
#define __pyx_kp_s_User_Agent __pyx_mstate_global->__pyx_kp_s_User_Agent
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s_WEBSITE_URL __pyx_mstate_global->__pyx_n_s_WEBSITE_URL
#define __pyx_kp_s_X_MBX_APIKEY __pyx_mstate_global->__pyx_kp_s_X_MBX_APIKEY
#define __pyx_kp_s_X_MBX_USED_WEIGHT __pyx_mstate_global->__pyx_kp_s_X_MBX_USED_WEIGHT
#define __pyx_kp_s__184 __pyx_mstate_global->__pyx_kp_s__184
#define __pyx_kp_u__185 __pyx_mstate_global->__pyx_kp_u__185
#define __pyx_n_s__186 __pyx_mstate_global->__pyx_n_s__186
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_kp_s__3 __pyx_mstate_global->__pyx_kp_s__3
#define __pyx_kp_u__3 __pyx_mstate_global->__pyx_kp_u__3
#define __pyx_kp_s__4 __pyx_mstate_global->__pyx_kp_s__4
#define __pyx_n_s__488 __pyx_mstate_global->__pyx_n_s__488
#define __pyx_n_u__5 __pyx_mstate_global->__pyx_n_u__5
#define __pyx_kp_u__6 __pyx_mstate_global->__pyx_kp_u__6
#define __pyx_kp_s__7 __pyx_mstate_global->__pyx_kp_s__7
#define __pyx_kp_s__8 __pyx_mstate_global->__pyx_kp_s__8
#define __pyx_kp_s__9 __pyx_mstate_global->__pyx_kp_s__9
#define __pyx_n_s_a __pyx_mstate_global->__pyx_n_s_a
#define __pyx_kp_s_a_d_b_Y_I_M_S_Z __pyx_mstate_global->__pyx_kp_s_a_d_b_Y_I_M_S_Z
#define __pyx_n_s_account __pyx_mstate_global->__pyx_n_s_account
#define __pyx_n_s_accountSnapshot __pyx_mstate_global->__pyx_n_s_accountSnapshot
#define __pyx_kp_s_account_apiTradingStatus __pyx_mstate_global->__pyx_kp_s_account_apiTradingStatus
#define __pyx_kp_s_account_status __pyx_mstate_global->__pyx_kp_s_account_status
#define __pyx_n_s_aggTrades __pyx_mstate_global->__pyx_n_s_aggTrades
#define __pyx_n_s_aggregate_trade_iter __pyx_mstate_global->__pyx_n_s_aggregate_trade_iter
#define __pyx_n_s_allForceOrders __pyx_mstate_global->__pyx_n_s_allForceOrders
#define __pyx_n_s_allOpenOrders __pyx_mstate_global->__pyx_n_s_allOpenOrders
#define __pyx_n_s_allOrders __pyx_mstate_global->__pyx_n_s_allOrders
#define __pyx_n_s_api_key __pyx_mstate_global->__pyx_n_s_api_key
#define __pyx_n_s_api_secret __pyx_mstate_global->__pyx_n_s_api_secret
#define __pyx_kp_s_application_json __pyx_mstate_global->__pyx_kp_s_application_json
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_s_asset __pyx_mstate_global->__pyx_n_s_asset
#define __pyx_kp_s_asset_assetDetail __pyx_mstate_global->__pyx_kp_s_asset_assetDetail
#define __pyx_kp_s_asset_assetDividend __pyx_mstate_global->__pyx_kp_s_asset_assetDividend
#define __pyx_kp_s_asset_dribblet __pyx_mstate_global->__pyx_kp_s_asset_dribblet
#define __pyx_kp_s_asset_dust __pyx_mstate_global->__pyx_kp_s_asset_dust
#define __pyx_kp_s_asset_tradeFee __pyx_mstate_global->__pyx_kp_s_asset_tradeFee
#define __pyx_kp_s_asset_transfer __pyx_mstate_global->__pyx_kp_s_asset_transfer
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_avgPrice __pyx_mstate_global->__pyx_n_s_avgPrice
#define __pyx_n_s_bal __pyx_mstate_global->__pyx_n_s_bal
#define __pyx_n_s_balance __pyx_mstate_global->__pyx_n_s_balance
#define __pyx_n_s_balances __pyx_mstate_global->__pyx_n_s_balances
#define __pyx_n_s_batchOrders __pyx_mstate_global->__pyx_n_s_batchOrders
#define __pyx_n_s_binance_api_status __pyx_mstate_global->__pyx_n_s_binance_api_status
#define __pyx_kp_s_binance_com __pyx_mstate_global->__pyx_kp_s_binance_com
#define __pyx_kp_s_binance_com_coin_futures __pyx_mstate_global->__pyx_kp_s_binance_com_coin_futures
#define __pyx_kp_s_binance_com_futures __pyx_mstate_global->__pyx_kp_s_binance_com_futures
#define __pyx_kp_s_binance_com_futures_testnet __pyx_mstate_global->__pyx_kp_s_binance_com_futures_testnet
#define __pyx_kp_s_binance_com_isolated_margin __pyx_mstate_global->__pyx_kp_s_binance_com_isolated_margin
#define __pyx_kp_s_binance_com_isolated_margin_test __pyx_mstate_global->__pyx_kp_s_binance_com_isolated_margin_test
#define __pyx_kp_s_binance_com_margin __pyx_mstate_global->__pyx_kp_s_binance_com_margin
#define __pyx_kp_s_binance_com_margin_testnet __pyx_mstate_global->__pyx_kp_s_binance_com_margin_testnet
#define __pyx_kp_s_binance_com_testnet __pyx_mstate_global->__pyx_kp_s_binance_com_testnet
#define __pyx_kp_s_binance_us __pyx_mstate_global->__pyx_kp_s_binance_us
#define __pyx_n_s_bnbBurn __pyx_mstate_global->__pyx_n_s_bnbBurn
#define __pyx_n_s_cancel_all_open_margin_orders __pyx_mstate_global->__pyx_n_s_cancel_all_open_margin_orders
#define __pyx_n_s_cancel_all_open_orders __pyx_mstate_global->__pyx_n_s_cancel_all_open_orders
#define __pyx_n_s_cancel_margin_oco_order __pyx_mstate_global->__pyx_n_s_cancel_margin_oco_order
#define __pyx_n_s_cancel_margin_order __pyx_mstate_global->__pyx_n_s_cancel_margin_order
#define __pyx_n_s_cancel_order __pyx_mstate_global->__pyx_n_s_cancel_order
#define __pyx_kp_s_capital_config_getall __pyx_mstate_global->__pyx_kp_s_capital_config_getall
#define __pyx_kp_s_capital_deposit_address __pyx_mstate_global->__pyx_kp_s_capital_deposit_address
#define __pyx_kp_s_capital_deposit_hisrec __pyx_mstate_global->__pyx_kp_s_capital_deposit_hisrec
#define __pyx_kp_s_capital_deposit_subAddress __pyx_mstate_global->__pyx_kp_s_capital_deposit_subAddress
#define __pyx_kp_s_capital_deposit_subHisrec __pyx_mstate_global->__pyx_kp_s_capital_deposit_subHisrec
#define __pyx_kp_s_capital_withdraw_apply __pyx_mstate_global->__pyx_kp_s_capital_withdraw_apply
#define __pyx_kp_s_capital_withdraw_history __pyx_mstate_global->__pyx_kp_s_capital_withdraw_history
#define __pyx_n_s_change_fixed_activity_to_daily_p __pyx_mstate_global->__pyx_n_s_change_fixed_activity_to_daily_p
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_close_api_session __pyx_mstate_global->__pyx_n_s_close_api_session
#define __pyx_n_s_colorama __pyx_mstate_global->__pyx_n_s_colorama
#define __pyx_n_s_commissionRate __pyx_mstate_global->__pyx_n_s_commissionRate
#define __pyx_kp_u_compiled_on __pyx_mstate_global->__pyx_kp_u_compiled_on
#define __pyx_n_s_continuousKlines __pyx_mstate_global->__pyx_n_s_continuousKlines
#define __pyx_n_s_countdownCancelAll __pyx_mstate_global->__pyx_n_s_countdownCancelAll
#define __pyx_n_s_create_api_uri __pyx_mstate_global->__pyx_n_s_create_api_uri
#define __pyx_n_s_create_futures_api_uri __pyx_mstate_global->__pyx_n_s_create_futures_api_uri
#define __pyx_n_s_create_futures_coin_api_url __pyx_mstate_global->__pyx_n_s_create_futures_coin_api_url
#define __pyx_n_s_create_futures_coin_data_api_ur __pyx_mstate_global->__pyx_n_s_create_futures_coin_data_api_ur
#define __pyx_n_s_create_futures_data_api_uri __pyx_mstate_global->__pyx_n_s_create_futures_data_api_uri
#define __pyx_n_s_create_isolated_margin_account __pyx_mstate_global->__pyx_n_s_create_isolated_margin_account
#define __pyx_n_s_create_margin_api_uri __pyx_mstate_global->__pyx_n_s_create_margin_api_uri
#define __pyx_n_s_create_margin_loan __pyx_mstate_global->__pyx_n_s_create_margin_loan
#define __pyx_n_s_create_margin_oco_order __pyx_mstate_global->__pyx_n_s_create_margin_oco_order
#define __pyx_n_s_create_margin_order __pyx_mstate_global->__pyx_n_s_create_margin_order
#define __pyx_n_s_create_oco_order __pyx_mstate_global->__pyx_n_s_create_oco_order
#define __pyx_n_s_create_order __pyx_mstate_global->__pyx_n_s_create_order
#define __pyx_n_s_create_sub_account_futures_trans __pyx_mstate_global->__pyx_n_s_create_sub_account_futures_trans
#define __pyx_n_s_create_test_order __pyx_mstate_global->__pyx_n_s_create_test_order
#define __pyx_n_s_create_website_uri __pyx_mstate_global->__pyx_n_s_create_website_uri
#define __pyx_n_s_critical __pyx_mstate_global->__pyx_n_s_critical
#define __pyx_n_s_d __pyx_mstate_global->__pyx_n_s_d
#define __pyx_n_s_data __pyx_mstate_global->__pyx_n_s_data
#define __pyx_n_s_date_time_obj __pyx_mstate_global->__pyx_n_s_date_time_obj
#define __pyx_n_s_date_to_milliseconds __pyx_mstate_global->__pyx_n_s_date_to_milliseconds
#define __pyx_n_s_datetime __pyx_mstate_global->__pyx_n_s_datetime
#define __pyx_n_s_debug __pyx_mstate_global->__pyx_n_s_debug
#define __pyx_n_s_delete __pyx_mstate_global->__pyx_n_s_delete
#define __pyx_n_s_delete_2 __pyx_mstate_global->__pyx_n_s_delete_2
#define __pyx_n_s_depth __pyx_mstate_global->__pyx_n_s_depth
#define __pyx_kp_s_dev __pyx_mstate_global->__pyx_kp_s_dev
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_disableFastWithdrawSwitch __pyx_mstate_global->__pyx_n_s_disableFastWithdrawSwitch
#define __pyx_n_s_disable_colorama __pyx_mstate_global->__pyx_n_s_disable_colorama
#define __pyx_n_s_disable_fast_withdraw_switch __pyx_mstate_global->__pyx_n_s_disable_fast_withdraw_switch
#define __pyx_n_s_doc __pyx_mstate_global->__pyx_n_s_doc
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_enableFastWithdrawSwitch __pyx_mstate_global->__pyx_n_s_enableFastWithdrawSwitch
#define __pyx_n_s_enable_fast_withdraw_switch __pyx_mstate_global->__pyx_n_s_enable_fast_withdraw_switch
#define __pyx_n_s_enable_subaccount_futures __pyx_mstate_global->__pyx_n_s_enable_subaccount_futures
#define __pyx_n_s_enable_subaccount_margin __pyx_mstate_global->__pyx_n_s_enable_subaccount_margin
#define __pyx_n_s_encode __pyx_mstate_global->__pyx_n_s_encode
#define __pyx_n_s_endTime __pyx_mstate_global->__pyx_n_s_endTime
#define __pyx_n_s_end_str __pyx_mstate_global->__pyx_n_s_end_str
#define __pyx_n_s_end_ts __pyx_mstate_global->__pyx_n_s_end_ts
#define __pyx_n_s_enter __pyx_mstate_global->__pyx_n_s_enter
#define __pyx_n_s_entry __pyx_mstate_global->__pyx_n_s_entry
#define __pyx_n_s_enumerate __pyx_mstate_global->__pyx_n_s_enumerate
#define __pyx_n_s_error_msg __pyx_mstate_global->__pyx_n_s_error_msg
#define __pyx_n_s_error_traceback __pyx_mstate_global->__pyx_n_s_error_traceback
#define __pyx_n_s_exc_type __pyx_mstate_global->__pyx_n_s_exc_type
#define __pyx_n_s_exc_value __pyx_mstate_global->__pyx_n_s_exc_value
#define __pyx_n_s_exceptions __pyx_mstate_global->__pyx_n_s_exceptions
#define __pyx_n_s_exchange __pyx_mstate_global->__pyx_n_s_exchange
#define __pyx_n_s_exchangeInfo __pyx_mstate_global->__pyx_n_s_exchangeInfo
#define __pyx_kp_u_exchange_2 __pyx_mstate_global->__pyx_kp_u_exchange_2
#define __pyx_kp_s_exchange_api_v1_public_asset_ser __pyx_mstate_global->__pyx_kp_s_exchange_api_v1_public_asset_ser
#define __pyx_n_s_exit __pyx_mstate_global->__pyx_n_s_exit
#define __pyx_n_s_f __pyx_mstate_global->__pyx_n_s_f
#define __pyx_n_s_first_valid_ts __pyx_mstate_global->__pyx_n_s_first_valid_ts
#define __pyx_kp_u_for_exchange __pyx_mstate_global->__pyx_kp_u_for_exchange
#define __pyx_n_s_force_params __pyx_mstate_global->__pyx_n_s_force_params
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_s_fromId __pyx_mstate_global->__pyx_n_s_fromId
#define __pyx_n_s_fundingRate __pyx_mstate_global->__pyx_n_s_fundingRate
#define __pyx_n_s_futures_account __pyx_mstate_global->__pyx_n_s_futures_account
#define __pyx_n_s_futures_account_balance __pyx_mstate_global->__pyx_n_s_futures_account_balance
#define __pyx_n_s_futures_account_trades __pyx_mstate_global->__pyx_n_s_futures_account_trades
#define __pyx_n_s_futures_account_transfer __pyx_mstate_global->__pyx_n_s_futures_account_transfer
#define __pyx_n_s_futures_aggregate_trades __pyx_mstate_global->__pyx_n_s_futures_aggregate_trades
#define __pyx_n_s_futures_auto_cancel_all_open_ord __pyx_mstate_global->__pyx_n_s_futures_auto_cancel_all_open_ord
#define __pyx_n_s_futures_cancel_all_open_orders __pyx_mstate_global->__pyx_n_s_futures_cancel_all_open_orders
#define __pyx_n_s_futures_cancel_order __pyx_mstate_global->__pyx_n_s_futures_cancel_order
#define __pyx_n_s_futures_cancel_orders __pyx_mstate_global->__pyx_n_s_futures_cancel_orders
#define __pyx_n_s_futures_change_leverage __pyx_mstate_global->__pyx_n_s_futures_change_leverage
#define __pyx_n_s_futures_change_margin_type __pyx_mstate_global->__pyx_n_s_futures_change_margin_type
#define __pyx_n_s_futures_change_position_margin __pyx_mstate_global->__pyx_n_s_futures_change_position_margin
#define __pyx_n_s_futures_change_position_mode __pyx_mstate_global->__pyx_n_s_futures_change_position_mode
#define __pyx_n_s_futures_coin_account __pyx_mstate_global->__pyx_n_s_futures_coin_account
#define __pyx_n_s_futures_coin_account_balance __pyx_mstate_global->__pyx_n_s_futures_coin_account_balance
#define __pyx_n_s_futures_coin_account_trades __pyx_mstate_global->__pyx_n_s_futures_coin_account_trades
#define __pyx_n_s_futures_coin_aggregate_trades __pyx_mstate_global->__pyx_n_s_futures_coin_aggregate_trades
#define __pyx_n_s_futures_coin_cancel_all_open_ord __pyx_mstate_global->__pyx_n_s_futures_coin_cancel_all_open_ord
#define __pyx_n_s_futures_coin_cancel_order __pyx_mstate_global->__pyx_n_s_futures_coin_cancel_order
#define __pyx_n_s_futures_coin_cancel_orders __pyx_mstate_global->__pyx_n_s_futures_coin_cancel_orders
#define __pyx_n_s_futures_coin_change_leverage __pyx_mstate_global->__pyx_n_s_futures_coin_change_leverage
#define __pyx_n_s_futures_coin_change_margin_type __pyx_mstate_global->__pyx_n_s_futures_coin_change_margin_type
#define __pyx_n_s_futures_coin_change_position_mar __pyx_mstate_global->__pyx_n_s_futures_coin_change_position_mar
#define __pyx_n_s_futures_coin_change_position_mod __pyx_mstate_global->__pyx_n_s_futures_coin_change_position_mod
#define __pyx_n_s_futures_coin_continous_klines __pyx_mstate_global->__pyx_n_s_futures_coin_continous_klines
#define __pyx_n_s_futures_coin_create_order __pyx_mstate_global->__pyx_n_s_futures_coin_create_order
#define __pyx_n_s_futures_coin_exchange_info __pyx_mstate_global->__pyx_n_s_futures_coin_exchange_info
#define __pyx_n_s_futures_coin_funding_rate __pyx_mstate_global->__pyx_n_s_futures_coin_funding_rate
#define __pyx_n_s_futures_coin_get_all_orders __pyx_mstate_global->__pyx_n_s_futures_coin_get_all_orders
#define __pyx_n_s_futures_coin_get_open_orders __pyx_mstate_global->__pyx_n_s_futures_coin_get_open_orders
#define __pyx_n_s_futures_coin_get_order __pyx_mstate_global->__pyx_n_s_futures_coin_get_order
#define __pyx_n_s_futures_coin_get_position_mode __pyx_mstate_global->__pyx_n_s_futures_coin_get_position_mode
#define __pyx_n_s_futures_coin_historical_trades __pyx_mstate_global->__pyx_n_s_futures_coin_historical_trades
#define __pyx_n_s_futures_coin_income_history __pyx_mstate_global->__pyx_n_s_futures_coin_income_history
#define __pyx_n_s_futures_coin_index_price_klines __pyx_mstate_global->__pyx_n_s_futures_coin_index_price_klines
#define __pyx_n_s_futures_coin_klines __pyx_mstate_global->__pyx_n_s_futures_coin_klines
#define __pyx_n_s_futures_coin_leverage_bracket __pyx_mstate_global->__pyx_n_s_futures_coin_leverage_bracket
#define __pyx_n_s_futures_coin_liquidation_orders __pyx_mstate_global->__pyx_n_s_futures_coin_liquidation_orders
#define __pyx_n_s_futures_coin_mark_price __pyx_mstate_global->__pyx_n_s_futures_coin_mark_price
#define __pyx_n_s_futures_coin_mark_price_klines __pyx_mstate_global->__pyx_n_s_futures_coin_mark_price_klines
#define __pyx_n_s_futures_coin_open_interest __pyx_mstate_global->__pyx_n_s_futures_coin_open_interest
#define __pyx_n_s_futures_coin_open_interest_hist __pyx_mstate_global->__pyx_n_s_futures_coin_open_interest_hist
#define __pyx_n_s_futures_coin_order_book __pyx_mstate_global->__pyx_n_s_futures_coin_order_book
#define __pyx_n_s_futures_coin_orderbook_ticker __pyx_mstate_global->__pyx_n_s_futures_coin_orderbook_ticker
#define __pyx_n_s_futures_coin_ping __pyx_mstate_global->__pyx_n_s_futures_coin_ping
#define __pyx_n_s_futures_coin_place_batch_order __pyx_mstate_global->__pyx_n_s_futures_coin_place_batch_order
#define __pyx_n_s_futures_coin_position_informatio __pyx_mstate_global->__pyx_n_s_futures_coin_position_informatio
#define __pyx_n_s_futures_coin_position_margin_his __pyx_mstate_global->__pyx_n_s_futures_coin_position_margin_his
#define __pyx_n_s_futures_coin_recent_trades __pyx_mstate_global->__pyx_n_s_futures_coin_recent_trades
#define __pyx_n_s_futures_coin_stream_close __pyx_mstate_global->__pyx_n_s_futures_coin_stream_close
#define __pyx_n_s_futures_coin_stream_get_listen_k __pyx_mstate_global->__pyx_n_s_futures_coin_stream_get_listen_k
#define __pyx_n_s_futures_coin_stream_keepalive __pyx_mstate_global->__pyx_n_s_futures_coin_stream_keepalive
#define __pyx_n_s_futures_coin_symbol_ticker __pyx_mstate_global->__pyx_n_s_futures_coin_symbol_ticker
#define __pyx_n_s_futures_coin_ticker __pyx_mstate_global->__pyx_n_s_futures_coin_ticker
#define __pyx_n_s_futures_coin_time __pyx_mstate_global->__pyx_n_s_futures_coin_time
#define __pyx_n_s_futures_commission_rate __pyx_mstate_global->__pyx_n_s_futures_commission_rate
#define __pyx_n_s_futures_create_order __pyx_mstate_global->__pyx_n_s_futures_create_order
#define __pyx_n_s_futures_exchange_info __pyx_mstate_global->__pyx_n_s_futures_exchange_info
#define __pyx_n_s_futures_funding_rate __pyx_mstate_global->__pyx_n_s_futures_funding_rate
#define __pyx_n_s_futures_get_all_orders __pyx_mstate_global->__pyx_n_s_futures_get_all_orders
#define __pyx_n_s_futures_get_open_orders __pyx_mstate_global->__pyx_n_s_futures_get_open_orders
#define __pyx_n_s_futures_get_order __pyx_mstate_global->__pyx_n_s_futures_get_order
#define __pyx_n_s_futures_get_position_mode __pyx_mstate_global->__pyx_n_s_futures_get_position_mode
#define __pyx_n_s_futures_historical_trades __pyx_mstate_global->__pyx_n_s_futures_historical_trades
#define __pyx_n_s_futures_income_history __pyx_mstate_global->__pyx_n_s_futures_income_history
#define __pyx_n_s_futures_klines __pyx_mstate_global->__pyx_n_s_futures_klines
#define __pyx_n_s_futures_leverage_bracket __pyx_mstate_global->__pyx_n_s_futures_leverage_bracket
#define __pyx_n_s_futures_liquidation_orders __pyx_mstate_global->__pyx_n_s_futures_liquidation_orders
#define __pyx_n_s_futures_mark_price __pyx_mstate_global->__pyx_n_s_futures_mark_price
#define __pyx_n_s_futures_open_interest __pyx_mstate_global->__pyx_n_s_futures_open_interest
#define __pyx_n_s_futures_open_interest_hist __pyx_mstate_global->__pyx_n_s_futures_open_interest_hist
#define __pyx_n_s_futures_order_book __pyx_mstate_global->__pyx_n_s_futures_order_book
#define __pyx_n_s_futures_orderbook_ticker __pyx_mstate_global->__pyx_n_s_futures_orderbook_ticker
#define __pyx_n_s_futures_ping __pyx_mstate_global->__pyx_n_s_futures_ping
#define __pyx_n_s_futures_place_batch_order __pyx_mstate_global->__pyx_n_s_futures_place_batch_order
#define __pyx_n_s_futures_position_information __pyx_mstate_global->__pyx_n_s_futures_position_information
#define __pyx_n_s_futures_position_margin_history __pyx_mstate_global->__pyx_n_s_futures_position_margin_history
#define __pyx_n_s_futures_recent_trades __pyx_mstate_global->__pyx_n_s_futures_recent_trades
#define __pyx_n_s_futures_stream_close __pyx_mstate_global->__pyx_n_s_futures_stream_close
#define __pyx_n_s_futures_stream_get_listen_key __pyx_mstate_global->__pyx_n_s_futures_stream_get_listen_key
#define __pyx_n_s_futures_stream_keepalive __pyx_mstate_global->__pyx_n_s_futures_stream_keepalive
#define __pyx_n_s_futures_symbol_ticker __pyx_mstate_global->__pyx_n_s_futures_symbol_ticker
#define __pyx_n_s_futures_ticker __pyx_mstate_global->__pyx_n_s_futures_ticker
#define __pyx_n_s_futures_time __pyx_mstate_global->__pyx_n_s_futures_time
#define __pyx_kp_s_futures_transfer __pyx_mstate_global->__pyx_kp_s_futures_transfer
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_generate_signature __pyx_mstate_global->__pyx_n_s_generate_signature
#define __pyx_n_s_genexpr __pyx_mstate_global->__pyx_n_s_genexpr
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_getLogger __pyx_mstate_global->__pyx_n_s_getLogger
#define __pyx_n_s_get_2 __pyx_mstate_global->__pyx_n_s_get_2
#define __pyx_n_s_get_account __pyx_mstate_global->__pyx_n_s_get_account
#define __pyx_n_s_get_account_api_trading_status __pyx_mstate_global->__pyx_n_s_get_account_api_trading_status
#define __pyx_n_s_get_account_snapshot __pyx_mstate_global->__pyx_n_s_get_account_snapshot
#define __pyx_n_s_get_account_status __pyx_mstate_global->__pyx_n_s_get_account_status
#define __pyx_n_s_get_aggregate_trades __pyx_mstate_global->__pyx_n_s_get_aggregate_trades
#define __pyx_n_s_get_all_coins_info __pyx_mstate_global->__pyx_n_s_get_all_coins_info
#define __pyx_n_s_get_all_isolated_margin_symbols __pyx_mstate_global->__pyx_n_s_get_all_isolated_margin_symbols
#define __pyx_n_s_get_all_margin_orders __pyx_mstate_global->__pyx_n_s_get_all_margin_orders
#define __pyx_n_s_get_all_orders __pyx_mstate_global->__pyx_n_s_get_all_orders
#define __pyx_n_s_get_all_tickers __pyx_mstate_global->__pyx_n_s_get_all_tickers
#define __pyx_n_s_get_asset_balance __pyx_mstate_global->__pyx_n_s_get_asset_balance
#define __pyx_n_s_get_asset_details __pyx_mstate_global->__pyx_n_s_get_asset_details
#define __pyx_n_s_get_asset_dividend_history __pyx_mstate_global->__pyx_n_s_get_asset_dividend_history
#define __pyx_n_s_get_avg_price __pyx_mstate_global->__pyx_n_s_get_avg_price
#define __pyx_n_s_get_bnb_burn_spot_margin __pyx_mstate_global->__pyx_n_s_get_bnb_burn_spot_margin
#define __pyx_n_s_get_deposit_address __pyx_mstate_global->__pyx_n_s_get_deposit_address
#define __pyx_n_s_get_deposit_history __pyx_mstate_global->__pyx_n_s_get_deposit_history
#define __pyx_n_s_get_dust_log __pyx_mstate_global->__pyx_n_s_get_dust_log
#define __pyx_n_s_get_earliest_valid_timestamp __pyx_mstate_global->__pyx_n_s_get_earliest_valid_timestamp
#define __pyx_n_s_get_exchange_info __pyx_mstate_global->__pyx_n_s_get_exchange_info
#define __pyx_n_s_get_fixed_activity_project_list __pyx_mstate_global->__pyx_n_s_get_fixed_activity_project_list
#define __pyx_n_s_get_historical_klines __pyx_mstate_global->__pyx_n_s_get_historical_klines
#define __pyx_n_s_get_historical_klines_generator __pyx_mstate_global->__pyx_n_s_get_historical_klines_generator
#define __pyx_n_s_get_historical_trades __pyx_mstate_global->__pyx_n_s_get_historical_trades
#define __pyx_n_s_get_isolated_margin_account __pyx_mstate_global->__pyx_n_s_get_isolated_margin_account
#define __pyx_n_s_get_isolated_margin_symbol __pyx_mstate_global->__pyx_n_s_get_isolated_margin_symbol
#define __pyx_n_s_get_klines __pyx_mstate_global->__pyx_n_s_get_klines
#define __pyx_n_s_get_latest_release_info __pyx_mstate_global->__pyx_n_s_get_latest_release_info
#define __pyx_n_s_get_latest_version __pyx_mstate_global->__pyx_n_s_get_latest_version
#define __pyx_n_s_get_lending_account __pyx_mstate_global->__pyx_n_s_get_lending_account
#define __pyx_n_s_get_lending_daily_quota_left __pyx_mstate_global->__pyx_n_s_get_lending_daily_quota_left
#define __pyx_n_s_get_lending_daily_redemption_quo __pyx_mstate_global->__pyx_n_s_get_lending_daily_redemption_quo
#define __pyx_n_s_get_lending_interest_history __pyx_mstate_global->__pyx_n_s_get_lending_interest_history
#define __pyx_n_s_get_lending_position __pyx_mstate_global->__pyx_n_s_get_lending_position
#define __pyx_n_s_get_lending_product_list __pyx_mstate_global->__pyx_n_s_get_lending_product_list
#define __pyx_n_s_get_lending_purchase_history __pyx_mstate_global->__pyx_n_s_get_lending_purchase_history
#define __pyx_n_s_get_lending_redemption_history __pyx_mstate_global->__pyx_n_s_get_lending_redemption_history
#define __pyx_n_s_get_margin_account __pyx_mstate_global->__pyx_n_s_get_margin_account
#define __pyx_n_s_get_margin_asset __pyx_mstate_global->__pyx_n_s_get_margin_asset
#define __pyx_n_s_get_margin_loan_details __pyx_mstate_global->__pyx_n_s_get_margin_loan_details
#define __pyx_n_s_get_margin_oco_order __pyx_mstate_global->__pyx_n_s_get_margin_oco_order
#define __pyx_n_s_get_margin_order __pyx_mstate_global->__pyx_n_s_get_margin_order
#define __pyx_n_s_get_margin_price_index __pyx_mstate_global->__pyx_n_s_get_margin_price_index
#define __pyx_n_s_get_margin_repay_details __pyx_mstate_global->__pyx_n_s_get_margin_repay_details
#define __pyx_n_s_get_margin_symbol __pyx_mstate_global->__pyx_n_s_get_margin_symbol
#define __pyx_n_s_get_margin_trades __pyx_mstate_global->__pyx_n_s_get_margin_trades
#define __pyx_n_s_get_max_margin_loan __pyx_mstate_global->__pyx_n_s_get_max_margin_loan
#define __pyx_n_s_get_max_margin_transfer __pyx_mstate_global->__pyx_n_s_get_max_margin_transfer
#define __pyx_n_s_get_my_trades __pyx_mstate_global->__pyx_n_s_get_my_trades
#define __pyx_n_s_get_open_isolated_margin_orders __pyx_mstate_global->__pyx_n_s_get_open_isolated_margin_orders
#define __pyx_n_s_get_open_margin_oco_orders __pyx_mstate_global->__pyx_n_s_get_open_margin_oco_orders
#define __pyx_n_s_get_open_margin_orders __pyx_mstate_global->__pyx_n_s_get_open_margin_orders
#define __pyx_n_s_get_open_orders __pyx_mstate_global->__pyx_n_s_get_open_orders
#define __pyx_n_s_get_order __pyx_mstate_global->__pyx_n_s_get_order
#define __pyx_n_s_get_order_book __pyx_mstate_global->__pyx_n_s_get_order_book
#define __pyx_n_s_get_orderbook_ticker __pyx_mstate_global->__pyx_n_s_get_orderbook_ticker
#define __pyx_n_s_get_orderbook_tickers __pyx_mstate_global->__pyx_n_s_get_orderbook_tickers
#define __pyx_n_s_get_products __pyx_mstate_global->__pyx_n_s_get_products
#define __pyx_n_s_get_recent_trades __pyx_mstate_global->__pyx_n_s_get_recent_trades
#define __pyx_n_s_get_server_time __pyx_mstate_global->__pyx_n_s_get_server_time
#define __pyx_n_s_get_sub_account_assets __pyx_mstate_global->__pyx_n_s_get_sub_account_assets
#define __pyx_n_s_get_sub_account_futures_transfer __pyx_mstate_global->__pyx_n_s_get_sub_account_futures_transfer
#define __pyx_n_s_get_sub_account_list __pyx_mstate_global->__pyx_n_s_get_sub_account_list
#define __pyx_n_s_get_sub_account_transfer_history __pyx_mstate_global->__pyx_n_s_get_sub_account_transfer_history
#define __pyx_n_s_get_subaccount_deposit_address __pyx_mstate_global->__pyx_n_s_get_subaccount_deposit_address
#define __pyx_n_s_get_subaccount_deposit_history __pyx_mstate_global->__pyx_n_s_get_subaccount_deposit_history
#define __pyx_n_s_get_subaccount_futures_details __pyx_mstate_global->__pyx_n_s_get_subaccount_futures_details
#define __pyx_n_s_get_subaccount_futures_margin_st __pyx_mstate_global->__pyx_n_s_get_subaccount_futures_margin_st
#define __pyx_n_s_get_subaccount_futures_positionr __pyx_mstate_global->__pyx_n_s_get_subaccount_futures_positionr
#define __pyx_n_s_get_subaccount_futures_summary __pyx_mstate_global->__pyx_n_s_get_subaccount_futures_summary
#define __pyx_n_s_get_subaccount_margin_details __pyx_mstate_global->__pyx_n_s_get_subaccount_margin_details
#define __pyx_n_s_get_subaccount_margin_summary __pyx_mstate_global->__pyx_n_s_get_subaccount_margin_summary
#define __pyx_n_s_get_subaccount_transfer_history __pyx_mstate_global->__pyx_n_s_get_subaccount_transfer_history
#define __pyx_n_s_get_symbol_info __pyx_mstate_global->__pyx_n_s_get_symbol_info
#define __pyx_n_s_get_symbol_ticker __pyx_mstate_global->__pyx_n_s_get_symbol_ticker
#define __pyx_n_s_get_system_status __pyx_mstate_global->__pyx_n_s_get_system_status
#define __pyx_n_s_get_ticker __pyx_mstate_global->__pyx_n_s_get_ticker
#define __pyx_n_s_get_trade_fee __pyx_mstate_global->__pyx_n_s_get_trade_fee
#define __pyx_n_s_get_universal_transfer_history __pyx_mstate_global->__pyx_n_s_get_universal_transfer_history
#define __pyx_n_s_get_used_weight __pyx_mstate_global->__pyx_n_s_get_used_weight
#define __pyx_n_s_get_user_agent __pyx_mstate_global->__pyx_n_s_get_user_agent
#define __pyx_n_s_get_version __pyx_mstate_global->__pyx_n_s_get_version
#define __pyx_n_s_get_withdraw_history __pyx_mstate_global->__pyx_n_s_get_withdraw_history
#define __pyx_n_s_get_withdraw_history_id __pyx_mstate_global->__pyx_n_s_get_withdraw_history_id
#define __pyx_n_s_handle_response __pyx_mstate_global->__pyx_n_s_handle_response
#define __pyx_n_s_has_signature __pyx_mstate_global->__pyx_n_s_has_signature
#define __pyx_n_s_hashlib __pyx_mstate_global->__pyx_n_s_hashlib
#define __pyx_n_s_headers __pyx_mstate_global->__pyx_n_s_headers
#define __pyx_n_s_helpers __pyx_mstate_global->__pyx_n_s_helpers
#define __pyx_n_s_hexdigest __pyx_mstate_global->__pyx_n_s_hexdigest
#define __pyx_n_s_historicalTrades __pyx_mstate_global->__pyx_n_s_historicalTrades
#define __pyx_n_s_hmac __pyx_mstate_global->__pyx_n_s_hmac
#define __pyx_n_s_http __pyx_mstate_global->__pyx_n_s_http
#define __pyx_n_s_https __pyx_mstate_global->__pyx_n_s_https
#define __pyx_kp_s_https_api_binance_api __pyx_mstate_global->__pyx_kp_s_https_api_binance_api
#define __pyx_kp_s_https_api_binance_com_api __pyx_mstate_global->__pyx_kp_s_https_api_binance_com_api
#define __pyx_kp_s_https_api_binance_com_sapi __pyx_mstate_global->__pyx_kp_s_https_api_binance_com_sapi
#define __pyx_kp_s_https_api_binance_sapi __pyx_mstate_global->__pyx_kp_s_https_api_binance_sapi
#define __pyx_kp_s_https_api_binance_us_api __pyx_mstate_global->__pyx_kp_s_https_api_binance_us_api
#define __pyx_kp_s_https_api_binance_us_sapi __pyx_mstate_global->__pyx_kp_s_https_api_binance_us_sapi
#define __pyx_kp_s_https_api_github_com_repos_LUCIT __pyx_mstate_global->__pyx_kp_s_https_api_github_com_repos_LUCIT
#define __pyx_kp_s_https_api_trbinance_com_sapi __pyx_mstate_global->__pyx_kp_s_https_api_trbinance_com_sapi
#define __pyx_kp_s_https_dapi_binance_com_futures_d __pyx_mstate_global->__pyx_kp_s_https_dapi_binance_com_futures_d
#define __pyx_kp_s_https_dapi_binance_futures_data __pyx_mstate_global->__pyx_kp_s_https_dapi_binance_futures_data
#define __pyx_kp_s_https_dapi_binance_us_futures_da __pyx_mstate_global->__pyx_kp_s_https_dapi_binance_us_futures_da
#define __pyx_kp_s_https_dapi_trbinance_com_futures __pyx_mstate_global->__pyx_kp_s_https_dapi_trbinance_com_futures
#define __pyx_kp_s_https_fapi_binance_com_fapi __pyx_mstate_global->__pyx_kp_s_https_fapi_binance_com_fapi
#define __pyx_kp_s_https_fapi_binance_com_futures_d __pyx_mstate_global->__pyx_kp_s_https_fapi_binance_com_futures_d
#define __pyx_kp_s_https_fapi_binance_fapi __pyx_mstate_global->__pyx_kp_s_https_fapi_binance_fapi
#define __pyx_kp_s_https_fapi_binance_futures_data __pyx_mstate_global->__pyx_kp_s_https_fapi_binance_futures_data
#define __pyx_kp_s_https_fapi_binance_us_fapi __pyx_mstate_global->__pyx_kp_s_https_fapi_binance_us_fapi
#define __pyx_kp_s_https_fapi_binance_us_futures_da __pyx_mstate_global->__pyx_kp_s_https_fapi_binance_us_futures_da
#define __pyx_kp_s_https_fapi_trbinance_com_fapi __pyx_mstate_global->__pyx_kp_s_https_fapi_trbinance_com_fapi
#define __pyx_kp_s_https_fapi_trbinance_com_futures __pyx_mstate_global->__pyx_kp_s_https_fapi_trbinance_com_futures
#define __pyx_kp_s_https_testnet_binance_vision __pyx_mstate_global->__pyx_kp_s_https_testnet_binance_vision
#define __pyx_kp_s_https_testnet_binance_vision_api __pyx_mstate_global->__pyx_kp_s_https_testnet_binance_vision_api
#define __pyx_kp_s_https_testnet_binancefuture_com __pyx_mstate_global->__pyx_kp_s_https_testnet_binancefuture_com
#define __pyx_kp_s_https_testnet_binancefuture_com_2 __pyx_mstate_global->__pyx_kp_s_https_testnet_binancefuture_com_2
#define __pyx_kp_s_https_testnet_binancefuture_com_3 __pyx_mstate_global->__pyx_kp_s_https_testnet_binancefuture_com_3
#define __pyx_kp_s_https_www_binance __pyx_mstate_global->__pyx_kp_s_https_www_binance
#define __pyx_kp_s_https_www_binance_com __pyx_mstate_global->__pyx_kp_s_https_www_binance_com
#define __pyx_kp_s_https_www_binance_us __pyx_mstate_global->__pyx_kp_s_https_www_binance_us
#define __pyx_kp_s_https_www_trbinance_com __pyx_mstate_global->__pyx_kp_s_https_www_trbinance_com
#define __pyx_kp_s_https_www_trbinance_com_api __pyx_mstate_global->__pyx_kp_s_https_www_trbinance_com_api
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_s_id __pyx_mstate_global->__pyx_n_s_id
#define __pyx_n_s_idx __pyx_mstate_global->__pyx_n_s_idx
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_income __pyx_mstate_global->__pyx_n_s_income
#define __pyx_n_s_indexPriceKlines __pyx_mstate_global->__pyx_n_s_indexPriceKlines
#define __pyx_n_s_info __pyx_mstate_global->__pyx_n_s_info
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_init_2 __pyx_mstate_global->__pyx_n_s_init_2
#define __pyx_n_s_init_session __pyx_mstate_global->__pyx_n_s_init_session
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_installed_version __pyx_mstate_global->__pyx_n_s_installed_version
#define __pyx_n_s_interval __pyx_mstate_global->__pyx_n_s_interval
#define __pyx_n_s_interval_to_milliseconds __pyx_mstate_global->__pyx_n_s_interval_to_milliseconds
#define __pyx_kp_u_is_available_please_consider_up __pyx_mstate_global->__pyx_kp_u_is_available_please_consider_up
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_n_s_is_update_availabe __pyx_mstate_global->__pyx_n_s_is_update_availabe
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_isolated_margin_stream_close __pyx_mstate_global->__pyx_n_s_isolated_margin_stream_close
#define __pyx_n_s_isolated_margin_stream_get_liste __pyx_mstate_global->__pyx_n_s_isolated_margin_stream_get_liste
#define __pyx_n_s_isolated_margin_stream_keepalive __pyx_mstate_global->__pyx_n_s_isolated_margin_stream_keepalive
#define __pyx_n_s_item __pyx_mstate_global->__pyx_n_s_item
#define __pyx_n_s_itemgetter __pyx_mstate_global->__pyx_n_s_itemgetter
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_join __pyx_mstate_global->__pyx_n_s_join
#define __pyx_n_s_json __pyx_mstate_global->__pyx_n_s_json
#define __pyx_n_s_key __pyx_mstate_global->__pyx_n_s_key
#define __pyx_n_s_kline __pyx_mstate_global->__pyx_n_s_kline
#define __pyx_n_s_klines __pyx_mstate_global->__pyx_n_s_klines
#define __pyx_n_s_kwargs __pyx_mstate_global->__pyx_n_s_kwargs
#define __pyx_n_s_l __pyx_mstate_global->__pyx_n_s_l
#define __pyx_n_s_last_id __pyx_mstate_global->__pyx_n_s_last_id
#define __pyx_n_s_last_update_check_github __pyx_mstate_global->__pyx_n_s_last_update_check_github
#define __pyx_n_s_latest_release_info __pyx_mstate_global->__pyx_n_s_latest_release_info
#define __pyx_kp_s_lending_daily_product_list __pyx_mstate_global->__pyx_kp_s_lending_daily_product_list
#define __pyx_kp_s_lending_daily_purchase __pyx_mstate_global->__pyx_kp_s_lending_daily_purchase
#define __pyx_kp_s_lending_daily_redeem __pyx_mstate_global->__pyx_kp_s_lending_daily_redeem
#define __pyx_kp_s_lending_daily_token_position __pyx_mstate_global->__pyx_kp_s_lending_daily_token_position
#define __pyx_kp_s_lending_daily_userLeftQuota __pyx_mstate_global->__pyx_kp_s_lending_daily_userLeftQuota
#define __pyx_kp_s_lending_daily_userRedemptionQuot __pyx_mstate_global->__pyx_kp_s_lending_daily_userRedemptionQuot
#define __pyx_kp_s_lending_positionChanged __pyx_mstate_global->__pyx_kp_s_lending_positionChanged
#define __pyx_kp_s_lending_project_list __pyx_mstate_global->__pyx_kp_s_lending_project_list
#define __pyx_kp_s_lending_union_account __pyx_mstate_global->__pyx_kp_s_lending_union_account
#define __pyx_kp_s_lending_union_interestHistory __pyx_mstate_global->__pyx_kp_s_lending_union_interestHistory
#define __pyx_kp_s_lending_union_purchaseRecord __pyx_mstate_global->__pyx_kp_s_lending_union_purchaseRecord
#define __pyx_kp_s_lending_union_redemptionRecord __pyx_mstate_global->__pyx_kp_s_lending_union_redemptionRecord
#define __pyx_n_s_leverage __pyx_mstate_global->__pyx_n_s_leverage
#define __pyx_n_s_leverageBracket __pyx_mstate_global->__pyx_n_s_leverageBracket
#define __pyx_n_s_license_ini __pyx_mstate_global->__pyx_n_s_license_ini
#define __pyx_n_s_license_profile __pyx_mstate_global->__pyx_n_s_license_profile
#define __pyx_n_s_license_token __pyx_mstate_global->__pyx_n_s_license_token
#define __pyx_n_s_limit __pyx_mstate_global->__pyx_n_s_limit
#define __pyx_n_s_listenKey __pyx_mstate_global->__pyx_n_s_listenKey
#define __pyx_n_s_llm __pyx_mstate_global->__pyx_n_s_llm
#define __pyx_n_s_logger __pyx_mstate_global->__pyx_n_s_logger
#define __pyx_n_s_logging __pyx_mstate_global->__pyx_n_s_logging
#define __pyx_n_s_lower __pyx_mstate_global->__pyx_n_s_lower
#define __pyx_n_s_lucit_api_secret __pyx_mstate_global->__pyx_n_s_lucit_api_secret
#define __pyx_n_s_lucit_license_ini __pyx_mstate_global->__pyx_n_s_lucit_license_ini
#define __pyx_n_s_lucit_license_profile __pyx_mstate_global->__pyx_n_s_lucit_license_profile
#define __pyx_n_s_lucit_license_token __pyx_mstate_global->__pyx_n_s_lucit_license_token
#define __pyx_n_s_lucit_licensing_python_manager __pyx_mstate_global->__pyx_n_s_lucit_licensing_python_manager
#define __pyx_n_s_m __pyx_mstate_global->__pyx_n_s_m
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_make_new_request __pyx_mstate_global->__pyx_n_s_make_new_request
#define __pyx_n_s_make_subaccount_futures_transfer __pyx_mstate_global->__pyx_n_s_make_subaccount_futures_transfer
#define __pyx_n_s_make_subaccount_margin_transfer __pyx_mstate_global->__pyx_n_s_make_subaccount_margin_transfer
#define __pyx_n_s_make_subaccount_to_master_transf __pyx_mstate_global->__pyx_n_s_make_subaccount_to_master_transf
#define __pyx_n_s_make_subaccount_to_subaccount_tr __pyx_mstate_global->__pyx_n_s_make_subaccount_to_subaccount_tr
#define __pyx_n_s_make_universal_transfer __pyx_mstate_global->__pyx_n_s_make_universal_transfer
#define __pyx_n_s_marginType __pyx_mstate_global->__pyx_n_s_marginType
#define __pyx_kp_s_margin_account __pyx_mstate_global->__pyx_kp_s_margin_account
#define __pyx_kp_s_margin_allOrderList __pyx_mstate_global->__pyx_kp_s_margin_allOrderList
#define __pyx_kp_s_margin_allOrders __pyx_mstate_global->__pyx_kp_s_margin_allOrders
#define __pyx_kp_s_margin_asset __pyx_mstate_global->__pyx_kp_s_margin_asset
#define __pyx_kp_s_margin_isolated_account __pyx_mstate_global->__pyx_kp_s_margin_isolated_account
#define __pyx_kp_s_margin_isolated_allPairs __pyx_mstate_global->__pyx_kp_s_margin_isolated_allPairs
#define __pyx_kp_s_margin_isolated_create __pyx_mstate_global->__pyx_kp_s_margin_isolated_create
#define __pyx_kp_s_margin_isolated_pair __pyx_mstate_global->__pyx_kp_s_margin_isolated_pair
#define __pyx_kp_s_margin_isolated_transfer __pyx_mstate_global->__pyx_kp_s_margin_isolated_transfer
#define __pyx_kp_s_margin_loan __pyx_mstate_global->__pyx_kp_s_margin_loan
#define __pyx_kp_s_margin_maxBorrowable __pyx_mstate_global->__pyx_kp_s_margin_maxBorrowable
#define __pyx_kp_s_margin_maxTransferable __pyx_mstate_global->__pyx_kp_s_margin_maxTransferable
#define __pyx_kp_s_margin_myTrades __pyx_mstate_global->__pyx_kp_s_margin_myTrades
#define __pyx_kp_s_margin_openOrders __pyx_mstate_global->__pyx_kp_s_margin_openOrders
#define __pyx_kp_s_margin_order __pyx_mstate_global->__pyx_kp_s_margin_order
#define __pyx_kp_s_margin_orderList __pyx_mstate_global->__pyx_kp_s_margin_orderList
#define __pyx_kp_s_margin_order_oco __pyx_mstate_global->__pyx_kp_s_margin_order_oco
#define __pyx_kp_s_margin_pair __pyx_mstate_global->__pyx_kp_s_margin_pair
#define __pyx_kp_s_margin_priceIndex __pyx_mstate_global->__pyx_kp_s_margin_priceIndex
#define __pyx_kp_s_margin_repay __pyx_mstate_global->__pyx_kp_s_margin_repay
#define __pyx_n_s_margin_stream_close __pyx_mstate_global->__pyx_n_s_margin_stream_close
#define __pyx_n_s_margin_stream_get_listen_key __pyx_mstate_global->__pyx_n_s_margin_stream_get_listen_key
#define __pyx_n_s_margin_stream_keepalive __pyx_mstate_global->__pyx_n_s_margin_stream_keepalive
#define __pyx_kp_s_margin_transfer __pyx_mstate_global->__pyx_kp_s_margin_transfer
#define __pyx_n_s_markPriceKlines __pyx_mstate_global->__pyx_n_s_markPriceKlines
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_n_s_method __pyx_mstate_global->__pyx_n_s_method
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_n_s_mro_entries __pyx_mstate_global->__pyx_n_s_mro_entries
#define __pyx_n_s_msg __pyx_mstate_global->__pyx_n_s_msg
#define __pyx_n_s_myTrades __pyx_mstate_global->__pyx_n_s_myTrades
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_needed_license_type __pyx_mstate_global->__pyx_n_s_needed_license_type
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_new_transfer_history __pyx_mstate_global->__pyx_n_s_new_transfer_history
#define __pyx_n_s_null_args __pyx_mstate_global->__pyx_n_s_null_args
#define __pyx_n_s_o __pyx_mstate_global->__pyx_n_s_o
#define __pyx_n_s_object __pyx_mstate_global->__pyx_n_s_object
#define __pyx_n_s_openInterest __pyx_mstate_global->__pyx_n_s_openInterest
#define __pyx_n_s_openInterestHist __pyx_mstate_global->__pyx_n_s_openInterestHist
#define __pyx_n_s_openOrders __pyx_mstate_global->__pyx_n_s_openOrders
#define __pyx_n_s_operator __pyx_mstate_global->__pyx_n_s_operator
#define __pyx_n_s_options __pyx_mstate_global->__pyx_n_s_options
#define __pyx_n_s_order __pyx_mstate_global->__pyx_n_s_order
#define __pyx_n_s_order_limit __pyx_mstate_global->__pyx_n_s_order_limit
#define __pyx_n_s_order_limit_buy __pyx_mstate_global->__pyx_n_s_order_limit_buy
#define __pyx_n_s_order_limit_sell __pyx_mstate_global->__pyx_n_s_order_limit_sell
#define __pyx_n_s_order_market __pyx_mstate_global->__pyx_n_s_order_market
#define __pyx_n_s_order_market_buy __pyx_mstate_global->__pyx_n_s_order_market_buy
#define __pyx_n_s_order_market_sell __pyx_mstate_global->__pyx_n_s_order_market_sell
#define __pyx_kp_s_order_oco __pyx_mstate_global->__pyx_kp_s_order_oco
#define __pyx_n_s_order_oco_buy __pyx_mstate_global->__pyx_n_s_order_oco_buy
#define __pyx_n_s_order_oco_sell __pyx_mstate_global->__pyx_n_s_order_oco_sell
#define __pyx_n_s_order_params __pyx_mstate_global->__pyx_n_s_order_params
#define __pyx_kp_s_order_test __pyx_mstate_global->__pyx_kp_s_order_test
#define __pyx_n_s_ordered_data __pyx_mstate_global->__pyx_n_s_ordered_data
#define __pyx_n_s_output __pyx_mstate_global->__pyx_n_s_output
#define __pyx_n_s_output_data __pyx_mstate_global->__pyx_n_s_output_data
#define __pyx_n_s_p __pyx_mstate_global->__pyx_n_s_p
#define __pyx_n_s_params __pyx_mstate_global->__pyx_n_s_params
#define __pyx_n_s_parent_shutdown_function __pyx_mstate_global->__pyx_n_s_parent_shutdown_function
#define __pyx_n_s_path __pyx_mstate_global->__pyx_n_s_path
#define __pyx_n_s_ping __pyx_mstate_global->__pyx_n_s_ping
#define __pyx_n_s_platform __pyx_mstate_global->__pyx_n_s_platform
#define __pyx_n_s_positionMargin __pyx_mstate_global->__pyx_n_s_positionMargin
#define __pyx_kp_s_positionMargin_history __pyx_mstate_global->__pyx_kp_s_positionMargin_history
#define __pyx_n_s_positionRisk __pyx_mstate_global->__pyx_n_s_positionRisk
#define __pyx_kp_s_positionSide_dual __pyx_mstate_global->__pyx_kp_s_positionSide_dual
#define __pyx_n_s_post __pyx_mstate_global->__pyx_n_s_post
#define __pyx_n_s_post_2 __pyx_mstate_global->__pyx_n_s_post_2
#define __pyx_n_s_premiumIndex __pyx_mstate_global->__pyx_n_s_premiumIndex
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_s_print __pyx_mstate_global->__pyx_n_s_print
#define __pyx_n_s_products __pyx_mstate_global->__pyx_n_s_products
#define __pyx_n_s_program_used __pyx_mstate_global->__pyx_n_s_program_used
#define __pyx_n_s_proxies __pyx_mstate_global->__pyx_n_s_proxies
#define __pyx_n_s_purchase_lending_product __pyx_mstate_global->__pyx_n_s_purchase_lending_product
#define __pyx_n_s_put __pyx_mstate_global->__pyx_n_s_put
#define __pyx_n_s_put_2 __pyx_mstate_global->__pyx_n_s_put_2
#define __pyx_kp_u_python __pyx_mstate_global->__pyx_kp_u_python
#define __pyx_n_s_python_version __pyx_mstate_global->__pyx_n_s_python_version
#define __pyx_n_s_q __pyx_mstate_global->__pyx_n_s_q
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_query_string __pyx_mstate_global->__pyx_n_s_query_string
#define __pyx_n_s_query_subaccount_spot_summary __pyx_mstate_global->__pyx_n_s_query_subaccount_spot_summary
#define __pyx_n_s_query_universal_transfer_history __pyx_mstate_global->__pyx_n_s_query_universal_transfer_history
#define __pyx_n_s_raw_data __pyx_mstate_global->__pyx_n_s_raw_data
#define __pyx_n_s_redeem_lending_product __pyx_mstate_global->__pyx_n_s_redeem_lending_product
#define __pyx_n_s_release __pyx_mstate_global->__pyx_n_s_release
#define __pyx_n_s_repay_margin_loan __pyx_mstate_global->__pyx_n_s_repay_margin_loan
#define __pyx_n_s_replace __pyx_mstate_global->__pyx_n_s_replace
#define __pyx_n_s_request __pyx_mstate_global->__pyx_n_s_request
#define __pyx_n_s_request_api __pyx_mstate_global->__pyx_n_s_request_api
#define __pyx_n_s_request_futures_api __pyx_mstate_global->__pyx_n_s_request_futures_api
#define __pyx_n_s_request_futures_coin_api __pyx_mstate_global->__pyx_n_s_request_futures_coin_api
#define __pyx_n_s_request_futures_coin_data_api __pyx_mstate_global->__pyx_n_s_request_futures_coin_data_api
#define __pyx_n_s_request_futures_data_api __pyx_mstate_global->__pyx_n_s_request_futures_data_api
#define __pyx_n_s_request_margin_api __pyx_mstate_global->__pyx_n_s_request_margin_api
#define __pyx_n_s_request_socks5_proxies __pyx_mstate_global->__pyx_n_s_request_socks5_proxies
#define __pyx_n_s_request_website __pyx_mstate_global->__pyx_n_s_request_website
#define __pyx_n_s_requests __pyx_mstate_global->__pyx_n_s_requests
#define __pyx_n_s_requests_params __pyx_mstate_global->__pyx_n_s_requests_params
#define __pyx_n_s_requests_params_2 __pyx_mstate_global->__pyx_n_s_requests_params_2
#define __pyx_n_s_res __pyx_mstate_global->__pyx_n_s_res
#define __pyx_n_s_respond __pyx_mstate_global->__pyx_n_s_respond
#define __pyx_n_s_response __pyx_mstate_global->__pyx_n_s_response
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_reversed __pyx_mstate_global->__pyx_n_s_reversed
#define __pyx_kp_s_s_s __pyx_mstate_global->__pyx_kp_s_s_s
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_kp_u_self_API_URL __pyx_mstate_global->__pyx_kp_u_self_API_URL
#define __pyx_kp_u_self_FUTURES_COIN_DATA_URL __pyx_mstate_global->__pyx_kp_u_self_FUTURES_COIN_DATA_URL
#define __pyx_kp_u_self_FUTURES_COIN_URL __pyx_mstate_global->__pyx_kp_u_self_FUTURES_COIN_URL
#define __pyx_kp_u_self_FUTURES_DATA_URL __pyx_mstate_global->__pyx_kp_u_self_FUTURES_DATA_URL
#define __pyx_kp_u_self_FUTURES_URL __pyx_mstate_global->__pyx_kp_u_self_FUTURES_URL
#define __pyx_kp_u_self_MARGIN_API_URL __pyx_mstate_global->__pyx_kp_u_self_MARGIN_API_URL
#define __pyx_kp_u_self_WEBSITE_URL __pyx_mstate_global->__pyx_kp_u_self_WEBSITE_URL
#define __pyx_n_s_send __pyx_mstate_global->__pyx_n_s_send
#define __pyx_n_s_serverTime __pyx_mstate_global->__pyx_n_s_serverTime
#define __pyx_n_s_session __pyx_mstate_global->__pyx_n_s_session
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_sha256 __pyx_mstate_global->__pyx_n_s_sha256
#define __pyx_n_s_side __pyx_mstate_global->__pyx_n_s_side
#define __pyx_n_s_signature __pyx_mstate_global->__pyx_n_s_signature
#define __pyx_n_s_signed __pyx_mstate_global->__pyx_n_s_signed
#define __pyx_n_s_sleep __pyx_mstate_global->__pyx_n_s_sleep
#define __pyx_kp_s_socks5 __pyx_mstate_global->__pyx_kp_s_socks5
#define __pyx_n_s_socks5_proxy_address __pyx_mstate_global->__pyx_n_s_socks5_proxy_address
#define __pyx_n_s_socks5_proxy_pass __pyx_mstate_global->__pyx_n_s_socks5_proxy_pass
#define __pyx_n_s_socks5_proxy_port __pyx_mstate_global->__pyx_n_s_socks5_proxy_port
#define __pyx_n_s_socks5_proxy_server __pyx_mstate_global->__pyx_n_s_socks5_proxy_server
#define __pyx_n_s_socks5_proxy_ssl_verification __pyx_mstate_global->__pyx_n_s_socks5_proxy_ssl_verification
#define __pyx_n_s_socks5_proxy_user __pyx_mstate_global->__pyx_n_s_socks5_proxy_user
#define __pyx_n_s_socks_proxy_uri __pyx_mstate_global->__pyx_n_s_socks_proxy_uri
#define __pyx_n_s_sort __pyx_mstate_global->__pyx_n_s_sort
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_split __pyx_mstate_global->__pyx_n_s_split
#define __pyx_n_s_start __pyx_mstate_global->__pyx_n_s_start
#define __pyx_n_s_startTime __pyx_mstate_global->__pyx_n_s_startTime
#define __pyx_n_s_start_str __pyx_mstate_global->__pyx_n_s_start_str
#define __pyx_kp_s_start_time_and_last_id_may_not_b __pyx_mstate_global->__pyx_kp_s_start_time_and_last_id_may_not_b
#define __pyx_n_s_start_ts __pyx_mstate_global->__pyx_n_s_start_ts
#define __pyx_kp_u_started __pyx_mstate_global->__pyx_kp_u_started
#define __pyx_n_s_status __pyx_mstate_global->__pyx_n_s_status
#define __pyx_n_s_status_code __pyx_mstate_global->__pyx_n_s_status_code
#define __pyx_n_s_stop_manager __pyx_mstate_global->__pyx_n_s_stop_manager
#define __pyx_n_s_str __pyx_mstate_global->__pyx_n_s_str
#define __pyx_n_s_stream_close __pyx_mstate_global->__pyx_n_s_stream_close
#define __pyx_n_s_stream_get_listen_key __pyx_mstate_global->__pyx_n_s_stream_get_listen_key
#define __pyx_n_s_stream_keepalive __pyx_mstate_global->__pyx_n_s_stream_keepalive
#define __pyx_n_s_strptime __pyx_mstate_global->__pyx_n_s_strptime
#define __pyx_kp_s_sub_account_assets __pyx_mstate_global->__pyx_kp_s_sub_account_assets
#define __pyx_kp_s_sub_account_futures_account __pyx_mstate_global->__pyx_kp_s_sub_account_futures_account
#define __pyx_kp_s_sub_account_futures_accountSumma __pyx_mstate_global->__pyx_kp_s_sub_account_futures_accountSumma
#define __pyx_kp_s_sub_account_futures_enable __pyx_mstate_global->__pyx_kp_s_sub_account_futures_enable
#define __pyx_kp_s_sub_account_futures_internalTran __pyx_mstate_global->__pyx_kp_s_sub_account_futures_internalTran
#define __pyx_kp_s_sub_account_futures_positionRisk __pyx_mstate_global->__pyx_kp_s_sub_account_futures_positionRisk
#define __pyx_kp_s_sub_account_futures_transfer __pyx_mstate_global->__pyx_kp_s_sub_account_futures_transfer
#define __pyx_kp_s_sub_account_list __pyx_mstate_global->__pyx_kp_s_sub_account_list
#define __pyx_kp_s_sub_account_margin_account __pyx_mstate_global->__pyx_kp_s_sub_account_margin_account
#define __pyx_kp_s_sub_account_margin_accountSummar __pyx_mstate_global->__pyx_kp_s_sub_account_margin_accountSummar
#define __pyx_kp_s_sub_account_margin_enable __pyx_mstate_global->__pyx_kp_s_sub_account_margin_enable
#define __pyx_kp_s_sub_account_margin_transfer __pyx_mstate_global->__pyx_kp_s_sub_account_margin_transfer
#define __pyx_kp_s_sub_account_spotSummary __pyx_mstate_global->__pyx_kp_s_sub_account_spotSummary
#define __pyx_kp_s_sub_account_status __pyx_mstate_global->__pyx_kp_s_sub_account_status
#define __pyx_kp_s_sub_account_sub_transfer_history __pyx_mstate_global->__pyx_kp_s_sub_account_sub_transfer_history
#define __pyx_kp_s_sub_account_transfer_subToMaster __pyx_mstate_global->__pyx_kp_s_sub_account_transfer_subToMaster
#define __pyx_kp_s_sub_account_transfer_subToSub __pyx_mstate_global->__pyx_kp_s_sub_account_transfer_subToSub
#define __pyx_kp_s_sub_account_transfer_subUserHist __pyx_mstate_global->__pyx_kp_s_sub_account_transfer_subUserHist
#define __pyx_kp_s_sub_account_universalTransfer __pyx_mstate_global->__pyx_kp_s_sub_account_universalTransfer
#define __pyx_n_s_success __pyx_mstate_global->__pyx_n_s_success
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_symbol __pyx_mstate_global->__pyx_n_s_symbol
#define __pyx_n_s_symbols __pyx_mstate_global->__pyx_n_s_symbols
#define __pyx_n_s_system __pyx_mstate_global->__pyx_n_s_system
#define __pyx_kp_s_system_status __pyx_mstate_global->__pyx_kp_s_system_status
#define __pyx_n_s_t __pyx_mstate_global->__pyx_n_s_t
#define __pyx_n_s_tag_name __pyx_mstate_global->__pyx_n_s_tag_name
#define __pyx_n_s_temp_data __pyx_mstate_global->__pyx_n_s_temp_data
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_text __pyx_mstate_global->__pyx_n_s_text
#define __pyx_n_s_throw __pyx_mstate_global->__pyx_n_s_throw
#define __pyx_n_s_throw_exception __pyx_mstate_global->__pyx_n_s_throw_exception
#define __pyx_kp_s_ticker_24hr __pyx_mstate_global->__pyx_kp_s_ticker_24hr
#define __pyx_kp_s_ticker_allForceOrders __pyx_mstate_global->__pyx_kp_s_ticker_allForceOrders
#define __pyx_kp_s_ticker_bookTicker __pyx_mstate_global->__pyx_kp_s_ticker_bookTicker
#define __pyx_kp_s_ticker_openInterest __pyx_mstate_global->__pyx_kp_s_ticker_openInterest
#define __pyx_kp_s_ticker_price __pyx_mstate_global->__pyx_kp_s_ticker_price
#define __pyx_n_s_time __pyx_mstate_global->__pyx_n_s_time
#define __pyx_n_s_timeInForce __pyx_mstate_global->__pyx_n_s_timeInForce
#define __pyx_n_s_timeframe __pyx_mstate_global->__pyx_n_s_timeframe
#define __pyx_n_s_timeout __pyx_mstate_global->__pyx_n_s_timeout
#define __pyx_n_s_timestamp __pyx_mstate_global->__pyx_n_s_timestamp
#define __pyx_n_s_timestamp_offset __pyx_mstate_global->__pyx_n_s_timestamp_offset
#define __pyx_n_s_tld __pyx_mstate_global->__pyx_n_s_tld
#define __pyx_kp_u_tld_2 __pyx_mstate_global->__pyx_kp_u_tld_2
#define __pyx_n_s_toggle_bnb_burn_spot_margin __pyx_mstate_global->__pyx_n_s_toggle_bnb_burn_spot_margin
#define __pyx_n_s_trades __pyx_mstate_global->__pyx_n_s_trades
#define __pyx_n_s_transFrom __pyx_mstate_global->__pyx_n_s_transFrom
#define __pyx_n_s_transTo __pyx_mstate_global->__pyx_n_s_transTo
#define __pyx_n_s_transfer_dust __pyx_mstate_global->__pyx_n_s_transfer_dust
#define __pyx_n_s_transfer_history __pyx_mstate_global->__pyx_n_s_transfer_history
#define __pyx_n_s_transfer_isolated_margin_to_spot __pyx_mstate_global->__pyx_n_s_transfer_isolated_margin_to_spot
#define __pyx_n_s_transfer_margin_to_spot __pyx_mstate_global->__pyx_n_s_transfer_margin_to_spot
#define __pyx_n_s_transfer_spot_to_isolated_margin __pyx_mstate_global->__pyx_n_s_transfer_spot_to_isolated_margin
#define __pyx_n_s_transfer_spot_to_margin __pyx_mstate_global->__pyx_n_s_transfer_spot_to_margin
#define __pyx_kp_s_trbinance_com __pyx_mstate_global->__pyx_kp_s_trbinance_com
#define __pyx_n_s_type __pyx_mstate_global->__pyx_n_s_type
#define __pyx_n_s_typing __pyx_mstate_global->__pyx_n_s_typing
#define __pyx_kp_s_unicorn_binance_rest_api __pyx_mstate_global->__pyx_kp_s_unicorn_binance_rest_api
#define __pyx_n_s_unicorn_binance_rest_api_2 __pyx_mstate_global->__pyx_n_s_unicorn_binance_rest_api_2
#define __pyx_n_s_unicorn_binance_rest_api_manager __pyx_mstate_global->__pyx_n_s_unicorn_binance_rest_api_manager
#define __pyx_kp_s_unicorn_binance_rest_api_manager_2 __pyx_mstate_global->__pyx_kp_s_unicorn_binance_rest_api_manager_2
#define __pyx_kp_s_unicorn_binance_websocket_api __pyx_mstate_global->__pyx_kp_s_unicorn_binance_websocket_api
#define __pyx_n_s_universal_transfer __pyx_mstate_global->__pyx_n_s_universal_transfer
#define __pyx_n_s_unknown __pyx_mstate_global->__pyx_n_s_unknown
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_update_msg __pyx_mstate_global->__pyx_n_s_update_msg
#define __pyx_n_s_upper __pyx_mstate_global->__pyx_n_s_upper
#define __pyx_n_s_uri __pyx_mstate_global->__pyx_n_s_uri
#define __pyx_n_s_urlencode __pyx_mstate_global->__pyx_n_s_urlencode
#define __pyx_n_s_urllib_parse __pyx_mstate_global->__pyx_n_s_urllib_parse
#define __pyx_n_s_userDataStream __pyx_mstate_global->__pyx_n_s_userDataStream
#define __pyx_kp_s_userDataStream_isolated __pyx_mstate_global->__pyx_kp_s_userDataStream_isolated
#define __pyx_n_s_userTrades __pyx_mstate_global->__pyx_n_s_userTrades
#define __pyx_n_s_user_agent __pyx_mstate_global->__pyx_n_s_user_agent
#define __pyx_kp_s_utf_8 __pyx_mstate_global->__pyx_kp_s_utf_8
#define __pyx_n_s_v __pyx_mstate_global->__pyx_n_s_v
#define __pyx_n_s_v1 __pyx_mstate_global->__pyx_n_s_v1
#define __pyx_n_s_v2 __pyx_mstate_global->__pyx_n_s_v2
#define __pyx_n_s_v3 __pyx_mstate_global->__pyx_n_s_v3
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_n_s_verify __pyx_mstate_global->__pyx_n_s_verify
#define __pyx_n_s_version __pyx_mstate_global->__pyx_n_s_version
#define __pyx_n_s_version_2 __pyx_mstate_global->__pyx_n_s_version_2
#define __pyx_n_s_warn_on_update __pyx_mstate_global->__pyx_n_s_warn_on_update
#define __pyx_n_s_warning __pyx_mstate_global->__pyx_n_s_warning
#define __pyx_n_s_weight __pyx_mstate_global->__pyx_n_s_weight
#define __pyx_n_s_withdraw __pyx_mstate_global->__pyx_n_s_withdraw
#define __pyx_n_s_withdrawList __pyx_mstate_global->__pyx_n_s_withdrawList
#define __pyx_n_s_withdraw_id __pyx_mstate_global->__pyx_n_s_withdraw_id
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_10 __pyx_mstate_global->__pyx_int_10
#define __pyx_int_12 __pyx_mstate_global->__pyx_int_12
#define __pyx_int_200 __pyx_mstate_global->__pyx_int_200
#define __pyx_int_300 __pyx_mstate_global->__pyx_int_300
#define __pyx_int_500 __pyx_mstate_global->__pyx_int_500
#define __pyx_int_1000 __pyx_mstate_global->__pyx_int_1000
#define __pyx_int_3600 __pyx_mstate_global->__pyx_int_3600
#define __pyx_int_3600000 __pyx_mstate_global->__pyx_int_3600000
#define __pyx_int_neg_4 __pyx_mstate_global->__pyx_int_neg_4
#define __pyx_slice__10 __pyx_mstate_global->__pyx_slice__10
#define __pyx_slice__24 __pyx_mstate_global->__pyx_slice__24
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__12 __pyx_mstate_global->__pyx_tuple__12
#define __pyx_tuple__13 __pyx_mstate_global->__pyx_tuple__13
#define __pyx_tuple__14 __pyx_mstate_global->__pyx_tuple__14
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__16 __pyx_mstate_global->__pyx_tuple__16
#define __pyx_tuple__17 __pyx_mstate_global->__pyx_tuple__17
#define __pyx_tuple__18 __pyx_mstate_global->__pyx_tuple__18
#define __pyx_tuple__19 __pyx_mstate_global->__pyx_tuple__19
#define __pyx_tuple__20 __pyx_mstate_global->__pyx_tuple__20
#define __pyx_tuple__21 __pyx_mstate_global->__pyx_tuple__21
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__25 __pyx_mstate_global->__pyx_tuple__25
#define __pyx_tuple__27 __pyx_mstate_global->__pyx_tuple__27
#define __pyx_tuple__28 __pyx_mstate_global->__pyx_tuple__28
#define __pyx_tuple__29 __pyx_mstate_global->__pyx_tuple__29
#define __pyx_tuple__30 __pyx_mstate_global->__pyx_tuple__30
#define __pyx_tuple__31 __pyx_mstate_global->__pyx_tuple__31
#define __pyx_tuple__32 __pyx_mstate_global->__pyx_tuple__32
#define __pyx_tuple__33 __pyx_mstate_global->__pyx_tuple__33
#define __pyx_tuple__34 __pyx_mstate_global->__pyx_tuple__34
#define __pyx_tuple__35 __pyx_mstate_global->__pyx_tuple__35
#define __pyx_tuple__36 __pyx_mstate_global->__pyx_tuple__36
#define __pyx_tuple__37 __pyx_mstate_global->__pyx_tuple__37
#define __pyx_tuple__38 __pyx_mstate_global->__pyx_tuple__38
#define __pyx_tuple__39 __pyx_mstate_global->__pyx_tuple__39
#define __pyx_tuple__40 __pyx_mstate_global->__pyx_tuple__40
#define __pyx_tuple__41 __pyx_mstate_global->__pyx_tuple__41
#define __pyx_tuple__42 __pyx_mstate_global->__pyx_tuple__42
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__44 __pyx_mstate_global->__pyx_tuple__44
#define __pyx_tuple__45 __pyx_mstate_global->__pyx_tuple__45
#define __pyx_tuple__46 __pyx_mstate_global->__pyx_tuple__46
#define __pyx_tuple__47 __pyx_mstate_global->__pyx_tuple__47
#define __pyx_tuple__48 __pyx_mstate_global->__pyx_tuple__48
#define __pyx_tuple__49 __pyx_mstate_global->__pyx_tuple__49
#define __pyx_tuple__50 __pyx_mstate_global->__pyx_tuple__50
#define __pyx_tuple__51 __pyx_mstate_global->__pyx_tuple__51
#define __pyx_tuple__52 __pyx_mstate_global->__pyx_tuple__52
#define __pyx_tuple__53 __pyx_mstate_global->__pyx_tuple__53
#define __pyx_tuple__54 __pyx_mstate_global->__pyx_tuple__54
#define __pyx_tuple__55 __pyx_mstate_global->__pyx_tuple__55
#define __pyx_tuple__56 __pyx_mstate_global->__pyx_tuple__56
#define __pyx_tuple__57 __pyx_mstate_global->__pyx_tuple__57
#define __pyx_tuple__58 __pyx_mstate_global->__pyx_tuple__58
#define __pyx_tuple__59 __pyx_mstate_global->__pyx_tuple__59
#define __pyx_tuple__60 __pyx_mstate_global->__pyx_tuple__60
#define __pyx_tuple__61 __pyx_mstate_global->__pyx_tuple__61
#define __pyx_tuple__62 __pyx_mstate_global->__pyx_tuple__62
#define __pyx_tuple__63 __pyx_mstate_global->__pyx_tuple__63
#define __pyx_tuple__64 __pyx_mstate_global->__pyx_tuple__64
#define __pyx_tuple__65 __pyx_mstate_global->__pyx_tuple__65
#define __pyx_tuple__66 __pyx_mstate_global->__pyx_tuple__66
#define __pyx_tuple__67 __pyx_mstate_global->__pyx_tuple__67
#define __pyx_tuple__68 __pyx_mstate_global->__pyx_tuple__68
#define __pyx_tuple__69 __pyx_mstate_global->__pyx_tuple__69
#define __pyx_tuple__70 __pyx_mstate_global->__pyx_tuple__70
#define __pyx_tuple__71 __pyx_mstate_global->__pyx_tuple__71
#define __pyx_tuple__72 __pyx_mstate_global->__pyx_tuple__72
#define __pyx_tuple__73 __pyx_mstate_global->__pyx_tuple__73
#define __pyx_tuple__74 __pyx_mstate_global->__pyx_tuple__74
#define __pyx_tuple__75 __pyx_mstate_global->__pyx_tuple__75
#define __pyx_tuple__76 __pyx_mstate_global->__pyx_tuple__76
#define __pyx_tuple__77 __pyx_mstate_global->__pyx_tuple__77
#define __pyx_tuple__78 __pyx_mstate_global->__pyx_tuple__78
#define __pyx_tuple__79 __pyx_mstate_global->__pyx_tuple__79
#define __pyx_tuple__80 __pyx_mstate_global->__pyx_tuple__80
#define __pyx_tuple__81 __pyx_mstate_global->__pyx_tuple__81
#define __pyx_tuple__82 __pyx_mstate_global->__pyx_tuple__82
#define __pyx_tuple__83 __pyx_mstate_global->__pyx_tuple__83
#define __pyx_tuple__84 __pyx_mstate_global->__pyx_tuple__84
#define __pyx_tuple__85 __pyx_mstate_global->__pyx_tuple__85
#define __pyx_tuple__86 __pyx_mstate_global->__pyx_tuple__86
#define __pyx_tuple__87 __pyx_mstate_global->__pyx_tuple__87
#define __pyx_tuple__88 __pyx_mstate_global->__pyx_tuple__88
#define __pyx_tuple__89 __pyx_mstate_global->__pyx_tuple__89
#define __pyx_tuple__90 __pyx_mstate_global->__pyx_tuple__90
#define __pyx_tuple__91 __pyx_mstate_global->__pyx_tuple__91
#define __pyx_tuple__92 __pyx_mstate_global->__pyx_tuple__92
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_tuple__94 __pyx_mstate_global->__pyx_tuple__94
#define __pyx_tuple__95 __pyx_mstate_global->__pyx_tuple__95
#define __pyx_tuple__96 __pyx_mstate_global->__pyx_tuple__96
#define __pyx_tuple__97 __pyx_mstate_global->__pyx_tuple__97
#define __pyx_tuple__98 __pyx_mstate_global->__pyx_tuple__98
#define __pyx_tuple__99 __pyx_mstate_global->__pyx_tuple__99
#define __pyx_slice__143 __pyx_mstate_global->__pyx_slice__143
#define __pyx_tuple__100 __pyx_mstate_global->__pyx_tuple__100
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__102 __pyx_mstate_global->__pyx_tuple__102
#define __pyx_tuple__103 __pyx_mstate_global->__pyx_tuple__103
#define __pyx_tuple__104 __pyx_mstate_global->__pyx_tuple__104
#define __pyx_tuple__105 __pyx_mstate_global->__pyx_tuple__105
#define __pyx_tuple__106 __pyx_mstate_global->__pyx_tuple__106
#define __pyx_tuple__107 __pyx_mstate_global->__pyx_tuple__107
#define __pyx_tuple__108 __pyx_mstate_global->__pyx_tuple__108
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_tuple__110 __pyx_mstate_global->__pyx_tuple__110
#define __pyx_tuple__111 __pyx_mstate_global->__pyx_tuple__111
#define __pyx_tuple__112 __pyx_mstate_global->__pyx_tuple__112
#define __pyx_tuple__113 __pyx_mstate_global->__pyx_tuple__113
#define __pyx_tuple__114 __pyx_mstate_global->__pyx_tuple__114
#define __pyx_tuple__115 __pyx_mstate_global->__pyx_tuple__115
#define __pyx_tuple__116 __pyx_mstate_global->__pyx_tuple__116
#define __pyx_tuple__117 __pyx_mstate_global->__pyx_tuple__117
#define __pyx_tuple__118 __pyx_mstate_global->__pyx_tuple__118
#define __pyx_tuple__119 __pyx_mstate_global->__pyx_tuple__119
#define __pyx_tuple__120 __pyx_mstate_global->__pyx_tuple__120
#define __pyx_tuple__121 __pyx_mstate_global->__pyx_tuple__121
#define __pyx_tuple__122 __pyx_mstate_global->__pyx_tuple__122
#define __pyx_tuple__123 __pyx_mstate_global->__pyx_tuple__123
#define __pyx_tuple__124 __pyx_mstate_global->__pyx_tuple__124
#define __pyx_tuple__125 __pyx_mstate_global->__pyx_tuple__125
#define __pyx_tuple__126 __pyx_mstate_global->__pyx_tuple__126
#define __pyx_tuple__127 __pyx_mstate_global->__pyx_tuple__127
#define __pyx_tuple__128 __pyx_mstate_global->__pyx_tuple__128
#define __pyx_tuple__129 __pyx_mstate_global->__pyx_tuple__129
#define __pyx_tuple__130 __pyx_mstate_global->__pyx_tuple__130
#define __pyx_tuple__131 __pyx_mstate_global->__pyx_tuple__131
#define __pyx_tuple__132 __pyx_mstate_global->__pyx_tuple__132
#define __pyx_tuple__133 __pyx_mstate_global->__pyx_tuple__133
#define __pyx_tuple__134 __pyx_mstate_global->__pyx_tuple__134
#define __pyx_tuple__135 __pyx_mstate_global->__pyx_tuple__135
#define __pyx_tuple__136 __pyx_mstate_global->__pyx_tuple__136
#define __pyx_tuple__137 __pyx_mstate_global->__pyx_tuple__137
#define __pyx_tuple__138 __pyx_mstate_global->__pyx_tuple__138
#define __pyx_tuple__139 __pyx_mstate_global->__pyx_tuple__139
#define __pyx_tuple__140 __pyx_mstate_global->__pyx_tuple__140
#define __pyx_tuple__141 __pyx_mstate_global->__pyx_tuple__141
#define __pyx_tuple__142 __pyx_mstate_global->__pyx_tuple__142
#define __pyx_tuple__144 __pyx_mstate_global->__pyx_tuple__144
#define __pyx_tuple__145 __pyx_mstate_global->__pyx_tuple__145
#define __pyx_tuple__146 __pyx_mstate_global->__pyx_tuple__146
#define __pyx_tuple__147 __pyx_mstate_global->__pyx_tuple__147
#define __pyx_tuple__148 __pyx_mstate_global->__pyx_tuple__148
#define __pyx_tuple__149 __pyx_mstate_global->__pyx_tuple__149
#define __pyx_tuple__150 __pyx_mstate_global->__pyx_tuple__150
#define __pyx_tuple__151 __pyx_mstate_global->__pyx_tuple__151
#define __pyx_tuple__152 __pyx_mstate_global->__pyx_tuple__152
#define __pyx_tuple__153 __pyx_mstate_global->__pyx_tuple__153
#define __pyx_tuple__154 __pyx_mstate_global->__pyx_tuple__154
#define __pyx_tuple__155 __pyx_mstate_global->__pyx_tuple__155
#define __pyx_tuple__156 __pyx_mstate_global->__pyx_tuple__156
#define __pyx_tuple__157 __pyx_mstate_global->__pyx_tuple__157
#define __pyx_tuple__158 __pyx_mstate_global->__pyx_tuple__158
#define __pyx_tuple__159 __pyx_mstate_global->__pyx_tuple__159
#define __pyx_tuple__160 __pyx_mstate_global->__pyx_tuple__160
#define __pyx_tuple__161 __pyx_mstate_global->__pyx_tuple__161
#define __pyx_tuple__162 __pyx_mstate_global->__pyx_tuple__162
#define __pyx_tuple__163 __pyx_mstate_global->__pyx_tuple__163
#define __pyx_tuple__164 __pyx_mstate_global->__pyx_tuple__164
#define __pyx_tuple__165 __pyx_mstate_global->__pyx_tuple__165
#define __pyx_tuple__166 __pyx_mstate_global->__pyx_tuple__166
#define __pyx_tuple__167 __pyx_mstate_global->__pyx_tuple__167
#define __pyx_tuple__168 __pyx_mstate_global->__pyx_tuple__168
#define __pyx_tuple__169 __pyx_mstate_global->__pyx_tuple__169
#define __pyx_tuple__170 __pyx_mstate_global->__pyx_tuple__170
#define __pyx_tuple__171 __pyx_mstate_global->__pyx_tuple__171
#define __pyx_tuple__172 __pyx_mstate_global->__pyx_tuple__172
#define __pyx_tuple__173 __pyx_mstate_global->__pyx_tuple__173
#define __pyx_tuple__174 __pyx_mstate_global->__pyx_tuple__174
#define __pyx_tuple__175 __pyx_mstate_global->__pyx_tuple__175
#define __pyx_tuple__176 __pyx_mstate_global->__pyx_tuple__176
#define __pyx_tuple__177 __pyx_mstate_global->__pyx_tuple__177
#define __pyx_tuple__178 __pyx_mstate_global->__pyx_tuple__178
#define __pyx_tuple__179 __pyx_mstate_global->__pyx_tuple__179
#define __pyx_tuple__180 __pyx_mstate_global->__pyx_tuple__180
#define __pyx_tuple__181 __pyx_mstate_global->__pyx_tuple__181
#define __pyx_tuple__182 __pyx_mstate_global->__pyx_tuple__182
#define __pyx_tuple__183 __pyx_mstate_global->__pyx_tuple__183
#define __pyx_tuple__187 __pyx_mstate_global->__pyx_tuple__187
#define __pyx_tuple__188 __pyx_mstate_global->__pyx_tuple__188
#define __pyx_tuple__189 __pyx_mstate_global->__pyx_tuple__189
#define __pyx_tuple__190 __pyx_mstate_global->__pyx_tuple__190
#define __pyx_tuple__192 __pyx_mstate_global->__pyx_tuple__192
#define __pyx_tuple__193 __pyx_mstate_global->__pyx_tuple__193
#define __pyx_tuple__195 __pyx_mstate_global->__pyx_tuple__195
#define __pyx_tuple__197 __pyx_mstate_global->__pyx_tuple__197
#define __pyx_tuple__199 __pyx_mstate_global->__pyx_tuple__199
#define __pyx_tuple__201 __pyx_mstate_global->__pyx_tuple__201
#define __pyx_tuple__203 __pyx_mstate_global->__pyx_tuple__203
#define __pyx_tuple__207 __pyx_mstate_global->__pyx_tuple__207
#define __pyx_tuple__209 __pyx_mstate_global->__pyx_tuple__209
#define __pyx_tuple__211 __pyx_mstate_global->__pyx_tuple__211
#define __pyx_tuple__213 __pyx_mstate_global->__pyx_tuple__213
#define __pyx_tuple__215 __pyx_mstate_global->__pyx_tuple__215
#define __pyx_tuple__217 __pyx_mstate_global->__pyx_tuple__217
#define __pyx_tuple__218 __pyx_mstate_global->__pyx_tuple__218
#define __pyx_tuple__221 __pyx_mstate_global->__pyx_tuple__221
#define __pyx_tuple__226 __pyx_mstate_global->__pyx_tuple__226
#define __pyx_tuple__228 __pyx_mstate_global->__pyx_tuple__228
#define __pyx_tuple__230 __pyx_mstate_global->__pyx_tuple__230
#define __pyx_tuple__231 __pyx_mstate_global->__pyx_tuple__231
#define __pyx_tuple__233 __pyx_mstate_global->__pyx_tuple__233
#define __pyx_tuple__237 __pyx_mstate_global->__pyx_tuple__237
#define __pyx_tuple__241 __pyx_mstate_global->__pyx_tuple__241
#define __pyx_tuple__243 __pyx_mstate_global->__pyx_tuple__243
#define __pyx_tuple__245 __pyx_mstate_global->__pyx_tuple__245
#define __pyx_tuple__248 __pyx_mstate_global->__pyx_tuple__248
#define __pyx_tuple__254 __pyx_mstate_global->__pyx_tuple__254
#define __pyx_tuple__259 __pyx_mstate_global->__pyx_tuple__259
#define __pyx_tuple__260 __pyx_mstate_global->__pyx_tuple__260
#define __pyx_tuple__262 __pyx_mstate_global->__pyx_tuple__262
#define __pyx_tuple__264 __pyx_mstate_global->__pyx_tuple__264
#define __pyx_tuple__266 __pyx_mstate_global->__pyx_tuple__266
#define __pyx_tuple__267 __pyx_mstate_global->__pyx_tuple__267
#define __pyx_tuple__268 __pyx_mstate_global->__pyx_tuple__268
#define __pyx_tuple__274 __pyx_mstate_global->__pyx_tuple__274
#define __pyx_tuple__292 __pyx_mstate_global->__pyx_tuple__292
#define __pyx_tuple__296 __pyx_mstate_global->__pyx_tuple__296
#define __pyx_tuple__308 __pyx_mstate_global->__pyx_tuple__308
#define __pyx_tuple__311 __pyx_mstate_global->__pyx_tuple__311
#define __pyx_tuple__313 __pyx_mstate_global->__pyx_tuple__313
#define __pyx_tuple__314 __pyx_mstate_global->__pyx_tuple__314
#define __pyx_tuple__351 __pyx_mstate_global->__pyx_tuple__351
#define __pyx_tuple__353 __pyx_mstate_global->__pyx_tuple__353
#define __pyx_tuple__391 __pyx_mstate_global->__pyx_tuple__391
#define __pyx_tuple__393 __pyx_mstate_global->__pyx_tuple__393
#define __pyx_tuple__416 __pyx_mstate_global->__pyx_tuple__416
#define __pyx_tuple__486 __pyx_mstate_global->__pyx_tuple__486
#define __pyx_codeobj__22 __pyx_mstate_global->__pyx_codeobj__22
#define __pyx_codeobj__26 __pyx_mstate_global->__pyx_codeobj__26
#define __pyx_codeobj__191 __pyx_mstate_global->__pyx_codeobj__191
#define __pyx_codeobj__194 __pyx_mstate_global->__pyx_codeobj__194
#define __pyx_codeobj__196 __pyx_mstate_global->__pyx_codeobj__196
#define __pyx_codeobj__198 __pyx_mstate_global->__pyx_codeobj__198
#define __pyx_codeobj__200 __pyx_mstate_global->__pyx_codeobj__200
#define __pyx_codeobj__202 __pyx_mstate_global->__pyx_codeobj__202
#define __pyx_codeobj__204 __pyx_mstate_global->__pyx_codeobj__204
#define __pyx_codeobj__205 __pyx_mstate_global->__pyx_codeobj__205
#define __pyx_codeobj__206 __pyx_mstate_global->__pyx_codeobj__206
#define __pyx_codeobj__208 __pyx_mstate_global->__pyx_codeobj__208
#define __pyx_codeobj__210 __pyx_mstate_global->__pyx_codeobj__210
#define __pyx_codeobj__212 __pyx_mstate_global->__pyx_codeobj__212
#define __pyx_codeobj__214 __pyx_mstate_global->__pyx_codeobj__214
#define __pyx_codeobj__216 __pyx_mstate_global->__pyx_codeobj__216
#define __pyx_codeobj__219 __pyx_mstate_global->__pyx_codeobj__219
#define __pyx_codeobj__220 __pyx_mstate_global->__pyx_codeobj__220
#define __pyx_codeobj__222 __pyx_mstate_global->__pyx_codeobj__222
#define __pyx_codeobj__223 __pyx_mstate_global->__pyx_codeobj__223
#define __pyx_codeobj__224 __pyx_mstate_global->__pyx_codeobj__224
#define __pyx_codeobj__225 __pyx_mstate_global->__pyx_codeobj__225
#define __pyx_codeobj__227 __pyx_mstate_global->__pyx_codeobj__227
#define __pyx_codeobj__229 __pyx_mstate_global->__pyx_codeobj__229
#define __pyx_codeobj__232 __pyx_mstate_global->__pyx_codeobj__232
#define __pyx_codeobj__234 __pyx_mstate_global->__pyx_codeobj__234
#define __pyx_codeobj__235 __pyx_mstate_global->__pyx_codeobj__235
#define __pyx_codeobj__236 __pyx_mstate_global->__pyx_codeobj__236
#define __pyx_codeobj__238 __pyx_mstate_global->__pyx_codeobj__238
#define __pyx_codeobj__239 __pyx_mstate_global->__pyx_codeobj__239
#define __pyx_codeobj__240 __pyx_mstate_global->__pyx_codeobj__240
#define __pyx_codeobj__242 __pyx_mstate_global->__pyx_codeobj__242
#define __pyx_codeobj__244 __pyx_mstate_global->__pyx_codeobj__244
#define __pyx_codeobj__246 __pyx_mstate_global->__pyx_codeobj__246
#define __pyx_codeobj__247 __pyx_mstate_global->__pyx_codeobj__247
#define __pyx_codeobj__249 __pyx_mstate_global->__pyx_codeobj__249
#define __pyx_codeobj__250 __pyx_mstate_global->__pyx_codeobj__250
#define __pyx_codeobj__251 __pyx_mstate_global->__pyx_codeobj__251
#define __pyx_codeobj__252 __pyx_mstate_global->__pyx_codeobj__252
#define __pyx_codeobj__253 __pyx_mstate_global->__pyx_codeobj__253
#define __pyx_codeobj__255 __pyx_mstate_global->__pyx_codeobj__255
#define __pyx_codeobj__256 __pyx_mstate_global->__pyx_codeobj__256
#define __pyx_codeobj__257 __pyx_mstate_global->__pyx_codeobj__257
#define __pyx_codeobj__258 __pyx_mstate_global->__pyx_codeobj__258
#define __pyx_codeobj__261 __pyx_mstate_global->__pyx_codeobj__261
#define __pyx_codeobj__263 __pyx_mstate_global->__pyx_codeobj__263
#define __pyx_codeobj__265 __pyx_mstate_global->__pyx_codeobj__265
#define __pyx_codeobj__269 __pyx_mstate_global->__pyx_codeobj__269
#define __pyx_codeobj__270 __pyx_mstate_global->__pyx_codeobj__270
#define __pyx_codeobj__271 __pyx_mstate_global->__pyx_codeobj__271
#define __pyx_codeobj__272 __pyx_mstate_global->__pyx_codeobj__272
#define __pyx_codeobj__273 __pyx_mstate_global->__pyx_codeobj__273
#define __pyx_codeobj__275 __pyx_mstate_global->__pyx_codeobj__275
#define __pyx_codeobj__276 __pyx_mstate_global->__pyx_codeobj__276
#define __pyx_codeobj__277 __pyx_mstate_global->__pyx_codeobj__277
#define __pyx_codeobj__278 __pyx_mstate_global->__pyx_codeobj__278
#define __pyx_codeobj__279 __pyx_mstate_global->__pyx_codeobj__279
#define __pyx_codeobj__280 __pyx_mstate_global->__pyx_codeobj__280
#define __pyx_codeobj__281 __pyx_mstate_global->__pyx_codeobj__281
#define __pyx_codeobj__282 __pyx_mstate_global->__pyx_codeobj__282
#define __pyx_codeobj__283 __pyx_mstate_global->__pyx_codeobj__283
#define __pyx_codeobj__284 __pyx_mstate_global->__pyx_codeobj__284
#define __pyx_codeobj__285 __pyx_mstate_global->__pyx_codeobj__285
#define __pyx_codeobj__286 __pyx_mstate_global->__pyx_codeobj__286
#define __pyx_codeobj__287 __pyx_mstate_global->__pyx_codeobj__287
#define __pyx_codeobj__288 __pyx_mstate_global->__pyx_codeobj__288
#define __pyx_codeobj__289 __pyx_mstate_global->__pyx_codeobj__289
#define __pyx_codeobj__290 __pyx_mstate_global->__pyx_codeobj__290
#define __pyx_codeobj__291 __pyx_mstate_global->__pyx_codeobj__291
#define __pyx_codeobj__293 __pyx_mstate_global->__pyx_codeobj__293
#define __pyx_codeobj__294 __pyx_mstate_global->__pyx_codeobj__294
#define __pyx_codeobj__295 __pyx_mstate_global->__pyx_codeobj__295
#define __pyx_codeobj__297 __pyx_mstate_global->__pyx_codeobj__297
#define __pyx_codeobj__298 __pyx_mstate_global->__pyx_codeobj__298
#define __pyx_codeobj__299 __pyx_mstate_global->__pyx_codeobj__299
#define __pyx_codeobj__300 __pyx_mstate_global->__pyx_codeobj__300
#define __pyx_codeobj__301 __pyx_mstate_global->__pyx_codeobj__301
#define __pyx_codeobj__302 __pyx_mstate_global->__pyx_codeobj__302
#define __pyx_codeobj__303 __pyx_mstate_global->__pyx_codeobj__303
#define __pyx_codeobj__304 __pyx_mstate_global->__pyx_codeobj__304
#define __pyx_codeobj__305 __pyx_mstate_global->__pyx_codeobj__305
#define __pyx_codeobj__306 __pyx_mstate_global->__pyx_codeobj__306
#define __pyx_codeobj__307 __pyx_mstate_global->__pyx_codeobj__307
#define __pyx_codeobj__309 __pyx_mstate_global->__pyx_codeobj__309
#define __pyx_codeobj__310 __pyx_mstate_global->__pyx_codeobj__310
#define __pyx_codeobj__312 __pyx_mstate_global->__pyx_codeobj__312
#define __pyx_codeobj__315 __pyx_mstate_global->__pyx_codeobj__315
#define __pyx_codeobj__316 __pyx_mstate_global->__pyx_codeobj__316
#define __pyx_codeobj__317 __pyx_mstate_global->__pyx_codeobj__317
#define __pyx_codeobj__318 __pyx_mstate_global->__pyx_codeobj__318
#define __pyx_codeobj__319 __pyx_mstate_global->__pyx_codeobj__319
#define __pyx_codeobj__320 __pyx_mstate_global->__pyx_codeobj__320
#define __pyx_codeobj__321 __pyx_mstate_global->__pyx_codeobj__321
#define __pyx_codeobj__322 __pyx_mstate_global->__pyx_codeobj__322
#define __pyx_codeobj__323 __pyx_mstate_global->__pyx_codeobj__323
#define __pyx_codeobj__324 __pyx_mstate_global->__pyx_codeobj__324
#define __pyx_codeobj__325 __pyx_mstate_global->__pyx_codeobj__325
#define __pyx_codeobj__326 __pyx_mstate_global->__pyx_codeobj__326
#define __pyx_codeobj__327 __pyx_mstate_global->__pyx_codeobj__327
#define __pyx_codeobj__328 __pyx_mstate_global->__pyx_codeobj__328
#define __pyx_codeobj__329 __pyx_mstate_global->__pyx_codeobj__329
#define __pyx_codeobj__330 __pyx_mstate_global->__pyx_codeobj__330
#define __pyx_codeobj__331 __pyx_mstate_global->__pyx_codeobj__331
#define __pyx_codeobj__332 __pyx_mstate_global->__pyx_codeobj__332
#define __pyx_codeobj__333 __pyx_mstate_global->__pyx_codeobj__333
#define __pyx_codeobj__334 __pyx_mstate_global->__pyx_codeobj__334
#define __pyx_codeobj__335 __pyx_mstate_global->__pyx_codeobj__335
#define __pyx_codeobj__336 __pyx_mstate_global->__pyx_codeobj__336
#define __pyx_codeobj__337 __pyx_mstate_global->__pyx_codeobj__337
#define __pyx_codeobj__338 __pyx_mstate_global->__pyx_codeobj__338
#define __pyx_codeobj__339 __pyx_mstate_global->__pyx_codeobj__339
#define __pyx_codeobj__340 __pyx_mstate_global->__pyx_codeobj__340
#define __pyx_codeobj__341 __pyx_mstate_global->__pyx_codeobj__341
#define __pyx_codeobj__342 __pyx_mstate_global->__pyx_codeobj__342
#define __pyx_codeobj__343 __pyx_mstate_global->__pyx_codeobj__343
#define __pyx_codeobj__344 __pyx_mstate_global->__pyx_codeobj__344
#define __pyx_codeobj__345 __pyx_mstate_global->__pyx_codeobj__345
#define __pyx_codeobj__346 __pyx_mstate_global->__pyx_codeobj__346
#define __pyx_codeobj__347 __pyx_mstate_global->__pyx_codeobj__347
#define __pyx_codeobj__348 __pyx_mstate_global->__pyx_codeobj__348
#define __pyx_codeobj__349 __pyx_mstate_global->__pyx_codeobj__349
#define __pyx_codeobj__350 __pyx_mstate_global->__pyx_codeobj__350
#define __pyx_codeobj__352 __pyx_mstate_global->__pyx_codeobj__352
#define __pyx_codeobj__354 __pyx_mstate_global->__pyx_codeobj__354
#define __pyx_codeobj__355 __pyx_mstate_global->__pyx_codeobj__355
#define __pyx_codeobj__356 __pyx_mstate_global->__pyx_codeobj__356
#define __pyx_codeobj__357 __pyx_mstate_global->__pyx_codeobj__357
#define __pyx_codeobj__358 __pyx_mstate_global->__pyx_codeobj__358
#define __pyx_codeobj__359 __pyx_mstate_global->__pyx_codeobj__359
#define __pyx_codeobj__360 __pyx_mstate_global->__pyx_codeobj__360
#define __pyx_codeobj__361 __pyx_mstate_global->__pyx_codeobj__361
#define __pyx_codeobj__362 __pyx_mstate_global->__pyx_codeobj__362
#define __pyx_codeobj__363 __pyx_mstate_global->__pyx_codeobj__363
#define __pyx_codeobj__364 __pyx_mstate_global->__pyx_codeobj__364
#define __pyx_codeobj__365 __pyx_mstate_global->__pyx_codeobj__365
#define __pyx_codeobj__366 __pyx_mstate_global->__pyx_codeobj__366
#define __pyx_codeobj__367 __pyx_mstate_global->__pyx_codeobj__367
#define __pyx_codeobj__368 __pyx_mstate_global->__pyx_codeobj__368
#define __pyx_codeobj__369 __pyx_mstate_global->__pyx_codeobj__369
#define __pyx_codeobj__370 __pyx_mstate_global->__pyx_codeobj__370
#define __pyx_codeobj__371 __pyx_mstate_global->__pyx_codeobj__371
#define __pyx_codeobj__372 __pyx_mstate_global->__pyx_codeobj__372
#define __pyx_codeobj__373 __pyx_mstate_global->__pyx_codeobj__373
#define __pyx_codeobj__374 __pyx_mstate_global->__pyx_codeobj__374
#define __pyx_codeobj__375 __pyx_mstate_global->__pyx_codeobj__375
#define __pyx_codeobj__376 __pyx_mstate_global->__pyx_codeobj__376
#define __pyx_codeobj__377 __pyx_mstate_global->__pyx_codeobj__377
#define __pyx_codeobj__378 __pyx_mstate_global->__pyx_codeobj__378
#define __pyx_codeobj__379 __pyx_mstate_global->__pyx_codeobj__379
#define __pyx_codeobj__380 __pyx_mstate_global->__pyx_codeobj__380
#define __pyx_codeobj__381 __pyx_mstate_global->__pyx_codeobj__381
#define __pyx_codeobj__382 __pyx_mstate_global->__pyx_codeobj__382
#define __pyx_codeobj__383 __pyx_mstate_global->__pyx_codeobj__383
#define __pyx_codeobj__384 __pyx_mstate_global->__pyx_codeobj__384
#define __pyx_codeobj__385 __pyx_mstate_global->__pyx_codeobj__385
#define __pyx_codeobj__386 __pyx_mstate_global->__pyx_codeobj__386
#define __pyx_codeobj__387 __pyx_mstate_global->__pyx_codeobj__387
#define __pyx_codeobj__388 __pyx_mstate_global->__pyx_codeobj__388
#define __pyx_codeobj__389 __pyx_mstate_global->__pyx_codeobj__389
#define __pyx_codeobj__390 __pyx_mstate_global->__pyx_codeobj__390
#define __pyx_codeobj__392 __pyx_mstate_global->__pyx_codeobj__392
#define __pyx_codeobj__394 __pyx_mstate_global->__pyx_codeobj__394
#define __pyx_codeobj__395 __pyx_mstate_global->__pyx_codeobj__395
#define __pyx_codeobj__396 __pyx_mstate_global->__pyx_codeobj__396
#define __pyx_codeobj__397 __pyx_mstate_global->__pyx_codeobj__397
#define __pyx_codeobj__398 __pyx_mstate_global->__pyx_codeobj__398
#define __pyx_codeobj__399 __pyx_mstate_global->__pyx_codeobj__399
#define __pyx_codeobj__400 __pyx_mstate_global->__pyx_codeobj__400
#define __pyx_codeobj__401 __pyx_mstate_global->__pyx_codeobj__401
#define __pyx_codeobj__402 __pyx_mstate_global->__pyx_codeobj__402
#define __pyx_codeobj__403 __pyx_mstate_global->__pyx_codeobj__403
#define __pyx_codeobj__404 __pyx_mstate_global->__pyx_codeobj__404
#define __pyx_codeobj__405 __pyx_mstate_global->__pyx_codeobj__405
#define __pyx_codeobj__406 __pyx_mstate_global->__pyx_codeobj__406
#define __pyx_codeobj__407 __pyx_mstate_global->__pyx_codeobj__407
#define __pyx_codeobj__408 __pyx_mstate_global->__pyx_codeobj__408
#define __pyx_codeobj__409 __pyx_mstate_global->__pyx_codeobj__409
#define __pyx_codeobj__410 __pyx_mstate_global->__pyx_codeobj__410
#define __pyx_codeobj__411 __pyx_mstate_global->__pyx_codeobj__411
#define __pyx_codeobj__412 __pyx_mstate_global->__pyx_codeobj__412
#define __pyx_codeobj__413 __pyx_mstate_global->__pyx_codeobj__413
#define __pyx_codeobj__414 __pyx_mstate_global->__pyx_codeobj__414
#define __pyx_codeobj__415 __pyx_mstate_global->__pyx_codeobj__415
#define __pyx_codeobj__417 __pyx_mstate_global->__pyx_codeobj__417
#define __pyx_codeobj__418 __pyx_mstate_global->__pyx_codeobj__418
#define __pyx_codeobj__419 __pyx_mstate_global->__pyx_codeobj__419
#define __pyx_codeobj__420 __pyx_mstate_global->__pyx_codeobj__420
#define __pyx_codeobj__421 __pyx_mstate_global->__pyx_codeobj__421
#define __pyx_codeobj__422 __pyx_mstate_global->__pyx_codeobj__422
#define __pyx_codeobj__423 __pyx_mstate_global->__pyx_codeobj__423
#define __pyx_codeobj__424 __pyx_mstate_global->__pyx_codeobj__424
#define __pyx_codeobj__425 __pyx_mstate_global->__pyx_codeobj__425
#define __pyx_codeobj__426 __pyx_mstate_global->__pyx_codeobj__426
#define __pyx_codeobj__427 __pyx_mstate_global->__pyx_codeobj__427
#define __pyx_codeobj__428 __pyx_mstate_global->__pyx_codeobj__428
#define __pyx_codeobj__429 __pyx_mstate_global->__pyx_codeobj__429
#define __pyx_codeobj__430 __pyx_mstate_global->__pyx_codeobj__430
#define __pyx_codeobj__431 __pyx_mstate_global->__pyx_codeobj__431
#define __pyx_codeobj__432 __pyx_mstate_global->__pyx_codeobj__432
#define __pyx_codeobj__433 __pyx_mstate_global->__pyx_codeobj__433
#define __pyx_codeobj__434 __pyx_mstate_global->__pyx_codeobj__434
#define __pyx_codeobj__435 __pyx_mstate_global->__pyx_codeobj__435
#define __pyx_codeobj__436 __pyx_mstate_global->__pyx_codeobj__436
#define __pyx_codeobj__437 __pyx_mstate_global->__pyx_codeobj__437
#define __pyx_codeobj__438 __pyx_mstate_global->__pyx_codeobj__438
#define __pyx_codeobj__439 __pyx_mstate_global->__pyx_codeobj__439
#define __pyx_codeobj__440 __pyx_mstate_global->__pyx_codeobj__440
#define __pyx_codeobj__441 __pyx_mstate_global->__pyx_codeobj__441
#define __pyx_codeobj__442 __pyx_mstate_global->__pyx_codeobj__442
#define __pyx_codeobj__443 __pyx_mstate_global->__pyx_codeobj__443
#define __pyx_codeobj__444 __pyx_mstate_global->__pyx_codeobj__444
#define __pyx_codeobj__445 __pyx_mstate_global->__pyx_codeobj__445
#define __pyx_codeobj__446 __pyx_mstate_global->__pyx_codeobj__446
#define __pyx_codeobj__447 __pyx_mstate_global->__pyx_codeobj__447
#define __pyx_codeobj__448 __pyx_mstate_global->__pyx_codeobj__448
#define __pyx_codeobj__449 __pyx_mstate_global->__pyx_codeobj__449
#define __pyx_codeobj__450 __pyx_mstate_global->__pyx_codeobj__450
#define __pyx_codeobj__451 __pyx_mstate_global->__pyx_codeobj__451
#define __pyx_codeobj__452 __pyx_mstate_global->__pyx_codeobj__452
#define __pyx_codeobj__453 __pyx_mstate_global->__pyx_codeobj__453
#define __pyx_codeobj__454 __pyx_mstate_global->__pyx_codeobj__454
#define __pyx_codeobj__455 __pyx_mstate_global->__pyx_codeobj__455
#define __pyx_codeobj__456 __pyx_mstate_global->__pyx_codeobj__456
#define __pyx_codeobj__457 __pyx_mstate_global->__pyx_codeobj__457
#define __pyx_codeobj__458 __pyx_mstate_global->__pyx_codeobj__458
#define __pyx_codeobj__459 __pyx_mstate_global->__pyx_codeobj__459
#define __pyx_codeobj__460 __pyx_mstate_global->__pyx_codeobj__460
#define __pyx_codeobj__461 __pyx_mstate_global->__pyx_codeobj__461
#define __pyx_codeobj__462 __pyx_mstate_global->__pyx_codeobj__462
#define __pyx_codeobj__463 __pyx_mstate_global->__pyx_codeobj__463
#define __pyx_codeobj__464 __pyx_mstate_global->__pyx_codeobj__464
#define __pyx_codeobj__465 __pyx_mstate_global->__pyx_codeobj__465
#define __pyx_codeobj__466 __pyx_mstate_global->__pyx_codeobj__466
#define __pyx_codeobj__467 __pyx_mstate_global->__pyx_codeobj__467
#define __pyx_codeobj__468 __pyx_mstate_global->__pyx_codeobj__468
#define __pyx_codeobj__469 __pyx_mstate_global->__pyx_codeobj__469
#define __pyx_codeobj__470 __pyx_mstate_global->__pyx_codeobj__470
#define __pyx_codeobj__471 __pyx_mstate_global->__pyx_codeobj__471
#define __pyx_codeobj__472 __pyx_mstate_global->__pyx_codeobj__472
#define __pyx_codeobj__473 __pyx_mstate_global->__pyx_codeobj__473
#define __pyx_codeobj__474 __pyx_mstate_global->__pyx_codeobj__474
#define __pyx_codeobj__475 __pyx_mstate_global->__pyx_codeobj__475
#define __pyx_codeobj__476 __pyx_mstate_global->__pyx_codeobj__476
#define __pyx_codeobj__477 __pyx_mstate_global->__pyx_codeobj__477
#define __pyx_codeobj__478 __pyx_mstate_global->__pyx_codeobj__478
#define __pyx_codeobj__479 __pyx_mstate_global->__pyx_codeobj__479
#define __pyx_codeobj__480 __pyx_mstate_global->__pyx_codeobj__480
#define __pyx_codeobj__481 __pyx_mstate_global->__pyx_codeobj__481
#define __pyx_codeobj__482 __pyx_mstate_global->__pyx_codeobj__482
#define __pyx_codeobj__483 __pyx_mstate_global->__pyx_codeobj__483
#define __pyx_codeobj__484 __pyx_mstate_global->__pyx_codeobj__484
#define __pyx_codeobj__485 __pyx_mstate_global->__pyx_codeobj__485
#define __pyx_codeobj__487 __pyx_mstate_global->__pyx_codeobj__487
/* #### Code section: module_code ### */

/* "unicorn_binance_rest_api/manager.py":204
 *     MINING_TO_FIAT = "MINING_C2C"
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  api_key=None,
 *                  api_secret=None,
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_api_key = 0;
  PyObject *__pyx_v_api_secret = 0;
  PyObject *__pyx_v_requests_params = 0;
  PyObject *__pyx_v_tld = 0;
  PyObject *__pyx_v_warn_on_update = 0;
  PyObject *__pyx_v_exchange = 0;
  PyObject *__pyx_v_disable_colorama = 0;
  PyObject *__pyx_v_debug = 0;
  PyObject *__pyx_v_socks5_proxy_server = 0;
  PyObject *__pyx_v_socks5_proxy_user = 0;
  PyObject *__pyx_v_socks5_proxy_pass = 0;
  PyObject *__pyx_v_socks5_proxy_ssl_verification = 0;
  PyObject *__pyx_v_lucit_api_secret = 0;
  PyObject *__pyx_v_lucit_license_ini = 0;
  PyObject *__pyx_v_lucit_license_profile = 0;
  PyObject *__pyx_v_lucit_license_token = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[17] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_api_key,&__pyx_n_s_api_secret,&__pyx_n_s_requests_params,&__pyx_n_s_tld,&__pyx_n_s_warn_on_update,&__pyx_n_s_exchange,&__pyx_n_s_disable_colorama,&__pyx_n_s_debug,&__pyx_n_s_socks5_proxy_server,&__pyx_n_s_socks5_proxy_user,&__pyx_n_s_socks5_proxy_pass,&__pyx_n_s_socks5_proxy_ssl_verification,&__pyx_n_s_lucit_api_secret,&__pyx_n_s_lucit_license_ini,&__pyx_n_s_lucit_license_profile,&__pyx_n_s_lucit_license_token,0};

    /* "unicorn_binance_rest_api/manager.py":205
 * 
 *     def __init__(self,
 *                  api_key=None,             # <<<<<<<<<<<<<<
 *                  api_secret=None,
 *                  requests_params=None,
 */
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "unicorn_binance_rest_api/manager.py":206
 *     def __init__(self,
 *                  api_key=None,
 *                  api_secret=None,             # <<<<<<<<<<<<<<
 *                  requests_params=None,
 *                  tld=False,
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "unicorn_binance_rest_api/manager.py":207
 *                  api_key=None,
 *                  api_secret=None,
 *                  requests_params=None,             # <<<<<<<<<<<<<<
 *                  tld=False,
 *                  warn_on_update=True,
 */
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "unicorn_binance_rest_api/manager.py":208
 *                  api_secret=None,
 *                  requests_params=None,
 *                  tld=False,             # <<<<<<<<<<<<<<
 *                  warn_on_update=True,
 *                  exchange=False,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));

    /* "unicorn_binance_rest_api/manager.py":209
 *                  requests_params=None,
 *                  tld=False,
 *                  warn_on_update=True,             # <<<<<<<<<<<<<<
 *                  exchange=False,
 *                  disable_colorama=False,
 */
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));

    /* "unicorn_binance_rest_api/manager.py":210
 *                  tld=False,
 *                  warn_on_update=True,
 *                  exchange=False,             # <<<<<<<<<<<<<<
 *                  disable_colorama=False,
 *                  debug=False,
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));

    /* "unicorn_binance_rest_api/manager.py":211
 *                  warn_on_update=True,
 *                  exchange=False,
 *                  disable_colorama=False,             # <<<<<<<<<<<<<<
 *                  debug=False,
 *                  socks5_proxy_server: Optional[str] = None,
 */
    values[7] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));

    /* "unicorn_binance_rest_api/manager.py":212
 *                  exchange=False,
 *                  disable_colorama=False,
 *                  debug=False,             # <<<<<<<<<<<<<<
 *                  socks5_proxy_server: Optional[str] = None,
 *                  socks5_proxy_user: Optional[str] = None,
 */
    values[8] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));

    /* "unicorn_binance_rest_api/manager.py":213
 *                  disable_colorama=False,
 *                  debug=False,
 *                  socks5_proxy_server: Optional[str] = None,             # <<<<<<<<<<<<<<
 *                  socks5_proxy_user: Optional[str] = None,
 *                  socks5_proxy_pass: Optional[str] = None,
 */
    values[9] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));

    /* "unicorn_binance_rest_api/manager.py":214
 *                  debug=False,
 *                  socks5_proxy_server: Optional[str] = None,
 *                  socks5_proxy_user: Optional[str] = None,             # <<<<<<<<<<<<<<
 *                  socks5_proxy_pass: Optional[str] = None,
 *                  socks5_proxy_ssl_verification: Optional[bool] = True,
 */
    values[10] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));

    /* "unicorn_binance_rest_api/manager.py":215
 *                  socks5_proxy_server: Optional[str] = None,
 *                  socks5_proxy_user: Optional[str] = None,
 *                  socks5_proxy_pass: Optional[str] = None,             # <<<<<<<<<<<<<<
 *                  socks5_proxy_ssl_verification: Optional[bool] = True,
 *                  lucit_api_secret: str = None,
 */
    values[11] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));

    /* "unicorn_binance_rest_api/manager.py":216
 *                  socks5_proxy_user: Optional[str] = None,
 *                  socks5_proxy_pass: Optional[str] = None,
 *                  socks5_proxy_ssl_verification: Optional[bool] = True,             # <<<<<<<<<<<<<<
 *                  lucit_api_secret: str = None,
 *                  lucit_license_ini: str = None,
 */
    values[12] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));

    /* "unicorn_binance_rest_api/manager.py":217
 *                  socks5_proxy_pass: Optional[str] = None,
 *                  socks5_proxy_ssl_verification: Optional[bool] = True,
 *                  lucit_api_secret: str = None,             # <<<<<<<<<<<<<<
 *                  lucit_license_ini: str = None,
 *                  lucit_license_profile: str = None,
 */
    values[13] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));

    /* "unicorn_binance_rest_api/manager.py":218
 *                  socks5_proxy_ssl_verification: Optional[bool] = True,
 *                  lucit_api_secret: str = None,
 *                  lucit_license_ini: str = None,             # <<<<<<<<<<<<<<
 *                  lucit_license_profile: str = None,
 *                  lucit_license_token: str = None):
 */
    values[14] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));

    /* "unicorn_binance_rest_api/manager.py":219
 *                  lucit_api_secret: str = None,
 *                  lucit_license_ini: str = None,
 *                  lucit_license_profile: str = None,             # <<<<<<<<<<<<<<
 *                  lucit_license_token: str = None):
 * 
 */
    values[15] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));

    /* "unicorn_binance_rest_api/manager.py":220
 *                  lucit_license_ini: str = None,
 *                  lucit_license_profile: str = None,
 *                  lucit_license_token: str = None):             # <<<<<<<<<<<<<<
 * 
 *         self.name = "unicorn-binance-rest-api"
 */
    values[16] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case 17: values[16] = __Pyx_Arg_FASTCALL(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = __Pyx_Arg_FASTCALL(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = __Pyx_Arg_FASTCALL(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = __Pyx_Arg_FASTCALL(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = __Pyx_Arg_FASTCALL(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_api_key);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_api_secret);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_requests_params);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tld);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_warn_on_update);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exchange);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_disable_colorama);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_debug);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_socks5_proxy_server);
          if (value) { values[9] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_socks5_proxy_user);
          if (value) { values[10] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_socks5_proxy_pass);
          if (value) { values[11] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_socks5_proxy_ssl_verification);
          if (value) { values[12] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lucit_api_secret);
          if (value) { values[13] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lucit_license_ini);
          if (value) { values[14] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lucit_license_profile);
          if (value) { values[15] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lucit_license_token);
          if (value) { values[16] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 204, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 204, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case 17: values[16] = __Pyx_Arg_FASTCALL(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = __Pyx_Arg_FASTCALL(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = __Pyx_Arg_FASTCALL(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = __Pyx_Arg_FASTCALL(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = __Pyx_Arg_FASTCALL(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_api_key = values[1];
    __pyx_v_api_secret = values[2];
    __pyx_v_requests_params = values[3];
    __pyx_v_tld = values[4];
    __pyx_v_warn_on_update = values[5];
    __pyx_v_exchange = values[6];
    __pyx_v_disable_colorama = values[7];
    __pyx_v_debug = values[8];
    __pyx_v_socks5_proxy_server = ((PyObject*)values[9]);
    __pyx_v_socks5_proxy_user = ((PyObject*)values[10]);
    __pyx_v_socks5_proxy_pass = ((PyObject*)values[11]);
    __pyx_v_socks5_proxy_ssl_verification = values[12];
    __pyx_v_lucit_api_secret = ((PyObject*)values[13]);
    __pyx_v_lucit_license_ini = ((PyObject*)values[14]);
    __pyx_v_lucit_license_profile = ((PyObject*)values[15]);
    __pyx_v_lucit_license_token = ((PyObject*)values[16]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 17, __pyx_nargs); __PYX_ERR(0, 204, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_socks5_proxy_server), (&PyString_Type), 1, "socks5_proxy_server", 1))) __PYX_ERR(0, 213, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_socks5_proxy_user), (&PyString_Type), 1, "socks5_proxy_user", 1))) __PYX_ERR(0, 214, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_socks5_proxy_pass), (&PyString_Type), 1, "socks5_proxy_pass", 1))) __PYX_ERR(0, 215, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lucit_api_secret), (&PyString_Type), 1, "lucit_api_secret", 1))) __PYX_ERR(0, 217, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lucit_license_ini), (&PyString_Type), 1, "lucit_license_ini", 1))) __PYX_ERR(0, 218, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lucit_license_profile), (&PyString_Type), 1, "lucit_license_profile", 1))) __PYX_ERR(0, 219, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lucit_license_token), (&PyString_Type), 1, "lucit_license_token", 1))) __PYX_ERR(0, 220, __pyx_L1_error)
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager___init__(__pyx_self, __pyx_v_self, __pyx_v_api_key, __pyx_v_api_secret, __pyx_v_requests_params, __pyx_v_tld, __pyx_v_warn_on_update, __pyx_v_exchange, __pyx_v_disable_colorama, __pyx_v_debug, __pyx_v_socks5_proxy_server, __pyx_v_socks5_proxy_user, __pyx_v_socks5_proxy_pass, __pyx_v_socks5_proxy_ssl_verification, __pyx_v_lucit_api_secret, __pyx_v_lucit_license_ini, __pyx_v_lucit_license_profile, __pyx_v_lucit_license_token);

  /* "unicorn_binance_rest_api/manager.py":204
 *     MINING_TO_FIAT = "MINING_C2C"
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  api_key=None,
 *                  api_secret=None,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_api_key, PyObject *__pyx_v_api_secret, PyObject *__pyx_v_requests_params, PyObject *__pyx_v_tld, PyObject *__pyx_v_warn_on_update, PyObject *__pyx_v_exchange, PyObject *__pyx_v_disable_colorama, PyObject *__pyx_v_debug, PyObject *__pyx_v_socks5_proxy_server, PyObject *__pyx_v_socks5_proxy_user, PyObject *__pyx_v_socks5_proxy_pass, PyObject *__pyx_v_socks5_proxy_ssl_verification, PyObject *__pyx_v_lucit_api_secret, PyObject *__pyx_v_lucit_license_ini, PyObject *__pyx_v_lucit_license_profile, PyObject *__pyx_v_lucit_license_token) {
  PyObject *__pyx_v_socks_proxy_uri = NULL;
  PyObject *__pyx_v_error_msg = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_update_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "unicorn_binance_rest_api/manager.py":222
 *                  lucit_license_token: str = None):
 * 
 *         self.name = "unicorn-binance-rest-api"             # <<<<<<<<<<<<<<
 *         self.version = "2.0.0"
 *         logger.info(f"New instance of {self.get_user_agent()}-{'compiled' if cython.compiled else 'source'} on "
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_kp_s_unicorn_binance_rest_api) < 0) __PYX_ERR(0, 222, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":223
 * 
 *         self.name = "unicorn-binance-rest-api"
 *         self.version = "2.0.0"             # <<<<<<<<<<<<<<
 *         logger.info(f"New instance of {self.get_user_agent()}-{'compiled' if cython.compiled else 'source'} on "
 *                     f"{str(platform.system())} {str(platform.release())} for exchange {exchange} started ...")
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_version, __pyx_kp_s_2_0_0) < 0) __PYX_ERR(0, 223, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":224
 *         self.name = "unicorn-binance-rest-api"
 *         self.version = "2.0.0"
 *         logger.info(f"New instance of {self.get_user_agent()}-{'compiled' if cython.compiled else 'source'} on "             # <<<<<<<<<<<<<<
 *                     f"{str(platform.system())} {str(platform.release())} for exchange {exchange} started ...")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = 0;
  __pyx_t_5 = 127;
  __Pyx_INCREF(__pyx_kp_u_New_instance_of);
  __pyx_t_4 += 16;
  __Pyx_GIVEREF(__pyx_kp_u_New_instance_of);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_New_instance_of);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_user_agent); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_kp_u_compiled_on);
  __pyx_t_4 += 13;
  __Pyx_GIVEREF(__pyx_kp_u_compiled_on);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_compiled_on);

  /* "unicorn_binance_rest_api/manager.py":225
 *         self.version = "2.0.0"
 *         logger.info(f"New instance of {self.get_user_agent()}-{'compiled' if cython.compiled else 'source'} on "
 *                     f"{str(platform.system())} {str(platform.release())} for exchange {exchange} started ...")             # <<<<<<<<<<<<<<
 * 
 *         self.lucit_api_secret = lucit_api_secret
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_platform); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_system); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_t_8 = __Pyx_PyObject_Str(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_8, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_kp_u_);
  __pyx_t_4 += 1;
  __Pyx_GIVEREF(__pyx_kp_u_);
  PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_kp_u_);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_platform); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_release); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_Str(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_kp_u_for_exchange);
  __pyx_t_4 += 14;
  __Pyx_GIVEREF(__pyx_kp_u_for_exchange);
  PyTuple_SET_ITEM(__pyx_t_2, 6, __pyx_kp_u_for_exchange);
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_v_exchange, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_2, 7, __pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_kp_u_started);
  __pyx_t_4 += 12;
  __Pyx_GIVEREF(__pyx_kp_u_started);
  PyTuple_SET_ITEM(__pyx_t_2, 8, __pyx_kp_u_started);

  /* "unicorn_binance_rest_api/manager.py":224
 *         self.name = "unicorn-binance-rest-api"
 *         self.version = "2.0.0"
 *         logger.info(f"New instance of {self.get_user_agent()}-{'compiled' if cython.compiled else 'source'} on "             # <<<<<<<<<<<<<<
 *                     f"{str(platform.system())} {str(platform.release())} for exchange {exchange} started ...")
 * 
 */
  __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_2, 9, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":227
 *                     f"{str(platform.system())} {str(platform.release())} for exchange {exchange} started ...")
 * 
 *         self.lucit_api_secret = lucit_api_secret             # <<<<<<<<<<<<<<
 *         self.lucit_license_token = lucit_license_token
 *         self.lucit_api_secret = lucit_api_secret
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_lucit_api_secret, __pyx_v_lucit_api_secret) < 0) __PYX_ERR(0, 227, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":228
 * 
 *         self.lucit_api_secret = lucit_api_secret
 *         self.lucit_license_token = lucit_license_token             # <<<<<<<<<<<<<<
 *         self.lucit_api_secret = lucit_api_secret
 *         self.lucit_license_ini = lucit_license_ini
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_lucit_license_token, __pyx_v_lucit_license_token) < 0) __PYX_ERR(0, 228, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":229
 *         self.lucit_api_secret = lucit_api_secret
 *         self.lucit_license_token = lucit_license_token
 *         self.lucit_api_secret = lucit_api_secret             # <<<<<<<<<<<<<<
 *         self.lucit_license_ini = lucit_license_ini
 *         self.lucit_license_profile = lucit_license_profile
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_lucit_api_secret, __pyx_v_lucit_api_secret) < 0) __PYX_ERR(0, 229, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":230
 *         self.lucit_license_token = lucit_license_token
 *         self.lucit_api_secret = lucit_api_secret
 *         self.lucit_license_ini = lucit_license_ini             # <<<<<<<<<<<<<<
 *         self.lucit_license_profile = lucit_license_profile
 *         self.lucit_license_token = lucit_license_token
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_lucit_license_ini, __pyx_v_lucit_license_ini) < 0) __PYX_ERR(0, 230, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":231
 *         self.lucit_api_secret = lucit_api_secret
 *         self.lucit_license_ini = lucit_license_ini
 *         self.lucit_license_profile = lucit_license_profile             # <<<<<<<<<<<<<<
 *         self.lucit_license_token = lucit_license_token
 *         self.llm = LucitLicensingManager(api_secret=self.lucit_api_secret,
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_lucit_license_profile, __pyx_v_lucit_license_profile) < 0) __PYX_ERR(0, 231, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":232
 *         self.lucit_license_ini = lucit_license_ini
 *         self.lucit_license_profile = lucit_license_profile
 *         self.lucit_license_token = lucit_license_token             # <<<<<<<<<<<<<<
 *         self.llm = LucitLicensingManager(api_secret=self.lucit_api_secret,
 *                                          license_ini=self.lucit_license_ini,
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_lucit_license_token, __pyx_v_lucit_license_token) < 0) __PYX_ERR(0, 232, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":233
 *         self.lucit_license_profile = lucit_license_profile
 *         self.lucit_license_token = lucit_license_token
 *         self.llm = LucitLicensingManager(api_secret=self.lucit_api_secret,             # <<<<<<<<<<<<<<
 *                                          license_ini=self.lucit_license_ini,
 *                                          license_profile=self.lucit_license_profile,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_LucitLicensingManager); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_lucit_api_secret); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_api_secret, __pyx_t_7) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "unicorn_binance_rest_api/manager.py":234
 *         self.lucit_license_token = lucit_license_token
 *         self.llm = LucitLicensingManager(api_secret=self.lucit_api_secret,
 *                                          license_ini=self.lucit_license_ini,             # <<<<<<<<<<<<<<
 *                                          license_profile=self.lucit_license_profile,
 *                                          license_token=self.lucit_license_token,
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_lucit_license_ini); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_license_ini, __pyx_t_7) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "unicorn_binance_rest_api/manager.py":235
 *         self.llm = LucitLicensingManager(api_secret=self.lucit_api_secret,
 *                                          license_ini=self.lucit_license_ini,
 *                                          license_profile=self.lucit_license_profile,             # <<<<<<<<<<<<<<
 *                                          license_token=self.lucit_license_token,
 *                                          parent_shutdown_function=self.stop_manager,
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_lucit_license_profile); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_license_profile, __pyx_t_7) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "unicorn_binance_rest_api/manager.py":236
 *                                          license_ini=self.lucit_license_ini,
 *                                          license_profile=self.lucit_license_profile,
 *                                          license_token=self.lucit_license_token,             # <<<<<<<<<<<<<<
 *                                          parent_shutdown_function=self.stop_manager,
 *                                          program_used="unicorn-binance-websocket-api",
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_lucit_license_token); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_license_token, __pyx_t_7) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "unicorn_binance_rest_api/manager.py":237
 *                                          license_profile=self.lucit_license_profile,
 *                                          license_token=self.lucit_license_token,
 *                                          parent_shutdown_function=self.stop_manager,             # <<<<<<<<<<<<<<
 *                                          program_used="unicorn-binance-websocket-api",
 *                                          needed_license_type="UNICORN-BINANCE-SUITE", start=True)
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stop_manager); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_parent_shutdown_function, __pyx_t_7) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_program_used, __pyx_kp_s_unicorn_binance_websocket_api) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_needed_license_type, __pyx_kp_s_UNICORN_BINANCE_SUITE) < 0) __PYX_ERR(0, 233, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":239
 *                                          parent_shutdown_function=self.stop_manager,
 *                                          program_used="unicorn-binance-websocket-api",
 *                                          needed_license_type="UNICORN-BINANCE-SUITE", start=True)             # <<<<<<<<<<<<<<
 * 
 *         if disable_colorama is not True:
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_start, Py_True) < 0) __PYX_ERR(0, 233, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":233
 *         self.lucit_license_profile = lucit_license_profile
 *         self.lucit_license_token = lucit_license_token
 *         self.llm = LucitLicensingManager(api_secret=self.lucit_api_secret,             # <<<<<<<<<<<<<<
 *                                          license_ini=self.lucit_license_ini,
 *                                          license_profile=self.lucit_license_profile,
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_llm, __pyx_t_7) < 0) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "unicorn_binance_rest_api/manager.py":241
 *                                          needed_license_type="UNICORN-BINANCE-SUITE", start=True)
 * 
 *         if disable_colorama is not True:             # <<<<<<<<<<<<<<
 *             logger.info(f"Initiating `colorama_{colorama.__version__}`")
 *             colorama.init()
 */
  __pyx_t_10 = (__pyx_v_disable_colorama != Py_True);
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":242
 * 
 *         if disable_colorama is not True:
 *             logger.info(f"Initiating `colorama_{colorama.__version__}`")             # <<<<<<<<<<<<<<
 *             colorama.init()
 *         self.exchange = exchange
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_logger); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_Initiating_colorama);
    __pyx_t_4 += 21;
    __Pyx_GIVEREF(__pyx_kp_u_Initiating_colorama);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Initiating_colorama);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_colorama); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_version_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_t_4 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__2);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__2);
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":243
 *         if disable_colorama is not True:
 *             logger.info(f"Initiating `colorama_{colorama.__version__}`")
 *             colorama.init()             # <<<<<<<<<<<<<<
 *         self.exchange = exchange
 *         self.debug = debug
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_colorama); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":241
 *                                          needed_license_type="UNICORN-BINANCE-SUITE", start=True)
 * 
 *         if disable_colorama is not True:             # <<<<<<<<<<<<<<
 *             logger.info(f"Initiating `colorama_{colorama.__version__}`")
 *             colorama.init()
 */
  }

  /* "unicorn_binance_rest_api/manager.py":244
 *             logger.info(f"Initiating `colorama_{colorama.__version__}`")
 *             colorama.init()
 *         self.exchange = exchange             # <<<<<<<<<<<<<<
 *         self.debug = debug
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exchange, __pyx_v_exchange) < 0) __PYX_ERR(0, 244, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":245
 *             colorama.init()
 *         self.exchange = exchange
 *         self.debug = debug             # <<<<<<<<<<<<<<
 * 
 *         if socks5_proxy_server is None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, __pyx_v_debug) < 0) __PYX_ERR(0, 245, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":247
 *         self.debug = debug
 * 
 *         if socks5_proxy_server is None:             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_address: Optional[str] = None
 *             self.socks5_proxy_user: Optional[str] = None
 */
  __pyx_t_10 = (__pyx_v_socks5_proxy_server == ((PyObject*)Py_None));
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":248
 * 
 *         if socks5_proxy_server is None:
 *             self.socks5_proxy_address: Optional[str] = None             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_user: Optional[str] = None
 *             self.socks5_proxy_pass: Optional[str] = None
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_address, Py_None) < 0) __PYX_ERR(0, 248, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":249
 *         if socks5_proxy_server is None:
 *             self.socks5_proxy_address: Optional[str] = None
 *             self.socks5_proxy_user: Optional[str] = None             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_pass: Optional[str] = None
 *             self.socks5_proxy_port: Optional[str] = None
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_user, Py_None) < 0) __PYX_ERR(0, 249, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":250
 *             self.socks5_proxy_address: Optional[str] = None
 *             self.socks5_proxy_user: Optional[str] = None
 *             self.socks5_proxy_pass: Optional[str] = None             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_port: Optional[str] = None
 *             self.socks5_proxy_ssl_verification: Optional[bool] = True
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_pass, Py_None) < 0) __PYX_ERR(0, 250, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":251
 *             self.socks5_proxy_user: Optional[str] = None
 *             self.socks5_proxy_pass: Optional[str] = None
 *             self.socks5_proxy_port: Optional[str] = None             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_ssl_verification: Optional[bool] = True
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_port, Py_None) < 0) __PYX_ERR(0, 251, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":252
 *             self.socks5_proxy_pass: Optional[str] = None
 *             self.socks5_proxy_port: Optional[str] = None
 *             self.socks5_proxy_ssl_verification: Optional[bool] = True             # <<<<<<<<<<<<<<
 *         else:
 *             # Prepare Socks Proxy usage
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_ssl_verification, Py_True) < 0) __PYX_ERR(0, 252, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":247
 *         self.debug = debug
 * 
 *         if socks5_proxy_server is None:             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_address: Optional[str] = None
 *             self.socks5_proxy_user: Optional[str] = None
 */
    goto __pyx_L4;
  }

  /* "unicorn_binance_rest_api/manager.py":255
 *         else:
 *             # Prepare Socks Proxy usage
 *             self.socks5_proxy_ssl_verification = socks5_proxy_ssl_verification             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_user = socks5_proxy_user
 *             self.socks5_proxy_pass = socks5_proxy_pass
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_ssl_verification, __pyx_v_socks5_proxy_ssl_verification) < 0) __PYX_ERR(0, 255, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":256
 *             # Prepare Socks Proxy usage
 *             self.socks5_proxy_ssl_verification = socks5_proxy_ssl_verification
 *             self.socks5_proxy_user = socks5_proxy_user             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_pass = socks5_proxy_pass
 *             self.socks5_proxy_address, self.socks5_proxy_port = socks5_proxy_server.split(":")
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_user, __pyx_v_socks5_proxy_user) < 0) __PYX_ERR(0, 256, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":257
 *             self.socks5_proxy_ssl_verification = socks5_proxy_ssl_verification
 *             self.socks5_proxy_user = socks5_proxy_user
 *             self.socks5_proxy_pass = socks5_proxy_pass             # <<<<<<<<<<<<<<
 *             self.socks5_proxy_address, self.socks5_proxy_port = socks5_proxy_server.split(":")
 *             socks_proxy_uri = "socks5://"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_pass, __pyx_v_socks5_proxy_pass) < 0) __PYX_ERR(0, 257, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":258
 *             self.socks5_proxy_user = socks5_proxy_user
 *             self.socks5_proxy_pass = socks5_proxy_pass
 *             self.socks5_proxy_address, self.socks5_proxy_port = socks5_proxy_server.split(":")             # <<<<<<<<<<<<<<
 *             socks_proxy_uri = "socks5://"
 *             if self.socks5_proxy_user is not None:
 */
    __pyx_t_7 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyString_Type_split, __pyx_v_socks5_proxy_server, __pyx_kp_s__3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
      PyObject* sequence = __pyx_t_7;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 258, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      #else
      __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 258, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 258, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_3 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 258, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
      index = 0; __pyx_t_2 = __pyx_t_11(__pyx_t_3); if (unlikely(!__pyx_t_2)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      index = 1; __pyx_t_1 = __pyx_t_11(__pyx_t_3); if (unlikely(!__pyx_t_1)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_3), 2) < 0) __PYX_ERR(0, 258, __pyx_L1_error)
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 258, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_address, __pyx_t_2) < 0) __PYX_ERR(0, 258, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_port, __pyx_t_1) < 0) __PYX_ERR(0, 258, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "unicorn_binance_rest_api/manager.py":259
 *             self.socks5_proxy_pass = socks5_proxy_pass
 *             self.socks5_proxy_address, self.socks5_proxy_port = socks5_proxy_server.split(":")
 *             socks_proxy_uri = "socks5://"             # <<<<<<<<<<<<<<
 *             if self.socks5_proxy_user is not None:
 *                 socks_proxy_uri += self.socks5_proxy_user
 */
    __Pyx_INCREF(__pyx_kp_s_socks5);
    __pyx_v_socks_proxy_uri = __pyx_kp_s_socks5;

    /* "unicorn_binance_rest_api/manager.py":260
 *             self.socks5_proxy_address, self.socks5_proxy_port = socks5_proxy_server.split(":")
 *             socks_proxy_uri = "socks5://"
 *             if self.socks5_proxy_user is not None:             # <<<<<<<<<<<<<<
 *                 socks_proxy_uri += self.socks5_proxy_user
 *                 if self.socks5_proxy_pass is not None:
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_user); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = (__pyx_t_7 != Py_None);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_10) {

      /* "unicorn_binance_rest_api/manager.py":261
 *             socks_proxy_uri = "socks5://"
 *             if self.socks5_proxy_user is not None:
 *                 socks_proxy_uri += self.socks5_proxy_user             # <<<<<<<<<<<<<<
 *                 if self.socks5_proxy_pass is not None:
 *                     socks_proxy_uri += f":{self.socks5_proxy_pass}"
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_user); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 261, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_socks_proxy_uri, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 261, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_socks_proxy_uri, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "unicorn_binance_rest_api/manager.py":262
 *             if self.socks5_proxy_user is not None:
 *                 socks_proxy_uri += self.socks5_proxy_user
 *                 if self.socks5_proxy_pass is not None:             # <<<<<<<<<<<<<<
 *                     socks_proxy_uri += f":{self.socks5_proxy_pass}"
 *                 socks_proxy_uri += "@"
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_pass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = (__pyx_t_1 != Py_None);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_10) {

        /* "unicorn_binance_rest_api/manager.py":263
 *                 socks_proxy_uri += self.socks5_proxy_user
 *                 if self.socks5_proxy_pass is not None:
 *                     socks_proxy_uri += f":{self.socks5_proxy_pass}"             # <<<<<<<<<<<<<<
 *                 socks_proxy_uri += "@"
 *             socks_proxy_uri += f"{self.socks5_proxy_address}:{self.socks5_proxy_port}"
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_pass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 263, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_kp_u__3, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_socks_proxy_uri, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 263, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_socks_proxy_uri, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "unicorn_binance_rest_api/manager.py":262
 *             if self.socks5_proxy_user is not None:
 *                 socks_proxy_uri += self.socks5_proxy_user
 *                 if self.socks5_proxy_pass is not None:             # <<<<<<<<<<<<<<
 *                     socks_proxy_uri += f":{self.socks5_proxy_pass}"
 *                 socks_proxy_uri += "@"
 */
      }

      /* "unicorn_binance_rest_api/manager.py":264
 *                 if self.socks5_proxy_pass is not None:
 *                     socks_proxy_uri += f":{self.socks5_proxy_pass}"
 *                 socks_proxy_uri += "@"             # <<<<<<<<<<<<<<
 *             socks_proxy_uri += f"{self.socks5_proxy_address}:{self.socks5_proxy_port}"
 *             logger.info(f"Created SOCKS5 proxy URI: {socks_proxy_uri}")
 */
      __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_socks_proxy_uri, __pyx_kp_s__4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 264, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_socks_proxy_uri, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "unicorn_binance_rest_api/manager.py":260
 *             self.socks5_proxy_address, self.socks5_proxy_port = socks5_proxy_server.split(":")
 *             socks_proxy_uri = "socks5://"
 *             if self.socks5_proxy_user is not None:             # <<<<<<<<<<<<<<
 *                 socks_proxy_uri += self.socks5_proxy_user
 *                 if self.socks5_proxy_pass is not None:
 */
    }

    /* "unicorn_binance_rest_api/manager.py":265
 *                     socks_proxy_uri += f":{self.socks5_proxy_pass}"
 *                 socks_proxy_uri += "@"
 *             socks_proxy_uri += f"{self.socks5_proxy_address}:{self.socks5_proxy_port}"             # <<<<<<<<<<<<<<
 *             logger.info(f"Created SOCKS5 proxy URI: {socks_proxy_uri}")
 *             self.request_socks5_proxies = {
 */
    __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_address); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_kp_u__3);
    __pyx_t_4 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__3);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_kp_u__3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_port); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_7, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_socks_proxy_uri, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_socks_proxy_uri, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":266
 *                 socks_proxy_uri += "@"
 *             socks_proxy_uri += f"{self.socks5_proxy_address}:{self.socks5_proxy_port}"
 *             logger.info(f"Created SOCKS5 proxy URI: {socks_proxy_uri}")             # <<<<<<<<<<<<<<
 *             self.request_socks5_proxies = {
 *                 'http': socks_proxy_uri,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_logger); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_v_socks_proxy_uri, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Created_SOCKS5_proxy_URI, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_3};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":268
 *             logger.info(f"Created SOCKS5 proxy URI: {socks_proxy_uri}")
 *             self.request_socks5_proxies = {
 *                 'http': socks_proxy_uri,             # <<<<<<<<<<<<<<
 *                 'https': socks_proxy_uri
 *             }
 */
    __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_http, __pyx_v_socks_proxy_uri) < 0) __PYX_ERR(0, 268, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":269
 *             self.request_socks5_proxies = {
 *                 'http': socks_proxy_uri,
 *                 'https': socks_proxy_uri             # <<<<<<<<<<<<<<
 *             }
 * 
 */
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_https, __pyx_v_socks_proxy_uri) < 0) __PYX_ERR(0, 268, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":267
 *             socks_proxy_uri += f"{self.socks5_proxy_address}:{self.socks5_proxy_port}"
 *             logger.info(f"Created SOCKS5 proxy URI: {socks_proxy_uri}")
 *             self.request_socks5_proxies = {             # <<<<<<<<<<<<<<
 *                 'http': socks_proxy_uri,
 *                 'https': socks_proxy_uri
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_request_socks5_proxies, __pyx_t_7) < 0) __PYX_ERR(0, 267, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L4:;

  /* "unicorn_binance_rest_api/manager.py":272
 *             }
 * 
 *         if tld is not False:             # <<<<<<<<<<<<<<
 *             # Todo: Remove Block with tld!
 *             logger.warning("The parameter BinanceRestApiManager(tld=`com`) is obsolete, use parameter `exchange` "
 */
  __pyx_t_10 = (__pyx_v_tld != Py_False);
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":274
 *         if tld is not False:
 *             # Todo: Remove Block with tld!
 *             logger.warning("The parameter BinanceRestApiManager(tld=`com`) is obsolete, use parameter `exchange` "             # <<<<<<<<<<<<<<
 *                            "instead! Attention: parameter `exchange` overrules `tld`!! ")
 *             self.API_URL = self.API_URL.format(tld)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warning); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_s_The_parameter_BinanceRestApiMana};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":276
 *             logger.warning("The parameter BinanceRestApiManager(tld=`com`) is obsolete, use parameter `exchange` "
 *                            "instead! Attention: parameter `exchange` overrules `tld`!! ")
 *             self.API_URL = self.API_URL.format(tld)             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = self.MARGIN_API_URL.format(tld)
 *             self.WEBSITE_URL = self.WEBSITE_URL.format(tld)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_API_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_tld};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_t_7) < 0) __PYX_ERR(0, 276, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":277
 *                            "instead! Attention: parameter `exchange` overrules `tld`!! ")
 *             self.API_URL = self.API_URL.format(tld)
 *             self.MARGIN_API_URL = self.MARGIN_API_URL.format(tld)             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = self.WEBSITE_URL.format(tld)
 *             self.FUTURES_URL = self.FUTURES_URL.format(tld)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_tld};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_t_7) < 0) __PYX_ERR(0, 277, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":278
 *             self.API_URL = self.API_URL.format(tld)
 *             self.MARGIN_API_URL = self.MARGIN_API_URL.format(tld)
 *             self.WEBSITE_URL = self.WEBSITE_URL.format(tld)             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = self.FUTURES_URL.format(tld)
 *             self.FUTURES_DATA_URL = self.FUTURES_DATA_URL.format(tld)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_tld};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_t_7) < 0) __PYX_ERR(0, 278, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":279
 *             self.MARGIN_API_URL = self.MARGIN_API_URL.format(tld)
 *             self.WEBSITE_URL = self.WEBSITE_URL.format(tld)
 *             self.FUTURES_URL = self.FUTURES_URL.format(tld)             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = self.FUTURES_DATA_URL.format(tld)
 *             self.FUTURES_COIN_URL = self.FUTURES_COIN_URL.format(tld)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_tld};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_t_7) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":280
 *             self.WEBSITE_URL = self.WEBSITE_URL.format(tld)
 *             self.FUTURES_URL = self.FUTURES_URL.format(tld)
 *             self.FUTURES_DATA_URL = self.FUTURES_DATA_URL.format(tld)             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = self.FUTURES_COIN_URL.format(tld)
 *             self.FUTURES_COIN_DATA_URL = self.FUTURES_COIN_DATA_URL.format(tld)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_tld};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 280, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_t_7) < 0) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":281
 *             self.FUTURES_URL = self.FUTURES_URL.format(tld)
 *             self.FUTURES_DATA_URL = self.FUTURES_DATA_URL.format(tld)
 *             self.FUTURES_COIN_URL = self.FUTURES_COIN_URL.format(tld)             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = self.FUTURES_COIN_DATA_URL.format(tld)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_tld};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_t_7) < 0) __PYX_ERR(0, 281, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":282
 *             self.FUTURES_DATA_URL = self.FUTURES_DATA_URL.format(tld)
 *             self.FUTURES_COIN_URL = self.FUTURES_COIN_URL.format(tld)
 *             self.FUTURES_COIN_DATA_URL = self.FUTURES_COIN_DATA_URL.format(tld)             # <<<<<<<<<<<<<<
 * 
 *         if self.exchange == "binance.com":
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_tld};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_t_7) < 0) __PYX_ERR(0, 282, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":272
 *             }
 * 
 *         if tld is not False:             # <<<<<<<<<<<<<<
 *             # Todo: Remove Block with tld!
 *             logger.warning("The parameter BinanceRestApiManager(tld=`com`) is obsolete, use parameter `exchange` "
 */
  }

  /* "unicorn_binance_rest_api/manager.py":284
 *             self.FUTURES_COIN_DATA_URL = self.FUTURES_COIN_DATA_URL.format(tld)
 * 
 *         if self.exchange == "binance.com":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":285
 * 
 *         if self.exchange == "binance.com":
 *             self.API_URL = "https://api.binance.com/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_com_api) < 0) __PYX_ERR(0, 285, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":286
 *         if self.exchange == "binance.com":
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 286, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":287
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance_com) < 0) __PYX_ERR(0, 287, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":288
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 288, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":289
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_com_futures_d) < 0) __PYX_ERR(0, 289, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":290
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-testnet" or self.exchange == "binance.com-futures-testnet":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 290, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":291
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.com-testnet" or self.exchange == "binance.com-futures-testnet":
 *             # https://github.com/LUCIT-Systems-and-Development/unicorn-binance-rest-api/issues/20
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_com_futures_d) < 0) __PYX_ERR(0, 291, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":284
 *             self.FUTURES_COIN_DATA_URL = self.FUTURES_COIN_DATA_URL.format(tld)
 * 
 *         if self.exchange == "binance.com":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":292
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-testnet" or self.exchange == "binance.com-futures-testnet":             # <<<<<<<<<<<<<<
 *             # https://github.com/LUCIT-Systems-and-Development/unicorn-binance-rest-api/issues/20
 *             self.API_URL = "https://testnet.binance.vision/api"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_testnet, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (!__pyx_t_12) {
  } else {
    __pyx_t_10 = __pyx_t_12;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_futures_testnet, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_10 = __pyx_t_12;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":294
 *         elif self.exchange == "binance.com-testnet" or self.exchange == "binance.com-futures-testnet":
 *             # https://github.com/LUCIT-Systems-and-Development/unicorn-binance-rest-api/issues/20
 *             self.API_URL = "https://testnet.binance.vision/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_testnet_binance_vision_api) < 0) __PYX_ERR(0, 294, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":295
 *             # https://github.com/LUCIT-Systems-and-Development/unicorn-binance-rest-api/issues/20
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 295, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":296
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_testnet_binance_vision) < 0) __PYX_ERR(0, 296, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":297
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_testnet_binancefuture_com) < 0) __PYX_ERR(0, 297, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":298
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_testnet_binancefuture_com_2) < 0) __PYX_ERR(0, 298, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":299
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-margin":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_testnet_binancefuture_com_3) < 0) __PYX_ERR(0, 299, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":300
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.com-margin":
 *             self.API_URL = "https://api.binance.com/api"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_testnet_binancefuture_com_2) < 0) __PYX_ERR(0, 300, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":292
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-testnet" or self.exchange == "binance.com-futures-testnet":             # <<<<<<<<<<<<<<
 *             # https://github.com/LUCIT-Systems-and-Development/unicorn-binance-rest-api/issues/20
 *             self.API_URL = "https://testnet.binance.vision/api"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":301
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-margin":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_margin, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":302
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-margin":
 *             self.API_URL = "https://api.binance.com/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_com_api) < 0) __PYX_ERR(0, 302, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":303
 *         elif self.exchange == "binance.com-margin":
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 303, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":304
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance_com) < 0) __PYX_ERR(0, 304, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":305
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 305, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":306
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_com_futures_d) < 0) __PYX_ERR(0, 306, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":307
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-margin-testnet":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 307, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":308
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.com-margin-testnet":
 *             self.API_URL = "https://testnet.binance.vision/api"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_com_futures_d) < 0) __PYX_ERR(0, 308, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":301
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-margin":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":309
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-margin-testnet":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_margin_testnet, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":310
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-margin-testnet":
 *             self.API_URL = "https://testnet.binance.vision/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_testnet_binance_vision_api) < 0) __PYX_ERR(0, 310, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":311
 *         elif self.exchange == "binance.com-margin-testnet":
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 311, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":312
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_testnet_binance_vision) < 0) __PYX_ERR(0, 312, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":313
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_testnet_binancefuture_com) < 0) __PYX_ERR(0, 313, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":314
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_testnet_binancefuture_com_2) < 0) __PYX_ERR(0, 314, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":315
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_testnet_binancefuture_com_3) < 0) __PYX_ERR(0, 315, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":316
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.com-isolated_margin":
 *             self.API_URL = "https://api.binance.com/api"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_testnet_binancefuture_com_2) < 0) __PYX_ERR(0, 316, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":309
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-margin-testnet":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":317
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_isolated_margin, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":318
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin":
 *             self.API_URL = "https://api.binance.com/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_com_api) < 0) __PYX_ERR(0, 318, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":319
 *         elif self.exchange == "binance.com-isolated_margin":
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 319, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":320
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance_com) < 0) __PYX_ERR(0, 320, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":321
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 321, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":322
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_com_futures_d) < 0) __PYX_ERR(0, 322, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":323
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin-testnet":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 323, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":324
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.com-isolated_margin-testnet":
 *             self.API_URL = "https://testnet.binance.vision/api"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_com_futures_d) < 0) __PYX_ERR(0, 324, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":317
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":325
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin-testnet":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_isolated_margin_test, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":326
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin-testnet":
 *             self.API_URL = "https://testnet.binance.vision/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_testnet_binance_vision_api) < 0) __PYX_ERR(0, 326, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":327
 *         elif self.exchange == "binance.com-isolated_margin-testnet":
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 327, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":328
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_testnet_binance_vision) < 0) __PYX_ERR(0, 328, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":329
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_testnet_binancefuture_com) < 0) __PYX_ERR(0, 329, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":330
 *             self.WEBSITE_URL = "https://testnet.binance.vision"
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_testnet_binancefuture_com_2) < 0) __PYX_ERR(0, 330, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":331
 *             self.FUTURES_URL = "https://testnet.binancefuture.com/fapi"
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-futures":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_testnet_binancefuture_com_3) < 0) __PYX_ERR(0, 331, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":332
 *             self.FUTURES_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.com-futures":
 *             self.API_URL = "https://api.binance.com/api"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_testnet_binancefuture_com_2) < 0) __PYX_ERR(0, 332, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":325
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-isolated_margin-testnet":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://testnet.binance.vision/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":333
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-futures":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_futures, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":334
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-futures":
 *             self.API_URL = "https://api.binance.com/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_com_api) < 0) __PYX_ERR(0, 334, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":335
 *         elif self.exchange == "binance.com-futures":
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 335, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":336
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance_com) < 0) __PYX_ERR(0, 336, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":337
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 337, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":338
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_com_futures_d) < 0) __PYX_ERR(0, 338, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":339
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-coin-futures":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 339, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":340
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.com-coin-futures":
 *             self.API_URL = "https://api.binance.com/api"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_com_futures_d) < 0) __PYX_ERR(0, 340, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":333
 *             self.FUTURES_COIN_URL = "https://testnet.binancefuture.com/dapi"
 *             self.FUTURES_COIN_DATA_URL = "https://testnet.binancefuture.com/futures/data"
 *         elif self.exchange == "binance.com-futures":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":341
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-coin-futures":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_com_coin_futures, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":342
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-coin-futures":
 *             self.API_URL = "https://api.binance.com/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_com_api) < 0) __PYX_ERR(0, 342, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":343
 *         elif self.exchange == "binance.com-coin-futures":
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 343, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":344
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance_com) < 0) __PYX_ERR(0, 344, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":345
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 345, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":346
 *             self.WEBSITE_URL = "https://www.binance.com"
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_com_futures_d) < 0) __PYX_ERR(0, 346, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":347
 *             self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.us":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 347, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":348
 *             self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "binance.us":
 *             # Todo: Needs a test
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_com_futures_d) < 0) __PYX_ERR(0, 348, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":341
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.com-coin-futures":             # <<<<<<<<<<<<<<
 *             self.API_URL = "https://api.binance.com/api"
 *             self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":349
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.us":             # <<<<<<<<<<<<<<
 *             # Todo: Needs a test
 *             self.API_URL = "https://api.binance.us/api"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_binance_us, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":351
 *         elif self.exchange == "binance.us":
 *             # Todo: Needs a test
 *             self.API_URL = "https://api.binance.us/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.binance.us/sapi"
 *             self.WEBSITE_URL = "https://www.binance.us"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_us_api) < 0) __PYX_ERR(0, 351, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":352
 *             # Todo: Needs a test
 *             self.API_URL = "https://api.binance.us/api"
 *             self.MARGIN_API_URL = " https://api.binance.us/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://www.binance.us"
 *             self.FUTURES_URL = "https://fapi.binance.us/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_us_sapi) < 0) __PYX_ERR(0, 352, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":353
 *             self.API_URL = "https://api.binance.us/api"
 *             self.MARGIN_API_URL = " https://api.binance.us/sapi"
 *             self.WEBSITE_URL = "https://www.binance.us"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://fapi.binance.us/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.us/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance_us) < 0) __PYX_ERR(0, 353, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":354
 *             self.MARGIN_API_URL = " https://api.binance.us/sapi"
 *             self.WEBSITE_URL = "https://www.binance.us"
 *             self.FUTURES_URL = "https://fapi.binance.us/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://fapi.binance.us/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.us/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_us_fapi) < 0) __PYX_ERR(0, 354, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":355
 *             self.WEBSITE_URL = "https://www.binance.us"
 *             self.FUTURES_URL = "https://fapi.binance.us/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.us/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://fapi.binance.us/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.us/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_us_futures_da) < 0) __PYX_ERR(0, 355, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":356
 *             self.FUTURES_URL = "https://fapi.binance.us/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.binance.us/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.us/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.us/futures/data"
 *         elif self.exchange == "trbinance.com":
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_us_fapi) < 0) __PYX_ERR(0, 356, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":357
 *             self.FUTURES_DATA_URL = "https://fapi.binance.us/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.binance.us/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.us/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange == "trbinance.com":
 *             # Todo: Needs a test
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_us_futures_da) < 0) __PYX_ERR(0, 357, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":349
 *             self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 *         elif self.exchange == "binance.us":             # <<<<<<<<<<<<<<
 *             # Todo: Needs a test
 *             self.API_URL = "https://api.binance.us/api"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":358
 *             self.FUTURES_COIN_URL = "https://fapi.binance.us/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.us/futures/data"
 *         elif self.exchange == "trbinance.com":             # <<<<<<<<<<<<<<
 *             # Todo: Needs a test
 *             self.API_URL = "https://www.trbinance.com/api"
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_t_7, __pyx_kp_s_trbinance_com, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":360
 *         elif self.exchange == "trbinance.com":
 *             # Todo: Needs a test
 *             self.API_URL = "https://www.trbinance.com/api"             # <<<<<<<<<<<<<<
 *             self.MARGIN_API_URL = " https://api.trbinance.com/sapi"
 *             self.WEBSITE_URL = "https://www.trbinance.com"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_www_trbinance_com_api) < 0) __PYX_ERR(0, 360, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":361
 *             # Todo: Needs a test
 *             self.API_URL = "https://www.trbinance.com/api"
 *             self.MARGIN_API_URL = " https://api.trbinance.com/sapi"             # <<<<<<<<<<<<<<
 *             self.WEBSITE_URL = "https://www.trbinance.com"
 *             self.FUTURES_URL = "https://fapi.trbinance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_trbinance_com_sapi) < 0) __PYX_ERR(0, 361, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":362
 *             self.API_URL = "https://www.trbinance.com/api"
 *             self.MARGIN_API_URL = " https://api.trbinance.com/sapi"
 *             self.WEBSITE_URL = "https://www.trbinance.com"             # <<<<<<<<<<<<<<
 *             self.FUTURES_URL = "https://fapi.trbinance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.trbinance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_trbinance_com) < 0) __PYX_ERR(0, 362, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":363
 *             self.MARGIN_API_URL = " https://api.trbinance.com/sapi"
 *             self.WEBSITE_URL = "https://www.trbinance.com"
 *             self.FUTURES_URL = "https://fapi.trbinance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_DATA_URL = "https://fapi.trbinance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.trbinance.com/fapi"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_trbinance_com_fapi) < 0) __PYX_ERR(0, 363, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":364
 *             self.WEBSITE_URL = "https://www.trbinance.com"
 *             self.FUTURES_URL = "https://fapi.trbinance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.trbinance.com/futures/data"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_URL = "https://fapi.trbinance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.trbinance.com/futures/data"
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_trbinance_com_futures) < 0) __PYX_ERR(0, 364, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":365
 *             self.FUTURES_URL = "https://fapi.trbinance.com/fapi"
 *             self.FUTURES_DATA_URL = "https://fapi.trbinance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.trbinance.com/fapi"             # <<<<<<<<<<<<<<
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.trbinance.com/futures/data"
 *         elif self.exchange:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_trbinance_com_fapi) < 0) __PYX_ERR(0, 365, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":366
 *             self.FUTURES_DATA_URL = "https://fapi.trbinance.com/futures/data"
 *             self.FUTURES_COIN_URL = "https://fapi.trbinance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.trbinance.com/futures/data"             # <<<<<<<<<<<<<<
 *         elif self.exchange:
 *             # Unknown Exchange
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_trbinance_com_futures) < 0) __PYX_ERR(0, 366, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":358
 *             self.FUTURES_COIN_URL = "https://fapi.binance.us/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.binance.us/futures/data"
 *         elif self.exchange == "trbinance.com":             # <<<<<<<<<<<<<<
 *             # Todo: Needs a test
 *             self.API_URL = "https://www.trbinance.com/api"
 */
    goto __pyx_L10;
  }

  /* "unicorn_binance_rest_api/manager.py":367
 *             self.FUTURES_COIN_URL = "https://fapi.trbinance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.trbinance.com/futures/data"
 *         elif self.exchange:             # <<<<<<<<<<<<<<
 *             # Unknown Exchange
 *             error_msg = f"Unknown exchange '{str(self.exchange)}'! Read the docs to see a list of supported " \
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(__pyx_t_10)) {

    /* "unicorn_binance_rest_api/manager.py":369
 *         elif self.exchange:
 *             # Unknown Exchange
 *             error_msg = f"Unknown exchange '{str(self.exchange)}'! Read the docs to see a list of supported " \             # <<<<<<<<<<<<<<
 *                         "exchanges: https://unicorn-binance-rest-api.docs.lucit.tech/unicorn_" \
 *                         "binance_rest_api.html#module-unicorn_binance_rest_api.unicorn_binance_rest_" \
 */
    __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_Unknown_exchange);
    __pyx_t_4 += 18;
    __Pyx_GIVEREF(__pyx_kp_u_Unknown_exchange);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_kp_u_Unknown_exchange);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exchange); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_Str(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_kp_u_Read_the_docs_to_see_a_list_of);
    __pyx_t_4 += 198;
    __Pyx_GIVEREF(__pyx_kp_u_Read_the_docs_to_see_a_list_of);
    PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_kp_u_Read_the_docs_to_see_a_list_of);
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_7, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_error_msg = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":373
 *                         "binance_rest_api.html#module-unicorn_binance_rest_api.unicorn_binance_rest_" \
 *                         "api_manager"
 *             logger.critical(error_msg)             # <<<<<<<<<<<<<<
 * 
 *             raise UnknownExchange(error_msg)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_logger); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 373, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_critical); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 373, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_error_msg};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":375
 *             logger.critical(error_msg)
 * 
 *             raise UnknownExchange(error_msg)             # <<<<<<<<<<<<<<
 *         else:
 *             if tld is False:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_UnknownExchange); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_error_msg};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 375, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":367
 *             self.FUTURES_COIN_URL = "https://fapi.trbinance.com/fapi"
 *             self.FUTURES_COIN_DATA_URL = "https://dapi.trbinance.com/futures/data"
 *         elif self.exchange:             # <<<<<<<<<<<<<<
 *             # Unknown Exchange
 *             error_msg = f"Unknown exchange '{str(self.exchange)}'! Read the docs to see a list of supported " \
 */
  }

  /* "unicorn_binance_rest_api/manager.py":377
 *             raise UnknownExchange(error_msg)
 *         else:
 *             if tld is False:             # <<<<<<<<<<<<<<
 *                 self.API_URL = "https://api.binance.com/api"
 *                 self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
  /*else*/ {
    __pyx_t_10 = (__pyx_v_tld == Py_False);
    if (__pyx_t_10) {

      /* "unicorn_binance_rest_api/manager.py":378
 *         else:
 *             if tld is False:
 *                 self.API_URL = "https://api.binance.com/api"             # <<<<<<<<<<<<<<
 *                 self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *                 self.WEBSITE_URL = "https://www.binance.com"
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_com_api) < 0) __PYX_ERR(0, 378, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":379
 *             if tld is False:
 *                 self.API_URL = "https://api.binance.com/api"
 *                 self.MARGIN_API_URL = " https://api.binance.com/sapi"             # <<<<<<<<<<<<<<
 *                 self.WEBSITE_URL = "https://www.binance.com"
 *                 self.FUTURES_URL = "https://fapi.binance.com/fapi"
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_com_sapi) < 0) __PYX_ERR(0, 379, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":380
 *                 self.API_URL = "https://api.binance.com/api"
 *                 self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *                 self.WEBSITE_URL = "https://www.binance.com"             # <<<<<<<<<<<<<<
 *                 self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *                 self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance_com) < 0) __PYX_ERR(0, 380, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":381
 *                 self.MARGIN_API_URL = " https://api.binance.com/sapi"
 *                 self.WEBSITE_URL = "https://www.binance.com"
 *                 self.FUTURES_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *                 self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *                 self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 381, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":382
 *                 self.WEBSITE_URL = "https://www.binance.com"
 *                 self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *                 self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 *                 self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *                 self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_com_futures_d) < 0) __PYX_ERR(0, 382, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":383
 *                 self.FUTURES_URL = "https://fapi.binance.com/fapi"
 *                 self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *                 self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"             # <<<<<<<<<<<<<<
 *                 self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 * 
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_com_fapi) < 0) __PYX_ERR(0, 383, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":384
 *                 self.FUTURES_DATA_URL = "https://fapi.binance.com/futures/data"
 *                 self.FUTURES_COIN_URL = "https://fapi.binance.com/fapi"
 *                 self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"             # <<<<<<<<<<<<<<
 * 
 *         if self.debug:
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_com_futures_d) < 0) __PYX_ERR(0, 384, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":377
 *             raise UnknownExchange(error_msg)
 *         else:
 *             if tld is False:             # <<<<<<<<<<<<<<
 *                 self.API_URL = "https://api.binance.com/api"
 *                 self.MARGIN_API_URL = " https://api.binance.com/sapi"
 */
    }
  }
  __pyx_L10:;

  /* "unicorn_binance_rest_api/manager.py":386
 *                 self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 * 
 *         if self.debug:             # <<<<<<<<<<<<<<
 *             print(f"tld: {tld}, exchange: {exchange}\r\n"
 *                   f"self.API_URL: {self.API_URL}\r\nself.MARGIN_API_URL: {self.MARGIN_API_URL}\r\n"
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debug); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":387
 * 
 *         if self.debug:
 *             print(f"tld: {tld}, exchange: {exchange}\r\n"             # <<<<<<<<<<<<<<
 *                   f"self.API_URL: {self.API_URL}\r\nself.MARGIN_API_URL: {self.MARGIN_API_URL}\r\n"
 *                   f"self.WEBSITE_URL: {self.WEBSITE_URL}\r\nself.FUTURES_URL: {self.FUTURES_URL}\r\n"
 */
    __pyx_t_2 = PyTuple_New(18); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_tld_2);
    __pyx_t_4 += 5;
    __Pyx_GIVEREF(__pyx_kp_u_tld_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_tld_2);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_tld, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_exchange_2);
    __pyx_t_4 += 12;
    __Pyx_GIVEREF(__pyx_kp_u_exchange_2);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_exchange_2);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_exchange, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_self_API_URL);
    __pyx_t_4 += 16;
    __Pyx_GIVEREF(__pyx_kp_u_self_API_URL);
    PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_kp_u_self_API_URL);

    /* "unicorn_binance_rest_api/manager.py":388
 *         if self.debug:
 *             print(f"tld: {tld}, exchange: {exchange}\r\n"
 *                   f"self.API_URL: {self.API_URL}\r\nself.MARGIN_API_URL: {self.MARGIN_API_URL}\r\n"             # <<<<<<<<<<<<<<
 *                   f"self.WEBSITE_URL: {self.WEBSITE_URL}\r\nself.FUTURES_URL: {self.FUTURES_URL}\r\n"
 *                   f"self.FUTURES_DATA_URL: {self.FUTURES_DATA_URL}\r\nself.FUTURES_COIN_URL: "
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_API_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u_self_MARGIN_API_URL);
    __pyx_t_4 += 23;
    __Pyx_GIVEREF(__pyx_kp_u_self_MARGIN_API_URL);
    PyTuple_SET_ITEM(__pyx_t_2, 6, __pyx_kp_u_self_MARGIN_API_URL);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 7, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_self_WEBSITE_URL);
    __pyx_t_4 += 20;
    __Pyx_GIVEREF(__pyx_kp_u_self_WEBSITE_URL);
    PyTuple_SET_ITEM(__pyx_t_2, 8, __pyx_kp_u_self_WEBSITE_URL);

    /* "unicorn_binance_rest_api/manager.py":389
 *             print(f"tld: {tld}, exchange: {exchange}\r\n"
 *                   f"self.API_URL: {self.API_URL}\r\nself.MARGIN_API_URL: {self.MARGIN_API_URL}\r\n"
 *                   f"self.WEBSITE_URL: {self.WEBSITE_URL}\r\nself.FUTURES_URL: {self.FUTURES_URL}\r\n"             # <<<<<<<<<<<<<<
 *                   f"self.FUTURES_DATA_URL: {self.FUTURES_DATA_URL}\r\nself.FUTURES_COIN_URL: "
 *                   f"{self.FUTURES_COIN_URL}\r\n"
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_2, 9, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u_self_FUTURES_URL);
    __pyx_t_4 += 20;
    __Pyx_GIVEREF(__pyx_kp_u_self_FUTURES_URL);
    PyTuple_SET_ITEM(__pyx_t_2, 10, __pyx_kp_u_self_FUTURES_URL);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 11, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_self_FUTURES_DATA_URL);
    __pyx_t_4 += 25;
    __Pyx_GIVEREF(__pyx_kp_u_self_FUTURES_DATA_URL);
    PyTuple_SET_ITEM(__pyx_t_2, 12, __pyx_kp_u_self_FUTURES_DATA_URL);

    /* "unicorn_binance_rest_api/manager.py":390
 *                   f"self.API_URL: {self.API_URL}\r\nself.MARGIN_API_URL: {self.MARGIN_API_URL}\r\n"
 *                   f"self.WEBSITE_URL: {self.WEBSITE_URL}\r\nself.FUTURES_URL: {self.FUTURES_URL}\r\n"
 *                   f"self.FUTURES_DATA_URL: {self.FUTURES_DATA_URL}\r\nself.FUTURES_COIN_URL: "             # <<<<<<<<<<<<<<
 *                   f"{self.FUTURES_COIN_URL}\r\n"
 *                   f"self.FUTURES_COIN_DATA_URL: {self.FUTURES_COIN_DATA_URL}")
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_2, 13, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u_self_FUTURES_COIN_URL);
    __pyx_t_4 += 25;
    __Pyx_GIVEREF(__pyx_kp_u_self_FUTURES_COIN_URL);
    PyTuple_SET_ITEM(__pyx_t_2, 14, __pyx_kp_u_self_FUTURES_COIN_URL);

    /* "unicorn_binance_rest_api/manager.py":391
 *                   f"self.WEBSITE_URL: {self.WEBSITE_URL}\r\nself.FUTURES_URL: {self.FUTURES_URL}\r\n"
 *                   f"self.FUTURES_DATA_URL: {self.FUTURES_DATA_URL}\r\nself.FUTURES_COIN_URL: "
 *                   f"{self.FUTURES_COIN_URL}\r\n"             # <<<<<<<<<<<<<<
 *                   f"self.FUTURES_COIN_DATA_URL: {self.FUTURES_COIN_DATA_URL}")
 * 
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 15, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_self_FUTURES_COIN_DATA_URL);
    __pyx_t_4 += 30;
    __Pyx_GIVEREF(__pyx_kp_u_self_FUTURES_COIN_DATA_URL);
    PyTuple_SET_ITEM(__pyx_t_2, 16, __pyx_kp_u_self_FUTURES_COIN_DATA_URL);

    /* "unicorn_binance_rest_api/manager.py":392
 *                   f"self.FUTURES_DATA_URL: {self.FUTURES_DATA_URL}\r\nself.FUTURES_COIN_URL: "
 *                   f"{self.FUTURES_COIN_URL}\r\n"
 *                   f"self.FUTURES_COIN_DATA_URL: {self.FUTURES_COIN_DATA_URL}")             # <<<<<<<<<<<<<<
 * 
 *         self.API_KEY = api_key
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_2, 17, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "unicorn_binance_rest_api/manager.py":387
 * 
 *         if self.debug:
 *             print(f"tld: {tld}, exchange: {exchange}\r\n"             # <<<<<<<<<<<<<<
 *                   f"self.API_URL: {self.API_URL}\r\nself.MARGIN_API_URL: {self.MARGIN_API_URL}\r\n"
 *                   f"self.WEBSITE_URL: {self.WEBSITE_URL}\r\nself.FUTURES_URL: {self.FUTURES_URL}\r\n"
 */
    __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_2, 18, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":386
 *                 self.FUTURES_COIN_DATA_URL = "https://dapi.binance.com/futures/data"
 * 
 *         if self.debug:             # <<<<<<<<<<<<<<
 *             print(f"tld: {tld}, exchange: {exchange}\r\n"
 *                   f"self.API_URL: {self.API_URL}\r\nself.MARGIN_API_URL: {self.MARGIN_API_URL}\r\n"
 */
  }

  /* "unicorn_binance_rest_api/manager.py":394
 *                   f"self.FUTURES_COIN_DATA_URL: {self.FUTURES_COIN_DATA_URL}")
 * 
 *         self.API_KEY = api_key             # <<<<<<<<<<<<<<
 *         self.API_SECRET = api_secret
 *         self.last_update_check_github = {'timestamp': time.time(),
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_KEY, __pyx_v_api_key) < 0) __PYX_ERR(0, 394, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":395
 * 
 *         self.API_KEY = api_key
 *         self.API_SECRET = api_secret             # <<<<<<<<<<<<<<
 *         self.last_update_check_github = {'timestamp': time.time(),
 *                                          'status': None}
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_API_SECRET, __pyx_v_api_secret) < 0) __PYX_ERR(0, 395, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":396
 *         self.API_KEY = api_key
 *         self.API_SECRET = api_secret
 *         self.last_update_check_github = {'timestamp': time.time(),             # <<<<<<<<<<<<<<
 *                                          'status': None}
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_timestamp, __pyx_t_7) < 0) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "unicorn_binance_rest_api/manager.py":397
 *         self.API_SECRET = api_secret
 *         self.last_update_check_github = {'timestamp': time.time(),
 *                                          'status': None}             # <<<<<<<<<<<<<<
 * 
 *         self._requests_params = requests_params
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_status, Py_None) < 0) __PYX_ERR(0, 396, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":396
 *         self.API_KEY = api_key
 *         self.API_SECRET = api_secret
 *         self.last_update_check_github = {'timestamp': time.time(),             # <<<<<<<<<<<<<<
 *                                          'status': None}
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_last_update_check_github, __pyx_t_2) < 0) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":399
 *                                          'status': None}
 * 
 *         self._requests_params = requests_params             # <<<<<<<<<<<<<<
 *         self.response = None
 *         self.session = self._init_session()
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_requests_params_2, __pyx_v_requests_params) < 0) __PYX_ERR(0, 399, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":400
 * 
 *         self._requests_params = requests_params
 *         self.response = None             # <<<<<<<<<<<<<<
 *         self.session = self._init_session()
 *         self.timestamp_offset = 0
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_response, Py_None) < 0) __PYX_ERR(0, 400, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":401
 *         self._requests_params = requests_params
 *         self.response = None
 *         self.session = self._init_session()             # <<<<<<<<<<<<<<
 *         self.timestamp_offset = 0
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_init_session); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_session, __pyx_t_2) < 0) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":402
 *         self.response = None
 *         self.session = self._init_session()
 *         self.timestamp_offset = 0             # <<<<<<<<<<<<<<
 * 
 *         # calculate timestamp offset between local and binance api server
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_timestamp_offset, __pyx_int_0) < 0) __PYX_ERR(0, 402, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":405
 * 
 *         # calculate timestamp offset between local and binance api server
 *         res = self.get_server_time()             # <<<<<<<<<<<<<<
 *         try:
 *             self.timestamp_offset = res['serverTime'] - int(time.time() * 1000)
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_server_time); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_res = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":406
 *         # calculate timestamp offset between local and binance api server
 *         res = self.get_server_time()
 *         try:             # <<<<<<<<<<<<<<
 *             self.timestamp_offset = res['serverTime'] - int(time.time() * 1000)
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
    __Pyx_XGOTREF(__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_14);
    __Pyx_XGOTREF(__pyx_t_15);
    /*try:*/ {

      /* "unicorn_binance_rest_api/manager.py":407
 *         res = self.get_server_time()
 *         try:
 *             self.timestamp_offset = res['serverTime'] - int(time.time() * 1000)             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             self.timestamp_offset = 0
 */
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_serverTime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 407, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 407, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 407, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = __Pyx_PyInt_MultiplyObjC(__pyx_t_7, __pyx_int_1000, 0x3E8, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 407, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyNumber_Int(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 407, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Subtract(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 407, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_timestamp_offset, __pyx_t_3) < 0) __PYX_ERR(0, 407, __pyx_L15_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":406
 *         # calculate timestamp offset between local and binance api server
 *         res = self.get_server_time()
 *         try:             # <<<<<<<<<<<<<<
 *             self.timestamp_offset = res['serverTime'] - int(time.time() * 1000)
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    goto __pyx_L20_try_end;
    __pyx_L15_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "unicorn_binance_rest_api/manager.py":408
 *         try:
 *             self.timestamp_offset = res['serverTime'] - int(time.time() * 1000)
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             self.timestamp_offset = 0
 * 
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_9) {
      __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_7, &__pyx_t_2) < 0) __PYX_ERR(0, 408, __pyx_L17_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_2);

      /* "unicorn_binance_rest_api/manager.py":409
 *             self.timestamp_offset = res['serverTime'] - int(time.time() * 1000)
 *         except KeyError:
 *             self.timestamp_offset = 0             # <<<<<<<<<<<<<<
 * 
 *         # Cache DNS and init request session
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_timestamp_offset, __pyx_int_0) < 0) __PYX_ERR(0, 409, __pyx_L17_except_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L16_exception_handled;
    }
    goto __pyx_L17_except_error;

    /* "unicorn_binance_rest_api/manager.py":406
 *         # calculate timestamp offset between local and binance api server
 *         res = self.get_server_time()
 *         try:             # <<<<<<<<<<<<<<
 *             self.timestamp_offset = res['serverTime'] - int(time.time() * 1000)
 *         except KeyError:
 */
    __pyx_L17_except_error:;
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_XGIVEREF(__pyx_t_14);
    __Pyx_XGIVEREF(__pyx_t_15);
    __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
    goto __pyx_L1_error;
    __pyx_L16_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_XGIVEREF(__pyx_t_14);
    __Pyx_XGIVEREF(__pyx_t_15);
    __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
    __pyx_L20_try_end:;
  }

  /* "unicorn_binance_rest_api/manager.py":412
 * 
 *         # Cache DNS and init request session
 *         self.ping()             # <<<<<<<<<<<<<<
 * 
 *         if warn_on_update and self.is_update_availabe():
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ping); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":414
 *         self.ping()
 * 
 *         if warn_on_update and self.is_update_availabe():             # <<<<<<<<<<<<<<
 *             update_msg = f"Release {self.name}_" + self.get_latest_version() + " is available, " \
 *                          f"please consider updating! (Changelog: " \
 */
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_warn_on_update); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 414, __pyx_L1_error)
  if (__pyx_t_12) {
  } else {
    __pyx_t_10 = __pyx_t_12;
    goto __pyx_L24_bool_binop_done;
  }
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_is_update_availabe); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_10 = __pyx_t_12;
  __pyx_L24_bool_binop_done:;
  if (__pyx_t_10) {

    /* "unicorn_binance_rest_api/manager.py":415
 * 
 *         if warn_on_update and self.is_update_availabe():
 *             update_msg = f"Release {self.name}_" + self.get_latest_version() + " is available, " \             # <<<<<<<<<<<<<<
 *                          f"please consider updating! (Changelog: " \
 *                          f"https://unicorn-binance-rest-api.docs.lucit.tech/changelog.html)"
 */
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_Release);
    __pyx_t_4 += 8;
    __Pyx_GIVEREF(__pyx_kp_u_Release);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_Release);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_n_u__5);
    __pyx_t_4 += 1;
    __Pyx_GIVEREF(__pyx_n_u__5);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_n_u__5);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_latest_version); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_kp_u_is_available_please_consider_up); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_update_msg = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":418
 *                          f"please consider updating! (Changelog: " \
 *                          f"https://unicorn-binance-rest-api.docs.lucit.tech/changelog.html)"
 *             print(update_msg)             # <<<<<<<<<<<<<<
 *             logger.warning(update_msg)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_update_msg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":419
 *                          f"https://unicorn-binance-rest-api.docs.lucit.tech/changelog.html)"
 *             print(update_msg)
 *             logger.warning(update_msg)             # <<<<<<<<<<<<<<
 * 
 *     def __enter__(self):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_logger); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_warning); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_update_msg};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":414
 *         self.ping()
 * 
 *         if warn_on_update and self.is_update_availabe():             # <<<<<<<<<<<<<<
 *             update_msg = f"Release {self.name}_" + self.get_latest_version() + " is available, " \
 *                          f"please consider updating! (Changelog: " \
 */
  }

  /* "unicorn_binance_rest_api/manager.py":204
 *     MINING_TO_FIAT = "MINING_C2C"
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  api_key=None,
 *                  api_secret=None,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_socks_proxy_uri);
  __Pyx_XDECREF(__pyx_v_error_msg);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_update_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":421
 *             logger.warning(update_msg)
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Entering 'with-context' ...")
 *         return self
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_3__enter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_3__enter__ = {"__enter__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_3__enter__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_3__enter__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__enter__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 421, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__enter__") < 0)) __PYX_ERR(0, 421, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__enter__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 421, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.__enter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_2__enter__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_2__enter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__enter__", 1);

  /* "unicorn_binance_rest_api/manager.py":422
 * 
 *     def __enter__(self):
 *         logger.debug(f"Entering 'with-context' ...")             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_Entering_with_context};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":423
 *     def __enter__(self):
 *         logger.debug(f"Entering 'with-context' ...")
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __exit__(self, exc_type, exc_value, error_traceback):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":421
 *             logger.warning(update_msg)
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Entering 'with-context' ...")
 *         return self
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.__enter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":425
 *         return self
 * 
 *     def __exit__(self, exc_type, exc_value, error_traceback):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Leaving 'with-context' ...")
 *         self.stop_manager()
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_5__exit__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_5__exit__ = {"__exit__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_5__exit__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_5__exit__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exc_type = 0;
  PyObject *__pyx_v_exc_value = 0;
  PyObject *__pyx_v_error_traceback = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__exit__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exc_type,&__pyx_n_s_exc_value,&__pyx_n_s_error_traceback,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exc_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__exit__", 1, 4, 4, 1); __PYX_ERR(0, 425, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exc_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__exit__", 1, 4, 4, 2); __PYX_ERR(0, 425, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_error_traceback)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 425, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__exit__", 1, 4, 4, 3); __PYX_ERR(0, 425, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__exit__") < 0)) __PYX_ERR(0, 425, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_exc_type = values[1];
    __pyx_v_exc_value = values[2];
    __pyx_v_error_traceback = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__exit__", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 425, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_4__exit__(__pyx_self, __pyx_v_self, __pyx_v_exc_type, __pyx_v_exc_value, __pyx_v_error_traceback);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_4__exit__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc_type, PyObject *__pyx_v_exc_value, PyObject *__pyx_v_error_traceback) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__exit__", 1);

  /* "unicorn_binance_rest_api/manager.py":426
 * 
 *     def __exit__(self, exc_type, exc_value, error_traceback):
 *         logger.debug(f"Leaving 'with-context' ...")             # <<<<<<<<<<<<<<
 *         self.stop_manager()
 *         if exc_type:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_kp_u_Leaving_with_context};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":427
 *     def __exit__(self, exc_type, exc_value, error_traceback):
 *         logger.debug(f"Leaving 'with-context' ...")
 *         self.stop_manager()             # <<<<<<<<<<<<<<
 *         if exc_type:
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_stop_manager); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":428
 *         logger.debug(f"Leaving 'with-context' ...")
 *         self.stop_manager()
 *         if exc_type:             # <<<<<<<<<<<<<<
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_exc_type); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 428, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":429
 *         self.stop_manager()
 *         if exc_type:
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")             # <<<<<<<<<<<<<<
 * 
 *     def _init_session(self):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_logger); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_critical); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = 0;
    __pyx_t_7 = 127;
    __Pyx_INCREF(__pyx_kp_u_An_exception_occurred);
    __pyx_t_6 += 23;
    __Pyx_GIVEREF(__pyx_kp_u_An_exception_occurred);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_An_exception_occurred);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_exc_type, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_7;
    __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__6);
    __pyx_t_6 += 3;
    __Pyx_GIVEREF(__pyx_kp_u__6);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__6);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_exc_value, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_7;
    __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__6);
    __pyx_t_6 += 3;
    __Pyx_GIVEREF(__pyx_kp_u__6);
    PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_kp_u__6);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_error_traceback, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_7;
    __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_3, 6, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "unicorn_binance_rest_api/manager.py":428
 *         logger.debug(f"Leaving 'with-context' ...")
 *         self.stop_manager()
 *         if exc_type:             # <<<<<<<<<<<<<<
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")
 * 
 */
  }

  /* "unicorn_binance_rest_api/manager.py":425
 *         return self
 * 
 *     def __exit__(self, exc_type, exc_value, error_traceback):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Leaving 'with-context' ...")
 *         self.stop_manager()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":431
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")
 * 
 *     def _init_session(self):             # <<<<<<<<<<<<<<
 *         session = requests.session()
 *         session.headers.update({'Accept': 'application/json',
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_7_init_session(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_7_init_session = {"_init_session", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_7_init_session, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_7_init_session(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_init_session (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 431, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_init_session") < 0)) __PYX_ERR(0, 431, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_init_session", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 431, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._init_session", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_6_init_session(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_6_init_session(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_session = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_init_session", 1);

  /* "unicorn_binance_rest_api/manager.py":432
 * 
 *     def _init_session(self):
 *         session = requests.session()             # <<<<<<<<<<<<<<
 *         session.headers.update({'Accept': 'application/json',
 *                                 'User-Agent': str(self.get_user_agent()),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_requests); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_session = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":433
 *     def _init_session(self):
 *         session = requests.session()
 *         session.headers.update({'Accept': 'application/json',             # <<<<<<<<<<<<<<
 *                                 'User-Agent': str(self.get_user_agent()),
 *                                 'X-MBX-APIKEY': str(self.API_KEY)})
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_session, __pyx_n_s_headers); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_update); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_Accept, __pyx_kp_s_application_json) < 0) __PYX_ERR(0, 433, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":434
 *         session = requests.session()
 *         session.headers.update({'Accept': 'application/json',
 *                                 'User-Agent': str(self.get_user_agent()),             # <<<<<<<<<<<<<<
 *                                 'X-MBX-APIKEY': str(self.API_KEY)})
 *         return session
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_user_agent); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_Str(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_kp_s_User_Agent, __pyx_t_6) < 0) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":435
 *         session.headers.update({'Accept': 'application/json',
 *                                 'User-Agent': str(self.get_user_agent()),
 *                                 'X-MBX-APIKEY': str(self.API_KEY)})             # <<<<<<<<<<<<<<
 *         return session
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_API_KEY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_Str(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_kp_s_X_MBX_APIKEY, __pyx_t_5) < 0) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":436
 *                                 'User-Agent': str(self.get_user_agent()),
 *                                 'X-MBX-APIKEY': str(self.API_KEY)})
 *         return session             # <<<<<<<<<<<<<<
 * 
 *     def _create_api_uri(self, path, signed=True, version=PUBLIC_API_VERSION):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_session);
  __pyx_r = __pyx_v_session;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":431
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")
 * 
 *     def _init_session(self):             # <<<<<<<<<<<<<<
 *         session = requests.session()
 *         session.headers.update({'Accept': 'application/json',
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._init_session", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_session);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":438
 *         return session
 * 
 *     def _create_api_uri(self, path, signed=True, version=PUBLIC_API_VERSION):             # <<<<<<<<<<<<<<
 *         v = self.PRIVATE_API_VERSION if signed else version
 *         return self.API_URL + '/' + v + '/' + path
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager___defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_True))) __PYX_ERR(0, 438, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 438, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 438, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 438, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_9_create_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_9_create_api_uri = {"_create_api_uri", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_9_create_api_uri, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_9_create_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_create_api_uri (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 438, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 438, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_create_api_uri", 0, 2, 4, 1); __PYX_ERR(0, 438, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 438, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 438, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_create_api_uri") < 0)) __PYX_ERR(0, 438, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_signed = values[2];
    __pyx_v_version = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_create_api_uri", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 438, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_create_api_uri(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_signed, __pyx_v_version);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_create_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version) {
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_api_uri", 1);

  /* "unicorn_binance_rest_api/manager.py":439
 * 
 *     def _create_api_uri(self, path, signed=True, version=PUBLIC_API_VERSION):
 *         v = self.PRIVATE_API_VERSION if signed else version             # <<<<<<<<<<<<<<
 *         return self.API_URL + '/' + v + '/' + path
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_signed); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 439, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_v_version);
    __pyx_t_1 = __pyx_v_version;
  }
  __pyx_v_v = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":440
 *     def _create_api_uri(self, path, signed=True, version=PUBLIC_API_VERSION):
 *         v = self.PRIVATE_API_VERSION if signed else version
 *         return self.API_URL + '/' + v + '/' + path             # <<<<<<<<<<<<<<
 * 
 *     def _create_margin_api_uri(self, path, version=MARGIN_API_VERSION):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_API_URL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_v_v); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":438
 *         return session
 * 
 *     def _create_api_uri(self, path, signed=True, version=PUBLIC_API_VERSION):             # <<<<<<<<<<<<<<
 *         v = self.PRIVATE_API_VERSION if signed else version
 *         return self.API_URL + '/' + v + '/' + path
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":442
 *         return self.API_URL + '/' + v + '/' + path
 * 
 *     def _create_margin_api_uri(self, path, version=MARGIN_API_VERSION):             # <<<<<<<<<<<<<<
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_2__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 442, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 442, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_11_create_margin_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_11_create_margin_api_uri = {"_create_margin_api_uri", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_11_create_margin_api_uri, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_11_create_margin_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_version = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_create_margin_api_uri (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_version,0};
    __pyx_defaults1 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 442, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 442, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_create_margin_api_uri", 0, 2, 3, 1); __PYX_ERR(0, 442, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 442, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_create_margin_api_uri") < 0)) __PYX_ERR(0, 442, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_version = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_create_margin_api_uri", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 442, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_margin_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_10_create_margin_api_uri(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_version);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_10_create_margin_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_version) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_margin_api_uri", 1);

  /* "unicorn_binance_rest_api/manager.py":443
 * 
 *     def _create_margin_api_uri(self, path, version=MARGIN_API_VERSION):
 *         return self.MARGIN_API_URL + '/' + version + '/' + path             # <<<<<<<<<<<<<<
 * 
 *     def _create_website_uri(self, path):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_MARGIN_API_URL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_version); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":442
 *         return self.API_URL + '/' + v + '/' + path
 * 
 *     def _create_margin_api_uri(self, path, version=MARGIN_API_VERSION):             # <<<<<<<<<<<<<<
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_margin_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":445
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 *     def _create_website_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.WEBSITE_URL + '/' + path
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_13_create_website_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_13_create_website_uri = {"_create_website_uri", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_13_create_website_uri, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_13_create_website_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_create_website_uri (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 445, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 445, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_create_website_uri", 1, 2, 2, 1); __PYX_ERR(0, 445, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_create_website_uri") < 0)) __PYX_ERR(0, 445, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_create_website_uri", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 445, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_website_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_12_create_website_uri(__pyx_self, __pyx_v_self, __pyx_v_path);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_12_create_website_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_website_uri", 1);

  /* "unicorn_binance_rest_api/manager.py":446
 * 
 *     def _create_website_uri(self, path):
 *         return self.WEBSITE_URL + '/' + path             # <<<<<<<<<<<<<<
 * 
 *     def _create_futures_api_uri(self, path):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_WEBSITE_URL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":445
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 *     def _create_website_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.WEBSITE_URL + '/' + path
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_website_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":448
 *         return self.WEBSITE_URL + '/' + path
 * 
 *     def _create_futures_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_15_create_futures_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_15_create_futures_api_uri = {"_create_futures_api_uri", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_15_create_futures_api_uri, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_15_create_futures_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_create_futures_api_uri (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 448, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 448, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_create_futures_api_uri", 1, 2, 2, 1); __PYX_ERR(0, 448, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_create_futures_api_uri") < 0)) __PYX_ERR(0, 448, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_create_futures_api_uri", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 448, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_14_create_futures_api_uri(__pyx_self, __pyx_v_self, __pyx_v_path);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_14_create_futures_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_futures_api_uri", 1);

  /* "unicorn_binance_rest_api/manager.py":449
 * 
 *     def _create_futures_api_uri(self, path):
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path             # <<<<<<<<<<<<<<
 * 
 *     def _create_futures_data_api_uri(self, path):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_URL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_API_VERSION); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_kp_s__7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":448
 *         return self.WEBSITE_URL + '/' + path
 * 
 *     def _create_futures_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":451
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 *     def _create_futures_data_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_17_create_futures_data_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_17_create_futures_data_api_uri = {"_create_futures_data_api_uri", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_17_create_futures_data_api_uri, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_17_create_futures_data_api_uri(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_create_futures_data_api_uri (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 451, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 451, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_create_futures_data_api_uri", 1, 2, 2, 1); __PYX_ERR(0, 451, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_create_futures_data_api_uri") < 0)) __PYX_ERR(0, 451, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_create_futures_data_api_uri", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 451, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_data_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_16_create_futures_data_api_uri(__pyx_self, __pyx_v_self, __pyx_v_path);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_16_create_futures_data_api_uri(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_futures_data_api_uri", 1);

  /* "unicorn_binance_rest_api/manager.py":452
 * 
 *     def _create_futures_data_api_uri(self, path):
 *         return self.FUTURES_DATA_URL + '/' + path             # <<<<<<<<<<<<<<
 * 
 *     def _create_futures_coin_api_url(self, path, version=1):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_DATA_URL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":451
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 *     def _create_futures_data_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_data_api_uri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":454
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 *     def _create_futures_coin_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         options = {1: self.FUTURES_API_VERSION, 2: self.FUTURES_API_VERSION2}
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_19_create_futures_coin_api_url(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_19_create_futures_coin_api_url = {"_create_futures_coin_api_url", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_19_create_futures_coin_api_url, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_19_create_futures_coin_api_url(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_version = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_create_futures_coin_api_url (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_version,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 454, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 454, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_create_futures_coin_api_url", 0, 2, 3, 1); __PYX_ERR(0, 454, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 454, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_create_futures_coin_api_url") < 0)) __PYX_ERR(0, 454, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_version = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_create_futures_coin_api_url", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 454, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_coin_api_url", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_18_create_futures_coin_api_url(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_version);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_18_create_futures_coin_api_url(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_version) {
  PyObject *__pyx_v_options = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_futures_coin_api_url", 1);

  /* "unicorn_binance_rest_api/manager.py":455
 * 
 *     def _create_futures_coin_api_url(self, path, version=1):
 *         options = {1: self.FUTURES_API_VERSION, 2: self.FUTURES_API_VERSION2}             # <<<<<<<<<<<<<<
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_API_VERSION); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_int_1, __pyx_t_2) < 0) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_API_VERSION2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_int_2, __pyx_t_2) < 0) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_options = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":456
 *     def _create_futures_coin_api_url(self, path, version=1):
 *         options = {1: self.FUTURES_API_VERSION, 2: self.FUTURES_API_VERSION2}
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path             # <<<<<<<<<<<<<<
 * 
 *     def _create_futures_coin_data_api_url(self, path, version=1):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_URL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_options, __pyx_v_version); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_kp_s__7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":454
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 *     def _create_futures_coin_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         options = {1: self.FUTURES_API_VERSION, 2: self.FUTURES_API_VERSION2}
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_coin_api_url", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_options);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":458
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 * 
 *     def _create_futures_coin_data_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         # Todo: version is obsolete?
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_21_create_futures_coin_data_api_url(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_21_create_futures_coin_data_api_url = {"_create_futures_coin_data_api_url", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_21_create_futures_coin_data_api_url, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_21_create_futures_coin_data_api_url(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  CYTHON_UNUSED PyObject *__pyx_v_version = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_create_futures_coin_data_api_url (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_version,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 458, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 458, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_create_futures_coin_data_api_url", 0, 2, 3, 1); __PYX_ERR(0, 458, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 458, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_create_futures_coin_data_api_url") < 0)) __PYX_ERR(0, 458, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_version = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_create_futures_coin_data_api_url", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 458, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_coin_data_api_url", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_20_create_futures_coin_data_api_url(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_version);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_20_create_futures_coin_data_api_url(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, CYTHON_UNUSED PyObject *__pyx_v_version) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_create_futures_coin_data_api_url", 1);

  /* "unicorn_binance_rest_api/manager.py":460
 *     def _create_futures_coin_data_api_url(self, path, version=1):
 *         # Todo: version is obsolete?
 *         return self.FUTURES_COIN_DATA_URL + "/" + path             # <<<<<<<<<<<<<<
 * 
 *     def _generate_signature(self, data):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_FUTURES_COIN_DATA_URL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s__7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":458
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 * 
 *     def _create_futures_coin_data_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         # Todo: version is obsolete?
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._create_futures_coin_data_api_url", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":462
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 * 
 *     def _generate_signature(self, data):             # <<<<<<<<<<<<<<
 * 
 *         ordered_data = self._order_params(data)
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_23_generate_signature(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_23_generate_signature = {"_generate_signature", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_23_generate_signature, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_23_generate_signature(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_data = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_generate_signature (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_data,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 462, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 462, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_generate_signature", 1, 2, 2, 1); __PYX_ERR(0, 462, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_generate_signature") < 0)) __PYX_ERR(0, 462, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_generate_signature", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 462, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._generate_signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_22_generate_signature(__pyx_self, __pyx_v_self, __pyx_v_data);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_22_generate_signature(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_v_ordered_data = NULL;
  PyObject *__pyx_v_query_string = NULL;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_7genexpr__pyx_v_d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_generate_signature", 1);

  /* "unicorn_binance_rest_api/manager.py":464
 *     def _generate_signature(self, data):
 * 
 *         ordered_data = self._order_params(data)             # <<<<<<<<<<<<<<
 *         query_string = '&'.join(["{}={}".format(d[0], d[1]) for d in ordered_data])
 *         m = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_order_params); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_data};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_ordered_data = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":465
 * 
 *         ordered_data = self._order_params(data)
 *         query_string = '&'.join(["{}={}".format(d[0], d[1]) for d in ordered_data])             # <<<<<<<<<<<<<<
 *         m = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256)
 *         return m.hexdigest()
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_ordered_data)) || PyTuple_CheckExact(__pyx_v_ordered_data)) {
      __pyx_t_2 = __pyx_v_ordered_data; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_ordered_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 465, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 465, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 465, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 465, __pyx_L5_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 465, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 465, __pyx_L5_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_6(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 465, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_d, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s__9, __pyx_n_s_format); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 465, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_7genexpr__pyx_v_d, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 465, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_7genexpr__pyx_v_d, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 465, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_8, __pyx_t_9};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 465, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_d); __pyx_7genexpr__pyx_v_d = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_d); __pyx_7genexpr__pyx_v_d = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_t_2 = __Pyx_PyString_Join(__pyx_kp_s__8, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_query_string = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":466
 *         ordered_data = self._order_params(data)
 *         query_string = '&'.join(["{}={}".format(d[0], d[1]) for d in ordered_data])
 *         m = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256)             # <<<<<<<<<<<<<<
 *         return m.hexdigest()
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_hmac); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_API_SECRET); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_encode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_kp_s_utf_8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_query_string, __pyx_n_s_encode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_s_utf_8};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_hashlib); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_sha256); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_1, __pyx_t_9, __pyx_t_8};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_m = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":467
 *         query_string = '&'.join(["{}={}".format(d[0], d[1]) for d in ordered_data])
 *         m = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256)
 *         return m.hexdigest()             # <<<<<<<<<<<<<<
 * 
 *     def _order_params(self, data):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_m, __pyx_n_s_hexdigest); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":462
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 * 
 *     def _generate_signature(self, data):             # <<<<<<<<<<<<<<
 * 
 *         ordered_data = self._order_params(data)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._generate_signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ordered_data);
  __Pyx_XDECREF(__pyx_v_query_string);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":469
 *         return m.hexdigest()
 * 
 *     def _order_params(self, data):             # <<<<<<<<<<<<<<
 *         """
 *         Convert params to list with signature as last element
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_25_order_params(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_24_order_params, "\n        Convert params to list with signature as last element\n\n        :param data:\n        :return:\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_25_order_params = {"_order_params", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_25_order_params, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_24_order_params};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_25_order_params(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_data = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_order_params (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_data,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 469, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_data)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 469, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_order_params", 1, 2, 2, 1); __PYX_ERR(0, 469, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_order_params") < 0)) __PYX_ERR(0, 469, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_order_params", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 469, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._order_params", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_24_order_params(__pyx_self, __pyx_v_self, __pyx_v_data);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_24_order_params(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  int __pyx_v_has_signature;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_order_params", 1);

  /* "unicorn_binance_rest_api/manager.py":477
 * 
 *         """
 *         has_signature = False             # <<<<<<<<<<<<<<
 *         params = []
 *         for key, value in data.items():
 */
  __pyx_v_has_signature = 0;

  /* "unicorn_binance_rest_api/manager.py":478
 *         """
 *         has_signature = False
 *         params = []             # <<<<<<<<<<<<<<
 *         for key, value in data.items():
 *             if key == 'signature':
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":479
 *         has_signature = False
 *         params = []
 *         for key, value in data.items():             # <<<<<<<<<<<<<<
 *             if key == 'signature':
 *                 has_signature = True
 */
  __pyx_t_2 = 0;
  if (unlikely(__pyx_v_data == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 479, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_data, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "unicorn_binance_rest_api/manager.py":480
 *         params = []
 *         for key, value in data.items():
 *             if key == 'signature':             # <<<<<<<<<<<<<<
 *                 has_signature = True
 *             else:
 */
    __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_v_key, __pyx_n_s_signature, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 480, __pyx_L1_error)
    if (__pyx_t_8) {

      /* "unicorn_binance_rest_api/manager.py":481
 *         for key, value in data.items():
 *             if key == 'signature':
 *                 has_signature = True             # <<<<<<<<<<<<<<
 *             else:
 *                 params.append((key, value))
 */
      __pyx_v_has_signature = 1;

      /* "unicorn_binance_rest_api/manager.py":480
 *         params = []
 *         for key, value in data.items():
 *             if key == 'signature':             # <<<<<<<<<<<<<<
 *                 has_signature = True
 *             else:
 */
      goto __pyx_L5;
    }

    /* "unicorn_binance_rest_api/manager.py":483
 *                 has_signature = True
 *             else:
 *                 params.append((key, value))             # <<<<<<<<<<<<<<
 *         # sort parameters by key
 *         params.sort(key=itemgetter(0))
 */
    /*else*/ {
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_key)) __PYX_ERR(0, 483, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_value)) __PYX_ERR(0, 483, __pyx_L1_error);
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_params, __pyx_t_6); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 483, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L5:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":485
 *                 params.append((key, value))
 *         # sort parameters by key
 *         params.sort(key=itemgetter(0))             # <<<<<<<<<<<<<<
 *         if has_signature:
 *             params.append(('signature', data['signature']))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_params, __pyx_n_s_sort); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_itemgetter); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_11 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_int_0};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_key, __pyx_t_5) < 0) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "unicorn_binance_rest_api/manager.py":486
 *         # sort parameters by key
 *         params.sort(key=itemgetter(0))
 *         if has_signature:             # <<<<<<<<<<<<<<
 *             params.append(('signature', data['signature']))
 *         return params
 */
  if (__pyx_v_has_signature) {

    /* "unicorn_binance_rest_api/manager.py":487
 *         params.sort(key=itemgetter(0))
 *         if has_signature:
 *             params.append(('signature', data['signature']))             # <<<<<<<<<<<<<<
 *         return params
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_data, __pyx_n_s_signature); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_n_s_signature);
    __Pyx_GIVEREF(__pyx_n_s_signature);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_n_s_signature)) __PYX_ERR(0, 487, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5)) __PYX_ERR(0, 487, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_params, __pyx_t_6); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "unicorn_binance_rest_api/manager.py":486
 *         # sort parameters by key
 *         params.sort(key=itemgetter(0))
 *         if has_signature:             # <<<<<<<<<<<<<<
 *             params.append(('signature', data['signature']))
 *         return params
 */
  }

  /* "unicorn_binance_rest_api/manager.py":488
 *         if has_signature:
 *             params.append(('signature', data['signature']))
 *         return params             # <<<<<<<<<<<<<<
 * 
 *     def _request(self, method, uri, signed, force_params=False, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_params);
  __pyx_r = __pyx_v_params;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":469
 *         return m.hexdigest()
 * 
 *     def _order_params(self, data):             # <<<<<<<<<<<<<<
 *         """
 *         Convert params to list with signature as last element
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._order_params", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":490
 *         return params
 * 
 *     def _request(self, method, uri, signed, force_params=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 * 
 *         # set default requests timeout
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_27_request(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_27_request = {"_request", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_27_request, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_27_request(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_uri = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_force_params = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_uri,&__pyx_n_s_signed,&__pyx_n_s_force_params,&__pyx_n_s_throw_exception,0};
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request", 0, 4, 6, 1); __PYX_ERR(0, 490, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uri)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request", 0, 4, 6, 2); __PYX_ERR(0, 490, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request", 0, 4, 6, 3); __PYX_ERR(0, 490, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_force_params);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 490, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request") < 0)) __PYX_ERR(0, 490, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_uri = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_force_params = values[4];
    __pyx_v_throw_exception = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request", 0, 4, 6, __pyx_nargs); __PYX_ERR(0, 490, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_26_request(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_uri, __pyx_v_signed, __pyx_v_force_params, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_2generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "unicorn_binance_rest_api/manager.py":525
 *         # if get request assign data array to params value for requests lib
 *         if data and (method == 'get' or force_params):
 *             kwargs['params'] = '&'.join('%s=%s' % (data[0], data[1]) for data in kwargs['data'])             # <<<<<<<<<<<<<<
 *             del(kwargs['data'])
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *)__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr(__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 525, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_2generator2, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_BinanceRestApiManager__request_l, __pyx_n_s_unicorn_binance_rest_api_manager); if (unlikely(!gen)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_2generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *__pyx_cur_scope = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 525, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 525, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 525, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 525, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 525, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 525, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 525, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 525, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 525, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 525, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_data);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_data, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_data, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_data, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4)) __PYX_ERR(0, 525, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5)) __PYX_ERR(0, 525, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_s_s, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 525, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":490
 *         return params
 * 
 *     def _request(self, method, uri, signed, force_params=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 * 
 *         # set default requests timeout
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_26_request(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_uri, PyObject *__pyx_v_signed, PyObject *__pyx_v_force_params, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_null_args = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_i = NULL;
  CYTHON_UNUSED PyObject *__pyx_8genexpr1__pyx_v_key = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_value = NULL;
  PyObject *__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_2generator2 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request", 1);

  /* "unicorn_binance_rest_api/manager.py":493
 * 
 *         # set default requests timeout
 *         kwargs['timeout'] = 10             # <<<<<<<<<<<<<<
 * 
 *         # add our global requests params
 */
  if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_s_timeout, __pyx_int_10) < 0))) __PYX_ERR(0, 493, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":496
 * 
 *         # add our global requests params
 *         if self._requests_params:             # <<<<<<<<<<<<<<
 *             kwargs.update(self._requests_params)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_requests_params_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "unicorn_binance_rest_api/manager.py":497
 *         # add our global requests params
 *         if self._requests_params:
 *             kwargs.update(self._requests_params)             # <<<<<<<<<<<<<<
 * 
 *         data = kwargs.get('data', None)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_requests_params_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_kwargs, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":496
 * 
 *         # add our global requests params
 *         if self._requests_params:             # <<<<<<<<<<<<<<
 *             kwargs.update(self._requests_params)
 * 
 */
  }

  /* "unicorn_binance_rest_api/manager.py":499
 *             kwargs.update(self._requests_params)
 * 
 *         data = kwargs.get('data', None)             # <<<<<<<<<<<<<<
 *         if data and isinstance(data, dict):
 *             kwargs['data'] = data
 */
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_s_data, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_data = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":500
 * 
 *         data = kwargs.get('data', None)
 *         if data and isinstance(data, dict):             # <<<<<<<<<<<<<<
 *             kwargs['data'] = data
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 500, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = PyDict_Check(__pyx_v_data); 
  __pyx_t_2 = __pyx_t_4;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_2) {

    /* "unicorn_binance_rest_api/manager.py":501
 *         data = kwargs.get('data', None)
 *         if data and isinstance(data, dict):
 *             kwargs['data'] = data             # <<<<<<<<<<<<<<
 * 
 *             # find any requests params passed and apply them
 */
    if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_s_data, __pyx_v_data) < 0))) __PYX_ERR(0, 501, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":504
 * 
 *             # find any requests params passed and apply them
 *             if 'requests_params' in kwargs['data']:             # <<<<<<<<<<<<<<
 *                 # merge requests params into kwargs
 *                 kwargs.update(kwargs['data']['requests_params'])
 */
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_requests_params, __pyx_t_3, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "unicorn_binance_rest_api/manager.py":506
 *             if 'requests_params' in kwargs['data']:
 *                 # merge requests params into kwargs
 *                 kwargs.update(kwargs['data']['requests_params'])             # <<<<<<<<<<<<<<
 *                 del(kwargs['data']['requests_params'])
 * 
 */
      __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_requests_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 506, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_kwargs, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":507
 *                 # merge requests params into kwargs
 *                 kwargs.update(kwargs['data']['requests_params'])
 *                 del(kwargs['data']['requests_params'])             # <<<<<<<<<<<<<<
 * 
 *         if signed:
 */
      __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 507, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely((PyObject_DelItem(__pyx_t_3, __pyx_n_s_requests_params) < 0))) __PYX_ERR(0, 507, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":504
 * 
 *             # find any requests params passed and apply them
 *             if 'requests_params' in kwargs['data']:             # <<<<<<<<<<<<<<
 *                 # merge requests params into kwargs
 *                 kwargs.update(kwargs['data']['requests_params'])
 */
    }

    /* "unicorn_binance_rest_api/manager.py":500
 * 
 *         data = kwargs.get('data', None)
 *         if data and isinstance(data, dict):             # <<<<<<<<<<<<<<
 *             kwargs['data'] = data
 * 
 */
  }

  /* "unicorn_binance_rest_api/manager.py":509
 *                 del(kwargs['data']['requests_params'])
 * 
 *         if signed:             # <<<<<<<<<<<<<<
 *             # generate signature
 *             kwargs['data']['timestamp'] = int(time.time() * 1000 + self.timestamp_offset)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_signed); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 509, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "unicorn_binance_rest_api/manager.py":511
 *         if signed:
 *             # generate signature
 *             kwargs['data']['timestamp'] = int(time.time() * 1000 + self.timestamp_offset)             # <<<<<<<<<<<<<<
 *             kwargs['data']['signature'] = self._generate_signature(kwargs['data'])
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyInt_MultiplyObjC(__pyx_t_3, __pyx_int_1000, 0x3E8, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_timestamp_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyNumber_Add(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_n_s_timestamp, __pyx_t_3) < 0))) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":512
 *             # generate signature
 *             kwargs['data']['timestamp'] = int(time.time() * 1000 + self.timestamp_offset)
 *             kwargs['data']['signature'] = self._generate_signature(kwargs['data'])             # <<<<<<<<<<<<<<
 * 
 *         # sort get and post params to match signature order
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_generate_signature); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_n_s_signature, __pyx_t_3) < 0))) __PYX_ERR(0, 512, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":509
 *                 del(kwargs['data']['requests_params'])
 * 
 *         if signed:             # <<<<<<<<<<<<<<
 *             # generate signature
 *             kwargs['data']['timestamp'] = int(time.time() * 1000 + self.timestamp_offset)
 */
  }

  /* "unicorn_binance_rest_api/manager.py":515
 * 
 *         # sort get and post params to match signature order
 *         if data:             # <<<<<<<<<<<<<<
 *             # sort post params
 *             kwargs['data'] = self._order_params(kwargs['data'])
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 515, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "unicorn_binance_rest_api/manager.py":517
 *         if data:
 *             # sort post params
 *             kwargs['data'] = self._order_params(kwargs['data'])             # <<<<<<<<<<<<<<
 *             # Remove any arguments with values of None.
 *             null_args = [i for i, (key, value) in enumerate(kwargs['data']) if value is None]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_order_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_s_data, __pyx_t_3) < 0))) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":519
 *             kwargs['data'] = self._order_params(kwargs['data'])
 *             # Remove any arguments with values of None.
 *             null_args = [i for i, (key, value) in enumerate(kwargs['data']) if value is None]             # <<<<<<<<<<<<<<
 *             for i in reversed(null_args):
 *                 del kwargs['data'][i]
 */
    { /* enter inner scope */
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 519, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_int_0);
      __pyx_t_1 = __pyx_int_0;
      __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 519, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
        __pyx_t_7 = __pyx_t_5; __Pyx_INCREF(__pyx_t_7);
        __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 519, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 519, __pyx_L12_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_7))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 519, __pyx_L12_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_8); __Pyx_INCREF(__pyx_t_5); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 519, __pyx_L12_error)
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 519, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 519, __pyx_L12_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_8); __Pyx_INCREF(__pyx_t_5); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 519, __pyx_L12_error)
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 519, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          }
        } else {
          __pyx_t_5 = __pyx_t_9(__pyx_t_7);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 519, __pyx_L12_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_5);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
          PyObject* sequence = __pyx_t_5;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 519, __pyx_L12_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_10 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_11 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          #else
          __pyx_t_10 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 519, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 519, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_11);
          #endif
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_12 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 519, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_12);
          index = 0; __pyx_t_10 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_10)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_10);
          index = 1; __pyx_t_11 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_11)) goto __pyx_L15_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_11);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_12), 2) < 0) __PYX_ERR(0, 519, __pyx_L12_error)
          __pyx_t_13 = NULL;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          goto __pyx_L16_unpacking_done;
          __pyx_L15_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_13 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 519, __pyx_L12_error)
          __pyx_L16_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_key, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_value, __pyx_t_11);
        __pyx_t_11 = 0;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_i, __pyx_t_1);
        __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 519, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1);
        __pyx_t_1 = __pyx_t_5;
        __pyx_t_5 = 0;
        __pyx_t_2 = (__pyx_8genexpr1__pyx_v_value == Py_None);
        if (__pyx_t_2) {
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_8genexpr1__pyx_v_i))) __PYX_ERR(0, 519, __pyx_L12_error)
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_i); __pyx_8genexpr1__pyx_v_i = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_value); __pyx_8genexpr1__pyx_v_value = 0;
      goto __pyx_L19_exit_scope;
      __pyx_L12_error:;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_i); __pyx_8genexpr1__pyx_v_i = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
      __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_value); __pyx_8genexpr1__pyx_v_value = 0;
      goto __pyx_L1_error;
      __pyx_L19_exit_scope:;
    } /* exit inner scope */
    __pyx_v_null_args = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":520
 *             # Remove any arguments with values of None.
 *             null_args = [i for i, (key, value) in enumerate(kwargs['data']) if value is None]
 *             for i in reversed(null_args):             # <<<<<<<<<<<<<<
 *                 del kwargs['data'][i]
 * 
 */
    __pyx_t_3 = __pyx_v_null_args; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyList_GET_SIZE(__pyx_t_3);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 520, __pyx_L1_error)
    #endif
    --__pyx_t_8;
    for (;;) {
      if (__pyx_t_8 < 0) break;
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 520, __pyx_L1_error)
        #endif
        if (__pyx_t_8 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8--; if (unlikely((0 < 0))) __PYX_ERR(0, 520, __pyx_L1_error)
      #else
      __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8--; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "unicorn_binance_rest_api/manager.py":521
 *             null_args = [i for i, (key, value) in enumerate(kwargs['data']) if value is None]
 *             for i in reversed(null_args):
 *                 del kwargs['data'][i]             # <<<<<<<<<<<<<<
 * 
 *         # if get request assign data array to params value for requests lib
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 521, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely((PyObject_DelItem(__pyx_t_1, __pyx_v_i) < 0))) __PYX_ERR(0, 521, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "unicorn_binance_rest_api/manager.py":520
 *             # Remove any arguments with values of None.
 *             null_args = [i for i, (key, value) in enumerate(kwargs['data']) if value is None]
 *             for i in reversed(null_args):             # <<<<<<<<<<<<<<
 *                 del kwargs['data'][i]
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":515
 * 
 *         # sort get and post params to match signature order
 *         if data:             # <<<<<<<<<<<<<<
 *             # sort post params
 *             kwargs['data'] = self._order_params(kwargs['data'])
 */
  }

  /* "unicorn_binance_rest_api/manager.py":524
 * 
 *         # if get request assign data array to params value for requests lib
 *         if data and (method == 'get' or force_params):             # <<<<<<<<<<<<<<
 *             kwargs['params'] = '&'.join('%s=%s' % (data[0], data[1]) for data in kwargs['data'])
 *             del(kwargs['data'])
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 524, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L24_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_method, __pyx_n_s_get, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 524, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L24_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_force_params); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 524, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L24_bool_binop_done:;
  if (__pyx_t_2) {

    /* "unicorn_binance_rest_api/manager.py":525
 *         # if get request assign data array to params value for requests lib
 *         if data and (method == 'get' or force_params):
 *             kwargs['params'] = '&'.join('%s=%s' % (data[0], data[1]) for data in kwargs['data'])             # <<<<<<<<<<<<<<
 *             del(kwargs['data'])
 * 
 */
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_kwargs, __pyx_n_s_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_genexpr(NULL, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyString_Join(__pyx_kp_s__8, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_s_params, __pyx_t_3) < 0))) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":526
 *         if data and (method == 'get' or force_params):
 *             kwargs['params'] = '&'.join('%s=%s' % (data[0], data[1]) for data in kwargs['data'])
 *             del(kwargs['data'])             # <<<<<<<<<<<<<<
 * 
 *         if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 */
    if (unlikely((PyDict_DelItem(__pyx_v_kwargs, __pyx_n_s_data) < 0))) __PYX_ERR(0, 526, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":524
 * 
 *         # if get request assign data array to params value for requests lib
 *         if data and (method == 'get' or force_params):             # <<<<<<<<<<<<<<
 *             kwargs['params'] = '&'.join('%s=%s' % (data[0], data[1]) for data in kwargs['data'])
 *             del(kwargs['data'])
 */
  }

  /* "unicorn_binance_rest_api/manager.py":528
 *             del(kwargs['data'])
 * 
 *         if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:             # <<<<<<<<<<<<<<
 *             self.response = getattr(self.session, method)(uri,
 *                                                           proxies=self.request_socks5_proxies,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_address); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L28_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_port); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __pyx_t_4;
  __pyx_L28_bool_binop_done:;
  if (__pyx_t_2) {

    /* "unicorn_binance_rest_api/manager.py":529
 * 
 *         if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *             self.response = getattr(self.session, method)(uri,             # <<<<<<<<<<<<<<
 *                                                           proxies=self.request_socks5_proxies,
 *                                                           verify=self.socks5_proxy_ssl_verification,
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_GetAttr(__pyx_t_3, __pyx_v_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_uri);
    __Pyx_GIVEREF(__pyx_v_uri);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_uri)) __PYX_ERR(0, 529, __pyx_L1_error);

    /* "unicorn_binance_rest_api/manager.py":530
 *         if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *             self.response = getattr(self.session, method)(uri,
 *                                                           proxies=self.request_socks5_proxies,             # <<<<<<<<<<<<<<
 *                                                           verify=self.socks5_proxy_ssl_verification,
 *                                                           **kwargs)
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 530, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_socks5_proxies); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 530, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_proxies, __pyx_t_11) < 0) __PYX_ERR(0, 530, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "unicorn_binance_rest_api/manager.py":531
 *             self.response = getattr(self.session, method)(uri,
 *                                                           proxies=self.request_socks5_proxies,
 *                                                           verify=self.socks5_proxy_ssl_verification,             # <<<<<<<<<<<<<<
 *                                                           **kwargs)
 *         else:
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_ssl_verification); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_verify, __pyx_t_11) < 0) __PYX_ERR(0, 530, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_7 = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "unicorn_binance_rest_api/manager.py":532
 *                                                           proxies=self.request_socks5_proxies,
 *                                                           verify=self.socks5_proxy_ssl_verification,
 *                                                           **kwargs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.response = getattr(self.session, method)(uri, **kwargs)
 */
    if (__Pyx_MergeKeywords(__pyx_t_7, __pyx_v_kwargs) < 0) __PYX_ERR(0, 532, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":529
 * 
 *         if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *             self.response = getattr(self.session, method)(uri,             # <<<<<<<<<<<<<<
 *                                                           proxies=self.request_socks5_proxies,
 *                                                           verify=self.socks5_proxy_ssl_verification,
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_response, __pyx_t_5) < 0) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "unicorn_binance_rest_api/manager.py":528
 *             del(kwargs['data'])
 * 
 *         if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:             # <<<<<<<<<<<<<<
 *             self.response = getattr(self.session, method)(uri,
 *                                                           proxies=self.request_socks5_proxies,
 */
    goto __pyx_L27;
  }

  /* "unicorn_binance_rest_api/manager.py":534
 *                                                           **kwargs)
 *         else:
 *             self.response = getattr(self.session, method)(uri, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *         return self._handle_response(throw_exception=throw_exception)
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_session); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_GetAttr(__pyx_t_5, __pyx_v_method); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_uri);
    __Pyx_GIVEREF(__pyx_v_uri);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_uri)) __PYX_ERR(0, 534, __pyx_L1_error);
    __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_response, __pyx_t_1) < 0) __PYX_ERR(0, 534, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L27:;

  /* "unicorn_binance_rest_api/manager.py":536
 *             self.response = getattr(self.session, method)(uri, **kwargs)
 * 
 *         return self._handle_response(throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     def _request_api(self, method, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_handle_response); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 536, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":490
 *         return params
 * 
 *     def _request(self, method, uri, signed, force_params=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 * 
 *         # set default requests timeout
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_null_args);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_i);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_value);
  __Pyx_XDECREF(__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_8_request_2generator2);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":538
 *         return self._handle_response(throw_exception=throw_exception)
 * 
 *     def _request_api(self, method, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_api_uri(path, signed, version)
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_4__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_False))) __PYX_ERR(0, 538, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 538, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)Py_True))) __PYX_ERR(0, 538, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 538, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_29_request_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_29_request_api = {"_request_api", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_29_request_api, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_29_request_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request_api (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,&__pyx_n_s_throw_exception,0};
    __pyx_defaults2 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self);
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 538, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 538, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_api", 0, 3, 6, 1); __PYX_ERR(0, 538, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 538, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_api", 0, 3, 6, 2); __PYX_ERR(0, 538, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 538, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 538, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 538, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request_api") < 0)) __PYX_ERR(0, 538, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_path = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_version = values[4];
    __pyx_v_throw_exception = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request_api", 0, 3, 6, __pyx_nargs); __PYX_ERR(0, 538, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_28_request_api(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_28_request_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_uri = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request_api", 1);

  /* "unicorn_binance_rest_api/manager.py":539
 * 
 *     def _request_api(self, method, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):
 *         uri = self._create_api_uri(path, signed, version)             # <<<<<<<<<<<<<<
 * 
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_api_uri); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_v_path, __pyx_v_signed, __pyx_v_version};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_uri = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":541
 *         uri = self._create_api_uri(path, signed, version)
 * 
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _request_margin_api(self, method, path, signed=False,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_method);
  __Pyx_GIVEREF(__pyx_v_method);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_method)) __PYX_ERR(0, 541, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_uri);
  __Pyx_GIVEREF(__pyx_v_uri);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_uri)) __PYX_ERR(0, 541, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 541, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 541, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_t_5 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_3, __pyx_v_kwargs) < 0) __PYX_ERR(0, 541, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":538
 *         return self._handle_response(throw_exception=throw_exception)
 * 
 *     def _request_api(self, method, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_api_uri(path, signed, version)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_uri);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":543
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_margin_api(self, method, path, signed=False,             # <<<<<<<<<<<<<<
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):
 *         uri = self._create_margin_api_uri(path, version)
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_6__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);

  /* "unicorn_binance_rest_api/manager.py":544
 * 
 *     def _request_margin_api(self, method, path, signed=False,
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_margin_api_uri(path, version)
 * 
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_False))) __PYX_ERR(0, 543, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 543, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)Py_True))) __PYX_ERR(0, 543, __pyx_L1_error);

  /* "unicorn_binance_rest_api/manager.py":543
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_margin_api(self, method, path, signed=False,             # <<<<<<<<<<<<<<
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):
 *         uri = self._create_margin_api_uri(path, version)
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 543, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_31_request_margin_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_31_request_margin_api = {"_request_margin_api", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_31_request_margin_api, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_31_request_margin_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request_margin_api (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,&__pyx_n_s_throw_exception,0};
    __pyx_defaults3 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self);
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 543, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 543, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_margin_api", 0, 3, 6, 1); __PYX_ERR(0, 543, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 543, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_margin_api", 0, 3, 6, 2); __PYX_ERR(0, 543, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 543, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 543, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 543, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request_margin_api") < 0)) __PYX_ERR(0, 543, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_path = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_version = values[4];
    __pyx_v_throw_exception = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request_margin_api", 0, 3, 6, __pyx_nargs); __PYX_ERR(0, 543, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_margin_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_30_request_margin_api(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_30_request_margin_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_uri = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request_margin_api", 1);

  /* "unicorn_binance_rest_api/manager.py":545
 *     def _request_margin_api(self, method, path, signed=False,
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):
 *         uri = self._create_margin_api_uri(path, version)             # <<<<<<<<<<<<<<
 * 
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_margin_api_uri); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_path, __pyx_v_version};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_uri = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":547
 *         uri = self._create_margin_api_uri(path, version)
 * 
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _request_website(self, method, path, signed=False, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_method);
  __Pyx_GIVEREF(__pyx_v_method);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_method)) __PYX_ERR(0, 547, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_uri);
  __Pyx_GIVEREF(__pyx_v_uri);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_uri)) __PYX_ERR(0, 547, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 547, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_t_5 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_3, __pyx_v_kwargs) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":543
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_margin_api(self, method, path, signed=False,             # <<<<<<<<<<<<<<
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):
 *         uri = self._create_margin_api_uri(path, version)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_margin_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_uri);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":549
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_website(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_website_uri(path)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_33_request_website(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_33_request_website = {"_request_website", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_33_request_website, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_33_request_website(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request_website (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_throw_exception,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 549, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 549, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_website", 0, 3, 5, 1); __PYX_ERR(0, 549, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 549, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_website", 0, 3, 5, 2); __PYX_ERR(0, 549, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 549, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 549, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request_website") < 0)) __PYX_ERR(0, 549, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_path = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_throw_exception = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request_website", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 549, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_website", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_32_request_website(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_path, __pyx_v_signed, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_32_request_website(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_uri = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request_website", 1);

  /* "unicorn_binance_rest_api/manager.py":550
 * 
 *     def _request_website(self, method, path, signed=False, throw_exception=True, **kwargs):
 *         uri = self._create_website_uri(path)             # <<<<<<<<<<<<<<
 * 
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_website_uri); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_uri = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":552
 *         uri = self._create_website_uri(path)
 * 
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _request_futures_api(self, method, path, signed=False, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_method);
  __Pyx_GIVEREF(__pyx_v_method);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_method)) __PYX_ERR(0, 552, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_uri);
  __Pyx_GIVEREF(__pyx_v_uri);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_uri)) __PYX_ERR(0, 552, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 552, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 552, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_t_5 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_3, __pyx_v_kwargs) < 0) __PYX_ERR(0, 552, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":549
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_website(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_website_uri(path)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_website", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_uri);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":554
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_api_uri(path)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_35_request_futures_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_35_request_futures_api = {"_request_futures_api", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_35_request_futures_api, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_35_request_futures_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request_futures_api (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_throw_exception,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 554, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 554, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_api", 0, 3, 5, 1); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 554, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_api", 0, 3, 5, 2); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 554, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request_futures_api") < 0)) __PYX_ERR(0, 554, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_path = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_throw_exception = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request_futures_api", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 554, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_34_request_futures_api(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_path, __pyx_v_signed, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_34_request_futures_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_uri = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request_futures_api", 1);

  /* "unicorn_binance_rest_api/manager.py":555
 * 
 *     def _request_futures_api(self, method, path, signed=False, throw_exception=True, **kwargs):
 *         uri = self._create_futures_api_uri(path)             # <<<<<<<<<<<<<<
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_futures_api_uri); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_uri = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":557
 *         uri = self._create_futures_api_uri(path)
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _request_futures_data_api(self, method, path, signed=False, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_method);
  __Pyx_GIVEREF(__pyx_v_method);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_method)) __PYX_ERR(0, 557, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_uri);
  __Pyx_GIVEREF(__pyx_v_uri);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_uri)) __PYX_ERR(0, 557, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 557, __pyx_L1_error);
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, Py_True)) __PYX_ERR(0, 557, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 557, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_t_5 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_3, __pyx_v_kwargs) < 0) __PYX_ERR(0, 557, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":554
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_api_uri(path)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_uri);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":559
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_data_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_data_api_uri(path)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_37_request_futures_data_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_37_request_futures_data_api = {"_request_futures_data_api", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_37_request_futures_data_api, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_37_request_futures_data_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request_futures_data_api (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_throw_exception,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 559, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 559, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_data_api", 0, 3, 5, 1); __PYX_ERR(0, 559, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 559, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_data_api", 0, 3, 5, 2); __PYX_ERR(0, 559, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 559, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 559, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request_futures_data_api") < 0)) __PYX_ERR(0, 559, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_path = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_throw_exception = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request_futures_data_api", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 559, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_data_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_36_request_futures_data_api(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_path, __pyx_v_signed, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_36_request_futures_data_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_uri = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request_futures_data_api", 1);

  /* "unicorn_binance_rest_api/manager.py":560
 * 
 *     def _request_futures_data_api(self, method, path, signed=False, throw_exception=True, **kwargs):
 *         uri = self._create_futures_data_api_uri(path)             # <<<<<<<<<<<<<<
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_futures_data_api_uri); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 560, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_uri = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":562
 *         uri = self._create_futures_data_api_uri(path)
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _request_futures_coin_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_method);
  __Pyx_GIVEREF(__pyx_v_method);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_method)) __PYX_ERR(0, 562, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_uri);
  __Pyx_GIVEREF(__pyx_v_uri);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_uri)) __PYX_ERR(0, 562, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 562, __pyx_L1_error);
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, Py_True)) __PYX_ERR(0, 562, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 562, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_t_5 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_3, __pyx_v_kwargs) < 0) __PYX_ERR(0, 562, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":559
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_data_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_data_api_uri(path)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_data_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_uri);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":564
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_api_url(path, version=version)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_39_request_futures_coin_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_39_request_futures_coin_api = {"_request_futures_coin_api", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_39_request_futures_coin_api, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_39_request_futures_coin_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request_futures_coin_api (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,&__pyx_n_s_throw_exception,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_coin_api", 0, 3, 6, 1); __PYX_ERR(0, 564, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_coin_api", 0, 3, 6, 2); __PYX_ERR(0, 564, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 564, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request_futures_coin_api") < 0)) __PYX_ERR(0, 564, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_path = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_version = values[4];
    __pyx_v_throw_exception = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request_futures_coin_api", 0, 3, 6, __pyx_nargs); __PYX_ERR(0, 564, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_coin_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_38_request_futures_coin_api(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_38_request_futures_coin_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_uri = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request_futures_coin_api", 1);

  /* "unicorn_binance_rest_api/manager.py":565
 * 
 *     def _request_futures_coin_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):
 *         uri = self._create_futures_coin_api_url(path, version=version)             # <<<<<<<<<<<<<<
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_futures_coin_api_url); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_GIVEREF(__pyx_v_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_path)) __PYX_ERR(0, 565, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_version, __pyx_v_version) < 0) __PYX_ERR(0, 565, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_uri = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "unicorn_binance_rest_api/manager.py":567
 *         uri = self._create_futures_coin_api_url(path, version=version)
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _request_futures_coin_data_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_method);
  __Pyx_GIVEREF(__pyx_v_method);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_method)) __PYX_ERR(0, 567, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_uri);
  __Pyx_GIVEREF(__pyx_v_uri);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_uri)) __PYX_ERR(0, 567, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_signed)) __PYX_ERR(0, 567, __pyx_L1_error);
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, Py_True)) __PYX_ERR(0, 567, __pyx_L1_error);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 567, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __pyx_t_1 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_2, __pyx_v_kwargs) < 0) __PYX_ERR(0, 567, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":564
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_api_url(path, version=version)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_coin_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_uri);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":569
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_data_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_data_api_url(path, version=version)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_41_request_futures_coin_data_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_41_request_futures_coin_data_api = {"_request_futures_coin_data_api", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_41_request_futures_coin_data_api, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_41_request_futures_coin_data_api(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_method = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_request_futures_coin_data_api (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_method,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,&__pyx_n_s_throw_exception,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_1)));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 569, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_method)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 569, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_coin_data_api", 0, 3, 6, 1); __PYX_ERR(0, 569, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 569, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_request_futures_coin_data_api", 0, 3, 6, 2); __PYX_ERR(0, 569, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 569, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 569, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 569, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_request_futures_coin_data_api") < 0)) __PYX_ERR(0, 569, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_method = values[1];
    __pyx_v_path = values[2];
    __pyx_v_signed = values[3];
    __pyx_v_version = values[4];
    __pyx_v_throw_exception = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_request_futures_coin_data_api", 0, 3, 6, __pyx_nargs); __PYX_ERR(0, 569, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_coin_data_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_40_request_futures_coin_data_api(__pyx_self, __pyx_v_self, __pyx_v_method, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_40_request_futures_coin_data_api(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_method, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_uri = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_request_futures_coin_data_api", 1);

  /* "unicorn_binance_rest_api/manager.py":570
 * 
 *     def _request_futures_coin_data_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):
 *         uri = self._create_futures_coin_data_api_url(path, version=version)             # <<<<<<<<<<<<<<
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_futures_coin_data_api_ur); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_GIVEREF(__pyx_v_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_path)) __PYX_ERR(0, 570, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_version, __pyx_v_version) < 0) __PYX_ERR(0, 570, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_uri = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "unicorn_binance_rest_api/manager.py":572
 *         uri = self._create_futures_coin_data_api_url(path, version=version)
 * 
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _handle_response(self, throw_exception=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_method);
  __Pyx_GIVEREF(__pyx_v_method);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_method)) __PYX_ERR(0, 572, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_uri);
  __Pyx_GIVEREF(__pyx_v_uri);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_uri)) __PYX_ERR(0, 572, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_signed)) __PYX_ERR(0, 572, __pyx_L1_error);
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, Py_True)) __PYX_ERR(0, 572, __pyx_L1_error);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 572, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __pyx_t_1 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_2, __pyx_v_kwargs) < 0) __PYX_ERR(0, 572, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":569
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_data_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_data_api_url(path, version=version)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._request_futures_coin_data_api", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_uri);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":574
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _handle_response(self, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """
 *         Internal helper for handling API responses from the Binance server.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_43_handle_response(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_42_handle_response, "\n        Internal helper for handling API responses from the Binance server.\n        Raises the appropriate exceptions when necessary; otherwise, returns the\n        response.\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_43_handle_response = {"_handle_response", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_43_handle_response, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_42_handle_response};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_43_handle_response(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_handle_response (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_throw_exception,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 574, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 574, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_handle_response") < 0)) __PYX_ERR(0, 574, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_throw_exception = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_handle_response", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 574, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._handle_response", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_42_handle_response(__pyx_self, __pyx_v_self, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_42_handle_response(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_handle_response", 1);

  /* "unicorn_binance_rest_api/manager.py":581
 * 
 *         """
 *         if throw_exception is True:             # <<<<<<<<<<<<<<
 *             if not (200 <= self.response.status_code < 300):
 *                 raise BinanceAPIException(self.response)
 */
  __pyx_t_1 = (__pyx_v_throw_exception == Py_True);
  if (__pyx_t_1) {

    /* "unicorn_binance_rest_api/manager.py":582
 *         """
 *         if throw_exception is True:
 *             if not (200 <= self.response.status_code < 300):             # <<<<<<<<<<<<<<
 *                 raise BinanceAPIException(self.response)
 *         try:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_response); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_status_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_RichCompare(__pyx_int_200, __pyx_t_3, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 582, __pyx_L1_error)
    if (__Pyx_PyObject_IsTrue(__pyx_t_2)) {
      __Pyx_DECREF(__pyx_t_2);
      __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, __pyx_int_300, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 582, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 582, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = (!__pyx_t_1);
    if (unlikely(__pyx_t_4)) {

      /* "unicorn_binance_rest_api/manager.py":583
 *         if throw_exception is True:
 *             if not (200 <= self.response.status_code < 300):
 *                 raise BinanceAPIException(self.response)             # <<<<<<<<<<<<<<
 *         try:
 *             return self.response.json()
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_BinanceAPIException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_response); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 583, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 583, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":582
 *         """
 *         if throw_exception is True:
 *             if not (200 <= self.response.status_code < 300):             # <<<<<<<<<<<<<<
 *                 raise BinanceAPIException(self.response)
 *         try:
 */
    }

    /* "unicorn_binance_rest_api/manager.py":581
 * 
 *         """
 *         if throw_exception is True:             # <<<<<<<<<<<<<<
 *             if not (200 <= self.response.status_code < 300):
 *                 raise BinanceAPIException(self.response)
 */
  }

  /* "unicorn_binance_rest_api/manager.py":584
 *             if not (200 <= self.response.status_code < 300):
 *                 raise BinanceAPIException(self.response)
 *         try:             # <<<<<<<<<<<<<<
 *             return self.response.json()
 *         except ValueError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "unicorn_binance_rest_api/manager.py":585
 *                 raise BinanceAPIException(self.response)
 *         try:
 *             return self.response.json()             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             raise BinanceRequestException('Invalid Response: %s' % self.response.text)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_response); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 585, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 585, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 585, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L9_try_return;

      /* "unicorn_binance_rest_api/manager.py":584
 *             if not (200 <= self.response.status_code < 300):
 *                 raise BinanceAPIException(self.response)
 *         try:             # <<<<<<<<<<<<<<
 *             return self.response.json()
 *         except ValueError:
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "unicorn_binance_rest_api/manager.py":586
 *         try:
 *             return self.response.json()
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             raise BinanceRequestException('Invalid Response: %s' % self.response.text)
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._handle_response", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_5, &__pyx_t_3) < 0) __PYX_ERR(0, 586, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);

      /* "unicorn_binance_rest_api/manager.py":587
 *             return self.response.json()
 *         except ValueError:
 *             raise BinanceRequestException('Invalid Response: %s' % self.response.text)             # <<<<<<<<<<<<<<
 * 
 *     def _get(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_BinanceRequestException); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 587, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_response); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 587, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_text); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 587, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyString_FormatSafe(__pyx_kp_s_Invalid_Response_s, __pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 587, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_12};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 587, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 587, __pyx_L7_except_error)
    }
    goto __pyx_L7_except_error;

    /* "unicorn_binance_rest_api/manager.py":584
 *             if not (200 <= self.response.status_code < 300):
 *                 raise BinanceAPIException(self.response)
 *         try:             # <<<<<<<<<<<<<<
 *             return self.response.json()
 *         except ValueError:
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":574
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _handle_response(self, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """
 *         Internal helper for handling API responses from the Binance server.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._handle_response", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":589
 *             raise BinanceRequestException('Invalid Response: %s' % self.response.text)
 * 
 *     def _get(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_8__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_False))) __PYX_ERR(0, 589, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 589, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 589, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_45_get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_45_get = {"_get", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_45_get, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_45_get(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,0};
    __pyx_defaults4 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 589, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 589, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_get", 0, 2, 4, 1); __PYX_ERR(0, 589, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 589, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 589, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_get") < 0)) __PYX_ERR(0, 589, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_signed = values[2];
    __pyx_v_version = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 589, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_44_get(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_44_get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get", 1);

  /* "unicorn_binance_rest_api/manager.py":590
 * 
 *     def _get(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):
 *         return self._request_api('get', path, signed, version, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _post(self, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_get);
  __Pyx_GIVEREF(__pyx_n_s_get);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_get)) __PYX_ERR(0, 590, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_GIVEREF(__pyx_v_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_path)) __PYX_ERR(0, 590, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 590, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_version);
  __Pyx_GIVEREF(__pyx_v_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_version)) __PYX_ERR(0, 590, __pyx_L1_error);
  __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":589
 *             raise BinanceRequestException('Invalid Response: %s' % self.response.text)
 * 
 *     def _get(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":592
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 *     def _post(self, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_10__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_False))) __PYX_ERR(0, 592, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 592, __pyx_L1_error);
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)Py_True))) __PYX_ERR(0, 592, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 592, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_47_post(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_47_post = {"_post", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_47_post, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_47_post(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_throw_exception = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_post (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,&__pyx_n_s_throw_exception,0};
    __pyx_defaults5 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 592, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 592, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_post", 0, 2, 5, 1); __PYX_ERR(0, 592, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 592, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 592, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 592, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_post") < 0)) __PYX_ERR(0, 592, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_signed = values[2];
    __pyx_v_version = values[3];
    __pyx_v_throw_exception = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_post", 0, 2, 5, __pyx_nargs); __PYX_ERR(0, 592, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._post", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_46_post(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_throw_exception, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_46_post(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_throw_exception, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_post", 1);

  /* "unicorn_binance_rest_api/manager.py":593
 * 
 *     def _post(self, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _put(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_post);
  __Pyx_GIVEREF(__pyx_n_s_post);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_post)) __PYX_ERR(0, 593, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_GIVEREF(__pyx_v_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_path)) __PYX_ERR(0, 593, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 593, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_version);
  __Pyx_GIVEREF(__pyx_v_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_version)) __PYX_ERR(0, 593, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_throw_exception);
  __Pyx_GIVEREF(__pyx_v_throw_exception);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_v_throw_exception)) __PYX_ERR(0, 593, __pyx_L1_error);
  __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":592
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 *     def _post(self, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._post", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":595
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 *     def _put(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_12__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_False))) __PYX_ERR(0, 595, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 595, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 595, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_49_put(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_49_put = {"_put", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_49_put, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_49_put(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_put (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,0};
    __pyx_defaults6 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 595, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 595, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_put", 0, 2, 4, 1); __PYX_ERR(0, 595, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 595, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 595, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_put") < 0)) __PYX_ERR(0, 595, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_signed = values[2];
    __pyx_v_version = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_put", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 595, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._put", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_48_put(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_48_put(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_put", 1);

  /* "unicorn_binance_rest_api/manager.py":596
 * 
 *     def _put(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):
 *         return self._request_api('put', path, signed, version, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def _delete(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_put);
  __Pyx_GIVEREF(__pyx_n_s_put);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_put)) __PYX_ERR(0, 596, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_GIVEREF(__pyx_v_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_path)) __PYX_ERR(0, 596, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 596, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_version);
  __Pyx_GIVEREF(__pyx_v_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_version)) __PYX_ERR(0, 596, __pyx_L1_error);
  __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":595
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 *     def _put(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._put", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":598
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 *     def _delete(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_14__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_False))) __PYX_ERR(0, 598, __pyx_L1_error);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_version);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_version)) __PYX_ERR(0, 598, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 598, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_51_delete(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_51_delete = {"_delete", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_51_delete, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_51_delete(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_signed = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_kwargs = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_delete (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_path,&__pyx_n_s_signed,&__pyx_n_s_version,0};
    __pyx_defaults7 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self);
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_version);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 598, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_path)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 598, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_delete", 0, 2, 4, 1); __PYX_ERR(0, 598, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signed);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 598, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 598, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwargs, values + 0, kwd_pos_args, "_delete") < 0)) __PYX_ERR(0, 598, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_path = values[1];
    __pyx_v_signed = values[2];
    __pyx_v_version = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_delete", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 598, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._delete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_50_delete(__pyx_self, __pyx_v_self, __pyx_v_path, __pyx_v_signed, __pyx_v_version, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwargs);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_50_delete(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_signed, PyObject *__pyx_v_version, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_delete", 1);

  /* "unicorn_binance_rest_api/manager.py":599
 * 
 *     def _delete(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):
 *         return self._request_api('delete', path, signed, version, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     def is_update_availabe(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_delete);
  __Pyx_GIVEREF(__pyx_n_s_delete);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_delete)) __PYX_ERR(0, 599, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_GIVEREF(__pyx_v_path);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_path)) __PYX_ERR(0, 599, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_signed);
  __Pyx_GIVEREF(__pyx_v_signed);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_signed)) __PYX_ERR(0, 599, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_version);
  __Pyx_GIVEREF(__pyx_v_version);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_version)) __PYX_ERR(0, 599, __pyx_L1_error);
  __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":598
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 *     def _delete(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._delete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":601
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 *     def is_update_availabe(self):             # <<<<<<<<<<<<<<
 *         """
 *         Is a new release of this package available?
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_53is_update_availabe(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_52is_update_availabe, "\n        Is a new release of this package available?\n\n        :return: bool\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_53is_update_availabe = {"is_update_availabe", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_53is_update_availabe, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_52is_update_availabe};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_53is_update_availabe(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_update_availabe (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 601, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_update_availabe") < 0)) __PYX_ERR(0, 601, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_update_availabe", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 601, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.is_update_availabe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_52is_update_availabe(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_52is_update_availabe(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_installed_version = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_update_availabe", 1);

  /* "unicorn_binance_rest_api/manager.py":607
 *         :return: bool
 *         """
 *         installed_version = self.get_version()             # <<<<<<<<<<<<<<
 *         if ".dev" in installed_version:
 *             installed_version = installed_version[:-4]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_version); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_installed_version = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":608
 *         """
 *         installed_version = self.get_version()
 *         if ".dev" in installed_version:             # <<<<<<<<<<<<<<
 *             installed_version = installed_version[:-4]
 *         if self.get_latest_version() == installed_version:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_kp_s_dev, __pyx_v_installed_version, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 608, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":609
 *         installed_version = self.get_version()
 *         if ".dev" in installed_version:
 *             installed_version = installed_version[:-4]             # <<<<<<<<<<<<<<
 *         if self.get_latest_version() == installed_version:
 *             return False
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_installed_version, 0, -4L, NULL, NULL, &__pyx_slice__10, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 609, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_installed_version, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "unicorn_binance_rest_api/manager.py":608
 *         """
 *         installed_version = self.get_version()
 *         if ".dev" in installed_version:             # <<<<<<<<<<<<<<
 *             installed_version = installed_version[:-4]
 *         if self.get_latest_version() == installed_version:
 */
  }

  /* "unicorn_binance_rest_api/manager.py":610
 *         if ".dev" in installed_version:
 *             installed_version = installed_version[:-4]
 *         if self.get_latest_version() == installed_version:             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.get_latest_version() == "unknown":
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_latest_version); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_v_installed_version, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":611
 *             installed_version = installed_version[:-4]
 *         if self.get_latest_version() == installed_version:
 *             return False             # <<<<<<<<<<<<<<
 *         elif self.get_latest_version() == "unknown":
 *             return False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":610
 *         if ".dev" in installed_version:
 *             installed_version = installed_version[:-4]
 *         if self.get_latest_version() == installed_version:             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.get_latest_version() == "unknown":
 */
  }

  /* "unicorn_binance_rest_api/manager.py":612
 *         if self.get_latest_version() == installed_version:
 *             return False
 *         elif self.get_latest_version() == "unknown":             # <<<<<<<<<<<<<<
 *             return False
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_latest_version); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 612, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_n_s_unknown, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":613
 *             return False
 *         elif self.get_latest_version() == "unknown":
 *             return False             # <<<<<<<<<<<<<<
 *         else:
 *             return True
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":612
 *         if self.get_latest_version() == installed_version:
 *             return False
 *         elif self.get_latest_version() == "unknown":             # <<<<<<<<<<<<<<
 *             return False
 *         else:
 */
  }

  /* "unicorn_binance_rest_api/manager.py":615
 *             return False
 *         else:
 *             return True             # <<<<<<<<<<<<<<
 * 
 *     def get_version(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":601
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 *     def is_update_availabe(self):             # <<<<<<<<<<<<<<
 *         """
 *         Is a new release of this package available?
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.is_update_availabe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_installed_version);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":617
 *             return True
 * 
 *     def get_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the package/module version
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_55get_version(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_54get_version, "\n        Get the package/module version\n\n        :return: str\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_55get_version = {"get_version", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_55get_version, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_54get_version};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_55get_version(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_version (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 617, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_version") < 0)) __PYX_ERR(0, 617, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_version", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 617, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_54get_version(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_54get_version(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_version", 1);

  /* "unicorn_binance_rest_api/manager.py":623
 *         :return: str
 *         """
 *         return self.version             # <<<<<<<<<<<<<<
 * 
 *     def get_latest_version(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_version); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":617
 *             return True
 * 
 *     def get_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the package/module version
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":625
 *         return self.version
 * 
 *     def get_latest_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the version of the latest available release (cache time 1 hour)
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_57get_latest_version(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_56get_latest_version, "\n        Get the version of the latest available release (cache time 1 hour)\n        :return: str or False\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_57get_latest_version = {"get_latest_version", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_57get_latest_version, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_56get_latest_version};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_57get_latest_version(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_latest_version (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 625, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_latest_version") < 0)) __PYX_ERR(0, 625, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_latest_version", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 625, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_latest_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_56get_latest_version(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_56get_latest_version(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_latest_version", 1);

  /* "unicorn_binance_rest_api/manager.py":631
 *         """
 *         # Do a fresh request if status is None or last timestamp is older 1 hour
 *         if self.last_update_check_github['status'] is None or \             # <<<<<<<<<<<<<<
 *                 (self.last_update_check_github['timestamp']+(60*60) < time.time()):
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_last_update_check_github); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_status); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 == Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }

  /* "unicorn_binance_rest_api/manager.py":632
 *         # Do a fresh request if status is None or last timestamp is older 1 hour
 *         if self.last_update_check_github['status'] is None or \
 *                 (self.last_update_check_github['timestamp']+(60*60) < time.time()):             # <<<<<<<<<<<<<<
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 *         if self.last_update_check_github['status']:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_last_update_check_github); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_timestamp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_3600, 0xe10, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_time); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_time); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_3, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;

  /* "unicorn_binance_rest_api/manager.py":631
 *         """
 *         # Do a fresh request if status is None or last timestamp is older 1 hour
 *         if self.last_update_check_github['status'] is None or \             # <<<<<<<<<<<<<<
 *                 (self.last_update_check_github['timestamp']+(60*60) < time.time()):
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 */
  if (__pyx_t_1) {

    /* "unicorn_binance_rest_api/manager.py":633
 *         if self.last_update_check_github['status'] is None or \
 *                 (self.last_update_check_github['timestamp']+(60*60) < time.time()):
 *             self.last_update_check_github['status'] = self.get_latest_release_info()             # <<<<<<<<<<<<<<
 *         if self.last_update_check_github['status']:
 *             try:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_latest_release_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_last_update_check_github); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_n_s_status, __pyx_t_6) < 0))) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "unicorn_binance_rest_api/manager.py":631
 *         """
 *         # Do a fresh request if status is None or last timestamp is older 1 hour
 *         if self.last_update_check_github['status'] is None or \             # <<<<<<<<<<<<<<
 *                 (self.last_update_check_github['timestamp']+(60*60) < time.time()):
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 */
  }

  /* "unicorn_binance_rest_api/manager.py":634
 *                 (self.last_update_check_github['timestamp']+(60*60) < time.time()):
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 *         if self.last_update_check_github['status']:             # <<<<<<<<<<<<<<
 *             try:
 *                 return self.last_update_check_github['status']["tag_name"]
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_last_update_check_github); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_6, __pyx_n_s_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "unicorn_binance_rest_api/manager.py":635
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 *         if self.last_update_check_github['status']:
 *             try:             # <<<<<<<<<<<<<<
 *                 return self.last_update_check_github['status']["tag_name"]
 *             except KeyError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "unicorn_binance_rest_api/manager.py":636
 *         if self.last_update_check_github['status']:
 *             try:
 *                 return self.last_update_check_github['status']["tag_name"]             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 return "unknown"
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_last_update_check_github); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 636, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_status); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 636, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_6, __pyx_n_s_tag_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 636, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        goto __pyx_L11_try_return;

        /* "unicorn_binance_rest_api/manager.py":635
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 *         if self.last_update_check_github['status']:
 *             try:             # <<<<<<<<<<<<<<
 *                 return self.last_update_check_github['status']["tag_name"]
 *             except KeyError:
 */
      }
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "unicorn_binance_rest_api/manager.py":637
 *             try:
 *                 return self.last_update_check_github['status']["tag_name"]
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 return "unknown"
 *         else:
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_7) {
        __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_latest_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_6, &__pyx_t_3) < 0) __PYX_ERR(0, 637, __pyx_L9_except_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_3);

        /* "unicorn_binance_rest_api/manager.py":638
 *                 return self.last_update_check_github['status']["tag_name"]
 *             except KeyError:
 *                 return "unknown"             # <<<<<<<<<<<<<<
 *         else:
 *             return "unknown"
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_n_s_unknown);
        __pyx_r = __pyx_n_s_unknown;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L10_except_return;
      }
      goto __pyx_L9_except_error;

      /* "unicorn_binance_rest_api/manager.py":635
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 *         if self.last_update_check_github['status']:
 *             try:             # <<<<<<<<<<<<<<
 *                 return self.last_update_check_github['status']["tag_name"]
 *             except KeyError:
 */
      __pyx_L9_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L11_try_return:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L0;
      __pyx_L10_except_return:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L0;
    }

    /* "unicorn_binance_rest_api/manager.py":634
 *                 (self.last_update_check_github['timestamp']+(60*60) < time.time()):
 *             self.last_update_check_github['status'] = self.get_latest_release_info()
 *         if self.last_update_check_github['status']:             # <<<<<<<<<<<<<<
 *             try:
 *                 return self.last_update_check_github['status']["tag_name"]
 */
  }

  /* "unicorn_binance_rest_api/manager.py":640
 *                 return "unknown"
 *         else:
 *             return "unknown"             # <<<<<<<<<<<<<<
 * 
 *     def get_latest_release_info(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_s_unknown);
    __pyx_r = __pyx_n_s_unknown;
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":625
 *         return self.version
 * 
 *     def get_latest_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the version of the latest available release (cache time 1 hour)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_latest_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":642
 *             return "unknown"
 * 
 *     def get_latest_release_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get infos about the latest available release
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_59get_latest_release_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_58get_latest_release_info, "\n        Get infos about the latest available release\n        :return: dict or False\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_59get_latest_release_info = {"get_latest_release_info", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_59get_latest_release_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_58get_latest_release_info};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_59get_latest_release_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_latest_release_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 642, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_latest_release_info") < 0)) __PYX_ERR(0, 642, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_latest_release_info", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 642, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_latest_release_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_58get_latest_release_info(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_58get_latest_release_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_respond = NULL;
  PyObject *__pyx_v_latest_release_info = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_latest_release_info", 1);

  /* "unicorn_binance_rest_api/manager.py":647
 *         :return: dict or False
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "unicorn_binance_rest_api/manager.py":648
 *         """
 *         try:
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:             # <<<<<<<<<<<<<<
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 *                                        'unicorn-binance-rest-api/releases/latest',
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_address); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 648, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = (__pyx_t_5 != Py_None);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_6) {
      } else {
        __pyx_t_4 = __pyx_t_6;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_port); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 648, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = (__pyx_t_5 != Py_None);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_4 = __pyx_t_6;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_4) {

        /* "unicorn_binance_rest_api/manager.py":649
 *         try:
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'             # <<<<<<<<<<<<<<
 *                                        'unicorn-binance-rest-api/releases/latest',
 *                                        proxies=self.request_socks5_proxies,
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_requests); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 649, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_get); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 649, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "unicorn_binance_rest_api/manager.py":651
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 *                                        'unicorn-binance-rest-api/releases/latest',
 *                                        proxies=self.request_socks5_proxies,             # <<<<<<<<<<<<<<
 *                                        verify=self.socks5_proxy_ssl_verification)
 *             else:
 */
        __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 651, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_socks5_proxies); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 651, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_proxies, __pyx_t_8) < 0) __PYX_ERR(0, 651, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "unicorn_binance_rest_api/manager.py":652
 *                                        'unicorn-binance-rest-api/releases/latest',
 *                                        proxies=self.request_socks5_proxies,
 *                                        verify=self.socks5_proxy_ssl_verification)             # <<<<<<<<<<<<<<
 *             else:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_socks5_proxy_ssl_verification); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 652, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_verify, __pyx_t_8) < 0) __PYX_ERR(0, 651, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "unicorn_binance_rest_api/manager.py":649
 *         try:
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'             # <<<<<<<<<<<<<<
 *                                        'unicorn-binance-rest-api/releases/latest',
 *                                        proxies=self.request_socks5_proxies,
 */
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__11, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 649, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_v_respond = __pyx_t_8;
        __pyx_t_8 = 0;

        /* "unicorn_binance_rest_api/manager.py":648
 *         """
 *         try:
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:             # <<<<<<<<<<<<<<
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 *                                        'unicorn-binance-rest-api/releases/latest',
 */
        goto __pyx_L9;
      }

      /* "unicorn_binance_rest_api/manager.py":654
 *                                        verify=self.socks5_proxy_ssl_verification)
 *             else:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'             # <<<<<<<<<<<<<<
 *                                        'unicorn-binance-rest-api/releases/latest')
 *             latest_release_info = respond.json()
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_requests); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 654, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_get); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 654, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        __pyx_t_9 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_9 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_s_https_api_github_com_repos_LUCIT};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 654, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_v_respond = __pyx_t_8;
        __pyx_t_8 = 0;
      }
      __pyx_L9:;

      /* "unicorn_binance_rest_api/manager.py":656
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 *                                        'unicorn-binance-rest-api/releases/latest')
 *             latest_release_info = respond.json()             # <<<<<<<<<<<<<<
 *             return latest_release_info
 *         except Exception:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_respond, __pyx_n_s_json); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 656, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 656, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_v_latest_release_info = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "unicorn_binance_rest_api/manager.py":657
 *                                        'unicorn-binance-rest-api/releases/latest')
 *             latest_release_info = respond.json()
 *             return latest_release_info             # <<<<<<<<<<<<<<
 *         except Exception:
 *             return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_latest_release_info);
      __pyx_r = __pyx_v_latest_release_info;
      goto __pyx_L7_try_return;

      /* "unicorn_binance_rest_api/manager.py":647
 *         :return: dict or False
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "unicorn_binance_rest_api/manager.py":658
 *             latest_release_info = respond.json()
 *             return latest_release_info
 *         except Exception:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_latest_release_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 658, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);

      /* "unicorn_binance_rest_api/manager.py":659
 *             return latest_release_info
 *         except Exception:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def get_user_agent(self):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "unicorn_binance_rest_api/manager.py":647
 *         :return: dict or False
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":642
 *             return "unknown"
 * 
 *     def get_latest_release_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get infos about the latest available release
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_latest_release_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_respond);
  __Pyx_XDECREF(__pyx_v_latest_release_info);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":661
 *             return False
 * 
 *     def get_user_agent(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the user_agent string "lib name + lib version + python version"
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_61get_user_agent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_60get_user_agent, "\n        Get the user_agent string \"lib name + lib version + python version\"\n\n        :return: str - user agent\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_61get_user_agent = {"get_user_agent", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_61get_user_agent, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_60get_user_agent};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_61get_user_agent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_user_agent (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 661, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_user_agent") < 0)) __PYX_ERR(0, 661, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_user_agent", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 661, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_user_agent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_60get_user_agent(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_60get_user_agent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_user_agent = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_user_agent", 1);

  /* "unicorn_binance_rest_api/manager.py":667
 *         :return: str - user agent
 *         """
 *         user_agent = f"{self.name}_{str(self.get_version())}-python_{str(platform.python_version())}"             # <<<<<<<<<<<<<<
 *         return user_agent
 * 
 */
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_n_u__5);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_n_u__5);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_u__5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_version); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_Str(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_python);
  __pyx_t_2 += 8;
  __Pyx_GIVEREF(__pyx_kp_u_python);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u_python);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_platform); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_python_version); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_Str(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_user_agent = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "unicorn_binance_rest_api/manager.py":668
 *         """
 *         user_agent = f"{self.name}_{str(self.get_version())}-python_{str(platform.python_version())}"
 *         return user_agent             # <<<<<<<<<<<<<<
 * 
 *     # Exchange Endpoints
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_user_agent);
  __pyx_r = __pyx_v_user_agent;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":661
 *             return False
 * 
 *     def get_user_agent(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the user_agent string "lib name + lib version + python version"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_user_agent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_user_agent);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":671
 * 
 *     # Exchange Endpoints
 *     def get_products(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return list of products currently listed on Binance
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_63get_products(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_62get_products, "\n        Return list of products currently listed on Binance\n\n        Use get_exchange_info() call instead\n\n        :returns: list - List of product dictionaries\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_63get_products = {"get_products", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_63get_products, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_62get_products};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_63get_products(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_products (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 671, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_products") < 0)) __PYX_ERR(0, 671, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_products", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 671, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_products", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_62get_products(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_62get_products(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_products = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_products", 1);

  /* "unicorn_binance_rest_api/manager.py":682
 * 
 *         """
 *         products = self._request_website('get', 'exchange-api/v1/public/asset-service/product/get-products')             # <<<<<<<<<<<<<<
 *         return products
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_website); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_products = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":683
 *         """
 *         products = self._request_website('get', 'exchange-api/v1/public/asset-service/product/get-products')
 *         return products             # <<<<<<<<<<<<<<
 * 
 *     def get_exchange_info(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_products);
  __pyx_r = __pyx_v_products;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":671
 * 
 *     # Exchange Endpoints
 *     def get_products(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return list of products currently listed on Binance
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_products", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_products);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":685
 *         return products
 * 
 *     def get_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return rate limits and list of symbols
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_65get_exchange_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_64get_exchange_info, "\n        Return rate limits and list of symbols\n\n        :returns: list - List of product dictionaries\n\n        .. code-block:: python\n\n            {\n                \"timezone\": \"UTC\",\n                \"serverTime\": 1508631584636,\n                \"rateLimits\": [\n                    {\n                        \"rateLimitType\": \"REQUESTS\",\n                        \"interval\": \"MINUTE\",\n                        \"limit\": 1200\n                    },\n                    {\n                        \"rateLimitType\": \"ORDERS\",\n                        \"interval\": \"SECOND\",\n                        \"limit\": 10\n                    },\n                    {\n                        \"rateLimitType\": \"ORDERS\",\n                        \"interval\": \"DAY\",\n                        \"limit\": 100000\n                    }\n                ],\n                \"exchangeFilters\": [],\n                \"symbols\": [\n                    {\n                        \"symbol\": \"ETHBTC\",\n                        \"status\": \"TRADING\",\n                        \"baseAsset\": \"ETH\",\n                        \"baseAssetPrecision\": 8,\n                        \"quoteAsset\": \"BTC\",\n                        \"quotePrecision\": 8,\n                        \"orderTypes\": [\"LIMIT\", \"MARKET\"],\n                        \"icebergAllowed\": false,\n                        \"filters\": [\n                            {\n                                \"filterType\": \"PRICE_FILTER\",\n                                \"minPrice\": \"0.00000100\",\n                                \"maxPrice\": \"100000.00000000\",\n                                \"tickSize\": \"0.00000100\"\n                            }, {\n                                \"filterType\": \"LOT_SIZE\",\n                                \"minQty\": \"0.00100000\",\n                                \"maxQty\": \"100000.00000000\",\n                                \"stepSize\": ""\"0.00100000\"\n                            }, {\n                                \"filterType\": \"MIN_NOTIONAL\",\n                                \"minNotional\": \"0.00100000\"\n                            }\n                        ]\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_65get_exchange_info = {"get_exchange_info", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_65get_exchange_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_64get_exchange_info};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_65get_exchange_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_exchange_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 685, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_exchange_info") < 0)) __PYX_ERR(0, 685, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_exchange_info", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 685, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_exchange_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_64get_exchange_info(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_64get_exchange_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_exchange_info", 1);

  /* "unicorn_binance_rest_api/manager.py":748
 *         """
 * 
 *         return self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_symbol_info(self, symbol):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__13, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":685
 *         return products
 * 
 *     def get_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return rate limits and list of symbols
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_exchange_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":750
 *         return self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_info(self, symbol):             # <<<<<<<<<<<<<<
 *         """
 *         Return information about a symbol
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_67get_symbol_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_66get_symbol_info, "\n        Return information about a symbol\n\n        :param symbol: required e.g. BNBBTC\n        :type symbol: str\n\n        :returns: Dict if found, None if not\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"ETHBTC\",\n                \"status\": \"TRADING\",\n                \"baseAsset\": \"ETH\",\n                \"baseAssetPrecision\": 8,\n                \"quoteAsset\": \"BTC\",\n                \"quotePrecision\": 8,\n                \"orderTypes\": [\"LIMIT\", \"MARKET\"],\n                \"icebergAllowed\": false,\n                \"filters\": [\n                    {\n                        \"filterType\": \"PRICE_FILTER\",\n                        \"minPrice\": \"0.00000100\",\n                        \"maxPrice\": \"100000.00000000\",\n                        \"tickSize\": \"0.00000100\"\n                    }, {\n                        \"filterType\": \"LOT_SIZE\",\n                        \"minQty\": \"0.00100000\",\n                        \"maxQty\": \"100000.00000000\",\n                        \"stepSize\": \"0.00100000\"\n                    }, {\n                        \"filterType\": \"MIN_NOTIONAL\",\n                        \"minNotional\": \"0.00100000\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_67get_symbol_info = {"get_symbol_info", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_67get_symbol_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_66get_symbol_info};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_67get_symbol_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_symbol_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 750, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 750, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_symbol_info", 1, 2, 2, 1); __PYX_ERR(0, 750, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_symbol_info") < 0)) __PYX_ERR(0, 750, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_symbol_info", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 750, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_symbol_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_66get_symbol_info(__pyx_self, __pyx_v_self, __pyx_v_symbol);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_66get_symbol_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_symbol_info", 1);

  /* "unicorn_binance_rest_api/manager.py":792
 *         """
 * 
 *         res = self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *         for item in res['symbols']:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__13, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":794
 *         res = self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)
 * 
 *         for item in res['symbols']:             # <<<<<<<<<<<<<<
 *             if item['symbol'] == symbol.upper():
 *                 return item
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_symbols); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 794, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 794, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 794, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 794, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 794, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 794, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 794, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 794, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":795
 * 
 *         for item in res['symbols']:
 *             if item['symbol'] == symbol.upper():             # <<<<<<<<<<<<<<
 *                 return item
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_item, __pyx_n_s_symbol); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_symbol, __pyx_n_s_upper); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 795, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = PyObject_RichCompare(__pyx_t_3, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_9) {

      /* "unicorn_binance_rest_api/manager.py":796
 *         for item in res['symbols']:
 *             if item['symbol'] == symbol.upper():
 *                 return item             # <<<<<<<<<<<<<<
 * 
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_item);
      __pyx_r = __pyx_v_item;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "unicorn_binance_rest_api/manager.py":795
 * 
 *         for item in res['symbols']:
 *             if item['symbol'] == symbol.upper():             # <<<<<<<<<<<<<<
 *                 return item
 * 
 */
    }

    /* "unicorn_binance_rest_api/manager.py":794
 *         res = self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)
 * 
 *         for item in res['symbols']:             # <<<<<<<<<<<<<<
 *             if item['symbol'] == symbol.upper():
 *                 return item
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":798
 *                 return item
 * 
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     # General Endpoints
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":750
 *         return self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_info(self, symbol):             # <<<<<<<<<<<<<<
 *         """
 *         Return information about a symbol
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_symbol_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":802
 *     # General Endpoints
 * 
 *     def ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_69ping(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_68ping, "\n        Test connectivity to the Rest API.\n\n        https://binance-docs.github.io/apidocs/spot/en/#test-connectivity\n\n        :returns: Empty array\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_69ping = {"ping", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_69ping, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_68ping};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_69ping(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ping (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 802, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "ping") < 0)) __PYX_ERR(0, 802, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ping", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 802, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.ping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_68ping(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_68ping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ping", 1);

  /* "unicorn_binance_rest_api/manager.py":817
 * 
 *         """
 *         return self._get('ping', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_server_time(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__14, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":802
 *     # General Endpoints
 * 
 *     def ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.ping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":819
 *         return self._get('ping', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_server_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_71get_server_time(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_70get_server_time, "\n        Test connectivity to the Rest API and get the current server time.\n\n        https://binance-docs.github.io/apidocs/spot/en/#check-server-time\n\n        :returns: Current server time\n\n        .. code-block:: python\n\n            {\n                \"serverTime\": 1499827319559\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_71get_server_time = {"get_server_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_71get_server_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_70get_server_time};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_71get_server_time(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_server_time (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 819, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_server_time") < 0)) __PYX_ERR(0, 819, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_server_time", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 819, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_server_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_70get_server_time(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_70get_server_time(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_server_time", 1);

  /* "unicorn_binance_rest_api/manager.py":836
 * 
 *         """
 *         return self._get('time', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     # Market Data Endpoints
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__15, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":819
 *         return self._get('ping', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_server_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_server_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":840
 *     # Market Data Endpoints
 * 
 *     def get_all_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for all symbols.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_73get_all_tickers(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_72get_all_tickers, "\n        Latest price for all symbols.\n\n        https://www.binance.com/restapipub.html#symbols-price-ticker\n\n        :returns: List of market tickers\n\n        .. code-block:: python\n\n            [\n                {\n                    \"symbol\": \"LTCBTC\",\n                    \"price\": \"4.00000200\"\n                },\n                {\n                    \"symbol\": \"ETHBTC\",\n                    \"price\": \"0.07946600\"\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_73get_all_tickers = {"get_all_tickers", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_73get_all_tickers, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_72get_all_tickers};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_73get_all_tickers(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_tickers (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 840, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_all_tickers") < 0)) __PYX_ERR(0, 840, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_tickers", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 840, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_tickers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_72get_all_tickers(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_72get_all_tickers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_all_tickers", 1);

  /* "unicorn_binance_rest_api/manager.py":864
 * 
 *         """
 *         return self._get('ticker/price', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_orderbook_tickers(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__16, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":840
 *     # Market Data Endpoints
 * 
 *     def get_all_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for all symbols.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_tickers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":866
 *         return self._get('ticker/price', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for all symbols.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_75get_orderbook_tickers(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_74get_orderbook_tickers, "\n        Best price/qty on the order book for all symbols.\n\n        https://www.binance.com/restapipub.html#symbols-order-book-ticker\n\n        :returns: List of order book market entries\n\n        .. code-block:: python\n\n            [\n                {\n                    \"symbol\": \"LTCBTC\",\n                    \"bidPrice\": \"4.00000000\",\n                    \"bidQty\": \"431.00000000\",\n                    \"askPrice\": \"4.00000200\",\n                    \"askQty\": \"9.00000000\"\n                },\n                {\n                    \"symbol\": \"ETHBTC\",\n                    \"bidPrice\": \"0.07946700\",\n                    \"bidQty\": \"9.00000000\",\n                    \"askPrice\": \"100000.00000000\",\n                    \"askQty\": \"1000.00000000\"\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_75get_orderbook_tickers = {"get_orderbook_tickers", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_75get_orderbook_tickers, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_74get_orderbook_tickers};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_75get_orderbook_tickers(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_orderbook_tickers (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 866, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_orderbook_tickers") < 0)) __PYX_ERR(0, 866, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_orderbook_tickers", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 866, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_orderbook_tickers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_74get_orderbook_tickers(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_74get_orderbook_tickers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_orderbook_tickers", 1);

  /* "unicorn_binance_rest_api/manager.py":896
 * 
 *         """
 *         return self._get('ticker/bookTicker', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_order_book(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__17, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":866
 *         return self._get('ticker/price', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for all symbols.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_orderbook_tickers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":898
 *         return self._get('ticker/bookTicker', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_77get_order_book(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_76get_order_book, "\n        Get the Order Book for the market\n\n        https://binance-docs.github.io/apidocs/spot/en/#order-book\n\n        :param symbol: required\n        :type symbol: str\n        :param limit:  Default 100; max 1000\n        :type limit: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"lastUpdateId\": 1027024,\n                \"bids\": [\n                    [\n                        \"4.00000000\",     # PRICE\n                        \"431.00000000\",   # QTY\n                        []                # Can be ignored\n                    ]\n                ],\n                \"asks\": [\n                    [\n                        \"4.00000200\",\n                        \"12.00000000\",\n                        []\n                    ]\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_77get_order_book = {"get_order_book", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_77get_order_book, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_76get_order_book};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_77get_order_book(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_order_book (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 898, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_order_book") < 0)) __PYX_ERR(0, 898, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_order_book", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 898, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_order_book", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_76get_order_book(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_76get_order_book(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_order_book", 1);

  /* "unicorn_binance_rest_api/manager.py":934
 * 
 *         """
 *         return self._get('depth', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_recent_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 934, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__18, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":898
 *         return self._get('ticker/bookTicker', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_order_book", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":936
 *         return self._get('depth', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get recent trades (up to last 500).
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_79get_recent_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_78get_recent_trades, "\n        Get recent trades (up to last 500).\n\n        https://binance-docs.github.io/apidocs/spot/en/#recent-trades-list\n\n        :param symbol: required\n        :type symbol: str\n        :param limit:  Default 500; max 500.\n        :type limit: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"id\": 28457,\n                    \"price\": \"4.00000100\",\n                    \"qty\": \"12.00000000\",\n                    \"time\": 1499865549590,\n                    \"isBuyerMaker\": true,\n                    \"isBestMatch\": true\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_79get_recent_trades = {"get_recent_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_79get_recent_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_78get_recent_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_79get_recent_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_recent_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 936, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_recent_trades") < 0)) __PYX_ERR(0, 936, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_recent_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 936, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_recent_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_78get_recent_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_78get_recent_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_recent_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":965
 * 
 *         """
 *         return self._get('trades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_historical_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 965, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__19, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":936
 *         return self._get('depth', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get recent trades (up to last 500).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_recent_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":967
 *         return self._get('trades', data=params)
 * 
 *     def get_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older trades.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_81get_historical_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_80get_historical_trades, "\n        Get older trades.\n\n        https://binance-docs.github.io/apidocs/spot/en/#recent-trades-list\n\n        :param symbol: required\n        :type symbol: str\n        :param limit:  Default 500; max 500.\n        :type limit: int\n        :param fromId:  TradeId to fetch from. Default gets most recent trades.\n        :type fromId: str\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"id\": 28457,\n                    \"price\": \"4.00000100\",\n                    \"qty\": \"12.00000000\",\n                    \"time\": 1499865549590,\n                    \"isBuyerMaker\": true,\n                    \"isBestMatch\": true\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_81get_historical_trades = {"get_historical_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_81get_historical_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_80get_historical_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_81get_historical_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_historical_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 967, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_historical_trades") < 0)) __PYX_ERR(0, 967, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_historical_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 967, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_historical_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_80get_historical_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_80get_historical_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_historical_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":998
 * 
 *         """
 *         return self._get('historicalTrades', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_aggregate_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 998, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__20, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":967
 *         return self._get('trades', data=params)
 * 
 *     def get_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older trades.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_historical_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1000
 *         return self._get('historicalTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time,
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_83get_aggregate_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_82get_aggregate_trades, "\n        Get compressed, aggregate trades. Trades that fill at the time,\n        from the same order, with the same price will have the quantity aggregated.\n\n        https://binance-docs.github.io/apidocs/spot/en/#compressedaggregate-trades-list\n\n        :param symbol: required\n        :type symbol: str\n        :param fromId:  ID to get aggregate trades from INCLUSIVE.\n        :type fromId: str\n        :param startTime: Timestamp in ms to get aggregate trades from INCLUSIVE.\n        :type startTime: int\n        :param endTime: Timestamp in ms to get aggregate trades until INCLUSIVE.\n        :type endTime: int\n        :param limit:  Default 500; max 500.\n        :type limit: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"a\": 26129,         # Aggregate tradeId\n                    \"p\": \"0.01633102\",  # Price\n                    \"q\": \"4.70443515\",  # Quantity\n                    \"f\": 27781,         # First tradeId\n                    \"l\": 27781,         # Last tradeId\n                    \"T\": 1498793709153, # Timestamp\n                    \"m\": true,          # Was the buyer the maker?\n                    \"M\": true,          # Was the trade the best price match?\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_83get_aggregate_trades = {"get_aggregate_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_83get_aggregate_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_82get_aggregate_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_83get_aggregate_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_aggregate_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1000, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_aggregate_trades") < 0)) __PYX_ERR(0, 1000, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_aggregate_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1000, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_aggregate_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_82get_aggregate_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_82get_aggregate_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_aggregate_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":1037
 *         :raises: BinanceRequestException, BinanceAPIException
 *         """
 *         return self._get('aggTrades', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def aggregate_trade_iter(self, symbol, start_str=None, last_id=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1037, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__21, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1000
 *         return self._get('historicalTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_aggregate_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_86generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "unicorn_binance_rest_api/manager.py":1039
 *         return self._get('aggTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def aggregate_trade_iter(self, symbol, start_str=None, last_id=None):             # <<<<<<<<<<<<<<
 *         """
 *         Iterate over aggregate trade data from (start_time or last_id) to
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_85aggregate_trade_iter(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_84aggregate_trade_iter, "\n        Iterate over aggregate trade data from (start_time or last_id) to\n        the end of the history so far.\n\n        If start_time is specified, start with the first trade after\n        start_time. Meant to initialise a local cache of trade data.\n\n        If last_id is specified, start with the trade after it. This is meant\n        for updating a pre-existing local trade data cache.\n\n        Only allows start_str or last_id\342\200\224not both. Not guaranteed to work\n        right if you're running more than one of these simultaneously. You\n        will probably hit your rate limit.\n\n        See dateparser docs for valid start and end string formats http://dateparser.readthedocs.io/en/latest/\n\n        If using offset strings for dates add \"UTC\" to date string e.g. \"now UTC\", \"11 hours ago UTC\"\n\n        :param symbol: Symbol string e.g. ETHBTC\n        :type symbol: str\n        :param start_str: Start date string in UTC format or timestamp in milliseconds. The iterator will\n                          return the first trade occurring later than this time.\n        :type start_str: str|int\n        :param last_id: aggregate trade ID of the last known aggregate trade.\n                        Not a regular trade ID. See\n                        https://binance-docs.github.io/apidocs/spot/en/#compressedaggregate-trades-list.\n\n        :returns: an iterator of JSON objects, one per trade. The format of\n                  each object is identical to Client.aggregate_trades().\n\n        :type last_id: int\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_85aggregate_trade_iter = {"aggregate_trade_iter", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_85aggregate_trade_iter, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_84aggregate_trade_iter};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_85aggregate_trade_iter(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_start_str = 0;
  PyObject *__pyx_v_last_id = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("aggregate_trade_iter (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,&__pyx_n_s_start_str,&__pyx_n_s_last_id,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1039, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1039, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("aggregate_trade_iter", 0, 2, 4, 1); __PYX_ERR(0, 1039, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start_str);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1039, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_last_id);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1039, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "aggregate_trade_iter") < 0)) __PYX_ERR(0, 1039, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
    __pyx_v_start_str = values[2];
    __pyx_v_last_id = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("aggregate_trade_iter", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 1039, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.aggregate_trade_iter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_84aggregate_trade_iter(__pyx_self, __pyx_v_self, __pyx_v_symbol, __pyx_v_start_str, __pyx_v_last_id);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_84aggregate_trade_iter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_start_str, PyObject *__pyx_v_last_id) {
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("aggregate_trade_iter", 0);
  __pyx_cur_scope = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *)__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter(__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1039, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_symbol = __pyx_v_symbol;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_symbol);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_symbol);
  __pyx_cur_scope->__pyx_v_start_str = __pyx_v_start_str;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_start_str);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_start_str);
  __pyx_cur_scope->__pyx_v_last_id = __pyx_v_last_id;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_last_id);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_last_id);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_86generator, __pyx_codeobj__22, (PyObject *) __pyx_cur_scope, __pyx_n_s_aggregate_trade_iter, __pyx_n_s_BinanceRestApiManager_aggregate, __pyx_n_s_unicorn_binance_rest_api_manager); if (unlikely(!gen)) __PYX_ERR(0, 1039, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.aggregate_trade_iter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_86generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *__pyx_cur_scope = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("aggregate_trade_iter", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L16_resume_from_yield;
    case 2: goto __pyx_L23_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1039, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1073
 * 
 *         """
 *         if start_str is not None and last_id is not None:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'start_time and last_id may not be simultaneously specified.')
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_start_str != Py_None);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_last_id != Py_None);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "unicorn_binance_rest_api/manager.py":1074
 *         """
 *         if start_str is not None and last_id is not None:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'start_time and last_id may not be simultaneously specified.')
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1074, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1073
 * 
 *         """
 *         if start_str is not None and last_id is not None:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'start_time and last_id may not be simultaneously specified.')
 */
  }

  /* "unicorn_binance_rest_api/manager.py":1078
 * 
 *         # If there's no last_id, get one.
 *         if last_id is None:             # <<<<<<<<<<<<<<
 *             # Without a last_id, we actually need the first trade.  Normally,
 *             # we'd get rid of it. See the next loop.
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_last_id == Py_None);
  if (__pyx_t_1) {

    /* "unicorn_binance_rest_api/manager.py":1081
 *             # Without a last_id, we actually need the first trade.  Normally,
 *             # we'd get rid of it. See the next loop.
 *             if start_str is None:             # <<<<<<<<<<<<<<
 *                 trades = self.get_aggregate_trades(symbol=symbol, fromId=0)
 *             else:
 */
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_start_str == Py_None);
    if (__pyx_t_1) {

      /* "unicorn_binance_rest_api/manager.py":1082
 *             # we'd get rid of it. See the next loop.
 *             if start_str is None:
 *                 trades = self.get_aggregate_trades(symbol=symbol, fromId=0)             # <<<<<<<<<<<<<<
 *             else:
 *                 # The difference between startTime and endTime should be less
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_get_aggregate_trades); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1082, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1082, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_symbol, __pyx_cur_scope->__pyx_v_symbol) < 0) __PYX_ERR(0, 1082, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_fromId, __pyx_int_0) < 0) __PYX_ERR(0, 1082, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1082, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_cur_scope->__pyx_v_trades = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "unicorn_binance_rest_api/manager.py":1081
 *             # Without a last_id, we actually need the first trade.  Normally,
 *             # we'd get rid of it. See the next loop.
 *             if start_str is None:             # <<<<<<<<<<<<<<
 *                 trades = self.get_aggregate_trades(symbol=symbol, fromId=0)
 *             else:
 */
      goto __pyx_L8;
    }

    /* "unicorn_binance_rest_api/manager.py":1087
 *                 # or equal than an hour and the result set should contain at
 *                 # least one trade.
 *                 if type(start_str) == int:             # <<<<<<<<<<<<<<
 *                     start_ts = start_str
 *                 else:
 */
    /*else*/ {
      __pyx_t_5 = PyObject_RichCompare(((PyObject *)Py_TYPE(__pyx_cur_scope->__pyx_v_start_str)), ((PyObject *)(&PyInt_Type)), Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1087, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1087, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {

        /* "unicorn_binance_rest_api/manager.py":1088
 *                 # least one trade.
 *                 if type(start_str) == int:
 *                     start_ts = start_str             # <<<<<<<<<<<<<<
 *                 else:
 *                     start_ts = date_to_milliseconds(start_str)
 */
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_start_str);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_start_str);
        __pyx_cur_scope->__pyx_v_start_ts = __pyx_cur_scope->__pyx_v_start_str;

        /* "unicorn_binance_rest_api/manager.py":1087
 *                 # or equal than an hour and the result set should contain at
 *                 # least one trade.
 *                 if type(start_str) == int:             # <<<<<<<<<<<<<<
 *                     start_ts = start_str
 *                 else:
 */
        goto __pyx_L9;
      }

      /* "unicorn_binance_rest_api/manager.py":1090
 *                     start_ts = start_str
 *                 else:
 *                     start_ts = date_to_milliseconds(start_str)             # <<<<<<<<<<<<<<
 *                 # If the resulting set is empty (i.e. no trades in that interval)
 *                 # then we just move forward hour by hour until we find at least one
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_date_to_milliseconds); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1090, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_start_str};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1090, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_cur_scope->__pyx_v_start_ts = __pyx_t_5;
        __pyx_t_5 = 0;
      }
      __pyx_L9:;

      /* "unicorn_binance_rest_api/manager.py":1094
 *                 # then we just move forward hour by hour until we find at least one
 *                 # trade or reach present moment
 *                 while True:             # <<<<<<<<<<<<<<
 *                     end_ts = start_ts + (60 * 60 * 1000)
 *                     trades = self.get_aggregate_trades(
 */
      while (1) {

        /* "unicorn_binance_rest_api/manager.py":1095
 *                 # trade or reach present moment
 *                 while True:
 *                     end_ts = start_ts + (60 * 60 * 1000)             # <<<<<<<<<<<<<<
 *                     trades = self.get_aggregate_trades(
 *                         symbol=symbol,
 */
        __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_start_ts, __pyx_int_3600000, 0x36ee80, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1095, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_end_ts);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_end_ts, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;

        /* "unicorn_binance_rest_api/manager.py":1096
 *                 while True:
 *                     end_ts = start_ts + (60 * 60 * 1000)
 *                     trades = self.get_aggregate_trades(             # <<<<<<<<<<<<<<
 *                         symbol=symbol,
 *                         startTime=start_ts,
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_get_aggregate_trades); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1096, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);

        /* "unicorn_binance_rest_api/manager.py":1097
 *                     end_ts = start_ts + (60 * 60 * 1000)
 *                     trades = self.get_aggregate_trades(
 *                         symbol=symbol,             # <<<<<<<<<<<<<<
 *                         startTime=start_ts,
 *                         endTime=end_ts)
 */
        __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1097, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_symbol, __pyx_cur_scope->__pyx_v_symbol) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)

        /* "unicorn_binance_rest_api/manager.py":1098
 *                     trades = self.get_aggregate_trades(
 *                         symbol=symbol,
 *                         startTime=start_ts,             # <<<<<<<<<<<<<<
 *                         endTime=end_ts)
 *                     if len(trades) > 0:
 */
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_startTime, __pyx_cur_scope->__pyx_v_start_ts) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)

        /* "unicorn_binance_rest_api/manager.py":1099
 *                         symbol=symbol,
 *                         startTime=start_ts,
 *                         endTime=end_ts)             # <<<<<<<<<<<<<<
 *                     if len(trades) > 0:
 *                         break
 */
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_endTime, __pyx_cur_scope->__pyx_v_end_ts) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)

        /* "unicorn_binance_rest_api/manager.py":1096
 *                 while True:
 *                     end_ts = start_ts + (60 * 60 * 1000)
 *                     trades = self.get_aggregate_trades(             # <<<<<<<<<<<<<<
 *                         symbol=symbol,
 *                         startTime=start_ts,
 */
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1096, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_trades);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_trades, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __pyx_t_3 = 0;

        /* "unicorn_binance_rest_api/manager.py":1100
 *                         startTime=start_ts,
 *                         endTime=end_ts)
 *                     if len(trades) > 0:             # <<<<<<<<<<<<<<
 *                         break
 *                     # If we reach present moment and find no trades then there is
 */
        __pyx_t_7 = PyObject_Length(__pyx_cur_scope->__pyx_v_trades); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1100, __pyx_L1_error)
        __pyx_t_1 = (__pyx_t_7 > 0);
        if (__pyx_t_1) {

          /* "unicorn_binance_rest_api/manager.py":1101
 *                         endTime=end_ts)
 *                     if len(trades) > 0:
 *                         break             # <<<<<<<<<<<<<<
 *                     # If we reach present moment and find no trades then there is
 *                     # nothing to iterate, so we're done
 */
          goto __pyx_L11_break;

          /* "unicorn_binance_rest_api/manager.py":1100
 *                         startTime=start_ts,
 *                         endTime=end_ts)
 *                     if len(trades) > 0:             # <<<<<<<<<<<<<<
 *                         break
 *                     # If we reach present moment and find no trades then there is
 */
        }

        /* "unicorn_binance_rest_api/manager.py":1104
 *                     # If we reach present moment and find no trades then there is
 *                     # nothing to iterate, so we're done
 *                     if end_ts > int(time.time() * 1000):             # <<<<<<<<<<<<<<
 *                         return
 *                     start_ts = end_ts
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1104, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_t_5 = __Pyx_PyInt_MultiplyObjC(__pyx_t_3, __pyx_int_1000, 0x3E8, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_end_ts, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1104, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1104, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (__pyx_t_1) {

          /* "unicorn_binance_rest_api/manager.py":1105
 *                     # nothing to iterate, so we're done
 *                     if end_ts > int(time.time() * 1000):
 *                         return             # <<<<<<<<<<<<<<
 *                     start_ts = end_ts
 *             for t in trades:
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_r = NULL;
          goto __pyx_L0;

          /* "unicorn_binance_rest_api/manager.py":1104
 *                     # If we reach present moment and find no trades then there is
 *                     # nothing to iterate, so we're done
 *                     if end_ts > int(time.time() * 1000):             # <<<<<<<<<<<<<<
 *                         return
 *                     start_ts = end_ts
 */
        }

        /* "unicorn_binance_rest_api/manager.py":1106
 *                     if end_ts > int(time.time() * 1000):
 *                         return
 *                     start_ts = end_ts             # <<<<<<<<<<<<<<
 *             for t in trades:
 *                 yield t
 */
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_end_ts);
        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_start_ts);
        __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_start_ts, __pyx_cur_scope->__pyx_v_end_ts);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_end_ts);
      }
      __pyx_L11_break:;
    }
    __pyx_L8:;

    /* "unicorn_binance_rest_api/manager.py":1107
 *                         return
 *                     start_ts = end_ts
 *             for t in trades:             # <<<<<<<<<<<<<<
 *                 yield t
 *             last_id = trades[-1][self.AGG_ID]
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_trades)) { __Pyx_RaiseUnboundLocalError("trades"); __PYX_ERR(0, 1107, __pyx_L1_error) }
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_trades)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_trades)) {
      __pyx_t_5 = __pyx_cur_scope->__pyx_v_trades; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_trades); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1107, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1107, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1107, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_8(__pyx_t_5);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1107, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":1108
 *                     start_ts = end_ts
 *             for t in trades:
 *                 yield t             # <<<<<<<<<<<<<<
 *             last_id = trades[-1][self.AGG_ID]
 * 
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_t);
      __pyx_r = __pyx_cur_scope->__pyx_v_t;
      __Pyx_XGIVEREF(__pyx_t_5);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_7;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_8;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L16_resume_from_yield:;
      __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_5);
      __pyx_t_7 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_8 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1108, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":1107
 *                         return
 *                     start_ts = end_ts
 *             for t in trades:             # <<<<<<<<<<<<<<
 *                 yield t
 *             last_id = trades[-1][self.AGG_ID]
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "unicorn_binance_rest_api/manager.py":1109
 *             for t in trades:
 *                 yield t
 *             last_id = trades[-1][self.AGG_ID]             # <<<<<<<<<<<<<<
 * 
 *         while True:
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_trades)) { __Pyx_RaiseUnboundLocalError("trades"); __PYX_ERR(0, 1109, __pyx_L1_error) }
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_trades, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_AGG_ID); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_last_id);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_last_id, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "unicorn_binance_rest_api/manager.py":1078
 * 
 *         # If there's no last_id, get one.
 *         if last_id is None:             # <<<<<<<<<<<<<<
 *             # Without a last_id, we actually need the first trade.  Normally,
 *             # we'd get rid of it. See the next loop.
 */
  }

  /* "unicorn_binance_rest_api/manager.py":1111
 *             last_id = trades[-1][self.AGG_ID]
 * 
 *         while True:             # <<<<<<<<<<<<<<
 *             # There is no need to wait between queries, to avoid hitting the
 *             # rate limit. We're using blocking IO, and as long as we're the
 */
  while (1) {

    /* "unicorn_binance_rest_api/manager.py":1118
 *             # data. That really simplifies this function's job. Binance is
 *             # fucking awesome.
 *             trades = self.get_aggregate_trades(symbol=symbol, fromId=last_id)             # <<<<<<<<<<<<<<
 *             # fromId=n returns a set starting with id n, but we already have
 *             # that one. So get rid of the first item in the result set.
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_get_aggregate_trades); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_symbol, __pyx_cur_scope->__pyx_v_symbol) < 0) __PYX_ERR(0, 1118, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_fromId, __pyx_cur_scope->__pyx_v_last_id) < 0) __PYX_ERR(0, 1118, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_trades);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_trades, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;

    /* "unicorn_binance_rest_api/manager.py":1121
 *             # fromId=n returns a set starting with id n, but we already have
 *             # that one. So get rid of the first item in the result set.
 *             trades = trades[1:]             # <<<<<<<<<<<<<<
 *             if len(trades) == 0:
 *                 return
 */
    __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_trades, 1, 0, NULL, NULL, &__pyx_slice__24, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_trades);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_trades, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;

    /* "unicorn_binance_rest_api/manager.py":1122
 *             # that one. So get rid of the first item in the result set.
 *             trades = trades[1:]
 *             if len(trades) == 0:             # <<<<<<<<<<<<<<
 *                 return
 *             for t in trades:
 */
    __pyx_t_7 = PyObject_Length(__pyx_cur_scope->__pyx_v_trades); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1122, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_7 == 0);
    if (__pyx_t_1) {

      /* "unicorn_binance_rest_api/manager.py":1123
 *             trades = trades[1:]
 *             if len(trades) == 0:
 *                 return             # <<<<<<<<<<<<<<
 *             for t in trades:
 *                 yield t
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = NULL;
      goto __pyx_L0;

      /* "unicorn_binance_rest_api/manager.py":1122
 *             # that one. So get rid of the first item in the result set.
 *             trades = trades[1:]
 *             if len(trades) == 0:             # <<<<<<<<<<<<<<
 *                 return
 *             for t in trades:
 */
    }

    /* "unicorn_binance_rest_api/manager.py":1124
 *             if len(trades) == 0:
 *                 return
 *             for t in trades:             # <<<<<<<<<<<<<<
 *                 yield t
 *             last_id = trades[-1][self.AGG_ID]
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_trades)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_trades)) {
      __pyx_t_5 = __pyx_cur_scope->__pyx_v_trades; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_trades); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1124, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1124, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1124, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_8(__pyx_t_5);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1124, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":1125
 *                 return
 *             for t in trades:
 *                 yield t             # <<<<<<<<<<<<<<
 *             last_id = trades[-1][self.AGG_ID]
 * 
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_t);
      __pyx_r = __pyx_cur_scope->__pyx_v_t;
      __Pyx_XGIVEREF(__pyx_t_5);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_7;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_8;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 2;
      return __pyx_r;
      __pyx_L23_resume_from_yield:;
      __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_5);
      __pyx_t_7 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_8 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1125, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":1124
 *             if len(trades) == 0:
 *                 return
 *             for t in trades:             # <<<<<<<<<<<<<<
 *                 yield t
 *             last_id = trades[-1][self.AGG_ID]
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "unicorn_binance_rest_api/manager.py":1126
 *             for t in trades:
 *                 yield t
 *             last_id = trades[-1][self.AGG_ID]             # <<<<<<<<<<<<<<
 * 
 *     def get_klines(self, **params):
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_trades, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_AGG_ID); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_last_id);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_last_id, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "unicorn_binance_rest_api/manager.py":1039
 *         return self._get('aggTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def aggregate_trade_iter(self, symbol, start_str=None, last_id=None):             # <<<<<<<<<<<<<<
 *         """
 *         Iterate over aggregate trade data from (start_time or last_id) to
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("aggregate_trade_iter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1128
 *             last_id = trades[-1][self.AGG_ID]
 * 
 *     def get_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_88get_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_87get_klines, "\n        Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.\n\n        https://binance-docs.github.io/apidocs/spot/en/#klinecandlestick-data\n\n        :param symbol: required\n        :type symbol: str\n        :param interval: -\n        :type interval: str\n        :param limit: - Default 500; max 500.\n        :type limit: int\n        :param startTime:\n        :type startTime: int\n        :param endTime:\n        :type endTime: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                [\n                    1499040000000,      # Open time\n                    \"0.01634790\",       # Open\n                    \"0.80000000\",       # High\n                    \"0.01575800\",       # Low\n                    \"0.01577100\",       # Close\n                    \"148976.11427815\",  # Volume\n                    1499644799999,      # Close time\n                    \"2434.19055334\",    # Quote asset volume\n                    308,                # Number of trades\n                    \"1756.87402397\",    # Taker buy base asset volume\n                    \"28.46694368\",      # Taker buy quote asset volume\n                    \"17928899.62484339\" # Can be ignored\n                ]\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_88get_klines = {"get_klines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_88get_klines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_87get_klines};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_88get_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_klines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1128, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_klines") < 0)) __PYX_ERR(0, 1128, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_klines", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1128, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_87get_klines(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_87get_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_klines", 1);

  /* "unicorn_binance_rest_api/manager.py":1169
 * 
 *         """
 *         return self._get('klines', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def _get_earliest_valid_timestamp(self, symbol, interval):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1169, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__25, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1128
 *             last_id = trades[-1][self.AGG_ID]
 * 
 *     def get_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1171
 *         return self._get('klines', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def _get_earliest_valid_timestamp(self, symbol, interval):             # <<<<<<<<<<<<<<
 *         """
 *         Get the earliest valid open timestamp from Binance
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_90_get_earliest_valid_timestamp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_89_get_earliest_valid_timestamp, "\n        Get the earliest valid open timestamp from Binance\n\n        :param symbol: Name of symbol pair e.g. BNBBTC\n        :type symbol: str\n        :param interval: Binance Kline interval\n        :type interval: str\n\n        :return: first valid timestamp\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_90_get_earliest_valid_timestamp = {"_get_earliest_valid_timestamp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_90_get_earliest_valid_timestamp, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_89_get_earliest_valid_timestamp};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_90_get_earliest_valid_timestamp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_interval = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_earliest_valid_timestamp (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,&__pyx_n_s_interval,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1171, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1171, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_get_earliest_valid_timestamp", 1, 3, 3, 1); __PYX_ERR(0, 1171, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_interval)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1171, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_get_earliest_valid_timestamp", 1, 3, 3, 2); __PYX_ERR(0, 1171, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_earliest_valid_timestamp") < 0)) __PYX_ERR(0, 1171, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
    __pyx_v_interval = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_earliest_valid_timestamp", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1171, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._get_earliest_valid_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_89_get_earliest_valid_timestamp(__pyx_self, __pyx_v_self, __pyx_v_symbol, __pyx_v_interval);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_89_get_earliest_valid_timestamp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_interval) {
  PyObject *__pyx_v_kline = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_earliest_valid_timestamp", 1);

  /* "unicorn_binance_rest_api/manager.py":1183
 * 
 *         """
 *         kline = self.get_klines(             # <<<<<<<<<<<<<<
 *             symbol=symbol,
 *             interval=interval,
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_klines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":1184
 *         """
 *         kline = self.get_klines(
 *             symbol=symbol,             # <<<<<<<<<<<<<<
 *             interval=interval,
 *             limit=1,
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_symbol, __pyx_v_symbol) < 0) __PYX_ERR(0, 1184, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1185
 *         kline = self.get_klines(
 *             symbol=symbol,
 *             interval=interval,             # <<<<<<<<<<<<<<
 *             limit=1,
 *             startTime=0,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_interval, __pyx_v_interval) < 0) __PYX_ERR(0, 1184, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_limit, __pyx_int_1) < 0) __PYX_ERR(0, 1184, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_startTime, __pyx_int_0) < 0) __PYX_ERR(0, 1184, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1188
 *             limit=1,
 *             startTime=0,
 *             endTime=None             # <<<<<<<<<<<<<<
 *         )
 *         return kline[0][0]
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_endTime, Py_None) < 0) __PYX_ERR(0, 1184, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1183
 * 
 *         """
 *         kline = self.get_klines(             # <<<<<<<<<<<<<<
 *             symbol=symbol,
 *             interval=interval,
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_kline = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":1190
 *             endTime=None
 *         )
 *         return kline[0][0]             # <<<<<<<<<<<<<<
 * 
 *     def get_historical_klines(self, symbol, interval, start_str, end_str=None,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_kline, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1171
 *         return self._get('klines', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def _get_earliest_valid_timestamp(self, symbol, interval):             # <<<<<<<<<<<<<<
 *         """
 *         Get the earliest valid open timestamp from Binance
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager._get_earliest_valid_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kline);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1192
 *         return kline[0][0]
 * 
 *     def get_historical_klines(self, symbol, interval, start_str, end_str=None,             # <<<<<<<<<<<<<<
 *                               limit=500):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_92get_historical_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_91get_historical_klines, "\n        Get Historical Klines from Binance\n\n        See dateparser docs for valid start and end string formats http://dateparser.readthedocs.io/en/latest/\n\n        If using offset strings for dates add \"UTC\" to date string e.g. \"now UTC\", \"11 hours ago UTC\"\n\n        :param symbol: Name of symbol pair e.g. BNBBTC\n        :type symbol: str\n        :param interval: Binance Kline interval\n        :type interval: str\n        :param start_str: Start date string in UTC format or timestamp in milliseconds\n        :type start_str: str|int\n        :param end_str: optional - end date string in UTC format or timestamp in milliseconds (default will fetch\n                        everything up to now)\n        :type end_str: str|int\n        :param limit: Default 500; max 1000.\n        :type limit: int\n\n        :return: list of OHLCV values\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_92get_historical_klines = {"get_historical_klines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_92get_historical_klines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_91get_historical_klines};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_92get_historical_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_interval = 0;
  PyObject *__pyx_v_start_str = 0;
  PyObject *__pyx_v_end_str = 0;
  PyObject *__pyx_v_limit = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_historical_klines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,&__pyx_n_s_interval,&__pyx_n_s_start_str,&__pyx_n_s_end_str,&__pyx_n_s_limit,0};
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)__pyx_int_500)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1192, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1192, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_historical_klines", 0, 4, 6, 1); __PYX_ERR(0, 1192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_interval)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1192, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_historical_klines", 0, 4, 6, 2); __PYX_ERR(0, 1192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start_str)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1192, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_historical_klines", 0, 4, 6, 3); __PYX_ERR(0, 1192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_end_str);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_limit);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1192, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_historical_klines") < 0)) __PYX_ERR(0, 1192, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
    __pyx_v_interval = values[2];
    __pyx_v_start_str = values[3];
    __pyx_v_end_str = values[4];
    __pyx_v_limit = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_historical_klines", 0, 4, 6, __pyx_nargs); __PYX_ERR(0, 1192, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_historical_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_91get_historical_klines(__pyx_self, __pyx_v_self, __pyx_v_symbol, __pyx_v_interval, __pyx_v_start_str, __pyx_v_end_str, __pyx_v_limit);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_91get_historical_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_interval, PyObject *__pyx_v_start_str, PyObject *__pyx_v_end_str, PyObject *__pyx_v_limit) {
  PyObject *__pyx_v_output_data = NULL;
  PyObject *__pyx_v_timeframe = NULL;
  PyObject *__pyx_v_start_ts = NULL;
  PyObject *__pyx_v_first_valid_ts = NULL;
  PyObject *__pyx_v_end_ts = NULL;
  PyObject *__pyx_v_idx = NULL;
  PyObject *__pyx_v_temp_data = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_historical_klines", 1);

  /* "unicorn_binance_rest_api/manager.py":1217
 *         """
 *         # init our list
 *         output_data = []             # <<<<<<<<<<<<<<
 * 
 *         # convert interval to useful value in seconds
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_output_data = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":1220
 * 
 *         # convert interval to useful value in seconds
 *         timeframe = interval_to_milliseconds(interval)             # <<<<<<<<<<<<<<
 * 
 *         # convert our date strings to milliseconds
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_interval_to_milliseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_interval};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_timeframe = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":1223
 * 
 *         # convert our date strings to milliseconds
 *         if type(start_str) == int:             # <<<<<<<<<<<<<<
 *             start_ts = start_str
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(((PyObject *)Py_TYPE(__pyx_v_start_str)), ((PyObject *)(&PyInt_Type)), Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1223, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":1224
 *         # convert our date strings to milliseconds
 *         if type(start_str) == int:
 *             start_ts = start_str             # <<<<<<<<<<<<<<
 *         else:
 *             start_ts = date_to_milliseconds(start_str)
 */
    __Pyx_INCREF(__pyx_v_start_str);
    __pyx_v_start_ts = __pyx_v_start_str;

    /* "unicorn_binance_rest_api/manager.py":1223
 * 
 *         # convert our date strings to milliseconds
 *         if type(start_str) == int:             # <<<<<<<<<<<<<<
 *             start_ts = start_str
 *         else:
 */
    goto __pyx_L3;
  }

  /* "unicorn_binance_rest_api/manager.py":1226
 *             start_ts = start_str
 *         else:
 *             start_ts = date_to_milliseconds(start_str)             # <<<<<<<<<<<<<<
 * 
 *         # establish first available start timestamp
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_date_to_milliseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_start_str};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_start_ts = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "unicorn_binance_rest_api/manager.py":1229
 * 
 *         # establish first available start timestamp
 *         first_valid_ts = self._get_earliest_valid_timestamp(symbol, interval)             # <<<<<<<<<<<<<<
 *         start_ts = max(start_ts, first_valid_ts)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_earliest_valid_timestamp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_symbol, __pyx_v_interval};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_first_valid_ts = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":1230
 *         # establish first available start timestamp
 *         first_valid_ts = self._get_earliest_valid_timestamp(symbol, interval)
 *         start_ts = max(start_ts, first_valid_ts)             # <<<<<<<<<<<<<<
 * 
 *         # if an end time was passed convert it
 */
  __Pyx_INCREF(__pyx_v_first_valid_ts);
  __pyx_t_1 = __pyx_v_first_valid_ts;
  __Pyx_INCREF(__pyx_v_start_ts);
  __pyx_t_2 = __pyx_v_start_ts;
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1230, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_5) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = __pyx_t_2;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_start_ts, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":1233
 * 
 *         # if an end time was passed convert it
 *         end_ts = None             # <<<<<<<<<<<<<<
 *         if end_str:
 *             if type(end_str) == int:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_end_ts = Py_None;

  /* "unicorn_binance_rest_api/manager.py":1234
 *         # if an end time was passed convert it
 *         end_ts = None
 *         if end_str:             # <<<<<<<<<<<<<<
 *             if type(end_str) == int:
 *                 end_ts = end_str
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_end_str); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1234, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":1235
 *         end_ts = None
 *         if end_str:
 *             if type(end_str) == int:             # <<<<<<<<<<<<<<
 *                 end_ts = end_str
 *             else:
 */
    __pyx_t_1 = PyObject_RichCompare(((PyObject *)Py_TYPE(__pyx_v_end_str)), ((PyObject *)(&PyInt_Type)), Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1235, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1235, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1236
 *         if end_str:
 *             if type(end_str) == int:
 *                 end_ts = end_str             # <<<<<<<<<<<<<<
 *             else:
 *                 end_ts = date_to_milliseconds(end_str)
 */
      __Pyx_INCREF(__pyx_v_end_str);
      __Pyx_DECREF_SET(__pyx_v_end_ts, __pyx_v_end_str);

      /* "unicorn_binance_rest_api/manager.py":1235
 *         end_ts = None
 *         if end_str:
 *             if type(end_str) == int:             # <<<<<<<<<<<<<<
 *                 end_ts = end_str
 *             else:
 */
      goto __pyx_L5;
    }

    /* "unicorn_binance_rest_api/manager.py":1238
 *                 end_ts = end_str
 *             else:
 *                 end_ts = date_to_milliseconds(end_str)             # <<<<<<<<<<<<<<
 * 
 *         idx = 0
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_date_to_milliseconds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1238, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_end_str};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1238, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_end_ts, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "unicorn_binance_rest_api/manager.py":1234
 *         # if an end time was passed convert it
 *         end_ts = None
 *         if end_str:             # <<<<<<<<<<<<<<
 *             if type(end_str) == int:
 *                 end_ts = end_str
 */
  }

  /* "unicorn_binance_rest_api/manager.py":1240
 *                 end_ts = date_to_milliseconds(end_str)
 * 
 *         idx = 0             # <<<<<<<<<<<<<<
 *         while True:
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_idx = __pyx_int_0;

  /* "unicorn_binance_rest_api/manager.py":1241
 * 
 *         idx = 0
 *         while True:             # <<<<<<<<<<<<<<
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             temp_data = self.get_klines(
 */
  while (1) {

    /* "unicorn_binance_rest_api/manager.py":1243
 *         while True:
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             temp_data = self.get_klines(             # <<<<<<<<<<<<<<
 *                 symbol=symbol,
 *                 interval=interval,
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_klines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "unicorn_binance_rest_api/manager.py":1244
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             temp_data = self.get_klines(
 *                 symbol=symbol,             # <<<<<<<<<<<<<<
 *                 interval=interval,
 *                 limit=limit,
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_symbol, __pyx_v_symbol) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1245
 *             temp_data = self.get_klines(
 *                 symbol=symbol,
 *                 interval=interval,             # <<<<<<<<<<<<<<
 *                 limit=limit,
 *                 startTime=start_ts,
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_interval, __pyx_v_interval) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1246
 *                 symbol=symbol,
 *                 interval=interval,
 *                 limit=limit,             # <<<<<<<<<<<<<<
 *                 startTime=start_ts,
 *                 endTime=end_ts
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_limit, __pyx_v_limit) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1247
 *                 interval=interval,
 *                 limit=limit,
 *                 startTime=start_ts,             # <<<<<<<<<<<<<<
 *                 endTime=end_ts
 *             )
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_startTime, __pyx_v_start_ts) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1248
 *                 limit=limit,
 *                 startTime=start_ts,
 *                 endTime=end_ts             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_endTime, __pyx_v_end_ts) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1243
 *         while True:
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             temp_data = self.get_klines(             # <<<<<<<<<<<<<<
 *                 symbol=symbol,
 *                 interval=interval,
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_temp_data, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":1252
 * 
 *             # handle the case where exactly the limit amount of data was returned last loop
 *             if not len(temp_data):             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    __pyx_t_7 = PyObject_Length(__pyx_v_temp_data); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1252, __pyx_L1_error)
    __pyx_t_5 = (!(__pyx_t_7 != 0));
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1253
 *             # handle the case where exactly the limit amount of data was returned last loop
 *             if not len(temp_data):
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             # append this loops data to our output data
 */
      goto __pyx_L7_break;

      /* "unicorn_binance_rest_api/manager.py":1252
 * 
 *             # handle the case where exactly the limit amount of data was returned last loop
 *             if not len(temp_data):             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    }

    /* "unicorn_binance_rest_api/manager.py":1256
 * 
 *             # append this loops data to our output data
 *             output_data += temp_data             # <<<<<<<<<<<<<<
 * 
 *             # set our start timestamp using the last value in the array
 */
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_output_data, __pyx_v_temp_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1256, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_output_data, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":1259
 * 
 *             # set our start timestamp using the last value in the array
 *             start_ts = temp_data[-1][0]             # <<<<<<<<<<<<<<
 * 
 *             idx += 1
 */
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_temp_data, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_start_ts, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":1261
 *             start_ts = temp_data[-1][0]
 * 
 *             idx += 1             # <<<<<<<<<<<<<<
 *             # check if we received less than the required limit and exit the loop
 *             if len(temp_data) < limit:
 */
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_idx, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_idx, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":1263
 *             idx += 1
 *             # check if we received less than the required limit and exit the loop
 *             if len(temp_data) < limit:             # <<<<<<<<<<<<<<
 *                 # exit the while loop
 *                 break
 */
    __pyx_t_7 = PyObject_Length(__pyx_v_temp_data); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1263, __pyx_L1_error)
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, __pyx_v_limit, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1263, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1263, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1265
 *             if len(temp_data) < limit:
 *                 # exit the while loop
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             # increment next call by our timeframe
 */
      goto __pyx_L7_break;

      /* "unicorn_binance_rest_api/manager.py":1263
 *             idx += 1
 *             # check if we received less than the required limit and exit the loop
 *             if len(temp_data) < limit:             # <<<<<<<<<<<<<<
 *                 # exit the while loop
 *                 break
 */
    }

    /* "unicorn_binance_rest_api/manager.py":1268
 * 
 *             # increment next call by our timeframe
 *             start_ts += timeframe             # <<<<<<<<<<<<<<
 * 
 *             # sleep after every 3rd call to be kind to the API
 */
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_start_ts, __pyx_v_timeframe); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_start_ts, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":1271
 * 
 *             # sleep after every 3rd call to be kind to the API
 *             if idx % 3 == 0:             # <<<<<<<<<<<<<<
 *                 time.sleep(1)
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_RemainderObjC(__pyx_v_idx, __pyx_int_3, 3, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1271, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1272
 *             # sleep after every 3rd call to be kind to the API
 *             if idx % 3 == 0:
 *                 time.sleep(1)             # <<<<<<<<<<<<<<
 * 
 *         return output_data
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_sleep); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_int_1};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1272, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "unicorn_binance_rest_api/manager.py":1271
 * 
 *             # sleep after every 3rd call to be kind to the API
 *             if idx % 3 == 0:             # <<<<<<<<<<<<<<
 *                 time.sleep(1)
 * 
 */
    }
  }
  __pyx_L7_break:;

  /* "unicorn_binance_rest_api/manager.py":1274
 *                 time.sleep(1)
 * 
 *         return output_data             # <<<<<<<<<<<<<<
 * 
 *     def get_historical_klines_generator(self, symbol, interval, start_str, end_str=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_output_data);
  __pyx_r = __pyx_v_output_data;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1192
 *         return kline[0][0]
 * 
 *     def get_historical_klines(self, symbol, interval, start_str, end_str=None,             # <<<<<<<<<<<<<<
 *                               limit=500):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_historical_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_output_data);
  __Pyx_XDECREF(__pyx_v_timeframe);
  __Pyx_XDECREF(__pyx_v_start_ts);
  __Pyx_XDECREF(__pyx_v_first_valid_ts);
  __Pyx_XDECREF(__pyx_v_end_ts);
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_XDECREF(__pyx_v_temp_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_95generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "unicorn_binance_rest_api/manager.py":1276
 *         return output_data
 * 
 *     def get_historical_klines_generator(self, symbol, interval, start_str, end_str=None):             # <<<<<<<<<<<<<<
 *         """
 *         Get Historical Klines from Binance
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_94get_historical_klines_generator(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_93get_historical_klines_generator, "\n        Get Historical Klines from Binance\n\n        See dateparser docs for valid start and end string formats http://dateparser.readthedocs.io/en/latest/\n\n        If using offset strings for dates add \"UTC\" to date string e.g. \"now UTC\", \"11 hours ago UTC\"\n\n        :param symbol: Name of symbol pair e.g. BNBBTC\n        :type symbol: str\n        :param interval: Binance Kline interval\n        :type interval: str\n        :param start_str: Start date string in UTC format or timestamp in milliseconds\n        :type start_str: str|int\n        :param end_str: optional - end date string in UTC format or timestamp in milliseconds (default will fetch\n                        everything up to now)\n        :type end_str: str|int\n\n        :return: generator of OHLCV values\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_94get_historical_klines_generator = {"get_historical_klines_generator", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_94get_historical_klines_generator, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_93get_historical_klines_generator};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_94get_historical_klines_generator(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_interval = 0;
  PyObject *__pyx_v_start_str = 0;
  PyObject *__pyx_v_end_str = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_historical_klines_generator (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,&__pyx_n_s_interval,&__pyx_n_s_start_str,&__pyx_n_s_end_str,0};
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1276, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1276, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_historical_klines_generator", 0, 4, 5, 1); __PYX_ERR(0, 1276, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_interval)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1276, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_historical_klines_generator", 0, 4, 5, 2); __PYX_ERR(0, 1276, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start_str)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1276, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_historical_klines_generator", 0, 4, 5, 3); __PYX_ERR(0, 1276, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_end_str);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1276, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_historical_klines_generator") < 0)) __PYX_ERR(0, 1276, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
    __pyx_v_interval = values[2];
    __pyx_v_start_str = values[3];
    __pyx_v_end_str = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_historical_klines_generator", 0, 4, 5, __pyx_nargs); __PYX_ERR(0, 1276, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_historical_klines_generator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_93get_historical_klines_generator(__pyx_self, __pyx_v_self, __pyx_v_symbol, __pyx_v_interval, __pyx_v_start_str, __pyx_v_end_str);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_93get_historical_klines_generator(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_interval, PyObject *__pyx_v_start_str, PyObject *__pyx_v_end_str) {
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_historical_klines_generator", 0);
  __pyx_cur_scope = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *)__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator(__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1276, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_symbol = __pyx_v_symbol;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_symbol);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_symbol);
  __pyx_cur_scope->__pyx_v_interval = __pyx_v_interval;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_interval);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_interval);
  __pyx_cur_scope->__pyx_v_start_str = __pyx_v_start_str;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_start_str);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_start_str);
  __pyx_cur_scope->__pyx_v_end_str = __pyx_v_end_str;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_end_str);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_end_str);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_95generator1, __pyx_codeobj__26, (PyObject *) __pyx_cur_scope, __pyx_n_s_get_historical_klines_generator, __pyx_n_s_BinanceRestApiManager_get_histor, __pyx_n_s_unicorn_binance_rest_api_manager); if (unlikely(!gen)) __PYX_ERR(0, 1276, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_historical_klines_generator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_95generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *__pyx_cur_scope = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_historical_klines_generator", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L12_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1276, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1299
 * 
 *         # set up the max limit
 *         limit = 500             # <<<<<<<<<<<<<<
 * 
 *         # convert interval to useful value in seconds
 */
  __pyx_cur_scope->__pyx_v_limit = 0x1F4;

  /* "unicorn_binance_rest_api/manager.py":1302
 * 
 *         # convert interval to useful value in seconds
 *         timeframe = interval_to_milliseconds(interval)             # <<<<<<<<<<<<<<
 * 
 *         # convert our date strings to milliseconds
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_interval_to_milliseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_interval};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_timeframe = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":1305
 * 
 *         # convert our date strings to milliseconds
 *         if type(start_str) == int:             # <<<<<<<<<<<<<<
 *             start_ts = start_str
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(((PyObject *)Py_TYPE(__pyx_cur_scope->__pyx_v_start_str)), ((PyObject *)(&PyInt_Type)), Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1305, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1305, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":1306
 *         # convert our date strings to milliseconds
 *         if type(start_str) == int:
 *             start_ts = start_str             # <<<<<<<<<<<<<<
 *         else:
 *             start_ts = date_to_milliseconds(start_str)
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_start_str);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_start_str);
    __pyx_cur_scope->__pyx_v_start_ts = __pyx_cur_scope->__pyx_v_start_str;

    /* "unicorn_binance_rest_api/manager.py":1305
 * 
 *         # convert our date strings to milliseconds
 *         if type(start_str) == int:             # <<<<<<<<<<<<<<
 *             start_ts = start_str
 *         else:
 */
    goto __pyx_L4;
  }

  /* "unicorn_binance_rest_api/manager.py":1308
 *             start_ts = start_str
 *         else:
 *             start_ts = date_to_milliseconds(start_str)             # <<<<<<<<<<<<<<
 * 
 *         # establish first available start timestamp
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_date_to_milliseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_start_str};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_v_start_ts = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "unicorn_binance_rest_api/manager.py":1311
 * 
 *         # establish first available start timestamp
 *         first_valid_ts = self._get_earliest_valid_timestamp(symbol, interval)             # <<<<<<<<<<<<<<
 *         start_ts = max(start_ts, first_valid_ts)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_get_earliest_valid_timestamp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_symbol, __pyx_cur_scope->__pyx_v_interval};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_first_valid_ts = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":1312
 *         # establish first available start timestamp
 *         first_valid_ts = self._get_earliest_valid_timestamp(symbol, interval)
 *         start_ts = max(start_ts, first_valid_ts)             # <<<<<<<<<<<<<<
 * 
 *         # if an end time was passed convert it
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_first_valid_ts);
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_first_valid_ts;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_start_ts);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_start_ts;
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_5) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = __pyx_t_2;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_start_ts);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_start_ts, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":1315
 * 
 *         # if an end time was passed convert it
 *         end_ts = None             # <<<<<<<<<<<<<<
 *         if end_str:
 *             if type(end_str) == int:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_cur_scope->__pyx_v_end_ts = Py_None;

  /* "unicorn_binance_rest_api/manager.py":1316
 *         # if an end time was passed convert it
 *         end_ts = None
 *         if end_str:             # <<<<<<<<<<<<<<
 *             if type(end_str) == int:
 *                 end_ts = end_str
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_end_str); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1316, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "unicorn_binance_rest_api/manager.py":1317
 *         end_ts = None
 *         if end_str:
 *             if type(end_str) == int:             # <<<<<<<<<<<<<<
 *                 end_ts = end_str
 *             else:
 */
    __pyx_t_1 = PyObject_RichCompare(((PyObject *)Py_TYPE(__pyx_cur_scope->__pyx_v_end_str)), ((PyObject *)(&PyInt_Type)), Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1317, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1317, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1318
 *         if end_str:
 *             if type(end_str) == int:
 *                 end_ts = end_str             # <<<<<<<<<<<<<<
 *             else:
 *                 end_ts = date_to_milliseconds(end_str)
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_end_str);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_end_ts);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_end_ts, __pyx_cur_scope->__pyx_v_end_str);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_end_str);

      /* "unicorn_binance_rest_api/manager.py":1317
 *         end_ts = None
 *         if end_str:
 *             if type(end_str) == int:             # <<<<<<<<<<<<<<
 *                 end_ts = end_str
 *             else:
 */
      goto __pyx_L6;
    }

    /* "unicorn_binance_rest_api/manager.py":1320
 *                 end_ts = end_str
 *             else:
 *                 end_ts = date_to_milliseconds(end_str)             # <<<<<<<<<<<<<<
 * 
 *         idx = 0
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_date_to_milliseconds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_end_str};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1320, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_end_ts);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_end_ts, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L6:;

    /* "unicorn_binance_rest_api/manager.py":1316
 *         # if an end time was passed convert it
 *         end_ts = None
 *         if end_str:             # <<<<<<<<<<<<<<
 *             if type(end_str) == int:
 *                 end_ts = end_str
 */
  }

  /* "unicorn_binance_rest_api/manager.py":1322
 *                 end_ts = date_to_milliseconds(end_str)
 * 
 *         idx = 0             # <<<<<<<<<<<<<<
 *         while True:
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 */
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __pyx_cur_scope->__pyx_v_idx = __pyx_int_0;

  /* "unicorn_binance_rest_api/manager.py":1323
 * 
 *         idx = 0
 *         while True:             # <<<<<<<<<<<<<<
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             output_data = self.get_klines(
 */
  while (1) {

    /* "unicorn_binance_rest_api/manager.py":1325
 *         while True:
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             output_data = self.get_klines(             # <<<<<<<<<<<<<<
 *                 symbol=symbol,
 *                 interval=interval,
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_get_klines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "unicorn_binance_rest_api/manager.py":1326
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             output_data = self.get_klines(
 *                 symbol=symbol,             # <<<<<<<<<<<<<<
 *                 interval=interval,
 *                 limit=limit,
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_symbol, __pyx_cur_scope->__pyx_v_symbol) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1327
 *             output_data = self.get_klines(
 *                 symbol=symbol,
 *                 interval=interval,             # <<<<<<<<<<<<<<
 *                 limit=limit,
 *                 startTime=start_ts,
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_interval, __pyx_cur_scope->__pyx_v_interval) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1328
 *                 symbol=symbol,
 *                 interval=interval,
 *                 limit=limit,             # <<<<<<<<<<<<<<
 *                 startTime=start_ts,
 *                 endTime=end_ts
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_cur_scope->__pyx_v_limit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_limit, __pyx_t_2) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":1329
 *                 interval=interval,
 *                 limit=limit,
 *                 startTime=start_ts,             # <<<<<<<<<<<<<<
 *                 endTime=end_ts
 *             )
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_startTime, __pyx_cur_scope->__pyx_v_start_ts) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1330
 *                 limit=limit,
 *                 startTime=start_ts,
 *                 endTime=end_ts             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_endTime, __pyx_cur_scope->__pyx_v_end_ts) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":1325
 *         while True:
 *             # fetch the klines from start_ts up to max 500 entries or the end_ts if set
 *             output_data = self.get_klines(             # <<<<<<<<<<<<<<
 *                 symbol=symbol,
 *                 interval=interval,
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_output_data);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_output_data, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":1334
 * 
 *             # handle the case where exactly the limit amount of data was returned last loop
 *             if not len(output_data):             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    __pyx_t_7 = PyObject_Length(__pyx_cur_scope->__pyx_v_output_data); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1334, __pyx_L1_error)
    __pyx_t_5 = (!(__pyx_t_7 != 0));
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1335
 *             # handle the case where exactly the limit amount of data was returned last loop
 *             if not len(output_data):
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             # yield data
 */
      goto __pyx_L8_break;

      /* "unicorn_binance_rest_api/manager.py":1334
 * 
 *             # handle the case where exactly the limit amount of data was returned last loop
 *             if not len(output_data):             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    }

    /* "unicorn_binance_rest_api/manager.py":1338
 * 
 *             # yield data
 *             for o in output_data:             # <<<<<<<<<<<<<<
 *                 yield o
 * 
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_output_data)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_output_data)) {
      __pyx_t_2 = __pyx_cur_scope->__pyx_v_output_data; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_output_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1338, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1338, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1338, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_8(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1338, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_o);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_o, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":1339
 *             # yield data
 *             for o in output_data:
 *                 yield o             # <<<<<<<<<<<<<<
 * 
 *             # set our start timestamp using the last value in the array
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_o);
      __pyx_r = __pyx_cur_scope->__pyx_v_o;
      __Pyx_XGIVEREF(__pyx_t_2);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_7;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_8;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L12_resume_from_yield:;
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_2);
      __pyx_t_7 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_8 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1339, __pyx_L1_error)

      /* "unicorn_binance_rest_api/manager.py":1338
 * 
 *             # yield data
 *             for o in output_data:             # <<<<<<<<<<<<<<
 *                 yield o
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":1342
 * 
 *             # set our start timestamp using the last value in the array
 *             start_ts = output_data[-1][0]             # <<<<<<<<<<<<<<
 * 
 *             idx += 1
 */
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_output_data, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1342, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1342, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_start_ts);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_start_ts, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":1344
 *             start_ts = output_data[-1][0]
 * 
 *             idx += 1             # <<<<<<<<<<<<<<
 *             # check if we received less than the required limit and exit the loop
 *             if len(output_data) < limit:
 */
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_idx, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_idx);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_idx, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":1346
 *             idx += 1
 *             # check if we received less than the required limit and exit the loop
 *             if len(output_data) < limit:             # <<<<<<<<<<<<<<
 *                 # exit the while loop
 *                 break
 */
    __pyx_t_7 = PyObject_Length(__pyx_cur_scope->__pyx_v_output_data); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1346, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_7 < __pyx_cur_scope->__pyx_v_limit);
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1348
 *             if len(output_data) < limit:
 *                 # exit the while loop
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             # increment next call by our timeframe
 */
      goto __pyx_L8_break;

      /* "unicorn_binance_rest_api/manager.py":1346
 *             idx += 1
 *             # check if we received less than the required limit and exit the loop
 *             if len(output_data) < limit:             # <<<<<<<<<<<<<<
 *                 # exit the while loop
 *                 break
 */
    }

    /* "unicorn_binance_rest_api/manager.py":1351
 * 
 *             # increment next call by our timeframe
 *             start_ts += timeframe             # <<<<<<<<<<<<<<
 * 
 *             # sleep after every 3rd call to be kind to the API
 */
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_cur_scope->__pyx_v_start_ts, __pyx_cur_scope->__pyx_v_timeframe); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_start_ts);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_start_ts, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":1354
 * 
 *             # sleep after every 3rd call to be kind to the API
 *             if idx % 3 == 0:             # <<<<<<<<<<<<<<
 *                 time.sleep(1)
 * 
 */
    __pyx_t_3 = __Pyx_PyInt_RemainderObjC(__pyx_cur_scope->__pyx_v_idx, __pyx_int_3, 3, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1354, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_5) {

      /* "unicorn_binance_rest_api/manager.py":1355
 *             # sleep after every 3rd call to be kind to the API
 *             if idx % 3 == 0:
 *                 time.sleep(1)             # <<<<<<<<<<<<<<
 * 
 *     def get_avg_price(self, **params):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_sleep); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_int_1};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1355, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":1354
 * 
 *             # sleep after every 3rd call to be kind to the API
 *             if idx % 3 == 0:             # <<<<<<<<<<<<<<
 *                 time.sleep(1)
 * 
 */
    }
  }
  __pyx_L8_break:;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "unicorn_binance_rest_api/manager.py":1276
 *         return output_data
 * 
 *     def get_historical_klines_generator(self, symbol, interval, start_str, end_str=None):             # <<<<<<<<<<<<<<
 *         """
 *         Get Historical Klines from Binance
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("get_historical_klines_generator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1357
 *                 time.sleep(1)
 * 
 *     def get_avg_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Current average price for a symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_97get_avg_price(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_96get_avg_price, "Current average price for a symbol.\n\n        https://binance-docs.github.io/apidocs/spot/en/#current-average-price\n\n        :param symbol:\n        :type symbol: str\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"mins\": 5,\n                \"price\": \"9.35751834\"\n            }\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_97get_avg_price = {"get_avg_price", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_97get_avg_price, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_96get_avg_price};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_97get_avg_price(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_avg_price (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1357, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_avg_price") < 0)) __PYX_ERR(0, 1357, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_avg_price", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1357, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_avg_price", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_96get_avg_price(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_96get_avg_price(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_avg_price", 1);

  /* "unicorn_binance_rest_api/manager.py":1374
 *             }
 *         """
 *         return self._get('avgPrice', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1374, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__27, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1357
 *                 time.sleep(1)
 * 
 *     def get_avg_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Current average price for a symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_avg_price", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1376
 *         return self._get('avgPrice', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour price change statistics.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_99get_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_98get_ticker, "24 hour price change statistics.\n\n        https://binance-docs.github.io/apidocs/spot/en/#24hr-ticker-price-change-statistics\n\n        :param symbol:\n        :type symbol: str\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"priceChange\": \"-94.99999800\",\n                \"priceChangePercent\": \"-95.960\",\n                \"weightedAvgPrice\": \"0.29628482\",\n                \"prevClosePrice\": \"0.10002000\",\n                \"lastPrice\": \"4.00000200\",\n                \"bidPrice\": \"4.00000000\",\n                \"askPrice\": \"4.00000200\",\n                \"openPrice\": \"99.00000000\",\n                \"highPrice\": \"100.00000000\",\n                \"lowPrice\": \"0.10000000\",\n                \"volume\": \"8913.30000000\",\n                \"openTime\": 1499783499040,\n                \"closeTime\": 1499869899040,\n                \"fristId\": 28385,   # First tradeId\n                \"lastId\": 28460,    # Last tradeId\n                \"count\": 76         # Trade count\n            }\n\n        OR\n\n        .. code-block:: python\n\n            [\n                {\n                    \"priceChange\": \"-94.99999800\",\n                    \"priceChangePercent\": \"-95.960\",\n                    \"weightedAvgPrice\": \"0.29628482\",\n                    \"prevClosePrice\": \"0.10002000\",\n                    \"lastPrice\": \"4.00000200\",\n                    \"bidPrice\": \"4.00000000\",\n                    \"askPrice\": \"4.00000200\",\n                    \"openPrice\": \"99.00000000\",\n                    \"highPrice\": \"100.00000000\",\n                    \"lowPrice\": \"0.10000000\",\n                    \"volume\": \"8913.30000000\",\n                    \"openTime\": 1499783499040,\n                    \"closeTime\": 1499869899040,\n                    \"fristId\": 28385,   # First tradeId\n                    \"lastId\": 28460,    # Last tradeId\n                 ""   \"count\": 76         # Trade count\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_99get_ticker = {"get_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_99get_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_98get_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_99get_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1376, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_ticker") < 0)) __PYX_ERR(0, 1376, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1376, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_98get_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_98get_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":1435
 * 
 *         """
 *         return self._get('ticker/24hr', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_symbol_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1435, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__28, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1376
 *         return self._get('avgPrice', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour price change statistics.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1437
 *         return self._get('ticker/24hr', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_101get_symbol_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_100get_symbol_ticker, "Latest price for a symbol or symbols.\n\n        https://binance-docs.github.io/apidocs/spot/en/#24hr-ticker-price-change-statistics\n\n        :param symbol:\n        :type symbol: str\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"LTCBTC\",\n                \"price\": \"4.00000200\"\n            }\n\n        OR\n\n        .. code-block:: python\n\n            [\n                {\n                    \"symbol\": \"LTCBTC\",\n                    \"price\": \"4.00000200\"\n                },\n                {\n                    \"symbol\": \"ETHBTC\",\n                    \"price\": \"0.07946600\"\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_101get_symbol_ticker = {"get_symbol_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_101get_symbol_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_100get_symbol_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_101get_symbol_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_symbol_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1437, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_symbol_ticker") < 0)) __PYX_ERR(0, 1437, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_symbol_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1437, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_symbol_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_100get_symbol_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_100get_symbol_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_symbol_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":1472
 * 
 *         """
 *         return self._get('ticker/price', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_orderbook_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1472, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__16, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1437
 *         return self._get('ticker/24hr', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_symbol_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1474
 *         return self._get('ticker/price', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_103get_orderbook_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_102get_orderbook_ticker, "Latest price for a symbol or symbols.\n\n        https://binance-docs.github.io/apidocs/spot/en/#symbol-order-book-ticker\n\n        :param symbol:\n        :type symbol: str\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"LTCBTC\",\n                \"bidPrice\": \"4.00000000\",\n                \"bidQty\": \"431.00000000\",\n                \"askPrice\": \"4.00000200\",\n                \"askQty\": \"9.00000000\"\n            }\n\n        OR\n\n        .. code-block:: python\n\n            [\n                {\n                    \"symbol\": \"LTCBTC\",\n                    \"bidPrice\": \"4.00000000\",\n                    \"bidQty\": \"431.00000000\",\n                    \"askPrice\": \"4.00000200\",\n                    \"askQty\": \"9.00000000\"\n                },\n                {\n                    \"symbol\": \"ETHBTC\",\n                    \"bidPrice\": \"0.07946700\",\n                    \"bidQty\": \"9.00000000\",\n                    \"askPrice\": \"100000.00000000\",\n                    \"askQty\": \"1000.00000000\"\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_103get_orderbook_ticker = {"get_orderbook_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_103get_orderbook_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_102get_orderbook_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_103get_orderbook_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_orderbook_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1474, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_orderbook_ticker") < 0)) __PYX_ERR(0, 1474, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_orderbook_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1474, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_orderbook_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_102get_orderbook_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_102get_orderbook_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_orderbook_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":1518
 * 
 *         """
 *         return self._get('ticker/bookTicker', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     # Account Endpoints
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1518, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__17, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1474
 *         return self._get('ticker/price', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_orderbook_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1522
 *     # Account Endpoints
 * 
 *     def create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_105create_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_104create_order, "Send in a new order\n\n        Any order with an icebergQty MUST have timeInForce set to GTC.\n\n        https://binance-docs.github.io/apidocs/spot/en/#new-order--trade\n\n        :param symbol: required\n        :type symbol: str\n        :param side: required\n        :type side: str\n        :param type: required\n        :type type: str\n        :param timeInForce: required if limit order\n        :type timeInForce: str\n        :param quantity: required\n        :type quantity: decimal\n        :param quoteOrderQty: amount the user wants to spend (when buying) or receive (when selling)\n            of the quote asset, applicable to MARKET orders\n        :type quoteOrderQty: decimal\n        :param price: required\n        :type price: str\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param icebergQty: Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order.\n        :type icebergQty: decimal\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        Response ACK:\n\n        .. code-block:: python\n\n            {\n                \"symbol\":\"LTCBTC\",\n                \"orderId\": 1,\n                \"clientOrderId\": \"myOrder1\" # Will be newClientOrderId\n                \"transactTime\": 1499827319559\n            }\n\n        Response RESULT:\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"BTCUSDT\",\n                \"orderId\": 28,\n                \"clientOrderId\": \"6gCrw2kRUAF9CvJDGP16IP\",\n                \"transactTime\": 1507725176595,\n                \"price\": \"0.00000000\",\n                \"origQty\": \"10.00000000\",\n                \"executedQty\": ""\"10.00000000\",\n                \"status\": \"FILLED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"MARKET\",\n                \"side\": \"SELL\"\n            }\n\n        Response FULL:\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"BTCUSDT\",\n                \"orderId\": 28,\n                \"clientOrderId\": \"6gCrw2kRUAF9CvJDGP16IP\",\n                \"transactTime\": 1507725176595,\n                \"price\": \"0.00000000\",\n                \"origQty\": \"10.00000000\",\n                \"executedQty\": \"10.00000000\",\n                \"status\": \"FILLED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"MARKET\",\n                \"side\": \"SELL\",\n                \"fills\": [\n                    {\n                        \"price\": \"4000.00000000\",\n                        \"qty\": \"1.00000000\",\n                        \"commission\": \"4.00000000\",\n                        \"commissionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3999.00000000\",\n                        \"qty\": \"5.00000000\",\n                        \"commission\": \"19.99500000\",\n                        \"commissionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3998.00000000\",\n                        \"qty\": \"2.00000000\",\n                        \"commission\": \"7.99600000\",\n                        \"commissionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3997.00000000\",\n                        \"qty\": \"1.00000000\",\n                        \"commission\": \"3.99700000\",\n                        \"commissionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3995.00000000\",\n                        \"qty\": \"1.00000000\",\n                        ""\"commission\": \"3.99500000\",\n                        \"commissionAsset\": \"USDT\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_105create_order = {"create_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_105create_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_104create_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_105create_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1522, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_order") < 0)) __PYX_ERR(0, 1522, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1522, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_104create_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_104create_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_order", 1);

  /* "unicorn_binance_rest_api/manager.py":1638
 *                  BinanceOrderInactiveSymbolException
 *         """
 *         return self._post('order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def order_limit(self, timeInForce=TIME_IN_FORCE_GTC, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_post_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1638, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__29, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1522
 *     # Account Endpoints
 * 
 *     def create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1640
 *         return self._post('order', True, data=params)
 * 
 *     def order_limit(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit order
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_16__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_timeInForce);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_timeInForce);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_timeInForce)) __PYX_ERR(0, 1640, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 1640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 1640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_107order_limit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_106order_limit, "Send in a new limit order\n\n        Any order with an icebergQty MUST have timeInForce set to GTC.\n\n        :param symbol: required\n        :type symbol: str\n        :param side: required\n        :type side: str\n        :param quantity: required\n        :type quantity: decimal\n        :param price: required\n        :type price: str\n        :param timeInForce: default Good till cancelled\n        :type timeInForce: str\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param icebergQty: Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order.\n        :type icebergQty: decimal\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_107order_limit = {"order_limit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_107order_limit, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_106order_limit};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_107order_limit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_timeInForce = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_limit (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_timeInForce,0};
    __pyx_defaults8 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_timeInForce);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_timeInForce);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_limit") < 0)) __PYX_ERR(0, 1640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_timeInForce = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_limit", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_limit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_106order_limit(__pyx_self, __pyx_v_self, __pyx_v_timeInForce, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_106order_limit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_timeInForce, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_limit", 1);

  /* "unicorn_binance_rest_api/manager.py":1674
 *         """
 *         params.update({
 *             'type': self.ORDER_TYPE_LIMIT,             # <<<<<<<<<<<<<<
 *             'timeInForce': timeInForce
 *         })
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ORDER_TYPE_LIMIT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_t_2) < 0) __PYX_ERR(0, 1674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1675
 *         params.update({
 *             'type': self.ORDER_TYPE_LIMIT,
 *             'timeInForce': timeInForce             # <<<<<<<<<<<<<<
 *         })
 *         return self.create_order(**params)
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_timeInForce, __pyx_v_timeInForce) < 0) __PYX_ERR(0, 1674, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1673
 * 
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'type': self.ORDER_TYPE_LIMIT,
 *             'timeInForce': timeInForce
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1677
 *             'timeInForce': timeInForce
 *         })
 *         return self.create_order(**params)             # <<<<<<<<<<<<<<
 * 
 *     def order_limit_buy(self, timeInForce=TIME_IN_FORCE_GTC, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyDict_Copy(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1640
 *         return self._post('order', True, data=params)
 * 
 *     def order_limit(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_limit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1679
 *         return self.create_order(**params)
 * 
 *     def order_limit_buy(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit buy order
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_18__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_timeInForce);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_timeInForce);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_timeInForce)) __PYX_ERR(0, 1679, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 1679, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 1679, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_109order_limit_buy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_108order_limit_buy, "Send in a new limit buy order\n\n        Any order with an icebergQty MUST have timeInForce set to GTC.\n\n        :param symbol: required\n        :type symbol: str\n        :param quantity: required\n        :type quantity: decimal\n        :param price: required\n        :type price: str\n        :param timeInForce: default Good till cancelled\n        :type timeInForce: str\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param stopPrice: Used with stop orders\n        :type stopPrice: decimal\n        :param icebergQty: Used with iceberg orders\n        :type icebergQty: decimal\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_109order_limit_buy = {"order_limit_buy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_109order_limit_buy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_108order_limit_buy};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_109order_limit_buy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_timeInForce = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_limit_buy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_timeInForce,0};
    __pyx_defaults9 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_timeInForce);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1679, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_timeInForce);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1679, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_limit_buy") < 0)) __PYX_ERR(0, 1679, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_timeInForce = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_limit_buy", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1679, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_limit_buy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_108order_limit_buy(__pyx_self, __pyx_v_self, __pyx_v_timeInForce, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_108order_limit_buy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_timeInForce, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_limit_buy", 1);

  /* "unicorn_binance_rest_api/manager.py":1713
 *         """
 *         params.update({
 *             'side': self.SIDE_BUY,             # <<<<<<<<<<<<<<
 *         })
 *         return self.order_limit(timeInForce=timeInForce, **params)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SIDE_BUY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_side, __pyx_t_2) < 0) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1712
 * 
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'side': self.SIDE_BUY,
 *         })
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1715
 *             'side': self.SIDE_BUY,
 *         })
 *         return self.order_limit(timeInForce=timeInForce, **params)             # <<<<<<<<<<<<<<
 * 
 *     def order_limit_sell(self, timeInForce=TIME_IN_FORCE_GTC, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_order_limit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_timeInForce, __pyx_v_timeInForce) < 0) __PYX_ERR(0, 1715, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_1, __pyx_v_params) < 0) __PYX_ERR(0, 1715, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1679
 *         return self.create_order(**params)
 * 
 *     def order_limit_buy(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit buy order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_limit_buy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1717
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_limit_sell(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit sell order
 * 
 */

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_20__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_timeInForce);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_timeInForce);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_timeInForce)) __PYX_ERR(0, 1717, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 1717, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 1717, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_111order_limit_sell(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_110order_limit_sell, "Send in a new limit sell order\n\n        :param symbol: required\n        :type symbol: str\n        :param quantity: required\n        :type quantity: decimal\n        :param price: required\n        :type price: str\n        :param timeInForce: default Good till cancelled\n        :type timeInForce: str\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param stopPrice: Used with stop orders\n        :type stopPrice: decimal\n        :param icebergQty: Used with iceberg orders\n        :type icebergQty: decimal\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_111order_limit_sell = {"order_limit_sell", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_111order_limit_sell, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_110order_limit_sell};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_111order_limit_sell(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_timeInForce = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_limit_sell (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_timeInForce,0};
    __pyx_defaults10 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_timeInForce);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1717, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_timeInForce);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1717, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_limit_sell") < 0)) __PYX_ERR(0, 1717, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_timeInForce = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_limit_sell", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1717, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_limit_sell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_110order_limit_sell(__pyx_self, __pyx_v_self, __pyx_v_timeInForce, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_110order_limit_sell(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_timeInForce, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_limit_sell", 1);

  /* "unicorn_binance_rest_api/manager.py":1749
 *         """
 *         params.update({
 *             'side': self.SIDE_SELL             # <<<<<<<<<<<<<<
 *         })
 *         return self.order_limit(timeInForce=timeInForce, **params)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SIDE_SELL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_side, __pyx_t_2) < 0) __PYX_ERR(0, 1749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1748
 * 
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'side': self.SIDE_SELL
 *         })
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1751
 *             'side': self.SIDE_SELL
 *         })
 *         return self.order_limit(timeInForce=timeInForce, **params)             # <<<<<<<<<<<<<<
 * 
 *     def order_market(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_order_limit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_timeInForce, __pyx_v_timeInForce) < 0) __PYX_ERR(0, 1751, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  if (__Pyx_MergeKeywords(__pyx_t_1, __pyx_v_params) < 0) __PYX_ERR(0, 1751, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1717
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_limit_sell(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit sell order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_limit_sell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1753
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_market(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_113order_market(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_112order_market, "Send in a new market order\n\n        :param symbol: required\n        :type symbol: str\n        :param side: required\n        :type side: str\n        :param quantity: required\n        :type quantity: decimal\n        :param quoteOrderQty: amount the user wants to spend (when buying) or receive (when selling)\n            of the quote asset\n        :type quoteOrderQty: decimal\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_113order_market = {"order_market", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_113order_market, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_112order_market};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_113order_market(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_market (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1753, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_market") < 0)) __PYX_ERR(0, 1753, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_market", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1753, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_market", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_112order_market(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_112order_market(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_market", 1);

  /* "unicorn_binance_rest_api/manager.py":1782
 *         """
 *         params.update({
 *             'type': self.ORDER_TYPE_MARKET             # <<<<<<<<<<<<<<
 *         })
 *         return self.create_order(**params)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ORDER_TYPE_MARKET); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_t_2) < 0) __PYX_ERR(0, 1782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1781
 * 
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'type': self.ORDER_TYPE_MARKET
 *         })
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1784
 *             'type': self.ORDER_TYPE_MARKET
 *         })
 *         return self.create_order(**params)             # <<<<<<<<<<<<<<
 * 
 *     def order_market_buy(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyDict_Copy(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1753
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_market(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_market", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1786
 *         return self.create_order(**params)
 * 
 *     def order_market_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market buy order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_115order_market_buy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_114order_market_buy, "Send in a new market buy order\n\n        :param symbol: required\n        :type symbol: str\n        :param quantity: required\n        :type quantity: decimal\n        :param quoteOrderQty: the amount the user wants to spend of the quote asset\n        :type quoteOrderQty: decimal\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_115order_market_buy = {"order_market_buy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_115order_market_buy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_114order_market_buy};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_115order_market_buy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_market_buy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1786, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_market_buy") < 0)) __PYX_ERR(0, 1786, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_market_buy", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1786, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_market_buy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_114order_market_buy(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_114order_market_buy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_market_buy", 1);

  /* "unicorn_binance_rest_api/manager.py":1812
 *         """
 *         params.update({
 *             'side': self.SIDE_BUY             # <<<<<<<<<<<<<<
 *         })
 *         return self.order_market(**params)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SIDE_BUY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_side, __pyx_t_2) < 0) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1811
 * 
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'side': self.SIDE_BUY
 *         })
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1814
 *             'side': self.SIDE_BUY
 *         })
 *         return self.order_market(**params)             # <<<<<<<<<<<<<<
 * 
 *     def order_market_sell(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_order_market); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyDict_Copy(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1786
 *         return self.create_order(**params)
 * 
 *     def order_market_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market buy order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_market_buy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1816
 *         return self.order_market(**params)
 * 
 *     def order_market_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market sell order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_117order_market_sell(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_116order_market_sell, "Send in a new market sell order\n\n        :param symbol: required\n        :type symbol: str\n        :param quantity: required\n        :type quantity: decimal\n        :param quoteOrderQty: the amount the user wants to receive of the quote asset\n        :type quoteOrderQty: decimal\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_117order_market_sell = {"order_market_sell", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_117order_market_sell, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_116order_market_sell};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_117order_market_sell(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_market_sell (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1816, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_market_sell") < 0)) __PYX_ERR(0, 1816, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_market_sell", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1816, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_market_sell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_116order_market_sell(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_116order_market_sell(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_market_sell", 1);

  /* "unicorn_binance_rest_api/manager.py":1842
 *         """
 *         params.update({
 *             'side': self.SIDE_SELL             # <<<<<<<<<<<<<<
 *         })
 *         return self.order_market(**params)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SIDE_SELL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_side, __pyx_t_2) < 0) __PYX_ERR(0, 1842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1841
 * 
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'side': self.SIDE_SELL
 *         })
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1844
 *             'side': self.SIDE_SELL
 *         })
 *         return self.order_market(**params)             # <<<<<<<<<<<<<<
 * 
 *     def create_oco_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_order_market); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyDict_Copy(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1816
 *         return self.order_market(**params)
 * 
 *     def order_market_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market sell order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_market_sell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1846
 *         return self.order_market(**params)
 * 
 *     def create_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_119create_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_118create_oco_order, "Send in a new OCO order\n\n        https://binance-docs.github.io/apidocs/spot/en/#new-oco-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param listClientOrderId: A unique id for the list order. Automatically generated if not sent.\n        :type listClientOrderId: str\n        :param side: required\n        :type side: str\n        :param quantity: required\n        :type quantity: decimal\n        :param limitClientOrderId: A unique id for the limit order. Automatically generated if not sent.\n        :type limitClientOrderId: str\n        :param price: required\n        :type price: str\n        :param limitIcebergQty: Used to make the LIMIT_MAKER leg an iceberg order.\n        :type limitIcebergQty: decimal\n        :param stopClientOrderId: A unique id for the stop order. Automatically generated if not sent.\n        :type stopClientOrderId: str\n        :param stopPrice: required\n        :type stopPrice: str\n        :param stopLimitPrice: If provided, stopLimitTimeInForce is required.\n        :type stopLimitPrice: str\n        :param stopIcebergQty: Used with STOP_LOSS_LIMIT leg to make an iceberg order.\n        :type stopIcebergQty: decimal\n        :param stopLimitTimeInForce: Valid values are GTC/FOK/IOC.\n        :type stopLimitTimeInForce: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        Response ACK:\n\n        .. code-block:: python\n\n            {\n            }\n\n        Response RESULT:\n\n        .. code-block:: python\n\n            {\n            }\n\n        Response FULL:\n\n        .. code-block:: python\n\n            {\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n             ""    BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_119create_oco_order = {"create_oco_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_119create_oco_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_118create_oco_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_119create_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_oco_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1846, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_oco_order") < 0)) __PYX_ERR(0, 1846, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_oco_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1846, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_118create_oco_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_118create_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_oco_order", 1);

  /* "unicorn_binance_rest_api/manager.py":1908
 * 
 *         """
 *         return self._post('order/oco', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def order_oco_buy(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_post_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 1908, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__30, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1846
 *         return self.order_market(**params)
 * 
 *     def create_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1910
 *         return self._post('order/oco', True, data=params)
 * 
 *     def order_oco_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO buy order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_121order_oco_buy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_120order_oco_buy, "Send in a new OCO buy order\n\n        :param symbol: required\n        :type symbol: str\n        :param listClientOrderId: A unique id for the list order. Automatically generated if not sent.\n        :type listClientOrderId: str\n        :param quantity: required\n        :type quantity: decimal\n        :param limitClientOrderId: A unique id for the limit order. Automatically generated if not sent.\n        :type limitClientOrderId: str\n        :param price: required\n        :type price: str\n        :param limitIcebergQty: Used to make the LIMIT_MAKER leg an iceberg order.\n        :type limitIcebergQty: decimal\n        :param stopClientOrderId: A unique id for the stop order. Automatically generated if not sent.\n        :type stopClientOrderId: str\n        :param stopPrice: required\n        :type stopPrice: str\n        :param stopLimitPrice: If provided, stopLimitTimeInForce is required.\n        :type stopLimitPrice: str\n        :param stopIcebergQty: Used with STOP_LOSS_LIMIT leg to make an iceberg order.\n        :type stopIcebergQty: decimal\n        :param stopLimitTimeInForce: Valid values are GTC/FOK/IOC.\n        :type stopLimitTimeInForce: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See OCO order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_121order_oco_buy = {"order_oco_buy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_121order_oco_buy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_120order_oco_buy};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_121order_oco_buy(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_oco_buy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1910, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_oco_buy") < 0)) __PYX_ERR(0, 1910, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_oco_buy", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1910, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_oco_buy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_120order_oco_buy(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_120order_oco_buy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_oco_buy", 1);

  /* "unicorn_binance_rest_api/manager.py":1950
 *         """
 *         params.update({
 *             'side': self.SIDE_BUY             # <<<<<<<<<<<<<<
 *         })
 *         return self.create_oco_order(**params)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SIDE_BUY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_side, __pyx_t_2) < 0) __PYX_ERR(0, 1950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1949
 * 
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'side': self.SIDE_BUY
 *         })
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1952
 *             'side': self.SIDE_BUY
 *         })
 *         return self.create_oco_order(**params)             # <<<<<<<<<<<<<<
 * 
 *     def order_oco_sell(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_oco_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyDict_Copy(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1910
 *         return self._post('order/oco', True, data=params)
 * 
 *     def order_oco_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO buy order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_oco_buy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1954
 *         return self.create_oco_order(**params)
 * 
 *     def order_oco_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO sell order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_123order_oco_sell(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_122order_oco_sell, "Send in a new OCO sell order\n\n        :param symbol: required\n        :type symbol: str\n        :param listClientOrderId: A unique id for the list order. Automatically generated if not sent.\n        :type listClientOrderId: str\n        :param quantity: required\n        :type quantity: decimal\n        :param limitClientOrderId: A unique id for the limit order. Automatically generated if not sent.\n        :type limitClientOrderId: str\n        :param price: required\n        :type price: str\n        :param limitIcebergQty: Used to make the LIMIT_MAKER leg an iceberg order.\n        :type limitIcebergQty: decimal\n        :param stopClientOrderId: A unique id for the stop order. Automatically generated if not sent.\n        :type stopClientOrderId: str\n        :param stopPrice: required\n        :type stopPrice: str\n        :param stopLimitPrice: If provided, stopLimitTimeInForce is required.\n        :type stopLimitPrice: str\n        :param stopIcebergQty: Used with STOP_LOSS_LIMIT leg to make an iceberg order.\n        :type stopIcebergQty: decimal\n        :param stopLimitTimeInForce: Valid values are GTC/FOK/IOC.\n        :type stopLimitTimeInForce: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        See OCO order endpoint for full response options\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_123order_oco_sell = {"order_oco_sell", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_123order_oco_sell, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_122order_oco_sell};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_123order_oco_sell(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_oco_sell (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1954, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "order_oco_sell") < 0)) __PYX_ERR(0, 1954, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("order_oco_sell", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1954, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_oco_sell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_122order_oco_sell(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_122order_oco_sell(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_oco_sell", 1);

  /* "unicorn_binance_rest_api/manager.py":1993
 *         """
 *         params.update({
 *             'side': self.SIDE_SELL             # <<<<<<<<<<<<<<
 *         })
 *         return self.create_oco_order(**params)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SIDE_SELL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_side, __pyx_t_2) < 0) __PYX_ERR(0, 1993, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1992
 *                  BinanceOrderInactiveSymbolException
 *         """
 *         params.update({             # <<<<<<<<<<<<<<
 *             'side': self.SIDE_SELL
 *         })
 */
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_update, __pyx_v_params, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1995
 *             'side': self.SIDE_SELL
 *         })
 *         return self.create_oco_order(**params)             # <<<<<<<<<<<<<<
 * 
 *     def create_test_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_create_oco_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyDict_Copy(__pyx_v_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1954
 *         return self.create_oco_order(**params)
 * 
 *     def order_oco_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO sell order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.order_oco_sell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":1997
 *         return self.create_oco_order(**params)
 * 
 *     def create_test_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Test new order creation and signature/recvWindow long. Creates and validates a new order but does not send
 *         it into the matching engine.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_125create_test_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_124create_test_order, "Test new order creation and signature/recvWindow long. Creates and validates a new order but does not send\n        it into the matching engine.\n\n        https://binance-docs.github.io/apidocs/spot/en/#test-new-order-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param side: required\n        :type side: str\n        :param type: required\n        :type type: str\n        :param timeInForce: required if limit order\n        :type timeInForce: str\n        :param quantity: required\n        :type quantity: decimal\n        :param price: required\n        :type price: str\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param icebergQty: Used with iceberg orders\n        :type icebergQty: decimal\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param recvWindow: The number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n                 BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n                 BinanceOrderInactiveSymbolException\n\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_125create_test_order = {"create_test_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_125create_test_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_124create_test_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_125create_test_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_test_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1997, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_test_order") < 0)) __PYX_ERR(0, 1997, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_test_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1997, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_test_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_124create_test_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_124create_test_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_test_order", 1);

  /* "unicorn_binance_rest_api/manager.py":2036
 * 
 *         """
 *         return self._post('order/test', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_post_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2036, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__31, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":1997
 *         return self.create_oco_order(**params)
 * 
 *     def create_test_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Test new order creation and signature/recvWindow long. Creates and validates a new order but does not send
 *         it into the matching engine.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_test_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2038
 *         return self._post('order/test', True, data=params)
 * 
 *     def get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Check an order's status. Either orderId or origClientOrderId must be sent.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_127get_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_126get_order, "Check an order's status. Either orderId or origClientOrderId must be sent.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-order-user_data\n\n        :param symbol: required\n        :type symbol: str\n        :param orderId: The unique order id\n        :type orderId: int\n        :param origClientOrderId: optional\n        :type origClientOrderId: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"LTCBTC\",\n                \"orderId\": 1,\n                \"clientOrderId\": \"myOrder1\",\n                \"price\": \"0.1\",\n                \"origQty\": \"1.0\",\n                \"executedQty\": \"0.0\",\n                \"status\": \"NEW\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"LIMIT\",\n                \"side\": \"BUY\",\n                \"stopPrice\": \"0.0\",\n                \"icebergQty\": \"0.0\",\n                \"time\": 1499827319559\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_127get_order = {"get_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_127get_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_126get_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_127get_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2038, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_order") < 0)) __PYX_ERR(0, 2038, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2038, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_126get_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_126get_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_order", 1);

  /* "unicorn_binance_rest_api/manager.py":2075
 * 
 *         """
 *         return self._get('order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_all_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2075, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__29, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2038
 *         return self._post('order/test', True, data=params)
 * 
 *     def get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Check an order's status. Either orderId or origClientOrderId must be sent.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2077
 *         return self._get('order', True, data=params)
 * 
 *     def get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all account orders; active, canceled, or filled.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_129get_all_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_128get_all_orders, "Get all account orders; active, canceled, or filled.\n\n        https://binance-docs.github.io/apidocs/spot/en/#all-orders-user_data\n\n        :param symbol: required\n        :type symbol: str\n        :param orderId: The unique order id\n        :type orderId: int\n        :param limit: Default 500; max 500.\n        :type limit: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"symbol\": \"LTCBTC\",\n                    \"orderId\": 1,\n                    \"clientOrderId\": \"myOrder1\",\n                    \"price\": \"0.1\",\n                    \"origQty\": \"1.0\",\n                    \"executedQty\": \"0.0\",\n                    \"status\": \"NEW\",\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"LIMIT\",\n                    \"side\": \"BUY\",\n                    \"stopPrice\": \"0.0\",\n                    \"icebergQty\": \"0.0\",\n                    \"time\": 1499827319559\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_129get_all_orders = {"get_all_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_129get_all_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_128get_all_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_129get_all_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2077, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_all_orders") < 0)) __PYX_ERR(0, 2077, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2077, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_128get_all_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_128get_all_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_all_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":2116
 * 
 *         """
 *         return self._get('allOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_all_open_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2116, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__32, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2077
 *         return self._get('order', True, data=params)
 * 
 *     def get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all account orders; active, canceled, or filled.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2118
 *         return self._get('allOrders', True, data=params)
 * 
 *     def cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open orders of a symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_131cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_130cancel_all_open_orders, "Cancel all open orders of a symbol.\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-cancel-order-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n              {\n                \"symbol\": \"BTCUSDT\",\n                \"isIsolated\": true,       // if isolated margin\n                \"origClientOrderId\": \"E6APeyTJvkMvLMYMqu1KQ4\",\n                \"orderId\": 11,\n                \"orderListId\": -1,\n                \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                \"price\": \"0.089853\",\n                \"origQty\": \"0.178622\",\n                \"executedQty\": \"0.000000\",\n                \"cummulativeQuoteQty\": \"0.000000\",\n                \"status\": \"CANCELED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"LIMIT\",\n                \"side\": \"BUY\"\n              },\n              {\n                \"symbol\": \"BTCUSDT\",\n                \"isIsolated\": false,       // if isolated margin\n                \"origClientOrderId\": \"A3EF2HCwxgZPFMrfwbgrhv\",\n                \"orderId\": 13,\n                \"orderListId\": -1,\n                \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                \"price\": \"0.090430\",\n                \"origQty\": \"0.178622\",\n                \"executedQty\": \"0.000000\",\n                \"cummulativeQuoteQty\": \"0.000000\",\n                \"status\": \"CANCELED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"LIMIT\",\n                \"side\": \"BUY\"\n              },\n              {\n                \"orderListId\": 1929,\n                \"contingencyType\": \"OCO\",\n                \"listStatusType\": \"ALL_DONE\",\n                \"listOrderStatus\": \"ALL_DONE\",\n          ""      \"listClientOrderId\": \"2inzWQdDvZLHbbAmAozX2N\",\n                \"transactionTime\": 1585230948299,\n                \"symbol\": \"BTCUSDT\",\n                \"isIsolated\": true,       // if isolated margin\n                \"orders\": [\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"orderId\": 20,\n                    \"clientOrderId\": \"CwOOIPHSmYywx6jZX77TdL\"\n                  },\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"orderId\": 21,\n                    \"clientOrderId\": \"461cPg51vQjV3zIMOXNz39\"\n                  }\n                ],\n                \"orderReports\": [\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"origClientOrderId\": \"CwOOIPHSmYywx6jZX77TdL\",\n                    \"orderId\": 20,\n                    \"orderListId\": 1929,\n                    \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                    \"price\": \"0.668611\",\n                    \"origQty\": \"0.690354\",\n                    \"executedQty\": \"0.000000\",\n                    \"cummulativeQuoteQty\": \"0.000000\",\n                    \"status\": \"CANCELED\",\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"STOP_LOSS_LIMIT\",\n                    \"side\": \"BUY\",\n                    \"stopPrice\": \"0.378131\",\n                    \"icebergQty\": \"0.017083\"\n                  },\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"origClientOrderId\": \"461cPg51vQjV3zIMOXNz39\",\n                    \"orderId\": 21,\n                    \"orderListId\": 1929,\n                    \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                    \"price\": \"0.008791\",\n                    \"origQty\": \"0.690354\",\n                    \"executedQty\": \"0.000000\",\n                    \"cummulativeQuoteQty\": \"0.000000\",\n       ""             \"status\": \"CANCELED\",\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"LIMIT_MAKER\",\n                    \"side\": \"BUY\",\n                    \"icebergQty\": \"0.639962\"\n                  }\n                ]\n              }\n            ]\n\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_131cancel_all_open_orders = {"cancel_all_open_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_131cancel_all_open_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_130cancel_all_open_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_131cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel_all_open_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2118, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "cancel_all_open_orders") < 0)) __PYX_ERR(0, 2118, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cancel_all_open_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2118, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_130cancel_all_open_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_130cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cancel_all_open_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":2229
 * 
 *         """
 *         return self._delete('openOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_all_open_margin_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_delete_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2229, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__33, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2118
 *         return self._get('allOrders', True, data=params)
 * 
 *     def cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open orders of a symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2231
 *         return self._delete('openOrders', True, data=params)
 * 
 *     def cancel_all_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open margin orders of a symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_133cancel_all_open_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_132cancel_all_open_margin_orders, "Cancel all open margin orders of a symbol.\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-cancel-all-open-orders-on-a-symbol-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n              {\n                \"symbol\": \"BTCUSDT\",\n                \"origClientOrderId\": \"E6APeyTJvkMvLMYMqu1KQ4\",\n                \"orderId\": 11,\n                \"orderListId\": -1,\n                \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                \"price\": \"0.089853\",\n                \"origQty\": \"0.178622\",\n                \"executedQty\": \"0.000000\",\n                \"cummulativeQuoteQty\": \"0.000000\",\n                \"status\": \"CANCELED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"LIMIT\",\n                \"side\": \"BUY\"\n              },\n              {\n                \"symbol\": \"BTCUSDT\",\n                \"origClientOrderId\": \"A3EF2HCwxgZPFMrfwbgrhv\",\n                \"orderId\": 13,\n                \"orderListId\": -1,\n                \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                \"price\": \"0.090430\",\n                \"origQty\": \"0.178622\",\n                \"executedQty\": \"0.000000\",\n                \"cummulativeQuoteQty\": \"0.000000\",\n                \"status\": \"CANCELED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"LIMIT\",\n                \"side\": \"BUY\"\n              },\n              {\n                \"orderListId\": 1929,\n                \"contingencyType\": \"OCO\",\n                \"listStatusType\": \"ALL_DONE\",\n                \"listOrderStatus\": \"ALL_DONE\",\n                \"listClientOrderId\": \"2inzWQdDvZLHbbAmAozX2N\",\n                \"transactionTime\": 15852309482""99,\n                \"symbol\": \"BTCUSDT\",\n                \"orders\": [\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"orderId\": 20,\n                    \"clientOrderId\": \"CwOOIPHSmYywx6jZX77TdL\"\n                  },\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"orderId\": 21,\n                    \"clientOrderId\": \"461cPg51vQjV3zIMOXNz39\"\n                  }\n                ],\n                \"orderReports\": [\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"origClientOrderId\": \"CwOOIPHSmYywx6jZX77TdL\",\n                    \"orderId\": 20,\n                    \"orderListId\": 1929,\n                    \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                    \"price\": \"0.668611\",\n                    \"origQty\": \"0.690354\",\n                    \"executedQty\": \"0.000000\",\n                    \"cummulativeQuoteQty\": \"0.000000\",\n                    \"status\": \"CANCELED\",\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"STOP_LOSS_LIMIT\",\n                    \"side\": \"BUY\",\n                    \"stopPrice\": \"0.378131\",\n                    \"icebergQty\": \"0.017083\"\n                  },\n                  {\n                    \"symbol\": \"BTCUSDT\",\n                    \"origClientOrderId\": \"461cPg51vQjV3zIMOXNz39\",\n                    \"orderId\": 21,\n                    \"orderListId\": 1929,\n                    \"clientOrderId\": \"pXLV6Hz6mprAcVYpVMTGgx\",\n                    \"price\": \"0.008791\",\n                    \"origQty\": \"0.690354\",\n                    \"executedQty\": \"0.000000\",\n                    \"cummulativeQuoteQty\": \"0.000000\",\n                    \"status\": \"CANCELED\",\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"LIMIT_MAKER\",\n                    \"side\": \"BUY""\",\n                    \"icebergQty\": \"0.639962\"\n                  }\n                ]\n              }\n            ]\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_133cancel_all_open_margin_orders = {"cancel_all_open_margin_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_133cancel_all_open_margin_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_132cancel_all_open_margin_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_133cancel_all_open_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel_all_open_margin_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2231, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "cancel_all_open_margin_orders") < 0)) __PYX_ERR(0, 2231, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cancel_all_open_margin_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2231, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_all_open_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_132cancel_all_open_margin_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_132cancel_all_open_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cancel_all_open_margin_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":2338
 * 
 *         """
 *         return self._request_margin_api('delete', 'margin/openOrders', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 2338, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2338, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__34, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2231
 *         return self._delete('openOrders', True, data=params)
 * 
 *     def cancel_all_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open margin orders of a symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_all_open_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2340
 *         return self._request_margin_api('delete', 'margin/openOrders', signed=True, data=params)
 * 
 *     def cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an active order. Either orderId or origClientOrderId must be sent.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_135cancel_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_134cancel_order, "Cancel an active order. Either orderId or origClientOrderId must be sent.\n\n        https://binance-docs.github.io/apidocs/spot/en/#cancel-order-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param orderId: The unique order id\n        :type orderId: int\n        :param origClientOrderId: optional\n        :type origClientOrderId: str\n        :param newClientOrderId: Used to uniquely identify this cancel. Automatically generated by default.\n        :type newClientOrderId: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"LTCBTC\",\n                \"origClientOrderId\": \"myOrder1\",\n                \"orderId\": 1,\n                \"clientOrderId\": \"cancelMyOrder1\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_135cancel_order = {"cancel_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_135cancel_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_134cancel_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_135cancel_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2340, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "cancel_order") < 0)) __PYX_ERR(0, 2340, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cancel_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2340, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_134cancel_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_134cancel_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cancel_order", 1);

  /* "unicorn_binance_rest_api/manager.py":2370
 * 
 *         """
 *         return self._delete('order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_open_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_delete_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2370, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__29, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2340
 *         return self._request_margin_api('delete', 'margin/openOrders', signed=True, data=params)
 * 
 *     def cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an active order. Either orderId or origClientOrderId must be sent.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2372
 *         return self._delete('order', True, data=params)
 * 
 *     def get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all open orders on a symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_137get_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_136get_open_orders, "Get all open orders on a symbol.\n\n        https://binance-docs.github.io/apidocs/spot/en/#current-open-orders-user_data\n\n        :param symbol: optional\n        :type symbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"symbol\": \"LTCBTC\",\n                    \"orderId\": 1,\n                    \"clientOrderId\": \"myOrder1\",\n                    \"price\": \"0.1\",\n                    \"origQty\": \"1.0\",\n                    \"executedQty\": \"0.0\",\n                    \"status\": \"NEW\",\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"LIMIT\",\n                    \"side\": \"BUY\",\n                    \"stopPrice\": \"0.0\",\n                    \"icebergQty\": \"0.0\",\n                    \"time\": 1499827319559\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_137get_open_orders = {"get_open_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_137get_open_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_136get_open_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_137get_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_open_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2372, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_open_orders") < 0)) __PYX_ERR(0, 2372, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_open_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2372, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_136get_open_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_136get_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_open_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":2407
 * 
 *         """
 *         return self._get('openOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     # User Stream Endpoints
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2407, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__33, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2372
 *         return self._delete('order', True, data=params)
 * 
 *     def get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all open orders on a symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2410
 * 
 *     # User Stream Endpoints
 *     def get_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get current account information.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_139get_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_138get_account, "Get current account information.\n\n        https://binance-docs.github.io/apidocs/spot/en/#account-information-user_data\n\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"makerCommission\": 15,\n                \"takerCommission\": 15,\n                \"buyerCommission\": 0,\n                \"sellerCommission\": 0,\n                \"canTrade\": true,\n                \"canWithdraw\": true,\n                \"canDeposit\": true,\n                \"balances\": [\n                    {\n                        \"asset\": \"BTC\",\n                        \"free\": \"4723846.89208129\",\n                        \"locked\": \"0.00000000\"\n                    },\n                    {\n                        \"asset\": \"LTC\",\n                        \"free\": \"4763368.68006011\",\n                        \"locked\": \"0.00000000\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_139get_account = {"get_account", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_139get_account, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_138get_account};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_139get_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_account (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2410, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_account") < 0)) __PYX_ERR(0, 2410, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_account", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2410, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_138get_account(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_138get_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_account", 1);

  /* "unicorn_binance_rest_api/manager.py":2447
 * 
 *         """
 *         return self._get('account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_asset_balance(self, asset, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2447, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__35, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2410
 * 
 *     # User Stream Endpoints
 *     def get_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get current account information.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2449
 *         return self._get('account', True, data=params)
 * 
 *     def get_asset_balance(self, asset, **params):             # <<<<<<<<<<<<<<
 *         """Get current asset balance.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_141get_asset_balance(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_140get_asset_balance, "Get current asset balance.\n\n        https://binance-docs.github.io/apidocs/spot/en/#account-information-user_data\n\n        :param asset: required\n        :type asset: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: dictionary or None if not found\n\n        .. code-block:: python\n\n            {\n                \"asset\": \"BTC\",\n                \"free\": \"4723846.89208129\",\n                \"locked\": \"0.00000000\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_141get_asset_balance = {"get_asset_balance", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_141get_asset_balance, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_140get_asset_balance};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_141get_asset_balance(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_asset = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_asset_balance (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_asset,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2449, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_asset)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2449, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_asset_balance", 1, 2, 2, 1); __PYX_ERR(0, 2449, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_asset_balance") < 0)) __PYX_ERR(0, 2449, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_asset = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_asset_balance", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2449, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_asset_balance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_140get_asset_balance(__pyx_self, __pyx_v_self, __pyx_v_asset, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_140get_asset_balance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_asset, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_bal = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_asset_balance", 1);

  /* "unicorn_binance_rest_api/manager.py":2472
 * 
 *         """
 *         res = self.get_account(**params)             # <<<<<<<<<<<<<<
 *         # find asset balance in list of balances
 *         if "balances" in res:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_account); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyDict_Copy(__pyx_v_params); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":2474
 *         res = self.get_account(**params)
 *         # find asset balance in list of balances
 *         if "balances" in res:             # <<<<<<<<<<<<<<
 *             for bal in res['balances']:
 *                 if bal['asset'].lower() == asset.lower():
 */
  __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_balances, __pyx_v_res, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2474, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":2475
 *         # find asset balance in list of balances
 *         if "balances" in res:
 *             for bal in res['balances']:             # <<<<<<<<<<<<<<
 *                 if bal['asset'].lower() == asset.lower():
 *                     return bal
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_balances); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2475, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2475, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 2475, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2475, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2475, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 2475, __pyx_L1_error)
          #else
          __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2475, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_6(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2475, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_bal, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":2476
 *         if "balances" in res:
 *             for bal in res['balances']:
 *                 if bal['asset'].lower() == asset.lower():             # <<<<<<<<<<<<<<
 *                     return bal
 *         return None
 */
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_bal, __pyx_n_s_asset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_lower); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2476, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_asset, __pyx_n_s_lower); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2476, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_1 = PyObject_RichCompare(__pyx_t_3, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2476, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2476, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_4) {

        /* "unicorn_binance_rest_api/manager.py":2477
 *             for bal in res['balances']:
 *                 if bal['asset'].lower() == asset.lower():
 *                     return bal             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_bal);
        __pyx_r = __pyx_v_bal;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L0;

        /* "unicorn_binance_rest_api/manager.py":2476
 *         if "balances" in res:
 *             for bal in res['balances']:
 *                 if bal['asset'].lower() == asset.lower():             # <<<<<<<<<<<<<<
 *                     return bal
 *         return None
 */
      }

      /* "unicorn_binance_rest_api/manager.py":2475
 *         # find asset balance in list of balances
 *         if "balances" in res:
 *             for bal in res['balances']:             # <<<<<<<<<<<<<<
 *                 if bal['asset'].lower() == asset.lower():
 *                     return bal
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "unicorn_binance_rest_api/manager.py":2474
 *         res = self.get_account(**params)
 *         # find asset balance in list of balances
 *         if "balances" in res:             # <<<<<<<<<<<<<<
 *             for bal in res['balances']:
 *                 if bal['asset'].lower() == asset.lower():
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2478
 *                 if bal['asset'].lower() == asset.lower():
 *                     return bal
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def get_my_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2449
 *         return self._get('account', True, data=params)
 * 
 *     def get_asset_balance(self, asset, **params):             # <<<<<<<<<<<<<<
 *         """Get current asset balance.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_asset_balance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_bal);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2480
 *         return None
 * 
 *     def get_my_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for a specific symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_143get_my_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_142get_my_trades, "Get trades for a specific symbol.\n\n        https://binance-docs.github.io/apidocs/spot/en/#account-trade-list-user_data\n\n        :param symbol: required\n        :type symbol: str\n        :param limit: Default 500; max 500.\n        :type limit: int\n        :param fromId: TradeId to fetch from. Default gets most recent trades.\n        :type fromId: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"id\": 28457,\n                    \"price\": \"4.00000100\",\n                    \"qty\": \"12.00000000\",\n                    \"commission\": \"10.10000000\",\n                    \"commissionAsset\": \"BNB\",\n                    \"time\": 1499865549590,\n                    \"isBuyer\": true,\n                    \"isMaker\": false,\n                    \"isBestMatch\": true\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_143get_my_trades = {"get_my_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_143get_my_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_142get_my_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_143get_my_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_my_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2480, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_my_trades") < 0)) __PYX_ERR(0, 2480, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_my_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2480, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_my_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_142get_my_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_142get_my_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_my_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":2515
 * 
 *         """
 *         return self._get('myTrades', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_system_status(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2515, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__36, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2480
 *         return None
 * 
 *     def get_my_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for a specific symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_my_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2517
 *         return self._get('myTrades', True, data=params)
 * 
 *     def get_system_status(self):             # <<<<<<<<<<<<<<
 *         """Get system status detail.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_145get_system_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_144get_system_status, "Get system status detail.\n\n        https://binance-docs.github.io/apidocs/spot/en/#system-status-sapi-system\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"status\": 0,        # 0: normal\357\274\2141\357\274\232system maintenance\n                \"msg\": \"normal\"     # normal or System maintenance.\n            }\n\n        :raises: BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_145get_system_status = {"get_system_status", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_145get_system_status, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_144get_system_status};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_145get_system_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_system_status (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2517, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_system_status") < 0)) __PYX_ERR(0, 2517, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_system_status", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2517, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_system_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_144get_system_status(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_144get_system_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_system_status", 1);

  /* "unicorn_binance_rest_api/manager.py":2534
 * 
 *         """
 *         return self._request_margin_api('get', 'system/status')             # <<<<<<<<<<<<<<
 * 
 *     def get_account_status(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2517
 *         return self._get('myTrades', True, data=params)
 * 
 *     def get_system_status(self):             # <<<<<<<<<<<<<<
 *         """Get system status detail.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_system_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2536
 *         return self._request_margin_api('get', 'system/status')
 * 
 *     def get_account_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get account status detail.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_147get_account_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_146get_account_status, "Get account status detail.\n\n        https://binance-docs.github.io/apidocs/spot/en/#account-status-sapi-user_data\n\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"data\": \"Normal\"\n            }\n\n        :raises: BinanceWithdrawException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_147get_account_status = {"get_account_status", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_147get_account_status, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_146get_account_status};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_147get_account_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_account_status (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2536, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_account_status") < 0)) __PYX_ERR(0, 2536, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_account_status", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2536, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_146get_account_status(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_146get_account_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_account_status", 1);

  /* "unicorn_binance_rest_api/manager.py":2555
 * 
 *         """
 *         res = self._request_margin_api('get', 'account/status', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2555, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__38, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":2556
 *         """
 *         res = self._request_margin_api('get', 'account/status', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_s_success};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "unicorn_binance_rest_api/manager.py":2557
 *         res = self._request_margin_api('get', 'account/status', True, data=params)
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_BinanceWithdrawException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2557, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":2556
 *         """
 *         res = self._request_margin_api('get', 'account/status', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2558
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     def get_account_api_trading_status(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2536
 *         return self._request_margin_api('get', 'system/status')
 * 
 *     def get_account_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get account status detail.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2560
 *         return res
 * 
 *     def get_account_api_trading_status(self, **params):             # <<<<<<<<<<<<<<
 *         r"""Fetch account api trading status detail.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_149get_account_api_trading_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_148get_account_api_trading_status, "Fetch account api trading status detail.\n\n        https://binance-docs.github.io/apidocs/spot/en/#account-api-trading-status-sapi-user_data\n\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            {\n                \"data\": {          // API trading status detail\n                    \"isLocked\": false,   // API trading function is locked or not\n                    \"plannedRecoverTime\": 0,  // If API trading function is locked, this is the planned recover time\n                    \"triggerCondition\": {\n                            \"GCR\": 150,  // Number of GTC orders\n                            \"IFER\": 150, // Number of FOK/IOC orders\n                            \"UFR\": 300   // Number of orders\n                    },\n                    \"indicators\": {  // The indicators updated every 30 seconds\n                         \"BTCUSDT\": [  // The symbol\n                            {\n                                \"i\": \"UFR\",  // Unfilled Ratio (UFR)\n                                \"c\": 20,     // Count of all orders\n                                \"v\": 0.05,   // Current UFR value\n                                \"t\": 0.995   // Trigger UFR value\n                            },\n                            {\n                                \"i\": \"IFER\", // IOC/FOK Expiration Ratio (IFER)\n                                \"c\": 20,     // Count of FOK/IOC orders\n                                \"v\": 0.99,   // Current IFER value\n                                \"t\": 0.99    // Trigger IFER value\n                            },\n                            {\n                                \"i\": \"GCR\",  // GTC Cancellation Ratio (GCR)\n                                \"c\": 20,     // Count of GTC orders\n                                \"v\": 0.99,   // Current GCR value\n              ""                  \"t\": 0.99    // Trigger GCR value\n                            }\n                        ],\n                        \"ETHUSDT\": [\n                            {\n                                \"i\": \"UFR\",\n                                \"c\": 20,\n                                \"v\": 0.05,\n                                \"t\": 0.995\n                            },\n                            {\n                                \"i\": \"IFER\",\n                                \"c\": 20,\n                                \"v\": 0.99,\n                                \"t\": 0.99\n                            },\n                            {\n                                \"i\": \"GCR\",\n                                \"c\": 20,\n                                \"v\": 0.99,\n                                \"t\": 0.99\n                            }\n                        ]\n                    },\n                    \"updateTime\": 1547630471725\n                }\n            }\n\n        :raises: BinanceWithdrawException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_149get_account_api_trading_status = {"get_account_api_trading_status", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_149get_account_api_trading_status, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_148get_account_api_trading_status};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_149get_account_api_trading_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_account_api_trading_status (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2560, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_account_api_trading_status") < 0)) __PYX_ERR(0, 2560, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_account_api_trading_status", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2560, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account_api_trading_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_148get_account_api_trading_status(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_148get_account_api_trading_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_account_api_trading_status", 1);

  /* "unicorn_binance_rest_api/manager.py":2630
 * 
 *         """
 *         res = self._request_margin_api('get', 'account/apiTradingStatus', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2630, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__39, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":2631
 *         """
 *         res = self._request_margin_api('get', 'account/apiTradingStatus', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_s_success};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2631, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "unicorn_binance_rest_api/manager.py":2632
 *         res = self._request_margin_api('get', 'account/apiTradingStatus', True, data=params)
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_BinanceWithdrawException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2632, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":2631
 *         """
 *         res = self._request_margin_api('get', 'account/apiTradingStatus', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2633
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     def get_dust_log(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2560
 *         return res
 * 
 *     def get_account_api_trading_status(self, **params):             # <<<<<<<<<<<<<<
 *         r"""Fetch account api trading status detail.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account_api_trading_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2635
 *         return res
 * 
 *     def get_dust_log(self, **params):             # <<<<<<<<<<<<<<
 *         """Get log of small amounts exchanged for BNB.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_151get_dust_log(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_150get_dust_log, "Get log of small amounts exchanged for BNB.\n\n        https://binance-docs.github.io/apidocs/spot/en/#dustlog-sapi-user_data\n\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"total\": 8,   //Total counts of exchange\n                \"userAssetDribblets\": [\n                    {\n                        \"totalTransferedAmount\": \"0.00132256\",   // Total transfered BNB amount for this exchange.\n                        \"totalServiceChargeAmount\": \"0.00002699\",    //Total service charge amount for this exchange.\n                        \"transId\": 45178372831,\n                        \"userAssetDribbletDetails\": [           //Details of  this exchange.\n                            {\n                                \"transId\": 4359321,\n                                \"serviceChargeAmount\": \"0.000009\",\n                                \"amount\": \"0.0009\",\n                                \"operateTime\": 1615985535000,\n                                \"transferedAmount\": \"0.000441\",\n                                \"fromAsset\": \"USDT\"\n                            },\n                            {\n                                \"transId\": 4359321,\n                                \"serviceChargeAmount\": \"0.00001799\",\n                                \"amount\": \"0.0009\",\n                                \"operateTime\": \"2018-05-03 17:07:04\",\n                                \"transferedAmount\": \"0.00088156\",\n                                \"fromAsset\": \"ETH\"\n                            }\n                        ]\n                    },\n                    {\n                        \"operateTime\":1616203180000,\n             ""           \"totalTransferedAmount\": \"0.00058795\",\n                        \"totalServiceChargeAmount\": \"0.000012\",\n                        \"transId\": 4357015,\n                        \"userAssetDribbletDetails\": [\n                            {\n                                \"transId\": 4357015,\n                                \"serviceChargeAmount\": \"0.00001\"\n                                \"amount\": \"0.001\",\n                                \"operateTime\": 1616203180000,\n                                \"transferedAmount\": \"0.00049\",\n                                \"fromAsset\": \"USDT\"\n                            },\n                            {\n                                \"transId\": 4357015,\n                                \"serviceChargeAmount\": \"0.000002\"\n                                \"amount\": \"0.0001\",\n                                \"operateTime\": 1616203180000,\n                                \"transferedAmount\": \"0.00009795\",\n                                \"fromAsset\": \"ETH\"\n                            }\n                        ]\n                    }\n                ]\n            }\n\n        :raises: BinanceWithdrawException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_151get_dust_log = {"get_dust_log", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_151get_dust_log, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_150get_dust_log};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_151get_dust_log(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dust_log (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2635, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_dust_log") < 0)) __PYX_ERR(0, 2635, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dust_log", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2635, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_dust_log", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_150get_dust_log(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_150get_dust_log(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dust_log", 1);

  /* "unicorn_binance_rest_api/manager.py":2707
 * 
 *         """
 *         res = self._request_margin_api('get', 'asset/dribblet', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2707, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__40, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":2708
 *         """
 *         res = self._request_margin_api('get', 'asset/dribblet', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_s_success};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2708, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "unicorn_binance_rest_api/manager.py":2709
 *         res = self._request_margin_api('get', 'asset/dribblet', True, data=params)
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_BinanceWithdrawException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2709, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2709, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":2708
 *         """
 *         res = self._request_margin_api('get', 'asset/dribblet', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2710
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     def transfer_dust(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2635
 *         return res
 * 
 *     def get_dust_log(self, **params):             # <<<<<<<<<<<<<<
 *         """Get log of small amounts exchanged for BNB.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_dust_log", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2712
 *         return res
 * 
 *     def transfer_dust(self, **params):             # <<<<<<<<<<<<<<
 *         """Convert dust assets to BNB.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_153transfer_dust(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_152transfer_dust, "Convert dust assets to BNB.\n\n        https://binance-docs.github.io/apidocs/spot/en/#dust-transfer-user_data\n\n        :param asset: The asset being converted. e.g: 'ONE'\n        :type asset: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            result = client.transfer_dust(asset='ONE')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"totalServiceCharge\":\"0.02102542\",\n                \"totalTransfered\":\"1.05127099\",\n                \"transferResult\":[\n                    {\n                        \"amount\":\"0.03000000\",\n                        \"fromAsset\":\"ETH\",\n                        \"operateTime\":1563368549307,\n                        \"serviceChargeAmount\":\"0.00500000\",\n                        \"tranId\":2970932918,\n                        \"transferedAmount\":\"0.25000000\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_153transfer_dust = {"transfer_dust", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_153transfer_dust, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_152transfer_dust};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_153transfer_dust(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transfer_dust (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2712, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "transfer_dust") < 0)) __PYX_ERR(0, 2712, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transfer_dust", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2712, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_dust", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_152transfer_dust(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_152transfer_dust(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transfer_dust", 1);

  /* "unicorn_binance_rest_api/manager.py":2749
 * 
 *         """
 *         return self._request_margin_api('post', 'asset/dust', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_asset_dividend_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2749, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__41, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2712
 *         return res
 * 
 *     def transfer_dust(self, **params):             # <<<<<<<<<<<<<<
 *         """Convert dust assets to BNB.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_dust", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2751
 *         return self._request_margin_api('post', 'asset/dust', True, data=params)
 * 
 *     def get_asset_dividend_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query asset dividend record.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_155get_asset_dividend_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_154get_asset_dividend_history, "Query asset dividend record.\n\n        https://binance-docs.github.io/apidocs/spot/en/#asset-dividend-record-user_data\n\n        :param asset: optional\n        :type asset: str\n        :param startTime: optional\n        :type startTime: long\n        :param endTime: optional\n        :type endTime: long\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            result = client.get_asset_dividend_history()\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"rows\":[\n                    {\n                        \"amount\":\"10.00000000\",\n                        \"asset\":\"BHFT\",\n                        \"divTime\":1563189166000,\n                        \"enInfo\":\"BHFT distribution\",\n                        \"tranId\":2968885920\n                    },\n                    {\n                        \"amount\":\"10.00000000\",\n                        \"asset\":\"BHFT\",\n                        \"divTime\":1563189165000,\n                        \"enInfo\":\"BHFT distribution\",\n                        \"tranId\":2968885920\n                    }\n                ],\n                \"total\":2\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_155get_asset_dividend_history = {"get_asset_dividend_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_155get_asset_dividend_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_154get_asset_dividend_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_155get_asset_dividend_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_asset_dividend_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2751, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_asset_dividend_history") < 0)) __PYX_ERR(0, 2751, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_asset_dividend_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2751, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_asset_dividend_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_154get_asset_dividend_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_154get_asset_dividend_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_asset_dividend_history", 1);

  /* "unicorn_binance_rest_api/manager.py":2797
 * 
 *         """
 *         return self._request_margin_api('get', 'asset/assetDividend', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def query_universal_transfer_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2797, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__42, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2751
 *         return self._request_margin_api('post', 'asset/dust', True, data=params)
 * 
 *     def get_asset_dividend_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query asset dividend record.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_asset_dividend_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2799
 *         return self._request_margin_api('get', 'asset/assetDividend', True, data=params)
 * 
 *     def query_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query User Universal Transfer History
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_157query_universal_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_156query_universal_transfer_history, "Query User Universal Transfer History\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-user-universal-transfer-history\n\n        :param type: required\n        :type type: str (ENUM)\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param current: optional - Default 1\n        :type current: int\n        :param size: required - Default 10, Max 100\n        :type size: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            transfer_status = client.query_universal_transfer_history(params)\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"total\":2,\n                \"rows\":[\n                    {\n                        \"asset\":\"USDT\",\n                        \"amount\":\"1\",\n                        \"type\":\"MAIN_UMFUTURE\"\n                        \"status\": \"CONFIRMED\",\n                        \"tranId\": 11415955596,\n                        \"timestamp\":1544433328000\n                    },\n                    {\n                        \"asset\":\"USDT\",\n                        \"amount\":\"2\",\n                        \"type\":\"MAIN_UMFUTURE\",\n                        \"status\": \"CONFIRMED\",\n                        \"tranId\": 11366865406,\n                        \"timestamp\":1544433328000\n                    }\n                ]\n            }\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_157query_universal_transfer_history = {"query_universal_transfer_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_157query_universal_transfer_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_156query_universal_transfer_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_157query_universal_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_universal_transfer_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2799, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "query_universal_transfer_history") < 0)) __PYX_ERR(0, 2799, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("query_universal_transfer_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2799, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.query_universal_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_156query_universal_transfer_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_156query_universal_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_universal_transfer_history", 1);

  /* "unicorn_binance_rest_api/manager.py":2852
 * 
 *         """
 *         return self._request_margin_api('get', 'asset/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_trade_fee(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 2852, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2852, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__43, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2799
 *         return self._request_margin_api('get', 'asset/assetDividend', True, data=params)
 * 
 *     def query_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query User Universal Transfer History
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.query_universal_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2854
 *         return self._request_margin_api('get', 'asset/transfer', signed=True, data=params)
 * 
 *     def get_trade_fee(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trade fee.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_159get_trade_fee(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_158get_trade_fee, "Get trade fee.\n\n        https://binance-docs.github.io/apidocs/spot/en/#trade-fee-sapi-user_data\n\n        :param symbol: optional\n        :type symbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"symbol\": \"ADABNB\",\n                    \"makerCommission\": \"0.001\",\n                    \"takerCommission\": \"0.001\"\n                },\n                {\n                    \"symbol\": \"BNBBTC\",\n                    \"makerCommission\": \"0.001\",\n                    \"takerCommission\": \"0.001\"\n                }\n            ]\n\n        :raises: BinanceWithdrawException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_159get_trade_fee = {"get_trade_fee", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_159get_trade_fee, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_158get_trade_fee};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_159get_trade_fee(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_trade_fee (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2854, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_trade_fee") < 0)) __PYX_ERR(0, 2854, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_trade_fee", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2854, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_trade_fee", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_158get_trade_fee(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_158get_trade_fee(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_trade_fee", 1);

  /* "unicorn_binance_rest_api/manager.py":2884
 * 
 *         """
 *         res = self._request_margin_api('get', 'asset/tradeFee', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2884, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__44, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":2885
 *         """
 *         res = self._request_margin_api('get', 'asset/tradeFee', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_s_success};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2885, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "unicorn_binance_rest_api/manager.py":2886
 *         res = self._request_margin_api('get', 'asset/tradeFee', True, data=params)
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_BinanceWithdrawException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2886, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2886, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":2885
 *         """
 *         res = self._request_margin_api('get', 'asset/tradeFee', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2887
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     def get_asset_details(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2854
 *         return self._request_margin_api('get', 'asset/transfer', signed=True, data=params)
 * 
 *     def get_trade_fee(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trade fee.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_trade_fee", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2889
 *         return res
 * 
 *     def get_asset_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch details on assets.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_161get_asset_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_160get_asset_details, "Fetch details on assets.\n\n        https://binance-docs.github.io/apidocs/spot/en/#asset-detail-sapi-user_data\n\n        :param asset: optional\n        :type asset: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"CTR\": {\n                    \"minWithdrawAmount\": \"70.00000000\", //min withdraw amount\n                    \"depositStatus\": false,//deposit status (false if ALL of networks' are false)\n                    \"withdrawFee\": 35, // withdraw fee\n                    \"withdrawStatus\": true, //withdraw status (false if ALL of networks' are false)\n                    \"depositTip\": \"Delisted, Deposit Suspended\" //reason\n                },\n                \"SKY\": {\n                    \"minWithdrawAmount\": \"0.02000000\",\n                    \"depositStatus\": true,\n                    \"withdrawFee\": 0.01,\n                    \"withdrawStatus\": true\n                }\n            }\n\n\n        :raises: BinanceWithdrawException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_161get_asset_details = {"get_asset_details", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_161get_asset_details, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_160get_asset_details};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_161get_asset_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_asset_details (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2889, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_asset_details") < 0)) __PYX_ERR(0, 2889, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_asset_details", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2889, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_asset_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_160get_asset_details(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_160get_asset_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_asset_details", 1);

  /* "unicorn_binance_rest_api/manager.py":2923
 * 
 *         """
 *         res = self._request_margin_api('get', 'asset/assetDetail', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2923, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__45, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":2924
 *         """
 *         res = self._request_margin_api('get', 'asset/assetDetail', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_s_success};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2924, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "unicorn_binance_rest_api/manager.py":2925
 *         res = self._request_margin_api('get', 'asset/assetDetail', True, data=params)
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_BinanceWithdrawException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2925, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2925, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":2924
 *         """
 *         res = self._request_margin_api('get', 'asset/assetDetail', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2926
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     # Withdraw Endpoints
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2889
 *         return res
 * 
 *     def get_asset_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch details on assets.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_asset_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2930
 *     # Withdraw Endpoints
 * 
 *     def withdraw(self, **params):             # <<<<<<<<<<<<<<
 *         """Submit a withdraw request.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_163withdraw(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_162withdraw, "Submit a withdraw request.\n\n        https://www.binance.com/restapipub.html\n\n        Assumptions:\n\n        - You must have withdrawal permissions enabled on your API key\n        - You must have withdrawal to the address specified through the website and approved the transaction via email\n\n        :param coin: required\n        :type coin: str\n        :param withdrawOrderId: optional - client id for withdraw\n        :type withdrawOrderId: str\n        :param network: optional\n        :type network: str\n        :param address: optional\n        :type address: str\n        :type addressTag: optional - Secondary address identifier for coins like XRP,XMR etc.\n        :param amount: required\n        :type amount: decimal\n        :param transactionFeeFlag: required - When making internal transfer, true for returning the fee to the\n                                   destination account; false for returning the fee back to the departure account.\n                                   Default false.\n        :type transactionFeeFlag: bool\n        :param name: optional - Description of the address, default asset value passed will be used\n        :type name: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"id\":\"7213fea8e94b4a5593d507237e5a555b\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceWithdrawException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_163withdraw = {"withdraw", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_163withdraw, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_162withdraw};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_163withdraw(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("withdraw (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2930, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "withdraw") < 0)) __PYX_ERR(0, 2930, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("withdraw", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2930, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.withdraw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_162withdraw(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_162withdraw(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("withdraw", 1);

  /* "unicorn_binance_rest_api/manager.py":2972
 *         """
 *         # force a name for the withdrawal if one not set
 *         if 'asset' in params and 'name' not in params:             # <<<<<<<<<<<<<<
 *             params['name'] = params['asset']
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)
 */
  __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_asset, __pyx_v_params, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2972, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_name, __pyx_v_params, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2972, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "unicorn_binance_rest_api/manager.py":2973
 *         # force a name for the withdrawal if one not set
 *         if 'asset' in params and 'name' not in params:
 *             params['name'] = params['asset']             # <<<<<<<<<<<<<<
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)
 *         if not res.get('success'):
 */
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_params, __pyx_n_s_asset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_name, __pyx_t_3) < 0))) __PYX_ERR(0, 2973, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":2972
 *         """
 *         # force a name for the withdrawal if one not set
 *         if 'asset' in params and 'name' not in params:             # <<<<<<<<<<<<<<
 *             params['name'] = params['asset']
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2974
 *         if 'asset' in params and 'name' not in params:
 *             params['name'] = params['asset']
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 2974, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__46, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_res = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "unicorn_binance_rest_api/manager.py":2975
 *             params['name'] = params['asset']
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_s_success};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = (!__pyx_t_1);
  if (unlikely(__pyx_t_2)) {

    /* "unicorn_binance_rest_api/manager.py":2976
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_BinanceWithdrawException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_msg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2976, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 2976, __pyx_L1_error)

    /* "unicorn_binance_rest_api/manager.py":2975
 *             params['name'] = params['asset']
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)
 *         if not res.get('success'):             # <<<<<<<<<<<<<<
 *             raise BinanceWithdrawException(res['msg'])
 *         return res
 */
  }

  /* "unicorn_binance_rest_api/manager.py":2977
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     def get_deposit_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2930
 *     # Withdraw Endpoints
 * 
 *     def withdraw(self, **params):             # <<<<<<<<<<<<<<
 *         """Submit a withdraw request.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.withdraw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":2979
 *         return res
 * 
 *     def get_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch deposit history.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_165get_deposit_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_164get_deposit_history, "Fetch deposit history.\n\n        https://binance-docs.github.io/apidocs/spot/en/#deposit-history-supporting-network-user_data\n\n        :param coin: optional\n        :type coin: str\n        :type status: optional - 0(0:pending,1:success) optional\n        :type status: int\n        :param startTime: optional\n        :type startTime: long\n        :param endTime: optional\n        :type endTime: long\n        :param offset: optional - default:0\n        :type offset: long\n        :param limit: optional\n        :type limit: long\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"amount\":\"0.00999800\",\n                    \"coin\":\"PAXG\",\n                    \"network\":\"ETH\",\n                    \"status\":1,\n                    \"address\":\"0x788cabe9236ce061e5a892e1a59395a81fc8d62c\",\n                    \"addressTag\":\"\",\n                    \"txId\":\"0xaad4654a3234aa6118af9b4b335f5ae81c360b2394721c019b5d1e75328b09f3\",\n                    \"insertTime\":1599621997000,\n                    \"transferType\":0,\n                    \"confirmTimes\":\"12/12\"\n                },\n                {\n                    \"amount\":\"0.50000000\",\n                    \"coin\":\"IOTA\",\n                    \"network\":\"IOTA\",\n                    \"status\":1,\n                    \"address\":\"SIZ9VLMHWATXKV99LH99CIGFJFUMLEHGWVZVNNZXRJJVWBPHYWPPBOSDORZ9EQSHCZAMPVAPGFYQAUUV9DROOXJLNW\",\n                    \"addressTag\":\"\",\n                    \"txId\":\"ESBFVQUTPIWQNJSPXFNHNYHSQNTGKRVKPRABQWTAXCDWOAKDKYWPTVG9BGXNVNKTLEJGESAVXIKIZ9999\",\n                    \"insertTime\":1599620082000,\n                    \"transferType\":0,\n                    \"confirmTimes\":\"1/1\"\n                }\n            ]\n\n        :raises: BinanceRequestException, Binanc""eAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_165get_deposit_history = {"get_deposit_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_165get_deposit_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_164get_deposit_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_165get_deposit_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_deposit_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2979, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_deposit_history") < 0)) __PYX_ERR(0, 2979, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_deposit_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2979, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_deposit_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_164get_deposit_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_164get_deposit_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_deposit_history", 1);

  /* "unicorn_binance_rest_api/manager.py":3033
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/hisrec', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_withdraw_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3033, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__47, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":2979
 *         return res
 * 
 *     def get_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch deposit history.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_deposit_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3035
 *         return self._request_margin_api('get', 'capital/deposit/hisrec', True, data=params)
 * 
 *     def get_withdraw_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_167get_withdraw_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_166get_withdraw_history, "Fetch withdraw history.\n\n        https://binance-docs.github.io/apidocs/spot/en/#deposit-history-supporting-network-user_data\n\n        :param coin: optional\n        :type coin: str\n        :param status: 0(0:Email Sent,1:Cancelled 2:Awaiting Approval 3:Rejected 4:Processing 5:Failure 6Completed)\n                       optional\n        :type status: int\n        :param offset: optional - default:0\n        :type offset: int\n        :param limit: optional\n        :type limit: int\n        :param startTime: optional - Default: 90 days from current timestamp\n        :type startTime: int\n        :param endTime: optional - Default: present timestamp\n        :type endTime: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"address\": \"0x94df8b352de7f46f64b01d3666bf6e936e44ce60\",\n                    \"amount\": \"8.91000000\",\n                    \"applyTime\": \"2019-10-12 11:12:02\",\n                    \"coin\": \"USDT\",\n                    \"id\": \"b6ae22b3aa844210a7041aee7589627c\",\n                    \"withdrawOrderId\": \"WITHDRAWtest123\", // will not be returned if there's no withdrawOrderId for\n                                       this withdraw.\n                    \"network\": \"ETH\",\n                    \"transferType\": 0,   // 1 for internal transfer, 0 for external transfer\n                    \"status\": 6,\n                    \"txId\": \"0xb5ef8c13b968a406cc62a93a8bd80f9e9a906ef1b3fcf20a2e48573c17659268\"\n                },\n                {\n                    \"address\": \"1FZdVHtiBqMrWdjPyRPULCUceZPJ2WLCsB\",\n                    \"amount\": \"0.00150000\",\n                    \"applyTime\": \"2019-09-24 12:43:45\",\n                    \"coin\": \"BTC\",\n                    \"id\": \"156ec387f49b41df8724fa744fa82719\",\n         ""           \"network\": \"BTC\",\n                    \"status\": 6,\n                    \"txId\": \"60fd9007ebfddc753455f95fafa808c4302c836e4d1eebc5a132c36c1d8ac354\"\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_167get_withdraw_history = {"get_withdraw_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_167get_withdraw_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_166get_withdraw_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_167get_withdraw_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_withdraw_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3035, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_withdraw_history") < 0)) __PYX_ERR(0, 3035, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_withdraw_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3035, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_withdraw_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_166get_withdraw_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_166get_withdraw_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_withdraw_history", 1);

  /* "unicorn_binance_rest_api/manager.py":3089
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/withdraw/history', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_withdraw_history_id(self, withdraw_id, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3089, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__48, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3035
 *         return self._request_margin_api('get', 'capital/deposit/hisrec', True, data=params)
 * 
 *     def get_withdraw_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_withdraw_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3091
 *         return self._request_margin_api('get', 'capital/withdraw/history', True, data=params)
 * 
 *     def get_withdraw_history_id(self, withdraw_id, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_169get_withdraw_history_id(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_168get_withdraw_history_id, "Fetch withdraw history.\n\n        https://binance-docs.github.io/apidocs/spot/en/#deposit-history-supporting-network-user_data\n\n        :param withdraw_id: required\n        :type withdraw_id: str\n        :param asset: optional\n        :type asset: str\n        :type status: 0(0:Email Sent,1:Cancelled 2:Awaiting Approval 3:Rejected 4:Processing 5:Failure 6Completed)\n                      optional\n        :type status: int\n        :param startTime: optional\n        :type startTime: long\n        :param endTime: optional\n        :type endTime: long\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"id\":\"7213fea8e94b4a5593d507237e5a555b\",\n                \"withdrawOrderId\": None,\n                \"amount\": 0.99,\n                \"transactionFee\": 0.01,\n                \"address\": \"0x6915f16f8791d0a1cc2bf47c13a6b2a92000504b\",\n                \"asset\": \"ETH\",\n                \"txId\": \"0xdf33b22bdb2b28b1f75ccd201a4a4m6e7g83jy5fc5d5a9d1340961598cfcb0a1\",\n                \"applyTime\": 1508198532000,\n                \"status\": 4\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_169get_withdraw_history_id = {"get_withdraw_history_id", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_169get_withdraw_history_id, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_168get_withdraw_history_id};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_169get_withdraw_history_id(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_withdraw_id = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_withdraw_history_id (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_withdraw_id,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3091, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_withdraw_id)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3091, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_withdraw_history_id", 1, 2, 2, 1); __PYX_ERR(0, 3091, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_withdraw_history_id") < 0)) __PYX_ERR(0, 3091, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_withdraw_id = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_withdraw_history_id", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3091, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_withdraw_history_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_168get_withdraw_history_id(__pyx_self, __pyx_v_self, __pyx_v_withdraw_id, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_168get_withdraw_history_id(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_withdraw_id, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_entry = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_withdraw_history_id", 1);

  /* "unicorn_binance_rest_api/manager.py":3129
 * 
 *         """
 *         result = self._request_margin_api('get', 'capital/withdraw/history', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *         for entry in result['withdrawList']:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3129, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__48, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":3131
 *         result = self._request_margin_api('get', 'capital/withdraw/history', True, data=params)
 * 
 *         for entry in result['withdrawList']:             # <<<<<<<<<<<<<<
 *             if 'id' in entry and entry['id'] == withdraw_id:
 *                 return entry
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_result, __pyx_n_s_withdrawList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3131, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3131, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 3131, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3131, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 3131, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3131, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_entry, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "unicorn_binance_rest_api/manager.py":3132
 * 
 *         for entry in result['withdrawList']:
 *             if 'id' in entry and entry['id'] == withdraw_id:             # <<<<<<<<<<<<<<
 *                 return entry
 * 
 */
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_id, __pyx_v_entry, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3132, __pyx_L1_error)
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_entry, __pyx_n_s_id); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_3, __pyx_v_withdraw_id, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __pyx_t_7;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_6) {

      /* "unicorn_binance_rest_api/manager.py":3133
 *         for entry in result['withdrawList']:
 *             if 'id' in entry and entry['id'] == withdraw_id:
 *                 return entry             # <<<<<<<<<<<<<<
 * 
 *         raise Exception("There is no entry with withdraw id", result)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_entry);
      __pyx_r = __pyx_v_entry;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "unicorn_binance_rest_api/manager.py":3132
 * 
 *         for entry in result['withdrawList']:
 *             if 'id' in entry and entry['id'] == withdraw_id:             # <<<<<<<<<<<<<<
 *                 return entry
 * 
 */
    }

    /* "unicorn_binance_rest_api/manager.py":3131
 *         result = self._request_margin_api('get', 'capital/withdraw/history', True, data=params)
 * 
 *         for entry in result['withdrawList']:             # <<<<<<<<<<<<<<
 *             if 'id' in entry and entry['id'] == withdraw_id:
 *                 return entry
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":3135
 *                 return entry
 * 
 *         raise Exception("There is no entry with withdraw id", result)             # <<<<<<<<<<<<<<
 * 
 *     def get_deposit_address(self, **params):
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_kp_s_There_is_no_entry_with_withdraw);
  __Pyx_GIVEREF(__pyx_kp_s_There_is_no_entry_with_withdraw);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_s_There_is_no_entry_with_withdraw)) __PYX_ERR(0, 3135, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_result);
  __Pyx_GIVEREF(__pyx_v_result);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_result)) __PYX_ERR(0, 3135, __pyx_L1_error);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 3135, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3091
 *         return self._request_margin_api('get', 'capital/withdraw/history', True, data=params)
 * 
 *     def get_withdraw_history_id(self, withdraw_id, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_withdraw_history_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_entry);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3137
 *         raise Exception("There is no entry with withdraw id", result)
 * 
 *     def get_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch a deposit address for a symbol
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_171get_deposit_address(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_170get_deposit_address, "Fetch a deposit address for a symbol\n\n        https://binance-docs.github.io/apidocs/spot/en/#deposit-history-supporting-network-user_data\n\n        :param coin: required\n        :type coin: str\n        :param network: optional\n        :type network: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"address\": \"1HPn8Rx2y6nNSfagQBKy27GB99Vbzg89wv\",\n                \"coin\": \"BTC\",\n                \"tag\": \"\",\n                \"url\": \"https://btc.com/1HPn8Rx2y6nNSfagQBKy27GB99Vbzg89wv\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_171get_deposit_address = {"get_deposit_address", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_171get_deposit_address, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_170get_deposit_address};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_171get_deposit_address(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_deposit_address (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3137, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_deposit_address") < 0)) __PYX_ERR(0, 3137, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_deposit_address", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3137, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_deposit_address", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_170get_deposit_address(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_170get_deposit_address(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_deposit_address", 1);

  /* "unicorn_binance_rest_api/manager.py":3163
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/address', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     # User Stream Endpoints
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3163, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__49, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3137
 *         raise Exception("There is no entry with withdraw id", result)
 * 
 *     def get_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch a deposit address for a symbol
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_deposit_address", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3167
 *     # User Stream Endpoints
 * 
 *     def stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new user data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_173stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_172stream_get_listen_key, "Start a new user data stream and return the listen key\n        If a stream already exists it should return the same key.\n        If the stream becomes invalid a new key is returned.\n\n        Can be used to keep the user stream alive.\n\n        https://binance-docs.github.io/apidocs/spot/en/#start-user-data-stream-user_stream\n\n        :param output: Set `output` to \"raw_data\" to receive the request resource, default is \"value\" which returns\n                        the plain listenKey.\n        :type output: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"listenKey\": \"pqia91ma19a5s61cv6a81va65sdf19v8a65a1a5s61cv6a81va65sdf19v8a65a1\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_173stream_get_listen_key = {"stream_get_listen_key", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_173stream_get_listen_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_172stream_get_listen_key};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_173stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_output = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stream_get_listen_key (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_output,&__pyx_n_s_throw_exception,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_value)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3167, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_output);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3167, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3167, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stream_get_listen_key") < 0)) __PYX_ERR(0, 3167, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_output = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stream_get_listen_key", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 3167, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_172stream_get_listen_key(__pyx_self, __pyx_v_self, __pyx_v_output, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_172stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stream_get_listen_key", 1);

  /* "unicorn_binance_rest_api/manager.py":3192
 * 
 *         """
 *         res = self._post('userDataStream', False, data={}, version=self.PRIVATE_API_VERSION,             # <<<<<<<<<<<<<<
 *                          throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_post_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_t_3) < 0) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":3193
 *         """
 *         res = self._post('userDataStream', False, data={}, version=self.PRIVATE_API_VERSION,
 *                          throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 *         if output == "value":
 *             return res['listenKey']
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 3192, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3192
 * 
 *         """
 *         res = self._post('userDataStream', False, data={}, version=self.PRIVATE_API_VERSION,             # <<<<<<<<<<<<<<
 *                          throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__50, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":3194
 *         res = self._post('userDataStream', False, data={}, version=self.PRIVATE_API_VERSION,
 *                          throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_value, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3194, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":3195
 *                          throw_exception=throw_exception)
 *         if output == "value":
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 *         elif output == "raw_data":
 *             return res
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":3194
 *         res = self._post('userDataStream', False, data={}, version=self.PRIVATE_API_VERSION,
 *                          throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  }

  /* "unicorn_binance_rest_api/manager.py":3196
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_raw_data, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3196, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":3197
 *             return res['listenKey']
 *         elif output == "raw_data":
 *             return res             # <<<<<<<<<<<<<<
 *         else:
 *             return res['listenKey']
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_res);
    __pyx_r = __pyx_v_res;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":3196
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  }

  /* "unicorn_binance_rest_api/manager.py":3199
 *             return res
 *         else:
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 * 
 *     def stream_keepalive(self, listenKey, throw_exception=True):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":3167
 *     # User Stream Endpoints
 * 
 *     def stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new user data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3201
 *             return res['listenKey']
 * 
 *     def stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a user data stream to prevent a time out.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_175stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_174stream_keepalive, "PING a user data stream to prevent a time out.\n\n        https://binance-docs.github.io/apidocs/spot/en/#keepalive-user-data-stream-user_stream\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_175stream_keepalive = {"stream_keepalive", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_175stream_keepalive, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_174stream_keepalive};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_175stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stream_keepalive (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("stream_keepalive", 0, 2, 3, 1); __PYX_ERR(0, 3201, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3201, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stream_keepalive") < 0)) __PYX_ERR(0, 3201, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stream_keepalive", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 3201, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_174stream_keepalive(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_174stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stream_keepalive", 1);

  /* "unicorn_binance_rest_api/manager.py":3221
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._put('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 3221, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":3223
 *             'listenKey': listenKey
 *         }
 *         return self._put('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,             # <<<<<<<<<<<<<<
 *                          throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_put_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3223, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 3223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":3224
 *         }
 *         return self._put('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,
 *                          throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     def stream_close(self, listenKey, throw_exception=True):
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 3223, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3223
 *             'listenKey': listenKey
 *         }
 *         return self._put('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,             # <<<<<<<<<<<<<<
 *                          throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__50, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3201
 *             return res['listenKey']
 * 
 *     def stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a user data stream to prevent a time out.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3226
 *                          throw_exception=throw_exception)
 * 
 *     def stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a user data stream.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_177stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_176stream_close, "Close out a user data stream.\n\n        https://binance-docs.github.io/apidocs/spot/en/#close-user-data-stream-user_stream\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_177stream_close = {"stream_close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_177stream_close, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_176stream_close};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_177stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stream_close (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3226, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3226, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("stream_close", 0, 2, 3, 1); __PYX_ERR(0, 3226, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3226, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stream_close") < 0)) __PYX_ERR(0, 3226, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stream_close", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 3226, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_176stream_close(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_176stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stream_close", 1);

  /* "unicorn_binance_rest_api/manager.py":3246
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._delete('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 3246, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":3248
 *             'listenKey': listenKey
 *         }
 *         return self._delete('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,             # <<<<<<<<<<<<<<
 *                          throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_delete_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3248, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_PRIVATE_API_VERSION); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_t_3) < 0) __PYX_ERR(0, 3248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":3249
 *         }
 *         return self._delete('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,
 *                          throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     # Margin Trading Endpoints
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 3248, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3248
 *             'listenKey': listenKey
 *         }
 *         return self._delete('userDataStream', False, data=params, version=self.PRIVATE_API_VERSION,             # <<<<<<<<<<<<<<
 *                          throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__50, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3226
 *                          throw_exception=throw_exception)
 * 
 *     def stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a user data stream.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3253
 *     # Margin Trading Endpoints
 * 
 *     def get_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin account details
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_179get_margin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_178get_margin_account, "Query cross-margin account details\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-cross-margin-account-details-user_data\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"borrowEnabled\": true,\n                \"marginLevel\": \"11.64405625\",\n                \"totalAssetOfBtc\": \"6.82728457\",\n                \"totalLiabilityOfBtc\": \"0.58633215\",\n                \"totalNetAssetOfBtc\": \"6.24095242\",\n                \"tradeEnabled\": true,\n                \"transferEnabled\": true,\n                \"userAssets\": [\n                    {\n                        \"asset\": \"BTC\",\n                        \"borrowed\": \"0.00000000\",\n                        \"free\": \"0.00499500\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                        \"netAsset\": \"0.00499500\"\n                    },\n                    {\n                        \"asset\": \"BNB\",\n                        \"borrowed\": \"201.66666672\",\n                        \"free\": \"2346.50000000\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                        \"netAsset\": \"2144.83333328\"\n                    },\n                    {\n                        \"asset\": \"ETH\",\n                        \"borrowed\": \"0.00000000\",\n                        \"free\": \"0.00000000\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                        \"netAsset\": \"0.00000000\"\n                    },\n                    {\n                        \"asset\": \"USDT\",\n                        \"borrowed\": \"0.00000000\",\n                        \"free\": \"0.00000000\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                      ""  \"netAsset\": \"0.00000000\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_179get_margin_account = {"get_margin_account", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_179get_margin_account, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_178get_margin_account};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_179get_margin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_account (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3253, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_account") < 0)) __PYX_ERR(0, 3253, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_account", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3253, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_178get_margin_account(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_178get_margin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_account", 1);

  /* "unicorn_binance_rest_api/manager.py":3309
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_isolated_margin_account(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3309, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__51, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3253
 *     # Margin Trading Endpoints
 * 
 *     def get_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin account details
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3311
 *         return self._request_margin_api('get', 'margin/account', True, data=params)
 * 
 *     def get_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin account details
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_181get_isolated_margin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_180get_isolated_margin_account, "Query isolated margin account details\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-isolated-margin-account-info-user_data\n\n        :param symbols: optional up to 5 margin pairs as a comma separated string\n        :type asset: str\n\n        .. code:: python\n\n            account_info = client.get_isolated_margin_account()\n            account_info = client.get_isolated_margin_account(symbols=\"BTCUSDT,ETHUSDT\")\n\n        :returns: API response\n\n        .. code-block:: python\n\n            If \"symbols\" is not sent:\n\n                {\n                \"assets\":[\n                    {\n                        \"baseAsset\": \n                        {\n                        \"asset\": \"BTC\",\n                        \"borrowEnabled\": true,\n                        \"borrowed\": \"0.00000000\",\n                        \"free\": \"0.00000000\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                        \"netAsset\": \"0.00000000\",\n                        \"netAssetOfBtc\": \"0.00000000\",\n                        \"repayEnabled\": true,\n                        \"totalAsset\": \"0.00000000\"\n                        },\n                        \"quoteAsset\": \n                        {\n                        \"asset\": \"USDT\",\n                        \"borrowEnabled\": true,\n                        \"borrowed\": \"0.00000000\",\n                        \"free\": \"0.00000000\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                        \"netAsset\": \"0.00000000\",\n                        \"netAssetOfBtc\": \"0.00000000\",\n                        \"repayEnabled\": true,\n                        \"totalAsset\": \"0.00000000\"\n                        },\n                        \"symbol\": \"BTCUSDT\"\n                        \"isolatedCreated\": true, \n                    ""    \"marginLevel\": \"0.00000000\", \n                        \"marginLevelStatus\": \"EXCESSIVE\", // \"EXCESSIVE\", \"NORMAL\", \"MARGIN_CALL\", \"PRE_LIQUIDATION\", \"FORCE_LIQUIDATION\"\n                        \"marginRatio\": \"0.00000000\",\n                        \"indexPrice\": \"10000.00000000\"\n                        \"liquidatePrice\": \"1000.00000000\",\n                        \"liquidateRate\": \"1.00000000\"\n                        \"tradeEnabled\": true\n                    }\n                    ],\n                    \"totalAssetOfBtc\": \"0.00000000\",\n                    \"totalLiabilityOfBtc\": \"0.00000000\",\n                    \"totalNetAssetOfBtc\": \"0.00000000\" \n                }\n\n            If \"symbols\" is sent:\n\n                {\n                \"assets\":[\n                    {\n                        \"baseAsset\": \n                        {\n                        \"asset\": \"BTC\",\n                        \"borrowEnabled\": true,\n                        \"borrowed\": \"0.00000000\",\n                        \"free\": \"0.00000000\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                        \"netAsset\": \"0.00000000\",\n                        \"netAssetOfBtc\": \"0.00000000\",\n                        \"repayEnabled\": true,\n                        \"totalAsset\": \"0.00000000\"\n                        },\n                        \"quoteAsset\": \n                        {\n                        \"asset\": \"USDT\",\n                        \"borrowEnabled\": true,\n                        \"borrowed\": \"0.00000000\",\n                        \"free\": \"0.00000000\",\n                        \"interest\": \"0.00000000\",\n                        \"locked\": \"0.00000000\",\n                        \"netAsset\": \"0.00000000\",\n                        \"netAssetOfBtc\": \"0.00000000\",\n                        \"repayEnabled""\": true,\n                        \"totalAsset\": \"0.00000000\"\n                        },\n                        \"symbol\": \"BTCUSDT\"\n                        \"isolatedCreated\": true, \n                        \"marginLevel\": \"0.00000000\", \n                        \"marginLevelStatus\": \"EXCESSIVE\", // \"EXCESSIVE\", \"NORMAL\", \"MARGIN_CALL\", \"PRE_LIQUIDATION\", \"FORCE_LIQUIDATION\"\n                        \"marginRatio\": \"0.00000000\",\n                        \"indexPrice\": \"10000.00000000\"\n                        \"liquidatePrice\": \"1000.00000000\",\n                        \"liquidateRate\": \"1.00000000\"\n                        \"tradeEnabled\": true\n                    }\n                    ]\n                }\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_181get_isolated_margin_account = {"get_isolated_margin_account", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_181get_isolated_margin_account, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_180get_isolated_margin_account};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_181get_isolated_margin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_isolated_margin_account (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3311, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_isolated_margin_account") < 0)) __PYX_ERR(0, 3311, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_isolated_margin_account", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3311, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_isolated_margin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_180get_isolated_margin_account(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_180get_isolated_margin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_isolated_margin_account", 1);

  /* "unicorn_binance_rest_api/manager.py":3420
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/isolated/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_asset(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3420, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__52, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3311
 *         return self._request_margin_api('get', 'margin/account', True, data=params)
 * 
 *     def get_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin account details
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_isolated_margin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3422
 *         return self._request_margin_api('get', 'margin/isolated/account', True, data=params)
 * 
 *     def get_margin_asset(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin asset
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_183get_margin_asset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_182get_margin_asset, "Query cross-margin asset\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-asset-market_data\n\n        :param asset: name of the asset\n        :type asset: str\n\n\n        .. code:: python\n\n            asset_details = client.get_margin_asset(asset='BNB')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"assetFullName\": \"Binance Coin\",\n                \"assetName\": \"BNB\",\n                \"isBorrowable\": false,\n                \"isMortgageable\": true,\n                \"userMinBorrow\": \"0.00000000\",\n                \"userMinRepay\": \"0.00000000\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_183get_margin_asset = {"get_margin_asset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_183get_margin_asset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_182get_margin_asset};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_183get_margin_asset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_asset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3422, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_asset") < 0)) __PYX_ERR(0, 3422, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_asset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3422, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_asset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_182get_margin_asset(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_182get_margin_asset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_asset", 1);

  /* "unicorn_binance_rest_api/manager.py":3451
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/asset', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_symbol(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3451, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__53, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3422
 *         return self._request_margin_api('get', 'margin/isolated/account', True, data=params)
 * 
 *     def get_margin_asset(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin asset
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_asset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3453
 *         return self._request_margin_api('get', 'margin/asset', data=params)
 * 
 *     def get_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin symbol info
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_185get_margin_symbol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_184get_margin_symbol, "Query cross-margin symbol info\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-cross-margin-pair-market_data\n\n        :param symbol: name of the symbol pair\n        :type symbol: str\n\n        .. code:: python\n\n            pair_details = client.get_margin_symbol(symbol='BTCUSDT')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"id\":323355778339572400,\n                \"symbol\":\"BTCUSDT\",\n                \"base\":\"BTC\",\n                \"quote\":\"USDT\",\n                \"isMarginTrade\":true,\n                \"isBuyAllowed\":true,\n                \"isSellAllowed\":true\n            }\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_185get_margin_symbol = {"get_margin_symbol", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_185get_margin_symbol, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_184get_margin_symbol};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_185get_margin_symbol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_symbol (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3453, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_symbol") < 0)) __PYX_ERR(0, 3453, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_symbol", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3453, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_184get_margin_symbol(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_184get_margin_symbol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_symbol", 1);

  /* "unicorn_binance_rest_api/manager.py":3483
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/pair', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def create_isolated_margin_account(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3483, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__54, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3453
 *         return self._request_margin_api('get', 'margin/asset', data=params)
 * 
 *     def get_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin symbol info
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3485
 *         return self._request_margin_api('get', 'margin/pair', data=params)
 * 
 *     def create_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Create isolated margin account for symbol
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_187create_isolated_margin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_186create_isolated_margin_account, "Create isolated margin account for symbol\n\n        https://binance-docs.github.io/apidocs/spot/en/#create-isolated-margin-account-margin\n\n        :param base: Base asset of symbol\n        :type base: str\n        :param quote: Quote asset of symbol\n        :type quote: str\n\n        .. code:: python\n\n            pair_details = client.create_isolated_margin_account(base='USDT', quote='BTC')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"success\": true,\n                \"symbol\": \"BTCUSDT\"\n            }\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_187create_isolated_margin_account = {"create_isolated_margin_account", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_187create_isolated_margin_account, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_186create_isolated_margin_account};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_187create_isolated_margin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_isolated_margin_account (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3485, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_isolated_margin_account") < 0)) __PYX_ERR(0, 3485, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_isolated_margin_account", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3485, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_isolated_margin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_186create_isolated_margin_account(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_186create_isolated_margin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_isolated_margin_account", 1);

  /* "unicorn_binance_rest_api/manager.py":3512
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/isolated/create', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3512, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3512, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__55, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3485
 *         return self._request_margin_api('get', 'margin/pair', data=params)
 * 
 *     def create_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Create isolated margin account for symbol
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_isolated_margin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3515
 * 
 * 
 *     def get_isolated_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_189get_isolated_margin_symbol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_188get_isolated_margin_symbol, "Query isolated margin symbol info\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-isolated-margin-symbol-user_data\n\n        :param symbol: name of the symbol pair\n        :type symbol: str\n\n        .. code:: python\n\n            pair_details = client.get_isolated_margin_symbol(symbol='BTCUSDT')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n            \"symbol\":\"BTCUSDT\",\n            \"base\":\"BTC\",\n            \"quote\":\"USDT\",\n            \"isMarginTrade\":true,\n            \"isBuyAllowed\":true,\n            \"isSellAllowed\":true      \n            }\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_189get_isolated_margin_symbol = {"get_isolated_margin_symbol", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_189get_isolated_margin_symbol, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_188get_isolated_margin_symbol};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_189get_isolated_margin_symbol(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_isolated_margin_symbol (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3515, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_isolated_margin_symbol") < 0)) __PYX_ERR(0, 3515, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_isolated_margin_symbol", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3515, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_isolated_margin_symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_188get_isolated_margin_symbol(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_188get_isolated_margin_symbol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_isolated_margin_symbol", 1);

  /* "unicorn_binance_rest_api/manager.py":3544
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/isolated/pair', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_all_isolated_margin_symbols(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3544, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3544, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__56, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3515
 * 
 * 
 *     def get_isolated_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_isolated_margin_symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3546
 *         return self._request_margin_api('get', 'margin/isolated/pair', signed=True, data=params)
 * 
 *     def get_all_isolated_margin_symbols(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info for all pairs
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_191get_all_isolated_margin_symbols(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_190get_all_isolated_margin_symbols, "Query isolated margin symbol info for all pairs\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-all-isolated-margin-symbol-user_data\n\n        .. code:: python\n\n            pair_details = client.get_all_isolated_margin_symbols()\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"base\": \"BNB\",\n                    \"isBuyAllowed\": true,\n                    \"isMarginTrade\": true,\n                    \"isSellAllowed\": true,\n                    \"quote\": \"BTC\",\n                    \"symbol\": \"BNBBTC\"     \n                },\n                {\n                    \"base\": \"TRX\",\n                    \"isBuyAllowed\": true,\n                    \"isMarginTrade\": true,\n                    \"isSellAllowed\": true,\n                    \"quote\": \"BTC\",\n                    \"symbol\": \"TRXBTC\"    \n                }\n            ]\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_191get_all_isolated_margin_symbols = {"get_all_isolated_margin_symbols", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_191get_all_isolated_margin_symbols, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_190get_all_isolated_margin_symbols};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_191get_all_isolated_margin_symbols(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_isolated_margin_symbols (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3546, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_all_isolated_margin_symbols") < 0)) __PYX_ERR(0, 3546, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_isolated_margin_symbols", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3546, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_isolated_margin_symbols", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_190get_all_isolated_margin_symbols(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_190get_all_isolated_margin_symbols(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_all_isolated_margin_symbols", 1);

  /* "unicorn_binance_rest_api/manager.py":3582
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/isolated/allPairs', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def toggle_bnb_burn_spot_margin(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3582, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3582, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__57, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3546
 *         return self._request_margin_api('get', 'margin/isolated/pair', signed=True, data=params)
 * 
 *     def get_all_isolated_margin_symbols(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info for all pairs
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_isolated_margin_symbols", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3584
 *         return self._request_margin_api('get', 'margin/isolated/allPairs', signed=True, data=params)
 * 
 *     def toggle_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Toggle BNB Burn On Spot Trade And Margin Interest
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_193toggle_bnb_burn_spot_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_192toggle_bnb_burn_spot_margin, "Toggle BNB Burn On Spot Trade And Margin Interest\n\n        https://binance-docs.github.io/apidocs/spot/en/#toggle-bnb-burn-on-spot-trade-and-margin-interest-user_data\n\n        :param spotBNBBurn: Determines whether to use BNB to pay for trading fees on SPOT\n        :type spotBNBBurn: bool\n        :param interestBNBBurn: Determines whether to use BNB to pay for margin loan's interest\n        :type interestBNBBurn: bool\n\n        .. code:: python\n\n            response = client.toggle_bnb_burn_spot_margin()\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n               \"spotBNBBurn\":true,\n               \"interestBNBBurn\": false\n            }\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_193toggle_bnb_burn_spot_margin = {"toggle_bnb_burn_spot_margin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_193toggle_bnb_burn_spot_margin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_192toggle_bnb_burn_spot_margin};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_193toggle_bnb_burn_spot_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("toggle_bnb_burn_spot_margin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3584, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "toggle_bnb_burn_spot_margin") < 0)) __PYX_ERR(0, 3584, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("toggle_bnb_burn_spot_margin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3584, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.toggle_bnb_burn_spot_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_192toggle_bnb_burn_spot_margin(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_192toggle_bnb_burn_spot_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("toggle_bnb_burn_spot_margin", 1);

  /* "unicorn_binance_rest_api/manager.py":3611
 * 
 *         """
 *         return self._request_margin_api('post', 'bnbBurn', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_bnb_burn_spot_margin(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3611, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3611, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__58, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3584
 *         return self._request_margin_api('get', 'margin/isolated/allPairs', signed=True, data=params)
 * 
 *     def toggle_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Toggle BNB Burn On Spot Trade And Margin Interest
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.toggle_bnb_burn_spot_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3613
 *         return self._request_margin_api('post', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Get BNB Burn Status
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_195get_bnb_burn_spot_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_194get_bnb_burn_spot_margin, "Get BNB Burn Status\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-bnb-burn-status-user_data\n\n        .. code:: python\n\n            status = client.get_bnb_burn_spot_margin()\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n               \"spotBNBBurn\":true,\n               \"interestBNBBurn\": false\n            }\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_195get_bnb_burn_spot_margin = {"get_bnb_burn_spot_margin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_195get_bnb_burn_spot_margin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_194get_bnb_burn_spot_margin};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_195get_bnb_burn_spot_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_bnb_burn_spot_margin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3613, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_bnb_burn_spot_margin") < 0)) __PYX_ERR(0, 3613, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_bnb_burn_spot_margin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3613, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_bnb_burn_spot_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_194get_bnb_burn_spot_margin(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_194get_bnb_burn_spot_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_bnb_burn_spot_margin", 1);

  /* "unicorn_binance_rest_api/manager.py":3635
 * 
 *         """
 *         return self._request_margin_api('get', 'bnbBurn', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_price_index(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3635, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3635, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__59, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3613
 *         return self._request_margin_api('post', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Get BNB Burn Status
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_bnb_burn_spot_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3637
 *         return self._request_margin_api('get', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_margin_price_index(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin priceIndex
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_197get_margin_price_index(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_196get_margin_price_index, "Query margin priceIndex\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-priceindex-market_data\n\n        :param symbol: name of the symbol pair\n        :type symbol: str\n\n        .. code:: python\n\n            price_index_details = client.get_margin_price_index(symbol='BTCUSDT')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"calcTime\": 1562046418000,\n                \"price\": \"0.00333930\",\n                \"symbol\": \"BNBBTC\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_197get_margin_price_index = {"get_margin_price_index", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_197get_margin_price_index, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_196get_margin_price_index};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_197get_margin_price_index(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_price_index (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3637, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_price_index") < 0)) __PYX_ERR(0, 3637, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_price_index", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3637, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_price_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_196get_margin_price_index(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_196get_margin_price_index(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_price_index", 1);

  /* "unicorn_binance_rest_api/manager.py":3662
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/priceIndex', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_margin_to_spot(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3662, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__60, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3637
 *         return self._request_margin_api('get', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_margin_price_index(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin priceIndex
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_price_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3664
 *         return self._request_margin_api('get', 'margin/priceIndex', data=params)
 * 
 *     def transfer_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between cross-margin account and spot account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_199transfer_margin_to_spot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_198transfer_margin_to_spot, "Execute transfer between cross-margin account and spot account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#cross-margin-account-transfer-margin\n\n        :param asset: name of the asset\n        :type asset: str\n        :param amount: amount to transfer\n        :type amount: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            transfer = client.transfer_margin_to_spot(asset='BTC', amount='1.1')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"tranId\": 100000001\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_199transfer_margin_to_spot = {"transfer_margin_to_spot", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_199transfer_margin_to_spot, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_198transfer_margin_to_spot};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_199transfer_margin_to_spot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transfer_margin_to_spot (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3664, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "transfer_margin_to_spot") < 0)) __PYX_ERR(0, 3664, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transfer_margin_to_spot", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3664, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_margin_to_spot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_198transfer_margin_to_spot(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_198transfer_margin_to_spot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transfer_margin_to_spot", 1);

  /* "unicorn_binance_rest_api/manager.py":3692
 * 
 *         """
 *         params['type'] = 2             # <<<<<<<<<<<<<<
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)
 * 
 */
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_type, __pyx_int_2) < 0))) __PYX_ERR(0, 3692, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3693
 *         """
 *         params['type'] = 2
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_spot_to_margin(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3693, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3693, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__61, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3664
 *         return self._request_margin_api('get', 'margin/priceIndex', data=params)
 * 
 *     def transfer_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between cross-margin account and spot account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_margin_to_spot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3695
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and cross-margin account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_201transfer_spot_to_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_200transfer_spot_to_margin, "Execute transfer between spot account and cross-margin account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#cross-margin-account-transfer-margin\n\n        :param asset: name of the asset\n        :type asset: str\n        :param amount: amount to transfer\n        :type amount: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            transfer = client.transfer_spot_to_margin(asset='BTC', amount='1.1')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"tranId\": 100000001\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_201transfer_spot_to_margin = {"transfer_spot_to_margin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_201transfer_spot_to_margin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_200transfer_spot_to_margin};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_201transfer_spot_to_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transfer_spot_to_margin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3695, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "transfer_spot_to_margin") < 0)) __PYX_ERR(0, 3695, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transfer_spot_to_margin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3695, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_spot_to_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_200transfer_spot_to_margin(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_200transfer_spot_to_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transfer_spot_to_margin", 1);

  /* "unicorn_binance_rest_api/manager.py":3723
 * 
 *         """
 *         params['type'] = 1             # <<<<<<<<<<<<<<
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)
 * 
 */
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_type, __pyx_int_1) < 0))) __PYX_ERR(0, 3723, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3724
 *         """
 *         params['type'] = 1
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3724, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3724, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__61, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3695
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and cross-margin account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_spot_to_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3727
 * 
 * 
 *     def transfer_isolated_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between isolated margin account and spot account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_203transfer_isolated_margin_to_spot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_202transfer_isolated_margin_to_spot, "Execute transfer between isolated margin account and spot account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#isolated-margin-account-transfer-margin\n\n        :param asset: name of the asset\n        :type asset: str\n        :param symbol: pair symbol\n        :type symbol: str\n        :param amount: amount to transfer\n        :type amount: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            transfer = client.transfer_isolated_margin_to_spot(asset='BTC', \n                                                                symbol='ETHBTC', amount='1.1')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"tranId\": 100000001\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_203transfer_isolated_margin_to_spot = {"transfer_isolated_margin_to_spot", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_203transfer_isolated_margin_to_spot, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_202transfer_isolated_margin_to_spot};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_203transfer_isolated_margin_to_spot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transfer_isolated_margin_to_spot (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3727, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "transfer_isolated_margin_to_spot") < 0)) __PYX_ERR(0, 3727, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transfer_isolated_margin_to_spot", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3727, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_isolated_margin_to_spot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_202transfer_isolated_margin_to_spot(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_202transfer_isolated_margin_to_spot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transfer_isolated_margin_to_spot", 1);

  /* "unicorn_binance_rest_api/manager.py":3758
 * 
 *         """
 *         params['transFrom'] = "ISOLATED_MARGIN"             # <<<<<<<<<<<<<<
 *         params['transTo'] = "SPOT"
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 */
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_transFrom, __pyx_n_s_ISOLATED_MARGIN) < 0))) __PYX_ERR(0, 3758, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3759
 *         """
 *         params['transFrom'] = "ISOLATED_MARGIN"
 *         params['transTo'] = "SPOT"             # <<<<<<<<<<<<<<
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 */
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_transTo, __pyx_n_s_SPOT) < 0))) __PYX_ERR(0, 3759, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3760
 *         params['transFrom'] = "ISOLATED_MARGIN"
 *         params['transTo'] = "SPOT"
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_spot_to_isolated_margin(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3760, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3760, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__62, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3727
 * 
 * 
 *     def transfer_isolated_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between isolated margin account and spot account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_isolated_margin_to_spot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3762
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_isolated_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and isolated margin account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_205transfer_spot_to_isolated_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_204transfer_spot_to_isolated_margin, "Execute transfer between spot account and isolated margin account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#isolated-margin-account-transfer-margin\n\n        :param asset: name of the asset\n        :type asset: str\n        :param symbol: pair symbol\n        :type symbol: str\n        :param amount: amount to transfer\n        :type amount: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            transfer = client.transfer_spot_to_isolated_margin(asset='BTC', \n                                                                symbol='ETHBTC', amount='1.1')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"tranId\": 100000001\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_205transfer_spot_to_isolated_margin = {"transfer_spot_to_isolated_margin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_205transfer_spot_to_isolated_margin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_204transfer_spot_to_isolated_margin};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_205transfer_spot_to_isolated_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transfer_spot_to_isolated_margin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3762, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "transfer_spot_to_isolated_margin") < 0)) __PYX_ERR(0, 3762, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transfer_spot_to_isolated_margin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3762, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_spot_to_isolated_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_204transfer_spot_to_isolated_margin(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_204transfer_spot_to_isolated_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transfer_spot_to_isolated_margin", 1);

  /* "unicorn_binance_rest_api/manager.py":3793
 * 
 *         """
 *         params['transFrom'] = "SPOT"             # <<<<<<<<<<<<<<
 *         params['transTo'] = "ISOLATED_MARGIN"
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 */
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_transFrom, __pyx_n_s_SPOT) < 0))) __PYX_ERR(0, 3793, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3794
 *         """
 *         params['transFrom'] = "SPOT"
 *         params['transTo'] = "ISOLATED_MARGIN"             # <<<<<<<<<<<<<<
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 */
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_transTo, __pyx_n_s_ISOLATED_MARGIN) < 0))) __PYX_ERR(0, 3794, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3795
 *         params['transFrom'] = "SPOT"
 *         params['transTo'] = "ISOLATED_MARGIN"
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def create_margin_loan(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3795, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3795, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__62, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3762
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_isolated_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and isolated margin account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_spot_to_isolated_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3797
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def create_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Apply for a loan in cross-margin or isolated-margin account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_207create_margin_loan(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_206create_margin_loan, "Apply for a loan in cross-margin or isolated-margin account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-borrow-margin\n\n        :param asset: name of the asset\n        :type asset: str\n        :param amount: amount to transfer\n        :type amount: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param symbol: Isolated margin symbol (default blank for cross-margin)\n        :type symbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            transaction = client.margin_create_loan(asset='BTC', amount='1.1')\n\n            transaction = client.margin_create_loan(asset='BTC', amount='1.1', \n                                                    isIsolated='TRUE', symbol='ETHBTC')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"tranId\": 100000001\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_207create_margin_loan = {"create_margin_loan", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_207create_margin_loan, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_206create_margin_loan};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_207create_margin_loan(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_margin_loan (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3797, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_margin_loan") < 0)) __PYX_ERR(0, 3797, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_margin_loan", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3797, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_margin_loan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_206create_margin_loan(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_206create_margin_loan(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_margin_loan", 1);

  /* "unicorn_binance_rest_api/manager.py":3832
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/loan', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def repay_margin_loan(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3832, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3832, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__63, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3797
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def create_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Apply for a loan in cross-margin or isolated-margin account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_margin_loan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3834
 *         return self._request_margin_api('post', 'margin/loan', signed=True, data=params)
 * 
 *     def repay_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Repay loan in cross-margin or isolated-margin account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_209repay_margin_loan(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_208repay_margin_loan, "Repay loan in cross-margin or isolated-margin account.\n\n        If amount is more than the amount borrowed, the full loan will be repaid. \n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-repay-margin\n\n        :param asset: name of the asset\n        :type asset: str\n        :param amount: amount to transfer\n        :type amount: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param symbol: Isolated margin symbol (default blank for cross-margin)\n        :type symbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n\n        .. code:: python\n\n            transaction = client.margin_repay_loan(asset='BTC', amount='1.1')\n\n            transaction = client.margin_repay_loan(asset='BTC', amount='1.1', \n                                                    isIsolated='TRUE', symbol='ETHBTC')\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"tranId\": 100000001\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_209repay_margin_loan = {"repay_margin_loan", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_209repay_margin_loan, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_208repay_margin_loan};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_209repay_margin_loan(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("repay_margin_loan (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3834, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "repay_margin_loan") < 0)) __PYX_ERR(0, 3834, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("repay_margin_loan", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3834, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.repay_margin_loan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_208repay_margin_loan(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_208repay_margin_loan(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("repay_margin_loan", 1);

  /* "unicorn_binance_rest_api/manager.py":3871
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/repay', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3871, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3871, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__64, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3834
 *         return self._request_margin_api('post', 'margin/loan', signed=True, data=params)
 * 
 *     def repay_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Repay loan in cross-margin or isolated-margin account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.repay_margin_loan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3876
 *     # Margin OCO
 * 
 *     def create_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new OCO trade for margin account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_211create_margin_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_210create_margin_oco_order, "Post a new OCO trade for margin account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-new-oco-trade\n\n\n        :param symbol: required\n        :type symbol: str\n        :param isIsolated: for isolated margin or not, \"TRUE\", \"FALSE\"\357\274\214default \"FALSE\"\n        :type symbol: str\n        :param listClientOrderId: A unique id for the list order. Automatically generated if not sent.\n        :type listClientOrderId: str\n        :param side: required\n        :type side: str\n        :param quantity: required\n        :type quantity: decimal\n        :param limitClientOrderId: A unique id for the limit order. Automatically generated if not sent.\n        :type limitClientOrderId: str\n        :param price: required\n        :type price: str\n        :param limitIcebergQty: Used to make the LIMIT_MAKER leg an iceberg order.\n        :type limitIcebergQty: decimal\n        :param stopClientOrderId: A unique Id for the stop loss/stop loss limit leg. Automatically generated if not\n                                  sent.\n        :type stopClientOrderId: str\n        :param stopPrice: required\n        :type stopPrice: str\n        :param stopLimitPrice: If provided, stopLimitTimeInForce is required.\n        :type stopLimitPrice: str\n        :param stopIcebergQty: Used with STOP_LOSS_LIMIT leg to make an iceberg order.\n        :type stopIcebergQty: decimal\n        :param stopLimitTimeInForce: Valid values are GTC/FOK/IOC.\n        :type stopLimitTimeInForce: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; default: RESULT.\n        :type newOrderRespType: str\n        :param sideEffectType: NO_SIDE_EFFECT, MARGIN_BUY, AUTO_REPAY; default NO_SIDE_EFFECT.\n        :type sideEffectType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n         ""       \"orderListId\": 0,\n                \"contingencyType\": \"OCO\",\n                \"listStatusType\": \"EXEC_STARTED\",\n                \"listOrderStatus\": \"EXECUTING\",\n                \"listClientOrderId\": \"JYVpp3F0f5CAG15DhtrqLp\",\n                \"transactionTime\": 1563417480525,\n                \"symbol\": \"LTCBTC\",\n                \"marginBuyBorrowAmount\": \"5\",       // will not return if no margin trade happens\n                \"marginBuyBorrowAsset\": \"BTC\",    // will not return if no margin trade happens\n                \"isIsolated\": false,       // if isolated margin\n                \"orders\": [\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orderId\": 2,\n                        \"clientOrderId\": \"Kk7sqHb9J6mJWTMDVW7Vos\"\n                    },\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orderId\": 3,\n                        \"clientOrderId\": \"xTXKaGYd4bluPVp78IVRvl\"\n                    }\n                ],\n                \"orderReports\": [\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orderId\": 2,\n                        \"orderListId\": 0,\n                        \"clientOrderId\": \"Kk7sqHb9J6mJWTMDVW7Vos\",\n                        \"transactTime\": 1563417480525,\n                        \"price\": \"0.000000\",\n                        \"origQty\": \"0.624363\",\n                        \"executedQty\": \"0.000000\",\n                        \"cummulativeQuoteQty\": \"0.000000\",\n                        \"status\": \"NEW\",\n                        \"timeInForce\": \"GTC\",\n                        \"type\": \"STOP_LOSS\",\n                        \"side\": \"BUY\",\n                        \"stopPrice\": \"0.960664\"\n                    },\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orde""rId\": 3,\n                        \"orderListId\": 0,\n                        \"clientOrderId\": \"xTXKaGYd4bluPVp78IVRvl\",\n                        \"transactTime\": 1563417480525,\n                        \"price\": \"0.036435\",\n                        \"origQty\": \"0.624363\",\n                        \"executedQty\": \"0.000000\",\n                        \"cummulativeQuoteQty\": \"0.000000\",\n                        \"status\": \"NEW\",\n                        \"timeInForce\": \"GTC\",\n                        \"type\": \"LIMIT_MAKER\",\n                        \"side\": \"BUY\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n            BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n            BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_211create_margin_oco_order = {"create_margin_oco_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_211create_margin_oco_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_210create_margin_oco_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_211create_margin_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_margin_oco_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3876, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_margin_oco_order") < 0)) __PYX_ERR(0, 3876, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_margin_oco_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3876, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_margin_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_210create_margin_oco_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_210create_margin_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_margin_oco_order", 1);

  /* "unicorn_binance_rest_api/manager.py":3983
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/order/oco', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_margin_oco_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 3983, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 3983, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__65, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3876
 *     # Margin OCO
 * 
 *     def create_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new OCO trade for margin account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_margin_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":3985
 *         return self._request_margin_api('post', 'margin/order/oco', signed=True, data=params)
 * 
 *     def cancel_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an entire Order List for a margin account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_213cancel_margin_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_212cancel_margin_oco_order, "Cancel an entire Order List for a margin account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-cancel-oco-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param isIsolated: for isolated margin or not, \"TRUE\", \"FALSE\"\357\274\214default \"FALSE\"\n        :type symbol: str\n        :param orderListId: Either orderListId or listClientOrderId must be provided\n        :type orderListId: int\n        :param listClientOrderId: Either orderListId or listClientOrderId must be provided\n        :type listClientOrderId: str\n        :param newClientOrderId: Used to uniquely identify this cancel. Automatically generated by default.\n        :type newClientOrderId: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"orderListId\": 0,\n                \"contingencyType\": \"OCO\",\n                \"listStatusType\": \"ALL_DONE\",\n                \"listOrderStatus\": \"ALL_DONE\",\n                \"listClientOrderId\": \"C3wyj4WVEktd7u9aVBRXcN\",\n                \"transactionTime\": 1574040868128,\n                \"symbol\": \"LTCBTC\",\n                \"isIsolated\": false,       // if isolated margin\n                \"orders\": [\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orderId\": 2,\n                        \"clientOrderId\": \"pO9ufTiFGg3nw2fOdgeOXa\"\n                    },\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orderId\": 3,\n                        \"clientOrderId\": \"TXOvglzXuaubXAaENpaRCB\"\n                    }\n                ],\n                \"orderReports\": [\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"origClientOrderId\": \"pO9ufTiFGg3nw2fOdgeOXa\",\n      ""                  \"orderId\": 2,\n                        \"orderListId\": 0,\n                        \"clientOrderId\": \"unfWT8ig8i0uj6lPuYLez6\",\n                        \"price\": \"1.00000000\",\n                        \"origQty\": \"10.00000000\",\n                        \"executedQty\": \"0.00000000\",\n                        \"cummulativeQuoteQty\": \"0.00000000\",\n                        \"status\": \"CANCELED\",\n                        \"timeInForce\": \"GTC\",\n                        \"type\": \"STOP_LOSS_LIMIT\",\n                        \"side\": \"SELL\",\n                        \"stopPrice\": \"1.00000000\"\n                    },\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"origClientOrderId\": \"TXOvglzXuaubXAaENpaRCB\",\n                        \"orderId\": 3,\n                        \"orderListId\": 0,\n                        \"clientOrderId\": \"unfWT8ig8i0uj6lPuYLez6\",\n                        \"price\": \"3.00000000\",\n                        \"origQty\": \"10.00000000\",\n                        \"executedQty\": \"0.00000000\",\n                        \"cummulativeQuoteQty\": \"0.00000000\",\n                        \"status\": \"CANCELED\",\n                        \"timeInForce\": \"GTC\",\n                        \"type\": \"LIMIT_MAKER\",\n                        \"side\": \"SELL\"\n                    }\n                ]\n            }\n\n    ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_213cancel_margin_oco_order = {"cancel_margin_oco_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_213cancel_margin_oco_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_212cancel_margin_oco_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_213cancel_margin_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel_margin_oco_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3985, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "cancel_margin_oco_order") < 0)) __PYX_ERR(0, 3985, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cancel_margin_oco_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3985, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_margin_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_212cancel_margin_oco_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_212cancel_margin_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cancel_margin_oco_order", 1);

  /* "unicorn_binance_rest_api/manager.py":4064
 * 
 *     """
 *         return self._request_margin_api('delete', 'margin/orderList', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_oco_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4064, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4064, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__66, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":3985
 *         return self._request_margin_api('post', 'margin/order/oco', signed=True, data=params)
 * 
 *     def cancel_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an entire Order List for a margin account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_margin_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4066
 *         return self._request_margin_api('delete', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """ Retrieves a specific OCO based on provided optional parameters
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_215get_margin_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_214get_margin_oco_order, " Retrieves a specific OCO based on provided optional parameters\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-account-39-s-oco-user_data\n\n        :param isIsolated: for isolated margin or not, \"TRUE\", \"FALSE\"\357\274\214default \"FALSE\"\n        :type symbol: str\n        :param symbol: mandatory for isolated margin, not supported for cross margin\n        :type symbol: str\n        :param orderListId: Either orderListId or listClientOrderId must be provided\n        :type orderListId: int\n        :param listClientOrderId: Either orderListId or listClientOrderId must be provided\n        :type listClientOrderId: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"orderListId\": 27,\n                \"contingencyType\": \"OCO\",\n                \"listStatusType\": \"EXEC_STARTED\",\n                \"listOrderStatus\": \"EXECUTING\",\n                \"listClientOrderId\": \"h2USkA5YQpaXHPIrkd96xE\",\n                \"transactionTime\": 1565245656253,\n                \"symbol\": \"LTCBTC\",\n                \"isIsolated\": false,       // if isolated margin\n                \"orders\": [\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orderId\": 4,\n                        \"clientOrderId\": \"qD1gy3kc3Gx0rihm9Y3xwS\"\n                    },\n                    {\n                        \"symbol\": \"LTCBTC\",\n                        \"orderId\": 5,\n                        \"clientOrderId\": \"ARzZ9I00CPM8i3NhmU9Ega\"\n                    }\n                ]\n            }\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_215get_margin_oco_order = {"get_margin_oco_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_215get_margin_oco_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_214get_margin_oco_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_215get_margin_oco_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_oco_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4066, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_oco_order") < 0)) __PYX_ERR(0, 4066, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_oco_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4066, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_214get_margin_oco_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_214get_margin_oco_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_oco_order", 1);

  /* "unicorn_binance_rest_api/manager.py":4110
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/orderList', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_open_margin_oco_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4110, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__67, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4066
 *         return self._request_margin_api('delete', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """ Retrieves a specific OCO based on provided optional parameters
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_oco_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4112
 *         return self._request_margin_api('get', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_open_margin_oco_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Retrieves open OCO trades
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_217get_open_margin_oco_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_216get_open_margin_oco_orders, "Retrieves open OCO trades\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-account-39-s-open-oco-user_data\n\n        :param isIsolated: for isolated margin or not, \"TRUE\", \"FALSE\"\357\274\214default \"FALSE\"\n        :type symbol: str\n        :param symbol: mandatory for isolated margin, not supported for cross margin\n        :type symbol: str\n        :param fromId: If supplied, neither startTime nor endTime can be provided\n        :type fromId: int\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param limit: optional Default Value: 500; Max Value: 1000\n        :type limit: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"orderListId\": 29,\n                    \"contingencyType\": \"OCO\",\n                    \"listStatusType\": \"EXEC_STARTED\",\n                    \"listOrderStatus\": \"EXECUTING\",\n                    \"listClientOrderId\": \"amEEAXryFzFwYF1FeRpUoZ\",\n                    \"transactionTime\": 1565245913483,\n                    \"symbol\": \"LTCBTC\",\n                    \"isIsolated\": true,       // if isolated margin\n                    \"orders\": [\n                        {\n                            \"symbol\": \"LTCBTC\",\n                            \"orderId\": 4,\n                            \"clientOrderId\": \"oD7aesZqjEGlZrbtRpy5zB\"\n                        },\n                        {\n                            \"symbol\": \"LTCBTC\",\n                            \"orderId\": 5,\n                            \"clientOrderId\": \"Jr1h6xirOxgeJOUuYQS7V3\"\n                        }\n                    ]\n                },\n                {\n                    \"orderListId\": 28,\n                    \"conti""ngencyType\": \"OCO\",\n                    \"listStatusType\": \"EXEC_STARTED\",\n                    \"listOrderStatus\": \"EXECUTING\",\n                    \"listClientOrderId\": \"hG7hFNxJV6cZy3Ze4AUT4d\",\n                    \"transactionTime\": 1565245913407,\n                    \"symbol\": \"LTCBTC\",\n                    \"orders\": [\n                        {\n                            \"symbol\": \"LTCBTC\",\n                            \"orderId\": 2,\n                            \"clientOrderId\": \"j6lFOfbmFMRjTYA7rRJ0LP\"\n                        },\n                        {\n                            \"symbol\": \"LTCBTC\",\n                            \"orderId\": 3,\n                            \"clientOrderId\": \"z0KCjOdditiLS5ekAFtK81\"\n                        }\n                    ]\n                }\n            ]\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_217get_open_margin_oco_orders = {"get_open_margin_oco_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_217get_open_margin_oco_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_216get_open_margin_oco_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_217get_open_margin_oco_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_open_margin_oco_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4112, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_open_margin_oco_orders") < 0)) __PYX_ERR(0, 4112, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_open_margin_oco_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4112, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_margin_oco_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_216get_open_margin_oco_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_216get_open_margin_oco_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_open_margin_oco_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":4183
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/allOrderList', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def create_margin_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4183, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4183, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__68, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4112
 *         return self._request_margin_api('get', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_open_margin_oco_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Retrieves open OCO trades
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_margin_oco_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4185
 *         return self._request_margin_api('get', 'margin/allOrderList', signed=True, data=params)
 * 
 *     def create_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new order for margin account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_219create_margin_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_218create_margin_order, "Post a new order for margin account.\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-new-order-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param side: required\n        :type side: str\n        :param type: required\n        :type type: str\n        :param quantity: required\n        :type quantity: decimal\n        :param price: required\n        :type price: str\n        :param stopPrice: Used with STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT, and TAKE_PROFIT_LIMIT orders.\n        :type stopPrice: str\n        :param timeInForce: required if limit order GTC,IOC,FOK\n        :type timeInForce: str\n        :param newClientOrderId: A unique id for the order. Automatically generated if not sent.\n        :type newClientOrderId: str\n        :param icebergQty: Used with LIMIT, STOP_LOSS_LIMIT, and TAKE_PROFIT_LIMIT to create an iceberg order.\n        :type icebergQty: str\n        :param newOrderRespType: Set the response JSON. ACK, RESULT, or FULL; MARKET and LIMIT order types default to\n            FULL, all other orders default to ACK.\n        :type newOrderRespType: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        Response ACK:\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"BTCUSDT\",\n                \"orderId\": 28,\n                \"clientOrderId\": \"6gCrw2kRUAF9CvJDGP16IP\",\n                \"transactTime\": 1507725176595\n            }\n\n        Response RESULT:\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"BTCUSDT\",\n                \"orderId\": 28,\n                \"clientOrderId\": \"6gCrw2kRUAF9CvJDGP16IP\",\n                \"transactTime\": 1507725176595,\n                \"price\": \"1.00000000\",""\n                \"origQty\": \"10.00000000\",\n                \"executedQty\": \"10.00000000\",\n                \"cummulativeQuoteQty\": \"10.00000000\",\n                \"status\": \"FILLED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"MARKET\",\n                \"side\": \"SELL\"\n            }\n\n        Response FULL:\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"BTCUSDT\",\n                \"orderId\": 28,\n                \"clientOrderId\": \"6gCrw2kRUAF9CvJDGP16IP\",\n                \"transactTime\": 1507725176595,\n                \"price\": \"1.00000000\",\n                \"origQty\": \"10.00000000\",\n                \"executedQty\": \"10.00000000\",\n                \"cummulativeQuoteQty\": \"10.00000000\",\n                \"status\": \"FILLED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"MARKET\",\n                \"side\": \"SELL\",\n                \"fills\": [\n                    {\n                        \"price\": \"4000.00000000\",\n                        \"qty\": \"1.00000000\",\n                        \"commission\": \"4.00000000\",\n                        \"commissionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3999.00000000\",\n                        \"qty\": \"5.00000000\",\n                        \"commission\": \"19.99500000\",\n                        \"commissionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3998.00000000\",\n                        \"qty\": \"2.00000000\",\n                        \"commission\": \"7.99600000\",\n                        \"commissionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3997.00000000\",\n                        \"qty\": \"1.00000000\",\n                        \"commission\": \"3.99700000\",\n                        \"commi""ssionAsset\": \"USDT\"\n                    },\n                    {\n                        \"price\": \"3995.00000000\",\n                        \"qty\": \"1.00000000\",\n                        \"commission\": \"3.99500000\",\n                        \"commissionAsset\": \"USDT\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException, BinanceOrderException, BinanceOrderMinAmountException,\n            BinanceOrderMinPriceException, BinanceOrderMinTotalException, BinanceOrderUnknownSymbolException,\n            BinanceOrderInactiveSymbolException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_219create_margin_order = {"create_margin_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_219create_margin_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_218create_margin_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_219create_margin_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_margin_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4185, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_margin_order") < 0)) __PYX_ERR(0, 4185, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_margin_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4185, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_margin_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_218create_margin_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_218create_margin_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_margin_order", 1);

  /* "unicorn_binance_rest_api/manager.py":4304
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/order', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_margin_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4304, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4304, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__69, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4185
 *         return self._request_margin_api('get', 'margin/allOrderList', signed=True, data=params)
 * 
 *     def create_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new order for margin account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_margin_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4306
 *         return self._request_margin_api('post', 'margin/order', signed=True, data=params)
 * 
 *     def cancel_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active order for margin account.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_221cancel_margin_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_220cancel_margin_order, "\n        Cancel an active order for margin account.\n\n        Either orderId or origClientOrderId must be sent.\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-account-cancel-order-trade\n\n        :param symbol: required\n        :type symbol: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param orderId:\n        :type orderId: str\n        :param origClientOrderId:\n        :type origClientOrderId: str\n        :param newClientOrderId: Used to uniquely identify this cancel. Automatically generated by default.\n        :type newClientOrderId: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"LTCBTC\",\n                \"orderId\": 28,\n                \"origClientOrderId\": \"myOrder1\",\n                \"clientOrderId\": \"cancelMyOrder1\",\n                \"transactTime\": 1507725176595,\n                \"price\": \"1.00000000\",\n                \"origQty\": \"10.00000000\",\n                \"executedQty\": \"8.00000000\",\n                \"cummulativeQuoteQty\": \"8.00000000\",\n                \"status\": \"CANCELED\",\n                \"timeInForce\": \"GTC\",\n                \"type\": \"LIMIT\",\n                \"side\": \"SELL\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_221cancel_margin_order = {"cancel_margin_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_221cancel_margin_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_220cancel_margin_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_221cancel_margin_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel_margin_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4306, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "cancel_margin_order") < 0)) __PYX_ERR(0, 4306, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cancel_margin_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4306, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_margin_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_220cancel_margin_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_220cancel_margin_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cancel_margin_order", 1);

  /* "unicorn_binance_rest_api/manager.py":4351
 *         """
 * 
 *         return self._request_margin_api('delete', 'margin/order', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_loan_details(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4351, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4351, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__70, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4306
 *         return self._request_margin_api('post', 'margin/order', signed=True, data=params)
 * 
 *     def cancel_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active order for margin account.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.cancel_margin_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4353
 *         return self._request_margin_api('delete', 'margin/order', signed=True, data=params)
 * 
 *     def get_margin_loan_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query loan record
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_223get_margin_loan_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_222get_margin_loan_details, "\n        Query loan record\n\n        txId or startTime must be sent. txId takes precedence.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-loan-record-user_data\n\n        :param asset: required\n        :type asset: str\n        :param isolatedSymbol: isolated symbol (if querying isolated margin)\n        :type isolatedSymbol: str\n        :param txId: the tranId in of the created loan\n        :type txId: str\n        :param startTime: the earliest timestamp to filter transactions\n        :type startTime: str\n        :param endTime: Used to uniquely identify this cancel. Automatically generated by default.\n        :type endTime: str\n        :param current: Currently querying page. Start from 1. Default:1\n        :type current: str\n        :param size: Default:10 Max:100\n        :type size: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            {\n                \"rows\": [\n                    {\n                        \"asset\": \"BNB\",\n                        \"principal\": \"0.84624403\",\n                        \"timestamp\": 1555056425000,\n                        //one of PENDING (pending to execution), CONFIRMED (successfully loaned), FAILED (execution failed, nothing happened to your account);\n                        \"status\": \"CONFIRMED\"\n                    }\n                ],\n                \"total\": 1\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_223get_margin_loan_details = {"get_margin_loan_details", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_223get_margin_loan_details, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_222get_margin_loan_details};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_223get_margin_loan_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_loan_details (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4353, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_loan_details") < 0)) __PYX_ERR(0, 4353, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_loan_details", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4353, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_loan_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_222get_margin_loan_details(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_222get_margin_loan_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_loan_details", 1);

  /* "unicorn_binance_rest_api/manager.py":4398
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/loan', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_repay_details(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4398, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4398, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__71, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4353
 *         return self._request_margin_api('delete', 'margin/order', signed=True, data=params)
 * 
 *     def get_margin_loan_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query loan record
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_loan_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4400
 *         return self._request_margin_api('get', 'margin/loan', signed=True, data=params)
 * 
 *     def get_margin_repay_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query repay record
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_225get_margin_repay_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_224get_margin_repay_details, "\n        Query repay record\n\n        txId or startTime must be sent. txId takes precedence.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-repay-record-user_data\n\n        :param asset: required\n        :type asset: str\n        :param isolatedSymbol: isolated symbol (if querying isolated margin)\n        :type isolatedSymbol: str\n        :param txId: the tranId in of the created loan\n        :type txId: str\n        :param startTime:\n        :type startTime: str\n        :param endTime: Used to uniquely identify this cancel. Automatically generated by default.\n        :type endTime: str\n        :param current: Currently querying page. Start from 1. Default:1\n        :type current: str\n        :param size: Default:10 Max:100\n        :type size: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            {\n                \"rows\": [\n                    {\n                        //Total amount repaid\n                        \"amount\": \"14.00000000\",\n                        \"asset\": \"BNB\",\n                        //Interest repaid\n                        \"interest\": \"0.01866667\",\n                        //Principal repaid\n                        \"principal\": \"13.98133333\",\n                        //one of PENDING (pending to execution), CONFIRMED (successfully loaned), FAILED (execution failed, nothing happened to your account);\n                        \"status\": \"CONFIRMED\",\n                        \"timestamp\": 1563438204000,\n                        \"txId\": 2970933056\n                    }\n                ],\n                \"total\": 1\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_225get_margin_repay_details = {"get_margin_repay_details", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_225get_margin_repay_details, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_224get_margin_repay_details};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_225get_margin_repay_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_repay_details (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4400, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_repay_details") < 0)) __PYX_ERR(0, 4400, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_repay_details", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4400, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_repay_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_224get_margin_repay_details(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_224get_margin_repay_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_repay_details", 1);

  /* "unicorn_binance_rest_api/manager.py":4451
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/repay', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4451, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4451, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__72, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4400
 *         return self._request_margin_api('get', 'margin/loan', signed=True, data=params)
 * 
 *     def get_margin_repay_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query repay record
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_repay_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4453
 *         return self._request_margin_api('get', 'margin/repay', signed=True, data=params)
 * 
 *     def get_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts order
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_227get_margin_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_226get_margin_order, "Query margin accounts order\n\n        Either orderId or origClientOrderId must be sent.\n\n        For some historical orders cummulativeQuoteQty will be < 0, meaning the data is not available at this time.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-account-39-s-order-user_data\n\n        :param symbol: required\n        :type symbol: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param orderId:\n        :type orderId: str\n        :param origClientOrderId:\n        :type origClientOrderId: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            {\n                \"clientOrderId\": \"ZwfQzuDIGpceVhKW5DvCmO\",\n                \"cummulativeQuoteQty\": \"0.00000000\",\n                \"executedQty\": \"0.00000000\",\n                \"icebergQty\": \"0.00000000\",\n                \"isWorking\": true,\n                \"orderId\": 213205622,\n                \"origQty\": \"0.30000000\",\n                \"price\": \"0.00493630\",\n                \"side\": \"SELL\",\n                \"status\": \"NEW\",\n                \"stopPrice\": \"0.00000000\",\n                \"symbol\": \"BNBBTC\",\n                \"time\": 1562133008725,\n                \"timeInForce\": \"GTC\",\n                \"type\": \"LIMIT\",\n                \"updateTime\": 1562133008725\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_227get_margin_order = {"get_margin_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_227get_margin_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_226get_margin_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_227get_margin_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4453, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_order") < 0)) __PYX_ERR(0, 4453, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4453, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_226get_margin_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_226get_margin_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_order", 1);

  /* "unicorn_binance_rest_api/manager.py":4499
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/order', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_open_margin_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4499, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4499, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__73, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4453
 *         return self._request_margin_api('get', 'margin/repay', signed=True, data=params)
 * 
 *     def get_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts order
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4501
 *         return self._request_margin_api('get', 'margin/order', signed=True, data=params)
 * 
 *     def get_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts open orders
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_229get_open_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_228get_open_margin_orders, "Query margin accounts open orders\n\n        If the symbol is not sent, orders for all symbols will be returned in an array (cross-margin only).\n\n        If querying isolated margin orders, both the isIsolated='TRUE' and symbol=symbol_name must be set.\n\n        When all symbols are returned, the number of requests counted against the rate limiter is equal to the number\n        of symbols currently trading on the exchange.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-account-39-s-open-order-user_data\n\n        :param symbol: optional\n        :type symbol: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"clientOrderId\": \"qhcZw71gAkCCTv0t0k8LUK\",\n                    \"cummulativeQuoteQty\": \"0.00000000\",\n                    \"executedQty\": \"0.00000000\",\n                    \"icebergQty\": \"0.00000000\",\n                    \"isWorking\": true,\n                    \"orderId\": 211842552,\n                    \"origQty\": \"0.30000000\",\n                    \"price\": \"0.00475010\",\n                    \"side\": \"SELL\",\n                    \"status\": \"NEW\",\n                    \"stopPrice\": \"0.00000000\",\n                    \"symbol\": \"BNBBTC\",\n                    \"time\": 1562040170089,\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"LIMIT\",\n                    \"updateTime\": 1562040170089\n                } ]\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_229get_open_margin_orders = {"get_open_margin_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_229get_open_margin_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_228get_open_margin_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_229get_open_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_open_margin_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4501, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_open_margin_orders") < 0)) __PYX_ERR(0, 4501, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_open_margin_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4501, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_228get_open_margin_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_228get_open_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_open_margin_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":4549
 *         """
 * 
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_open_isolated_margin_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4549, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4549, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__74, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4501
 *         return self._request_margin_api('get', 'margin/order', signed=True, data=params)
 * 
 *     def get_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts open orders
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4551
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_open_isolated_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin accounts open orders
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_231get_open_isolated_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_230get_open_isolated_margin_orders, "Query isolated margin accounts open orders\n\n        If the symbol is not sent, orders for all symbols will be returned in an array (cross-margin only).\n\n        If querying isolated margin orders, both the isIsolated='TRUE' and symbol=symbol_name must be set.\n\n        When all symbols are returned, the number of requests counted against the rate limiter is equal to the number\n        of symbols currently trading on the exchange.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-account-39-s-open-order-user_data\n\n        :param symbol: optional\n        :type symbol: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n        :return: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"clientOrderId\": \"qhcZw71gAkCCTv0t0k8LUK\",\n                    \"cummulativeQuoteQty\": \"0.00000000\",\n                    \"executedQty\": \"0.00000000\",\n                    \"icebergQty\": \"0.00000000\",\n                    \"isWorking\": true,\n                    \"orderId\": 211842552,\n                    \"origQty\": \"0.30000000\",\n                    \"price\": \"0.00475010\",\n                    \"side\": \"SELL\",\n                    \"status\": \"NEW\",\n                    \"stopPrice\": \"0.00000000\",\n                    \"symbol\": \"BNBBTC\",\n                    \"time\": 1562040170089,\n                    \"timeInForce\": \"GTC\",\n                    \"type\": \"LIMIT\",\n                    \"updateTime\": 1562040170089\n                } ]\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_231get_open_isolated_margin_orders = {"get_open_isolated_margin_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_231get_open_isolated_margin_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_230get_open_isolated_margin_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_231get_open_isolated_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_open_isolated_margin_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4551, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_open_isolated_margin_orders") < 0)) __PYX_ERR(0, 4551, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_open_isolated_margin_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4551, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_isolated_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_230get_open_isolated_margin_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_230get_open_isolated_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_open_isolated_margin_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":4599
 * 
 *         # Todo: Add isIsolated parameter
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_all_margin_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4599, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4599, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__74, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4551
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_open_isolated_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin accounts open orders
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_open_isolated_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4601
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_all_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query all margin accounts orders
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_233get_all_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_232get_all_margin_orders, "Query all margin accounts orders\n\n        If orderId is set, it will get orders >= that orderId. Otherwise most recent orders are returned.\n\n        For some historical orders cummulativeQuoteQty will be < 0, meaning the data is not available at this time.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-account-39-s-all-order-user_data\n\n        :param symbol: required\n        :type symbol: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param orderId: optional\n        :type orderId: str\n        :param startTime: optional\n        :type startTime: str\n        :param endTime: optional\n        :type endTime: str\n        :param limit: Default 500; max 1000\n        :type limit: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"id\": 43123876,\n                    \"price\": \"0.00395740\",\n                    \"qty\": \"4.06000000\",\n                    \"quoteQty\": \"0.01606704\",\n                    \"symbol\": \"BNBBTC\",\n                    \"time\": 1556089977693\n                },\n                {\n                    \"id\": 43123877,\n                    \"price\": \"0.00395740\",\n                    \"qty\": \"0.77000000\",\n                    \"quoteQty\": \"0.00304719\",\n                    \"symbol\": \"BNBBTC\",\n                    \"time\": 1556089977693\n                },\n                {\n                    \"id\": 43253549,\n                    \"price\": \"0.00428930\",\n                    \"qty\": \"23.30000000\",\n                    \"quoteQty\": \"0.09994069\",\n                    \"symbol\": \"BNBBTC\",\n                    \"time\": 1556163963504\n                }\n            ]\n\n\n        :raises: BinanceRequestException, Bina""nceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_233get_all_margin_orders = {"get_all_margin_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_233get_all_margin_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_232get_all_margin_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_233get_all_margin_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_margin_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4601, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_all_margin_orders") < 0)) __PYX_ERR(0, 4601, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_margin_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4601, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_232get_all_margin_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_232get_all_margin_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_all_margin_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":4660
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/allOrders', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4660, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4660, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__75, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4601
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_all_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query all margin accounts orders
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_margin_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4662
 *         return self._request_margin_api('get', 'margin/allOrders', signed=True, data=params)
 * 
 *     def get_margin_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts trades
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_235get_margin_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_234get_margin_trades, "Query margin accounts trades\n\n        If fromId is set, it will get orders >= that fromId. Otherwise most recent orders are returned.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-margin-account-39-s-trade-list-user_data\n\n        :param symbol: required\n        :type symbol: str\n        :param isIsolated: set to 'TRUE' for isolated margin (default 'FALSE')\n        :type isIsolated: str\n        :param fromId: optional\n        :type fromId: str\n        :param startTime: optional\n        :type startTime: str\n        :param endTime: optional\n        :type endTime: str\n        :param limit: Default 500; max 1000\n        :type limit: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"commission\": \"0.00006000\",\n                    \"commissionAsset\": \"BTC\",\n                    \"id\": 34,\n                    \"isBestMatch\": true,\n                    \"isBuyer\": false,\n                    \"isMaker\": false,\n                    \"orderId\": 39324,\n                    \"price\": \"0.02000000\",\n                    \"qty\": \"3.00000000\",\n                    \"symbol\": \"BNBBTC\",\n                    \"time\": 1561973357171\n                }, {\n                    \"commission\": \"0.00002950\",\n                    \"commissionAsset\": \"BTC\",\n                    \"id\": 32,\n                    \"isBestMatch\": true,\n                    \"isBuyer\": false,\n                    \"isMaker\": true,\n                    \"orderId\": 39319,\n                    \"price\": \"0.00590000\",\n                    \"qty\": \"5.00000000\",\n                    \"symbol\": \"BNBBTC\",\n                    \"time\": 1561964645345\n                }\n            ]\n\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_235get_margin_trades = {"get_margin_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_235get_margin_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_234get_margin_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_235get_margin_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_margin_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4662, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_margin_trades") < 0)) __PYX_ERR(0, 4662, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_margin_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4662, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_234get_margin_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_234get_margin_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_margin_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":4720
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/myTrades', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_max_margin_loan(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4720, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4720, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__76, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4662
 *         return self._request_margin_api('get', 'margin/allOrders', signed=True, data=params)
 * 
 *     def get_margin_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts trades
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_margin_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4722
 *         return self._request_margin_api('get', 'margin/myTrades', signed=True, data=params)
 * 
 *     def get_max_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Query max borrow amount for an asset
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_237get_max_margin_loan(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_236get_max_margin_loan, "Query max borrow amount for an asset\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-max-borrow-user_data\n\n        :param asset: required\n        :type asset: str\n        :param isolatedSymbol: isolated symbol (if querying isolated margin)\n        :type isolatedSymbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"amount\": \"1.69248805\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_237get_max_margin_loan = {"get_max_margin_loan", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_237get_max_margin_loan, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_236get_max_margin_loan};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_237get_max_margin_loan(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_max_margin_loan (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4722, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_max_margin_loan") < 0)) __PYX_ERR(0, 4722, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_max_margin_loan", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4722, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_max_margin_loan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_236get_max_margin_loan(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_236get_max_margin_loan(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_max_margin_loan", 1);

  /* "unicorn_binance_rest_api/manager.py":4745
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/maxBorrowable', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_max_margin_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4745, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4745, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__77, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4722
 *         return self._request_margin_api('get', 'margin/myTrades', signed=True, data=params)
 * 
 *     def get_max_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Query max borrow amount for an asset
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_max_margin_loan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4747
 *         return self._request_margin_api('get', 'margin/maxBorrowable', signed=True, data=params)
 * 
 *     def get_max_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         r"""
 *         Query max transfer-out amount
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_239get_max_margin_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_238get_max_margin_transfer, "\n        Query max transfer-out amount\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-max-transfer-out-amount-user_data\n\n        :param asset: required\n        :type asset: str\n        :param isolatedSymbol: isolated symbol (if querying isolated margin)\n        :type isolatedSymbol: str\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            {\n                \"amount\": \"3.59498107\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_239get_max_margin_transfer = {"get_max_margin_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_239get_max_margin_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_238get_max_margin_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_239get_max_margin_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_max_margin_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4747, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_max_margin_transfer") < 0)) __PYX_ERR(0, 4747, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_max_margin_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4747, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_max_margin_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_238get_max_margin_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_238get_max_margin_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_max_margin_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":4771
 *         """
 * 
 *         return self._request_margin_api('get', 'margin/maxTransferable', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     # Cross-margin
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4771, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4771, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__78, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4747
 *         return self._request_margin_api('get', 'margin/maxBorrowable', signed=True, data=params)
 * 
 *     def get_max_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         r"""
 *         Query max transfer-out amount
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_max_margin_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4775
 *     # Cross-margin
 * 
 *     def margin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new cross-margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_241margin_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_240margin_stream_get_listen_key, "Start a new cross-margin data stream and return the listen key\n        If a stream already exists it should return the same key.\n        If the stream becomes invalid a new key is returned.\n\n        Can be used to keep the stream alive.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param output: Set `output` to \"raw_data\" to receive the request resource, default is \"value\" which returns\n                        the plain listenKey.\n        :type output: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"listenKey\": \"pqia91ma19a5s61cv6a81va65sdf19v8a65a1a5s61cv6a81va65sdf19v8a65a1\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_241margin_stream_get_listen_key = {"margin_stream_get_listen_key", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_241margin_stream_get_listen_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_240margin_stream_get_listen_key};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_241margin_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_output = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("margin_stream_get_listen_key (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_output,&__pyx_n_s_throw_exception,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_value)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4775, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_output);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4775, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4775, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "margin_stream_get_listen_key") < 0)) __PYX_ERR(0, 4775, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_output = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("margin_stream_get_listen_key", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 4775, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.margin_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_240margin_stream_get_listen_key(__pyx_self, __pyx_v_self, __pyx_v_output, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_240margin_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("margin_stream_get_listen_key", 1);

  /* "unicorn_binance_rest_api/manager.py":4800
 * 
 *         """
 *         res = self._request_margin_api('post', 'userDataStream', signed=False, data={}, throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 *         if output == "value":
 *             return res['listenKey']
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 4800, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_t_3) < 0) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 4800, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__79, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":4801
 *         """
 *         res = self._request_margin_api('post', 'userDataStream', signed=False, data={}, throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_value, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4801, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":4802
 *         res = self._request_margin_api('post', 'userDataStream', signed=False, data={}, throw_exception=throw_exception)
 *         if output == "value":
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 *         elif output == "raw_data":
 *             return res
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4802, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":4801
 *         """
 *         res = self._request_margin_api('post', 'userDataStream', signed=False, data={}, throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  }

  /* "unicorn_binance_rest_api/manager.py":4803
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_raw_data, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4803, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":4804
 *             return res['listenKey']
 *         elif output == "raw_data":
 *             return res             # <<<<<<<<<<<<<<
 *         else:
 *             return res['listenKey']
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_res);
    __pyx_r = __pyx_v_res;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":4803
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  }

  /* "unicorn_binance_rest_api/manager.py":4806
 *             return res
 *         else:
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 * 
 *     def margin_stream_keepalive(self, listenKey, throw_exception=True):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":4775
 *     # Cross-margin
 * 
 *     def margin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new cross-margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.margin_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4808
 *             return res['listenKey']
 * 
 *     def margin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a cross-margin data stream to prevent a time out.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_243margin_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_242margin_stream_keepalive, "PING a cross-margin data stream to prevent a time out.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_243margin_stream_keepalive = {"margin_stream_keepalive", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_243margin_stream_keepalive, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_242margin_stream_keepalive};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_243margin_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("margin_stream_keepalive (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4808, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4808, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("margin_stream_keepalive", 0, 2, 3, 1); __PYX_ERR(0, 4808, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4808, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "margin_stream_keepalive") < 0)) __PYX_ERR(0, 4808, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("margin_stream_keepalive", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4808, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.margin_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_242margin_stream_keepalive(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_242margin_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("margin_stream_keepalive", 1);

  /* "unicorn_binance_rest_api/manager.py":4828
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_margin_api('put', 'userDataStream', signed=False, data=params,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 4828, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":4830
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('put', 'userDataStream', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 4830, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4830, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4831
 *         }
 *         return self._request_margin_api('put', 'userDataStream', signed=False, data=params,
 *                                         throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     def margin_stream_close(self, listenKey, throw_exception=True):
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 4830, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4830
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('put', 'userDataStream', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__80, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4808
 *             return res['listenKey']
 * 
 *     def margin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a cross-margin data stream to prevent a time out.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.margin_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4833
 *                                         throw_exception=throw_exception)
 * 
 *     def margin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a cross-margin data stream.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_245margin_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_244margin_stream_close, "Close out a cross-margin data stream.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_245margin_stream_close = {"margin_stream_close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_245margin_stream_close, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_244margin_stream_close};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_245margin_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("margin_stream_close (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4833, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4833, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("margin_stream_close", 0, 2, 3, 1); __PYX_ERR(0, 4833, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4833, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "margin_stream_close") < 0)) __PYX_ERR(0, 4833, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("margin_stream_close", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4833, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.margin_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_244margin_stream_close(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_244margin_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("margin_stream_close", 1);

  /* "unicorn_binance_rest_api/manager.py":4853
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_margin_api('delete', 'userDataStream', signed=False, data=params,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 4853, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":4855
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('delete', 'userDataStream', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 4855, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4855, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4856
 *         }
 *         return self._request_margin_api('delete', 'userDataStream', signed=False, data=params,
 *                                         throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     # Isolated margin
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 4855, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4855
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('delete', 'userDataStream', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__81, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4833
 *                                         throw_exception=throw_exception)
 * 
 *     def margin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a cross-margin data stream.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.margin_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4860
 *     # Isolated margin
 * 
 *     def isolated_margin_stream_get_listen_key(self, symbol, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new isolated margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_247isolated_margin_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_246isolated_margin_stream_get_listen_key, "Start a new isolated margin data stream and return the listen key\n        If a stream already exists it should return the same key.\n        If the stream becomes invalid a new key is returned.\n\n        Can be used to keep the stream alive.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-isolated-margin\n\n        :param symbol: required - symbol for the isolated margin account\n        :type symbol: str\n\n        :param output: Set `output` to \"raw_data\" to receive the request resource, default is \"value\" which returns\n                        the plain listenKey.\n        :type output: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"listenKey\":  \"T3ee22BIYuWqmvne0HNq2A2WsFlEtLhvWCtItw6ffhhdmjifQ2tRbuKkTHhr\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_247isolated_margin_stream_get_listen_key = {"isolated_margin_stream_get_listen_key", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_247isolated_margin_stream_get_listen_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_246isolated_margin_stream_get_listen_key};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_247isolated_margin_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_output = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isolated_margin_stream_get_listen_key (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,&__pyx_n_s_output,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_value)));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4860, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4860, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_get_listen_key", 0, 2, 4, 1); __PYX_ERR(0, 4860, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_output);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4860, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4860, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "isolated_margin_stream_get_listen_key") < 0)) __PYX_ERR(0, 4860, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
    __pyx_v_output = values[2];
    __pyx_v_throw_exception = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_get_listen_key", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 4860, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.isolated_margin_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_246isolated_margin_stream_get_listen_key(__pyx_self, __pyx_v_self, __pyx_v_symbol, __pyx_v_output, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_246isolated_margin_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isolated_margin_stream_get_listen_key", 1);

  /* "unicorn_binance_rest_api/manager.py":4889
 *         """
 *         params = {
 *             'symbol': symbol             # <<<<<<<<<<<<<<
 *         }
 *         res = self._request_margin_api('post', 'userDataStream/isolated', signed=False, data=params,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_symbol, __pyx_v_symbol) < 0) __PYX_ERR(0, 4889, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":4891
 *             'symbol': symbol
 *         }
 *         res = self._request_margin_api('post', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                        throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 4891, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4891, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4892
 *         }
 *         res = self._request_margin_api('post', 'userDataStream/isolated', signed=False, data=params,
 *                                        throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 *         if output == "value":
 *             return res['listenKey']
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 4891, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4891
 *             'symbol': symbol
 *         }
 *         res = self._request_margin_api('post', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                        throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__82, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":4893
 *         res = self._request_margin_api('post', 'userDataStream/isolated', signed=False, data=params,
 *                                        throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_value, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4893, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":4894
 *                                        throw_exception=throw_exception)
 *         if output == "value":
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 *         elif output == "raw_data":
 *             return res
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":4893
 *         res = self._request_margin_api('post', 'userDataStream/isolated', signed=False, data=params,
 *                                        throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  }

  /* "unicorn_binance_rest_api/manager.py":4895
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_raw_data, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4895, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":4896
 *             return res['listenKey']
 *         elif output == "raw_data":
 *             return res             # <<<<<<<<<<<<<<
 *         else:
 *             return res['listenKey']
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_res);
    __pyx_r = __pyx_v_res;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":4895
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  }

  /* "unicorn_binance_rest_api/manager.py":4898
 *             return res
 *         else:
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 * 
 *     def isolated_margin_stream_keepalive(self, symbol, listenKey, throw_exception=True):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":4860
 *     # Isolated margin
 * 
 *     def isolated_margin_stream_get_listen_key(self, symbol, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new isolated margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.isolated_margin_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4900
 *             return res['listenKey']
 * 
 *     def isolated_margin_stream_keepalive(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING an isolated margin data stream to prevent a time out.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_249isolated_margin_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_248isolated_margin_stream_keepalive, "PING an isolated margin data stream to prevent a time out.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-isolated-margin\n\n        :param symbol: required - symbol for the isolated margin account\n        :type symbol: str\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_249isolated_margin_stream_keepalive = {"isolated_margin_stream_keepalive", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_249isolated_margin_stream_keepalive, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_248isolated_margin_stream_keepalive};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_249isolated_margin_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isolated_margin_stream_keepalive (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4900, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4900, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_keepalive", 0, 3, 4, 1); __PYX_ERR(0, 4900, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4900, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_keepalive", 0, 3, 4, 2); __PYX_ERR(0, 4900, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4900, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "isolated_margin_stream_keepalive") < 0)) __PYX_ERR(0, 4900, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
    __pyx_v_listenKey = values[2];
    __pyx_v_throw_exception = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_keepalive", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4900, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.isolated_margin_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_248isolated_margin_stream_keepalive(__pyx_self, __pyx_v_self, __pyx_v_symbol, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_248isolated_margin_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isolated_margin_stream_keepalive", 1);

  /* "unicorn_binance_rest_api/manager.py":4922
 *         """
 *         params = {
 *             'symbol': symbol,             # <<<<<<<<<<<<<<
 *             'listenKey': listenKey
 *         }
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_symbol, __pyx_v_symbol) < 0) __PYX_ERR(0, 4922, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4923
 *         params = {
 *             'symbol': symbol,
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_margin_api('put', 'userDataStream/isolated', signed=False, data=params,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 4922, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":4925
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('put', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 4925, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4925, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4926
 *         }
 *         return self._request_margin_api('put', 'userDataStream/isolated', signed=False, data=params,
 *                                         throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     def isolated_margin_stream_close(self, symbol, listenKey, throw_exception=True):
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 4925, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4925
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('put', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__83, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4900
 *             return res['listenKey']
 * 
 *     def isolated_margin_stream_keepalive(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING an isolated margin data stream to prevent a time out.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.isolated_margin_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4928
 *                                         throw_exception=throw_exception)
 * 
 *     def isolated_margin_stream_close(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out an isolated margin data stream.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_251isolated_margin_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_250isolated_margin_stream_close, "Close out an isolated margin data stream.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-isolated-margin\n\n        :param symbol: required - symbol for the isolated margin account\n        :type symbol: str\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_251isolated_margin_stream_close = {"isolated_margin_stream_close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_251isolated_margin_stream_close, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_250isolated_margin_stream_close};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_251isolated_margin_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_symbol = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isolated_margin_stream_close (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_symbol,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4928, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_symbol)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4928, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_close", 0, 3, 4, 1); __PYX_ERR(0, 4928, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4928, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_close", 0, 3, 4, 2); __PYX_ERR(0, 4928, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4928, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "isolated_margin_stream_close") < 0)) __PYX_ERR(0, 4928, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_symbol = values[1];
    __pyx_v_listenKey = values[2];
    __pyx_v_throw_exception = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("isolated_margin_stream_close", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4928, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.isolated_margin_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_250isolated_margin_stream_close(__pyx_self, __pyx_v_self, __pyx_v_symbol, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_250isolated_margin_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_symbol, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isolated_margin_stream_close", 1);

  /* "unicorn_binance_rest_api/manager.py":4950
 *         """
 *         params = {
 *             'symbol': symbol,             # <<<<<<<<<<<<<<
 *             'listenKey': listenKey
 *         }
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_symbol, __pyx_v_symbol) < 0) __PYX_ERR(0, 4950, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4951
 *         params = {
 *             'symbol': symbol,
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_margin_api('delete', 'userDataStream/isolated', signed=False, data=params,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 4950, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":4953
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('delete', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 4953, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4953, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4954
 *         }
 *         return self._request_margin_api('delete', 'userDataStream/isolated', signed=False, data=params,
 *                                         throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     # Lending Endpoints
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 4953, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4953
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('delete', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__84, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4928
 *                                         throw_exception=throw_exception)
 * 
 *     def isolated_margin_stream_close(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out an isolated margin data stream.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.isolated_margin_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4958
 *     # Lending Endpoints
 * 
 *     def get_lending_product_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Product List
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_253get_lending_product_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_252get_lending_product_list, "Get Lending Product List\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-flexible-product-list-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_253get_lending_product_list = {"get_lending_product_list", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_253get_lending_product_list, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_252get_lending_product_list};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_253get_lending_product_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_product_list (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4958, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_product_list") < 0)) __PYX_ERR(0, 4958, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_product_list", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4958, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_product_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_252get_lending_product_list(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_252get_lending_product_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_product_list", 1);

  /* "unicorn_binance_rest_api/manager.py":4964
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/product/list', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_daily_quota_left(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4964, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4964, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__85, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4958
 *     # Lending Endpoints
 * 
 *     def get_lending_product_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Product List
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_product_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4966
 *         return self._request_margin_api('get', 'lending/daily/product/list', signed=True, data=params)
 * 
 *     def get_lending_daily_quota_left(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Purchase Quota of Flexible Product.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_255get_lending_daily_quota_left(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_254get_lending_daily_quota_left, "Get Left Daily Purchase Quota of Flexible Product.\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-left-daily-purchase-quota-of-flexible-product-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_255get_lending_daily_quota_left = {"get_lending_daily_quota_left", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_255get_lending_daily_quota_left, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_254get_lending_daily_quota_left};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_255get_lending_daily_quota_left(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_daily_quota_left (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4966, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_daily_quota_left") < 0)) __PYX_ERR(0, 4966, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_daily_quota_left", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4966, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_daily_quota_left", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_254get_lending_daily_quota_left(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_254get_lending_daily_quota_left(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_daily_quota_left", 1);

  /* "unicorn_binance_rest_api/manager.py":4972
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/userLeftQuota', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def purchase_lending_product(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4972, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4972, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__86, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4966
 *         return self._request_margin_api('get', 'lending/daily/product/list', signed=True, data=params)
 * 
 *     def get_lending_daily_quota_left(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Purchase Quota of Flexible Product.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_daily_quota_left", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4974
 *         return self._request_margin_api('get', 'lending/daily/userLeftQuota', signed=True, data=params)
 * 
 *     def purchase_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Purchase Flexible Product
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_257purchase_lending_product(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_256purchase_lending_product, "Purchase Flexible Product\n\n        https://binance-docs.github.io/apidocs/spot/en/#purchase-flexible-product-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_257purchase_lending_product = {"purchase_lending_product", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_257purchase_lending_product, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_256purchase_lending_product};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_257purchase_lending_product(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("purchase_lending_product (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4974, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "purchase_lending_product") < 0)) __PYX_ERR(0, 4974, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("purchase_lending_product", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4974, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.purchase_lending_product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_256purchase_lending_product(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_256purchase_lending_product(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("purchase_lending_product", 1);

  /* "unicorn_binance_rest_api/manager.py":4980
 * 
 *         """
 *         return self._request_margin_api('post', 'lending/daily/purchase', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_daily_redemption_quota(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4980, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4980, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__87, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4974
 *         return self._request_margin_api('get', 'lending/daily/userLeftQuota', signed=True, data=params)
 * 
 *     def purchase_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Purchase Flexible Product
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.purchase_lending_product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4982
 *         return self._request_margin_api('post', 'lending/daily/purchase', signed=True, data=params)
 * 
 *     def get_lending_daily_redemption_quota(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Redemption Quota of Flexible Product
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_259get_lending_daily_redemption_quota(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_258get_lending_daily_redemption_quota, "Get Left Daily Redemption Quota of Flexible Product\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-left-daily-redemption-quota-of-flexible-product-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_259get_lending_daily_redemption_quota = {"get_lending_daily_redemption_quota", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_259get_lending_daily_redemption_quota, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_258get_lending_daily_redemption_quota};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_259get_lending_daily_redemption_quota(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_daily_redemption_quota (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4982, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_daily_redemption_quota") < 0)) __PYX_ERR(0, 4982, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_daily_redemption_quota", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4982, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_daily_redemption_quota", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_258get_lending_daily_redemption_quota(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_258get_lending_daily_redemption_quota(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_daily_redemption_quota", 1);

  /* "unicorn_binance_rest_api/manager.py":4988
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/userRedemptionQuota', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def redeem_lending_product(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4988, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4988, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__88, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4982
 *         return self._request_margin_api('post', 'lending/daily/purchase', signed=True, data=params)
 * 
 *     def get_lending_daily_redemption_quota(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Redemption Quota of Flexible Product
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_daily_redemption_quota", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4990
 *         return self._request_margin_api('get', 'lending/daily/userRedemptionQuota', signed=True, data=params)
 * 
 *     def redeem_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Redeem Flexible Product
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_261redeem_lending_product(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_260redeem_lending_product, "Redeem Flexible Product\n\n        https://binance-docs.github.io/apidocs/spot/en/#redeem-flexible-product-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_261redeem_lending_product = {"redeem_lending_product", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_261redeem_lending_product, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_260redeem_lending_product};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_261redeem_lending_product(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("redeem_lending_product (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4990, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "redeem_lending_product") < 0)) __PYX_ERR(0, 4990, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("redeem_lending_product", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4990, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.redeem_lending_product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_260redeem_lending_product(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_260redeem_lending_product(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("redeem_lending_product", 1);

  /* "unicorn_binance_rest_api/manager.py":4996
 * 
 *         """
 *         return self._request_margin_api('post', 'lending/daily/redeem', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_position(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 4996, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 4996, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__89, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4990
 *         return self._request_margin_api('get', 'lending/daily/userRedemptionQuota', signed=True, data=params)
 * 
 *     def redeem_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Redeem Flexible Product
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.redeem_lending_product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":4998
 *         return self._request_margin_api('post', 'lending/daily/redeem', signed=True, data=params)
 * 
 *     def get_lending_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Flexible Product Position
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_263get_lending_position(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_262get_lending_position, "Get Flexible Product Position\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-flexible-product-position-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_263get_lending_position = {"get_lending_position", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_263get_lending_position, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_262get_lending_position};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_263get_lending_position(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_position (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4998, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_position") < 0)) __PYX_ERR(0, 4998, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_position", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4998, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_262get_lending_position(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_262get_lending_position(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_position", 1);

  /* "unicorn_binance_rest_api/manager.py":5004
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/token/position', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_fixed_activity_project_list(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 5004, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5004, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__90, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":4998
 *         return self._request_margin_api('post', 'lending/daily/redeem', signed=True, data=params)
 * 
 *     def get_lending_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Flexible Product Position
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5006
 *         return self._request_margin_api('get', 'lending/daily/token/position', signed=True, data=params)
 * 
 *     def get_fixed_activity_project_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Fixed and Activity Project List
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_265get_fixed_activity_project_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_264get_fixed_activity_project_list, "Get Fixed and Activity Project List\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-fixed-and-activity-project-list-user_data\n\n        :param asset: optional\n        :type asset: str\n        :param type: required - \"ACTIVITY\", \"CUSTOMIZED_FIXED\"\n        :type type: str\n        :param status: optional - \"ALL\", \"SUBSCRIBABLE\", \"UNSUBSCRIBABLE\"; default \"ALL\"\n        :type status: str\n        :param sortBy: optional - \"START_TIME\", \"LOT_SIZE\", \"INTEREST_RATE\", \"DURATION\"; default \"START_TIME\"\n        :type sortBy: str\n        :param current: optional - Currently querying page. Start from 1. Default:1\n        :type current: int\n        :param size: optional - Default:10, Max:100\n        :type size: int\n        :param recvWindow: the number of milliseconds the request is valid for\n        :type recvWindow: int\n\n        :return: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"asset\": \"USDT\",\n                    \"displayPriority\": 1,\n                    \"duration\": 90,\n                    \"interestPerLot\": \"1.35810000\",\n                    \"interestRate\": \"0.05510000\",\n                    \"lotSize\": \"100.00000000\",\n                    \"lotsLowLimit\": 1,\n                    \"lotsPurchased\": 74155,\n                    \"lotsUpLimit\": 80000,\n                    \"maxLotsPerUser\": 2000,\n                    \"needKyc\": False,\n                    \"projectId\": \"CUSDT90DAYSS001\",\n                    \"projectName\": \"USDT\",\n                    \"status\": \"PURCHASING\",\n                    \"type\": \"CUSTOMIZED_FIXED\",\n                    \"withAreaLimitation\": False\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n        \n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_265get_fixed_activity_project_list = {"get_fixed_activity_project_list", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_265get_fixed_activity_project_list, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_264get_fixed_activity_project_list};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_265get_fixed_activity_project_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_fixed_activity_project_list (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5006, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_fixed_activity_project_list") < 0)) __PYX_ERR(0, 5006, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_fixed_activity_project_list", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5006, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_fixed_activity_project_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_264get_fixed_activity_project_list(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_264get_fixed_activity_project_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_fixed_activity_project_list", 1);

  /* "unicorn_binance_rest_api/manager.py":5054
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/project/list', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_account(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 5054, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5054, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__91, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5006
 *         return self._request_margin_api('get', 'lending/daily/token/position', signed=True, data=params)
 * 
 *     def get_fixed_activity_project_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Fixed and Activity Project List
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_fixed_activity_project_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5056
 *         return self._request_margin_api('get', 'lending/project/list', signed=True, data=params)
 * 
 *     def get_lending_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Account Details
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_267get_lending_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_266get_lending_account, "Get Lending Account Details\n\n        https://binance-docs.github.io/apidocs/spot/en/#lending-account-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_267get_lending_account = {"get_lending_account", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_267get_lending_account, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_266get_lending_account};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_267get_lending_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_account (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5056, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_account") < 0)) __PYX_ERR(0, 5056, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_account", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5056, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_266get_lending_account(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_266get_lending_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_account", 1);

  /* "unicorn_binance_rest_api/manager.py":5062
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/account', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_purchase_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 5062, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5062, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__92, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5056
 *         return self._request_margin_api('get', 'lending/project/list', signed=True, data=params)
 * 
 *     def get_lending_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Account Details
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5064
 *         return self._request_margin_api('get', 'lending/union/account', signed=True, data=params)
 * 
 *     def get_lending_purchase_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Purchase History
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_269get_lending_purchase_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_268get_lending_purchase_history, "Get Lending Purchase History\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-purchase-record-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_269get_lending_purchase_history = {"get_lending_purchase_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_269get_lending_purchase_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_268get_lending_purchase_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_269get_lending_purchase_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_purchase_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5064, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_purchase_history") < 0)) __PYX_ERR(0, 5064, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_purchase_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5064, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_purchase_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_268get_lending_purchase_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_268get_lending_purchase_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_purchase_history", 1);

  /* "unicorn_binance_rest_api/manager.py":5070
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/purchaseRecord', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_redemption_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 5070, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5070, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__93, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5064
 *         return self._request_margin_api('get', 'lending/union/account', signed=True, data=params)
 * 
 *     def get_lending_purchase_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Purchase History
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_purchase_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5072
 *         return self._request_margin_api('get', 'lending/union/purchaseRecord', signed=True, data=params)
 * 
 *     def get_lending_redemption_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Redemption History
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_271get_lending_redemption_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_270get_lending_redemption_history, "Get Lending Redemption History\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-redemption-record-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_271get_lending_redemption_history = {"get_lending_redemption_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_271get_lending_redemption_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_270get_lending_redemption_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_271get_lending_redemption_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_redemption_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5072, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_redemption_history") < 0)) __PYX_ERR(0, 5072, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_redemption_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5072, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_redemption_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_270get_lending_redemption_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_270get_lending_redemption_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_redemption_history", 1);

  /* "unicorn_binance_rest_api/manager.py":5078
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/redemptionRecord', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_interest_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 5078, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5078, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__94, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5072
 *         return self._request_margin_api('get', 'lending/union/purchaseRecord', signed=True, data=params)
 * 
 *     def get_lending_redemption_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Redemption History
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_redemption_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5080
 *         return self._request_margin_api('get', 'lending/union/redemptionRecord', signed=True, data=params)
 * 
 *     def get_lending_interest_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Interest History
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_273get_lending_interest_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_272get_lending_interest_history, "Get Lending Interest History\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-interest-history-user_data-2\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_273get_lending_interest_history = {"get_lending_interest_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_273get_lending_interest_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_272get_lending_interest_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_273get_lending_interest_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lending_interest_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5080, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_lending_interest_history") < 0)) __PYX_ERR(0, 5080, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lending_interest_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5080, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_interest_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_272get_lending_interest_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_272get_lending_interest_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lending_interest_history", 1);

  /* "unicorn_binance_rest_api/manager.py":5086
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/interestHistory', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def change_fixed_activity_to_daily_position(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 5086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5086, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__95, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5080
 *         return self._request_margin_api('get', 'lending/union/redemptionRecord', signed=True, data=params)
 * 
 *     def get_lending_interest_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Interest History
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_lending_interest_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5088
 *         return self._request_margin_api('get', 'lending/union/interestHistory', signed=True, data=params)
 * 
 *     def change_fixed_activity_to_daily_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Change Fixed/Activity Position to Daily Position
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_275change_fixed_activity_to_daily_position(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_274change_fixed_activity_to_daily_position, "Change Fixed/Activity Position to Daily Position\n\n        https://binance-docs.github.io/apidocs/spot/en/#change-fixed-activity-position-to-daily-position-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_275change_fixed_activity_to_daily_position = {"change_fixed_activity_to_daily_position", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_275change_fixed_activity_to_daily_position, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_274change_fixed_activity_to_daily_position};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_275change_fixed_activity_to_daily_position(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("change_fixed_activity_to_daily_position (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5088, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "change_fixed_activity_to_daily_position") < 0)) __PYX_ERR(0, 5088, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("change_fixed_activity_to_daily_position", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5088, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.change_fixed_activity_to_daily_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_274change_fixed_activity_to_daily_position(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_274change_fixed_activity_to_daily_position(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("change_fixed_activity_to_daily_position", 1);

  /* "unicorn_binance_rest_api/manager.py":5094
 * 
 *         """
 *         return self._request_margin_api('post', 'lending/positionChanged', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     # Sub Accounts
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 5094, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5094, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__96, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5088
 *         return self._request_margin_api('get', 'lending/union/interestHistory', signed=True, data=params)
 * 
 *     def change_fixed_activity_to_daily_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Change Fixed/Activity Position to Daily Position
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.change_fixed_activity_to_daily_position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5098
 *     # Sub Accounts
 * 
 *     def get_sub_account_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account List.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_277get_sub_account_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_276get_sub_account_list, "Query Sub-account List.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-sub-account-list-sapi-for-master-account\n\n        :param email: optional - Sub-account email\n        :type email: str\n        :param isFreeze: optional\n        :type isFreeze: str\n        :param page: optional - Default value: 1\n        :param limit: optional - Default value: 1, Max value: 200\n        :type limit: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"subAccounts\":[\n                    {\n                        \"email\":\"testsub@gmail.com\",\n                        \"isFreeze\":false,\n                        \"createTime\":1544433328000\n                    },\n                    {\n                        \"email\":\"virtual@oxebmvfonoemail.com\",\n                        \"isFreeze\":false,\n                        \"createTime\":1544433328000\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_277get_sub_account_list = {"get_sub_account_list", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_277get_sub_account_list, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_276get_sub_account_list};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_277get_sub_account_list(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sub_account_list (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5098, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_sub_account_list") < 0)) __PYX_ERR(0, 5098, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sub_account_list", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5098, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_276get_sub_account_list(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_276get_sub_account_list(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sub_account_list", 1);

  /* "unicorn_binance_rest_api/manager.py":5135
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/list', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_sub_account_transfer_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5135, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__97, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5098
 *     # Sub Accounts
 * 
 *     def get_sub_account_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account List.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5137
 *         return self._request_margin_api('get', 'sub-account/list', True, data=params)
 * 
 *     def get_sub_account_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Transfer History.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_279get_sub_account_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_278get_sub_account_transfer_history, "Query Sub-account Transfer History.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-sub-account-spot-asset-transfer-history-sapi-for-master-account\n\n        :param fromEmail: optional\n        :type fromEmail: str\n        :param toEmail: optional\n        :type toEmail: str\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param page: optional - Default value: 1\n        :type page: int\n        :param limit: optional - Default value: 500\n        :type limit: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"from\":\"aaa@test.com\",\n                    \"to\":\"bbb@test.com\",\n                    \"asset\":\"BTC\",\n                    \"qty\":\"10\",\n                    \"status\": \"SUCCESS\",\n                    \"tranId\": 6489943656,\n                    \"time\":1544433328000\n                },\n                {\n                    \"from\":\"bbb@test.com\",\n                    \"to\":\"ccc@test.com\",\n                    \"asset\":\"ETH\",\n                    \"qty\":\"2\",\n                    \"status\": \"SUCCESS\",\n                    \"tranId\": 6489938713,\n                    \"time\":1544433328000\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_279get_sub_account_transfer_history = {"get_sub_account_transfer_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_279get_sub_account_transfer_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_278get_sub_account_transfer_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_279get_sub_account_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sub_account_transfer_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5137, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_sub_account_transfer_history") < 0)) __PYX_ERR(0, 5137, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sub_account_transfer_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5137, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_278get_sub_account_transfer_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_278get_sub_account_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sub_account_transfer_history", 1);

  /* "unicorn_binance_rest_api/manager.py":5185
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/sub/transfer/history', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_sub_account_futures_transfer_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5185, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__98, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5137
 *         return self._request_margin_api('get', 'sub-account/list', True, data=params)
 * 
 *     def get_sub_account_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Transfer History.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5187
 *         return self._request_margin_api('get', 'sub-account/sub/transfer/history', True, data=params)
 * 
 *     def get_sub_account_futures_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Futures Transfer History.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_281get_sub_account_futures_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_280get_sub_account_futures_transfer_history, "Query Sub-account Futures Transfer History.\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-sub-account-futures-asset-transfer-history-for-master-account\n\n        :param email: required\n        :type email: str\n        :param futuresType: required\n        :type futuresType: int\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param page: optional\n        :type page: int\n        :param limit: optional\n        :type limit: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"success\":true,\n                \"futuresType\": 2,\n                \"transfers\":[\n                    {\n                        \"from\":\"aaa@test.com\",\n                        \"to\":\"bbb@test.com\",\n                        \"asset\":\"BTC\",\n                        \"qty\":\"1\",\n                        \"time\":1544433328000\n                    },\n                    {\n                        \"from\":\"bbb@test.com\",\n                        \"to\":\"ccc@test.com\",\n                        \"asset\":\"ETH\",\n                        \"qty\":\"2\",\n                        \"time\":1544433328000\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_281get_sub_account_futures_transfer_history = {"get_sub_account_futures_transfer_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_281get_sub_account_futures_transfer_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_280get_sub_account_futures_transfer_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_281get_sub_account_futures_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sub_account_futures_transfer_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5187, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_sub_account_futures_transfer_history") < 0)) __PYX_ERR(0, 5187, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sub_account_futures_transfer_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5187, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_futures_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_280get_sub_account_futures_transfer_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_280get_sub_account_futures_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sub_account_futures_transfer_history", 1);

  /* "unicorn_binance_rest_api/manager.py":5235
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/internalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def create_sub_account_futures_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5235, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__99, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5187
 *         return self._request_margin_api('get', 'sub-account/sub/transfer/history', True, data=params)
 * 
 *     def get_sub_account_futures_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Futures Transfer History.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_futures_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5237
 *         return self._request_margin_api('get', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def create_sub_account_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute sub-account Futures transfer
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_283create_sub_account_futures_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_282create_sub_account_futures_transfer, "Execute sub-account Futures transfer\n\n        https://github.com/binance-exchange/binance-official-api-docs/blob/9dbe0e961b80557bb19708a707c7fad08842b28e/wapi-api.md#sub-account-transferfor-master-account\n\n        :param fromEmail: required - Sender email\n        :type fromEmail: str\n        :param toEmail: required - Recipient email\n        :type toEmail: str\n        :param futuresType: required\n        :type futuresType: int\n        :param asset: required\n        :type asset: str\n        :param amount: required\n        :type amount: decimal\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n           {\n                \"success\":true,\n                \"txnId\":\"2934662589\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_283create_sub_account_futures_transfer = {"create_sub_account_futures_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_283create_sub_account_futures_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_282create_sub_account_futures_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_283create_sub_account_futures_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_sub_account_futures_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5237, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "create_sub_account_futures_transfer") < 0)) __PYX_ERR(0, 5237, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_sub_account_futures_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5237, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_sub_account_futures_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_282create_sub_account_futures_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_282create_sub_account_futures_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_sub_account_futures_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":5267
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/futures/internalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_sub_account_assets(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5267, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__100, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5237
 *         return self._request_margin_api('get', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def create_sub_account_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute sub-account Futures transfer
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.create_sub_account_futures_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5269
 *         return self._request_margin_api('post', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def get_sub_account_assets(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch sub-account assets
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_285get_sub_account_assets(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_284get_sub_account_assets, "Fetch sub-account assets\n\n         https://binance-docs.github.io/apidocs/spot/en/#query-sub-account-assets-sapi-for-master-account\n\n        :param email: required\n        :type email: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"balances\":[\n                    {\n                        \"asset\":\"ADA\",\n                        \"free\":10000,\n                        \"locked\":0\n                    },\n                    {\n                        \"asset\":\"BNB\",\n                        \"free\":10003,\n                        \"locked\":0\n                    },\n                    {\n                        \"asset\":\"BTC\",\n                        \"free\":11467.6399,\n                        \"locked\":0\n                    },\n                    {\n                        \"asset\":\"ETH\",\n                        \"free\":10004.995,\n                        \"locked\":0\n                    },\n                    {\n                        \"asset\":\"USDT\",\n                        \"free\":11652.14213,\n                        \"locked\":0\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_285get_sub_account_assets = {"get_sub_account_assets", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_285get_sub_account_assets, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_284get_sub_account_assets};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_285get_sub_account_assets(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sub_account_assets (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5269, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_sub_account_assets") < 0)) __PYX_ERR(0, 5269, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sub_account_assets", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5269, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_assets", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_284get_sub_account_assets(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_284get_sub_account_assets(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sub_account_assets", 1);

  /* "unicorn_binance_rest_api/manager.py":5316
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/assets', True, data=params, version='v3')             # <<<<<<<<<<<<<<
 * 
 *     def query_subaccount_spot_summary(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5316, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_n_s_v3) < 0) __PYX_ERR(0, 5316, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__101, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5269
 *         return self._request_margin_api('post', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def get_sub_account_assets(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch sub-account assets
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_sub_account_assets", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5318
 *         return self._request_margin_api('get', 'sub-account/assets', True, data=params, version='v3')
 * 
 *     def query_subaccount_spot_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Spot Assets Summary (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_287query_subaccount_spot_summary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_286query_subaccount_spot_summary, "Query Sub-account Spot Assets Summary (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-sub-account-spot-assets-summary-for-master-account\n\n        :param email: optional - Sub account email\n        :type email: str\n        :param page: optional - default 1\n        :type page: int\n        :param size: optional - default 10, max 20\n        :type size: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n           {\n                \"totalCount\":2,\n                \"masterAccountTotalAsset\": \"0.23231201\",\n                \"spotSubUserAssetBtcVoList\":[\n                    {\n                        \"email\":\"sub123@test.com\",\n                        \"totalAsset\":\"9999.00000000\"\n                    },\n                    {\n                        \"email\":\"test456@test.com\",\n                        \"totalAsset\":\"0.00000000\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_287query_subaccount_spot_summary = {"query_subaccount_spot_summary", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_287query_subaccount_spot_summary, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_286query_subaccount_spot_summary};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_287query_subaccount_spot_summary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_subaccount_spot_summary (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5318, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "query_subaccount_spot_summary") < 0)) __PYX_ERR(0, 5318, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("query_subaccount_spot_summary", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5318, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.query_subaccount_spot_summary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_286query_subaccount_spot_summary(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_286query_subaccount_spot_summary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_subaccount_spot_summary", 1);

  /* "unicorn_binance_rest_api/manager.py":5354
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/spotSummary', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_deposit_address(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5354, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__102, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5318
 *         return self._request_margin_api('get', 'sub-account/assets', True, data=params, version='v3')
 * 
 *     def query_subaccount_spot_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Spot Assets Summary (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.query_subaccount_spot_summary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5356
 *         return self._request_margin_api('get', 'sub-account/spotSummary', True, data=params)
 * 
 *     def get_subaccount_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit Address (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_289get_subaccount_deposit_address(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_288get_subaccount_deposit_address, "Get Sub-account Deposit Address (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-sub-account-deposit-address-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param coin: required\n        :type coin: str\n        :param network: optional\n        :type network: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n           {\n                \"address\":\"TDunhSa7jkTNuKrusUTU1MUHtqXoBPKETV\",\n                \"coin\":\"USDT\",\n                \"tag\":\"\",\n                \"url\":\"https://tronscan.org/#/address/TDunhSa7jkTNuKrusUTU1MUHtqXoBPKETV\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_289get_subaccount_deposit_address = {"get_subaccount_deposit_address", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_289get_subaccount_deposit_address, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_288get_subaccount_deposit_address};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_289get_subaccount_deposit_address(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_deposit_address (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5356, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_deposit_address") < 0)) __PYX_ERR(0, 5356, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_deposit_address", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5356, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_deposit_address", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_288get_subaccount_deposit_address(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_288get_subaccount_deposit_address(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_deposit_address", 1);

  /* "unicorn_binance_rest_api/manager.py":5384
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/subAddress', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_deposit_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5384, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__103, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5356
 *         return self._request_margin_api('get', 'sub-account/spotSummary', True, data=params)
 * 
 *     def get_subaccount_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit Address (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_deposit_address", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5386
 *         return self._request_margin_api('get', 'capital/deposit/subAddress', True, data=params)
 * 
 *     def get_subaccount_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit History (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_291get_subaccount_deposit_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_290get_subaccount_deposit_history, "Get Sub-account Deposit History (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-sub-account-deposit-address-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param coin: optional\n        :type coin: str\n        :param status: optional - (0:pending,6: credited but cannot withdraw, 1:success)\n        :type status: int\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param limit: optional\n        :type limit: int\n        :param offset: optional - default:0\n        :type offset: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n           [\n                {\n                    \"amount\":\"0.00999800\",\n                    \"coin\":\"PAXG\",\n                    \"network\":\"ETH\",\n                    \"status\":1,\n                    \"address\":\"0x788cabe9236ce061e5a892e1a59395a81fc8d62c\",\n                    \"addressTag\":\"\",\n                    \"txId\":\"0xaad4654a3234aa6118af9b4b335f5ae81c360b2394721c019b5d1e75328b09f3\",\n                    \"insertTime\":1599621997000,\n                    \"transferType\":0,\n                    \"confirmTimes\":\"12/12\"\n                },\n                {\n                    \"amount\":\"0.50000000\",\n                    \"coin\":\"IOTA\",\n                    \"network\":\"IOTA\",\n                    \"status\":1,\n                    \"address\":\"SIZ9VLMHWATXKV99LH99CIGFJFUMLEHGWVZVNNZXRJJVWBPHYWPPBOSDORZ9EQSHCZAMPVAPGFYQAUUV9DROOXJLNW\",\n                    \"addressTag\":\"\",\n                    \"txId\":\"ESBFVQUTPIWQNJSPXFNHNYHSQNTGKRVKPRABQWTAXCDWOAKDKYWPTVG9BGXNVNKTLEJGESAVXIKIZ9999\",\n                    \"insertTime\":1599620082000,\n                    \"transferType\":0,\n                    \"confirmTimes\":""\"1/1\"\n                }\n           ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_291get_subaccount_deposit_history = {"get_subaccount_deposit_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_291get_subaccount_deposit_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_290get_subaccount_deposit_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_291get_subaccount_deposit_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_deposit_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5386, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_deposit_history") < 0)) __PYX_ERR(0, 5386, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_deposit_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5386, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_deposit_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_290get_subaccount_deposit_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_290get_subaccount_deposit_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_deposit_history", 1);

  /* "unicorn_binance_rest_api/manager.py":5442
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/subHisrec', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_margin_status(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5442, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__104, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5386
 *         return self._request_margin_api('get', 'capital/deposit/subAddress', True, data=params)
 * 
 *     def get_subaccount_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit History (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_deposit_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5444
 *         return self._request_margin_api('get', 'capital/deposit/subHisrec', True, data=params)
 * 
 *     def get_subaccount_futures_margin_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account's Status on Margin/Futures (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_293get_subaccount_futures_margin_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_292get_subaccount_futures_margin_status, "Get Sub-account's Status on Margin/Futures (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-sub-account-39-s-status-on-margin-futures-for-master-account\n\n        :param email: optional - Sub account email\n        :type email: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n           [\n                {\n                    \"email\":\"123@test.com\",      // user email\n                    \"isSubUserEnabled\": true,    // true or false\n                    \"isUserActive\": true,        // true or false\n                    \"insertTime\": 1570791523523  // subaccount create time\n                    \"isMarginEnabled\": true,     // true or false for margin\n                    \"isFutureEnabled\": true      // true or false for futures.\n                    \"mobile\": 1570791523523      // user mobile number\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_293get_subaccount_futures_margin_status = {"get_subaccount_futures_margin_status", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_293get_subaccount_futures_margin_status, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_292get_subaccount_futures_margin_status};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_293get_subaccount_futures_margin_status(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_futures_margin_status (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5444, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_futures_margin_status") < 0)) __PYX_ERR(0, 5444, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_futures_margin_status", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5444, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_margin_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_292get_subaccount_futures_margin_status(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_292get_subaccount_futures_margin_status(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_futures_margin_status", 1);

  /* "unicorn_binance_rest_api/manager.py":5473
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/status', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def enable_subaccount_margin(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5473, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__105, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5444
 *         return self._request_margin_api('get', 'capital/deposit/subHisrec', True, data=params)
 * 
 *     def get_subaccount_futures_margin_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account's Status on Margin/Futures (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_margin_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5475
 *         return self._request_margin_api('get', 'sub-account/status', True, data=params)
 * 
 *     def enable_subaccount_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Margin for Sub-account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_295enable_subaccount_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_294enable_subaccount_margin, "Enable Margin for Sub-account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#enable-margin-for-sub-account-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n           {\n\n                \"email\":\"123@test.com\",\n\n                \"isMarginEnabled\": true\n\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_295enable_subaccount_margin = {"enable_subaccount_margin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_295enable_subaccount_margin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_294enable_subaccount_margin};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_295enable_subaccount_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enable_subaccount_margin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5475, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "enable_subaccount_margin") < 0)) __PYX_ERR(0, 5475, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enable_subaccount_margin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5475, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.enable_subaccount_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_294enable_subaccount_margin(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_294enable_subaccount_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enable_subaccount_margin", 1);

  /* "unicorn_binance_rest_api/manager.py":5500
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/margin/enable', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_margin_details(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5500, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__106, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5475
 *         return self._request_margin_api('get', 'sub-account/status', True, data=params)
 * 
 *     def enable_subaccount_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Margin for Sub-account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.enable_subaccount_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5502
 *         return self._request_margin_api('post', 'sub-account/margin/enable', True, data=params)
 * 
 *     def get_subaccount_margin_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Margin Account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_297get_subaccount_margin_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_296get_subaccount_margin_details, "Get Detail on Sub-account's Margin Account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-detail-on-sub-account-39-s-margin-account-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                  \"email\":\"123@test.com\",\n                  \"marginLevel\": \"11.64405625\",\n                  \"totalAssetOfBtc\": \"6.82728457\",\n                  \"totalLiabilityOfBtc\": \"0.58633215\",\n                  \"totalNetAssetOfBtc\": \"6.24095242\",\n                  \"marginTradeCoeffVo\":\n                        {\n                            \"forceLiquidationBar\": \"1.10000000\",  // Liquidation margin ratio\n                            \"marginCallBar\": \"1.50000000\",        // Margin call margin ratio\n                            \"normalBar\": \"2.00000000\"             // Initial margin ratio\n                        },\n                  \"marginUserAssetVoList\": [\n                      {\n                          \"asset\": \"BTC\",\n                          \"borrowed\": \"0.00000000\",\n                          \"free\": \"0.00499500\",\n                          \"interest\": \"0.00000000\",\n                          \"locked\": \"0.00000000\",\n                          \"netAsset\": \"0.00499500\"\n                      },\n                      {\n                          \"asset\": \"BNB\",\n                          \"borrowed\": \"201.66666672\",\n                          \"free\": \"2346.50000000\",\n                          \"interest\": \"0.00000000\",\n                          \"locked\": \"0.00000000\",\n                          \"netAsset\": \"2144.83333328\"\n                      },\n                      {\n                          \"asset\": \"ETH\",\n                          \"borr""owed\": \"0.00000000\",\n                          \"free\": \"0.00000000\",\n                          \"interest\": \"0.00000000\",\n                          \"locked\": \"0.00000000\",\n                          \"netAsset\": \"0.00000000\"\n                      },\n                      {\n                          \"asset\": \"USDT\",\n                          \"borrowed\": \"0.00000000\",\n                          \"free\": \"0.00000000\",\n                          \"interest\": \"0.00000000\",\n                          \"locked\": \"0.00000000\",\n                          \"netAsset\": \"0.00000000\"\n                      }\n                  ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_297get_subaccount_margin_details = {"get_subaccount_margin_details", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_297get_subaccount_margin_details, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_296get_subaccount_margin_details};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_297get_subaccount_margin_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_margin_details (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5502, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_margin_details") < 0)) __PYX_ERR(0, 5502, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_margin_details", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5502, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_margin_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_296get_subaccount_margin_details(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_296get_subaccount_margin_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_margin_details", 1);

  /* "unicorn_binance_rest_api/manager.py":5567
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/margin/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_margin_summary(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5567, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__107, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5502
 *         return self._request_margin_api('post', 'sub-account/margin/enable', True, data=params)
 * 
 *     def get_subaccount_margin_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Margin Account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_margin_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5569
 *         return self._request_margin_api('get', 'sub-account/margin/account', True, data=params)
 * 
 *     def get_subaccount_margin_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Margin Account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_299get_subaccount_margin_summary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_298get_subaccount_margin_summary, "Get Summary of Sub-account's Margin Account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-summary-of-sub-account-39-s-margin-account-for-master-account\n\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"totalAssetOfBtc\": \"4.33333333\",\n                \"totalLiabilityOfBtc\": \"2.11111112\",\n                \"totalNetAssetOfBtc\": \"2.22222221\",\n                \"subAccountList\":[\n                    {\n                        \"email\":\"123@test.com\",\n                        \"totalAssetOfBtc\": \"2.11111111\",\n                        \"totalLiabilityOfBtc\": \"1.11111111\",\n                        \"totalNetAssetOfBtc\": \"1.00000000\"\n                    },\n                    {\n                        \"email\":\"345@test.com\",\n                        \"totalAssetOfBtc\": \"2.22222222\",\n                        \"totalLiabilityOfBtc\": \"1.00000001\",\n                        \"totalNetAssetOfBtc\": \"1.22222221\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_299get_subaccount_margin_summary = {"get_subaccount_margin_summary", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_299get_subaccount_margin_summary, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_298get_subaccount_margin_summary};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_299get_subaccount_margin_summary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_margin_summary (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5569, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_margin_summary") < 0)) __PYX_ERR(0, 5569, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_margin_summary", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5569, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_margin_summary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_298get_subaccount_margin_summary(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_298get_subaccount_margin_summary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_margin_summary", 1);

  /* "unicorn_binance_rest_api/manager.py":5604
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/margin/accountSummary', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def enable_subaccount_futures(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5604, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__108, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5569
 *         return self._request_margin_api('get', 'sub-account/margin/account', True, data=params)
 * 
 *     def get_subaccount_margin_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Margin Account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_margin_summary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5606
 *         return self._request_margin_api('get', 'sub-account/margin/accountSummary', True, data=params)
 * 
 *     def enable_subaccount_futures(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Futures for Sub-account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_301enable_subaccount_futures(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_300enable_subaccount_futures, "Enable Futures for Sub-account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#enable-futures-for-sub-account-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n\n                \"email\":\"123@test.com\",\n\n                \"isFuturesEnabled\": true  // true or false\n\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_301enable_subaccount_futures = {"enable_subaccount_futures", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_301enable_subaccount_futures, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_300enable_subaccount_futures};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_301enable_subaccount_futures(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enable_subaccount_futures (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5606, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "enable_subaccount_futures") < 0)) __PYX_ERR(0, 5606, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enable_subaccount_futures", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5606, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.enable_subaccount_futures", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_300enable_subaccount_futures(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_300enable_subaccount_futures(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enable_subaccount_futures", 1);

  /* "unicorn_binance_rest_api/manager.py":5631
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/futures/enable', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_details(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5631, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__109, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5606
 *         return self._request_margin_api('get', 'sub-account/margin/accountSummary', True, data=params)
 * 
 *     def enable_subaccount_futures(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Futures for Sub-account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.enable_subaccount_futures", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5633
 *         return self._request_margin_api('post', 'sub-account/futures/enable', True, data=params)
 * 
 *     def get_subaccount_futures_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Futures Account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_303get_subaccount_futures_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_302get_subaccount_futures_details, "Get Detail on Sub-account's Futures Account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-detail-on-sub-account-39-s-futures-account-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"email\": \"abc@test.com\",\n                \"asset\": \"USDT\",\n                \"assets\":[\n                    {\n                        \"asset\": \"USDT\",\n                        \"initialMargin\": \"0.00000000\",\n                        \"maintenanceMargin\": \"0.00000000\",\n                        \"marginBalance\": \"0.88308000\",\n                        \"maxWithdrawAmount\": \"0.88308000\",\n                        \"openOrderInitialMargin\": \"0.00000000\",\n                        \"positionInitialMargin\": \"0.00000000\",\n                        \"unrealizedProfit\": \"0.00000000\",\n                        \"walletBalance\": \"0.88308000\"\n                     }\n                ],\n                \"canDeposit\": true,\n                \"canTrade\": true,\n                \"canWithdraw\": true,\n                \"feeTier\": 2,\n                \"maxWithdrawAmount\": \"0.88308000\",\n                \"totalInitialMargin\": \"0.00000000\",\n                \"totalMaintenanceMargin\": \"0.00000000\",\n                \"totalMarginBalance\": \"0.88308000\",\n                \"totalOpenOrderInitialMargin\": \"0.00000000\",\n                \"totalPositionInitialMargin\": \"0.00000000\",\n                \"totalUnrealizedProfit\": \"0.00000000\",\n                \"totalWalletBalance\": \"0.88308000\",\n                \"updateTime\": 1576756674610\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_303get_subaccount_futures_details = {"get_subaccount_futures_details", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_303get_subaccount_futures_details, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_302get_subaccount_futures_details};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_303get_subaccount_futures_details(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_futures_details (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5633, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_futures_details") < 0)) __PYX_ERR(0, 5633, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_futures_details", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5633, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_302get_subaccount_futures_details(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_302get_subaccount_futures_details(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_futures_details", 1);

  /* "unicorn_binance_rest_api/manager.py":5681
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_summary(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5681, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__110, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5633
 *         return self._request_margin_api('post', 'sub-account/futures/enable', True, data=params)
 * 
 *     def get_subaccount_futures_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Futures Account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_details", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5683
 *         return self._request_margin_api('get', 'sub-account/futures/account', True, data=params)
 * 
 *     def get_subaccount_futures_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Futures Account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_305get_subaccount_futures_summary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_304get_subaccount_futures_summary, "Get Summary of Sub-account's Futures Account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-summary-of-sub-account-39-s-futures-account-for-master-account\n\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"totalInitialMargin\": \"9.83137400\",\n                \"totalMaintenanceMargin\": \"0.41568700\",\n                \"totalMarginBalance\": \"23.03235621\",\n                \"totalOpenOrderInitialMargin\": \"9.00000000\",\n                \"totalPositionInitialMargin\": \"0.83137400\",\n                \"totalUnrealizedProfit\": \"0.03219710\",\n                \"totalWalletBalance\": \"22.15879444\",\n                \"asset\": \"USDT\",\n                \"subAccountList\":[\n                    {\n                        \"email\": \"123@test.com\",\n                        \"totalInitialMargin\": \"9.00000000\",\n                        \"totalMaintenanceMargin\": \"0.00000000\",\n                        \"totalMarginBalance\": \"22.12659734\",\n                        \"totalOpenOrderInitialMargin\": \"9.00000000\",\n                        \"totalPositionInitialMargin\": \"0.00000000\",\n                        \"totalUnrealizedProfit\": \"0.00000000\",\n                        \"totalWalletBalance\": \"22.12659734\",\n                        \"asset\": \"USDT\"\n                    },\n                    {\n                        \"email\": \"345@test.com\",\n                        \"totalInitialMargin\": \"0.83137400\",\n                        \"totalMaintenanceMargin\": \"0.41568700\",\n                        \"totalMarginBalance\": \"0.90575887\",\n                        \"totalOpenOrderInitialMargin\": \"0.00000000\",\n                        \"totalPositionInitialMargin\": \"0.83137400\",\n                        \"totalUnrealizedProfit\": \"0.03219710\",\n                        \"totalWa""lletBalance\": \"0.87356177\",\n                        \"asset\": \"USDT\"\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_305get_subaccount_futures_summary = {"get_subaccount_futures_summary", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_305get_subaccount_futures_summary, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_304get_subaccount_futures_summary};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_305get_subaccount_futures_summary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_futures_summary (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5683, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_futures_summary") < 0)) __PYX_ERR(0, 5683, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_futures_summary", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5683, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_summary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_304get_subaccount_futures_summary(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_304get_subaccount_futures_summary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_futures_summary", 1);

  /* "unicorn_binance_rest_api/manager.py":5733
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/accountSummary', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_positionrisk(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5733, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__111, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5683
 *         return self._request_margin_api('get', 'sub-account/futures/account', True, data=params)
 * 
 *     def get_subaccount_futures_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Futures Account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_summary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5735
 *         return self._request_margin_api('get', 'sub-account/futures/accountSummary', True, data=params)
 * 
 *     def get_subaccount_futures_positionrisk(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Futures Position-Risk of Sub-account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_307get_subaccount_futures_positionrisk(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_306get_subaccount_futures_positionrisk, "Get Futures Position-Risk of Sub-account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#get-futures-position-risk-of-sub-account-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n                {\n                    \"entryPrice\": \"9975.12000\",\n                    \"leverage\": \"50\",              // current initial leverage\n                    \"maxNotional\": \"1000000\",      // notional value limit of current initial leverage\n                    \"liquidationPrice\": \"7963.54\",\n                    \"markPrice\": \"9973.50770517\",\n                    \"positionAmount\": \"0.010\",\n                    \"symbol\": \"BTCUSDT\",\n                    \"unrealizedProfit\": \"-0.01612295\"\n                }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_307get_subaccount_futures_positionrisk = {"get_subaccount_futures_positionrisk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_307get_subaccount_futures_positionrisk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_306get_subaccount_futures_positionrisk};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_307get_subaccount_futures_positionrisk(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_futures_positionrisk (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5735, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_futures_positionrisk") < 0)) __PYX_ERR(0, 5735, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_futures_positionrisk", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5735, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_positionrisk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_306get_subaccount_futures_positionrisk(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_306get_subaccount_futures_positionrisk(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_futures_positionrisk", 1);

  /* "unicorn_binance_rest_api/manager.py":5765
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/positionRisk', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_futures_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5765, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__112, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5735
 *         return self._request_margin_api('get', 'sub-account/futures/accountSummary', True, data=params)
 * 
 *     def get_subaccount_futures_positionrisk(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Futures Position-Risk of Sub-account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_futures_positionrisk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5767
 *         return self._request_margin_api('get', 'sub-account/futures/positionRisk', True, data=params)
 * 
 *     def make_subaccount_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Futures Transfer for Sub-account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_309make_subaccount_futures_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_308make_subaccount_futures_transfer, "Futures Transfer for Sub-account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#futures-transfer-for-sub-account-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param asset: required - The asset being transferred, e.g., USDT\n        :type asset: str\n        :param amount: required - The amount to be transferred\n        :type amount: float\n        :param type: required - 1: transfer from subaccount's spot account to its USDT-margined futures account\n                                2: transfer from subaccount's USDT-margined futures account to its spot account\n                                3: transfer from subaccount's spot account to its COIN-margined futures account\n                                4: transfer from subaccount's COIN-margined futures account to its spot account\n        :type type: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"txnId\":\"2966662589\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_309make_subaccount_futures_transfer = {"make_subaccount_futures_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_309make_subaccount_futures_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_308make_subaccount_futures_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_309make_subaccount_futures_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_subaccount_futures_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5767, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "make_subaccount_futures_transfer") < 0)) __PYX_ERR(0, 5767, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_subaccount_futures_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5767, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_futures_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_308make_subaccount_futures_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_308make_subaccount_futures_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_subaccount_futures_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":5795
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/futures/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_margin_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5795, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__113, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5767
 *         return self._request_margin_api('get', 'sub-account/futures/positionRisk', True, data=params)
 * 
 *     def make_subaccount_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Futures Transfer for Sub-account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_futures_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5797
 *         return self._request_margin_api('post', 'sub-account/futures/transfer', True, data=params)
 * 
 *     def make_subaccount_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Margin Transfer for Sub-account (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_311make_subaccount_margin_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_310make_subaccount_margin_transfer, "Margin Transfer for Sub-account (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#margin-transfer-for-sub-account-for-master-account\n\n        :param email: required - Sub account email\n        :type email: str\n        :param asset: required - The asset being transferred, e.g., USDT\n        :type asset: str\n        :param amount: required - The amount to be transferred\n        :type amount: float\n        :param type: required - 1: transfer from subaccount's spot account to margin account\n                                2: transfer from subaccount's margin account to its spot account\n        :type type: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"txnId\":\"2966662589\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_311make_subaccount_margin_transfer = {"make_subaccount_margin_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_311make_subaccount_margin_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_310make_subaccount_margin_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_311make_subaccount_margin_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_subaccount_margin_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5797, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "make_subaccount_margin_transfer") < 0)) __PYX_ERR(0, 5797, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_subaccount_margin_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5797, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_margin_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_310make_subaccount_margin_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_310make_subaccount_margin_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_subaccount_margin_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":5823
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/margin/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_to_subaccount_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5823, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__114, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5797
 *         return self._request_margin_api('post', 'sub-account/futures/transfer', True, data=params)
 * 
 *     def make_subaccount_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Margin Transfer for Sub-account (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_margin_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5825
 *         return self._request_margin_api('post', 'sub-account/margin/transfer', True, data=params)
 * 
 *     def make_subaccount_to_subaccount_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Sub-account of Same Master (For Sub-account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_313make_subaccount_to_subaccount_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_312make_subaccount_to_subaccount_transfer, "Transfer to Sub-account of Same Master (For Sub-account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#transfer-to-sub-account-of-same-master-for-sub-account\n\n        :param toEmail: required - Sub account email\n        :type toEmail: str\n        :param asset: required - The asset being transferred, e.g., USDT\n        :type asset: str\n        :param amount: required - The amount to be transferred\n        :type amount: float\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"txnId\":\"2966662589\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_313make_subaccount_to_subaccount_transfer = {"make_subaccount_to_subaccount_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_313make_subaccount_to_subaccount_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_312make_subaccount_to_subaccount_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_313make_subaccount_to_subaccount_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_subaccount_to_subaccount_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5825, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "make_subaccount_to_subaccount_transfer") < 0)) __PYX_ERR(0, 5825, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_subaccount_to_subaccount_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5825, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_to_subaccount_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_312make_subaccount_to_subaccount_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_312make_subaccount_to_subaccount_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_subaccount_to_subaccount_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":5850
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/transfer/subToSub', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_to_master_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5850, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__115, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5825
 *         return self._request_margin_api('post', 'sub-account/margin/transfer', True, data=params)
 * 
 *     def make_subaccount_to_subaccount_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Sub-account of Same Master (For Sub-account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_to_subaccount_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5852
 *         return self._request_margin_api('post', 'sub-account/transfer/subToSub', True, data=params)
 * 
 *     def make_subaccount_to_master_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Master (For Sub-account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_315make_subaccount_to_master_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_314make_subaccount_to_master_transfer, "Transfer to Master (For Sub-account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#transfer-to-master-for-sub-account\n\n        :param asset: required - The asset being transferred, e.g., USDT\n        :type asset: str\n        :param amount: required - The amount to be transferred\n        :type amount: float\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"txnId\":\"2966662589\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_315make_subaccount_to_master_transfer = {"make_subaccount_to_master_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_315make_subaccount_to_master_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_314make_subaccount_to_master_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_315make_subaccount_to_master_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_subaccount_to_master_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5852, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "make_subaccount_to_master_transfer") < 0)) __PYX_ERR(0, 5852, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_subaccount_to_master_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5852, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_to_master_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_314make_subaccount_to_master_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_314make_subaccount_to_master_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_subaccount_to_master_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":5875
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/transfer/subToMaster', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_transfer_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5875, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__116, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5852
 *         return self._request_margin_api('post', 'sub-account/transfer/subToSub', True, data=params)
 * 
 *     def make_subaccount_to_master_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Master (For Sub-account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_subaccount_to_master_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5877
 *         return self._request_margin_api('post', 'sub-account/transfer/subToMaster', True, data=params)
 * 
 *     def get_subaccount_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Subaccount Transfer History (For Sub-account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_317get_subaccount_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_316get_subaccount_transfer_history, "Subaccount Transfer History (For Sub-account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#transfer-to-master-for-sub-account\n\n        :param asset: required - The asset being transferred, e.g., USDT\n        :type asset: str\n        :param type: optional - 1: transfer in, 2: transfer out\n        :type type: int\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param limit: optional - Default 500\n        :type limit: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n              {\n                \"counterParty\":\"master\",\n                \"email\":\"master@test.com\",\n                \"type\":1,  // 1 for transfer in, 2 for transfer out\n                \"asset\":\"BTC\",\n                \"qty\":\"1\",\n                \"status\":\"SUCCESS\",\n                \"tranId\":11798835829,\n                \"time\":1544433325000\n              },\n              {\n                \"counterParty\":\"subAccount\",\n                \"email\":\"sub2@test.com\",\n                \"type\":2,\n                \"asset\":\"ETH\",\n                \"qty\":\"2\",\n                \"status\":\"SUCCESS\",\n                \"tranId\":11798829519,\n                \"time\":1544433326000\n              }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_317get_subaccount_transfer_history = {"get_subaccount_transfer_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_317get_subaccount_transfer_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_316get_subaccount_transfer_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_317get_subaccount_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_subaccount_transfer_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5877, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_subaccount_transfer_history") < 0)) __PYX_ERR(0, 5877, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_subaccount_transfer_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5877, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_316get_subaccount_transfer_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_316get_subaccount_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_subaccount_transfer_history", 1);

  /* "unicorn_binance_rest_api/manager.py":5925
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/transfer/subUserHistory', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_universal_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5925, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__117, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5877
 *         return self._request_margin_api('post', 'sub-account/transfer/subToMaster', True, data=params)
 * 
 *     def get_subaccount_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Subaccount Transfer History (For Sub-account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_subaccount_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5927
 *         return self._request_margin_api('get', 'sub-account/transfer/subUserHistory', True, data=params)
 * 
 *     def make_universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_319make_universal_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_318make_universal_transfer, "Universal Transfer (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#universal-transfer-for-master-account\n\n        :param fromEmail: optional\n        :type fromEmail: str\n        :param toEmail: optional\n        :type toEmail: str\n        :param fromAccountType: required - \"SPOT\",\"USDT_FUTURE\",\"COIN_FUTURE\"\n        :type fromAccountType: str\n        :param toAccountType: required - \"SPOT\",\"USDT_FUTURE\",\"COIN_FUTURE\"\n        :type toAccountType: str\n        :param asset: required - The asset being transferred, e.g., USDT\n        :type asset: str\n        :param amount: required\n        :type amount: float\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"tranId\":11945860693\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_319make_universal_transfer = {"make_universal_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_319make_universal_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_318make_universal_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_319make_universal_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_universal_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5927, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "make_universal_transfer") < 0)) __PYX_ERR(0, 5927, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("make_universal_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5927, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_universal_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_318make_universal_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_318make_universal_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_universal_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":5958
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/universalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_universal_transfer_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 5958, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__118, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5927
 *         return self._request_margin_api('get', 'sub-account/transfer/subUserHistory', True, data=params)
 * 
 *     def make_universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.make_universal_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":5960
 *         return self._request_margin_api('post', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_321get_universal_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_320get_universal_transfer_history, "Universal Transfer (For Master Account)\n\n        https://binance-docs.github.io/apidocs/spot/en/#query-universal-transfer-history\n\n        :param fromEmail: optional\n        :type fromEmail: str\n        :param toEmail: optional\n        :type toEmail: str\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param page: optional\n        :type page: int\n        :param limit: optional\n        :type limit: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            [\n              {\n                \"tranId\":11945860693,\n                \"fromEmail\":\"master@test.com\",\n                \"toEmail\":\"subaccount1@test.com\",\n                \"asset\":\"BTC\",\n                \"amount\":\"0.1\",\n                \"fromAccountType\":\"SPOT\",\n                \"toAccountType\":\"COIN_FUTURE\",\n                \"status\":\"SUCCESS\",\n                \"createTimeStamp\":1544433325000\n              },\n              {\n                \"tranId\":11945857955,\n                \"fromEmail\":\"master@test.com\",\n                \"toEmail\":\"subaccount2@test.com\",\n                \"asset\":\"ETH\",\n                \"amount\":\"0.2\",\n                \"fromAccountType\":\"SPOT\",\n                \"toAccountType\":\"USDT_FUTURE\",\n                \"status\":\"SUCCESS\",\n                \"createTimeStamp\":1544433326000\n              }\n            ]\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_321get_universal_transfer_history = {"get_universal_transfer_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_321get_universal_transfer_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_320get_universal_transfer_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_321get_universal_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_universal_transfer_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5960, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_universal_transfer_history") < 0)) __PYX_ERR(0, 5960, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_universal_transfer_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5960, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_universal_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_320get_universal_transfer_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_320get_universal_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_universal_transfer_history", 1);

  /* "unicorn_binance_rest_api/manager.py":6012
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/universalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_used_weight(self, make_new_request=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6012, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__119, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":5960
 *         return self._request_margin_api('post', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_universal_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6014
 *         return self._request_margin_api('get', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_used_weight(self, make_new_request=False):             # <<<<<<<<<<<<<<
 *         """Get the used weight from Binance endpoints
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_323get_used_weight(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_322get_used_weight, "Get the used weight from Binance endpoints\n\n        https://binance-docs.github.io/apidocs/spot/en/\n\n        :param make_new_request: Set to True to make a new request before returning the used_weight.\n        :type make_new_request: int\n\n        :return: int - used weight\n\n        .. code-block:: python\n\n            {\n             'weight': '5',\n             'timestamp': 1626079769.0,\n             'status_code': 200\n            }\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_323get_used_weight = {"get_used_weight", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_323get_used_weight, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_322get_used_weight};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_323get_used_weight(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_make_new_request = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_used_weight (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_make_new_request,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_False)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6014, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_make_new_request);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6014, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_used_weight") < 0)) __PYX_ERR(0, 6014, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_make_new_request = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_used_weight", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 6014, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_used_weight", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_322get_used_weight(__pyx_self, __pyx_v_self, __pyx_v_make_new_request);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_322get_used_weight(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_make_new_request) {
  PyObject *__pyx_v_binance_api_status = NULL;
  PyObject *__pyx_v_date_time_obj = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_used_weight", 1);

  /* "unicorn_binance_rest_api/manager.py":6032
 *             }
 *         """
 *         binance_api_status = {}             # <<<<<<<<<<<<<<
 *         if make_new_request is True:
 *             self.get_exchange_info()
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_binance_api_status = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6033
 *         """
 *         binance_api_status = {}
 *         if make_new_request is True:             # <<<<<<<<<<<<<<
 *             self.get_exchange_info()
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')
 */
  __pyx_t_2 = (__pyx_v_make_new_request == Py_True);
  if (__pyx_t_2) {

    /* "unicorn_binance_rest_api/manager.py":6034
 *         binance_api_status = {}
 *         if make_new_request is True:
 *             self.get_exchange_info()             # <<<<<<<<<<<<<<
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')
 *         binance_api_status['status_code'] = self.response.status_code
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_exchange_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6034, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "unicorn_binance_rest_api/manager.py":6033
 *         """
 *         binance_api_status = {}
 *         if make_new_request is True:             # <<<<<<<<<<<<<<
 *             self.get_exchange_info()
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')
 */
  }

  /* "unicorn_binance_rest_api/manager.py":6035
 *         if make_new_request is True:
 *             self.get_exchange_info()
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')             # <<<<<<<<<<<<<<
 *         binance_api_status['status_code'] = self.response.status_code
 *         try:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_response); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_headers); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_s_X_MBX_USED_WEIGHT};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6035, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_binance_api_status, __pyx_n_s_weight, __pyx_t_1) < 0))) __PYX_ERR(0, 6035, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6036
 *             self.get_exchange_info()
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')
 *         binance_api_status['status_code'] = self.response.status_code             # <<<<<<<<<<<<<<
 *         try:
 *             date_time_obj = datetime.datetime.strptime(self.response.headers.get('Date'), '%a, %d %b %Y %I:%M:%S %Z')
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_response); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_status_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely((PyDict_SetItem(__pyx_v_binance_api_status, __pyx_n_s_status_code, __pyx_t_3) < 0))) __PYX_ERR(0, 6036, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":6037
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')
 *         binance_api_status['status_code'] = self.response.status_code
 *         try:             # <<<<<<<<<<<<<<
 *             date_time_obj = datetime.datetime.strptime(self.response.headers.get('Date'), '%a, %d %b %Y %I:%M:%S %Z')
 *         except ValueError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "unicorn_binance_rest_api/manager.py":6038
 *         binance_api_status['status_code'] = self.response.status_code
 *         try:
 *             date_time_obj = datetime.datetime.strptime(self.response.headers.get('Date'), '%a, %d %b %Y %I:%M:%S %Z')             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             binance_api_status['timestamp'] = 0
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_datetime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6038, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_datetime); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6038, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_strptime); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6038, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_response); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6038, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_headers); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 6038, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_get); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 6038, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_n_s_Date};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6038, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_t_9 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_t_4, __pyx_kp_s_a_d_b_Y_I_M_S_Z};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6038, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_v_date_time_obj = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "unicorn_binance_rest_api/manager.py":6037
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')
 *         binance_api_status['status_code'] = self.response.status_code
 *         try:             # <<<<<<<<<<<<<<
 *             date_time_obj = datetime.datetime.strptime(self.response.headers.get('Date'), '%a, %d %b %Y %I:%M:%S %Z')
 *         except ValueError:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "unicorn_binance_rest_api/manager.py":6039
 *         try:
 *             date_time_obj = datetime.datetime.strptime(self.response.headers.get('Date'), '%a, %d %b %Y %I:%M:%S %Z')
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             binance_api_status['timestamp'] = 0
 *             return binance_api_status
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_5) {
      __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_used_weight", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_4) < 0) __PYX_ERR(0, 6039, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "unicorn_binance_rest_api/manager.py":6040
 *             date_time_obj = datetime.datetime.strptime(self.response.headers.get('Date'), '%a, %d %b %Y %I:%M:%S %Z')
 *         except ValueError:
 *             binance_api_status['timestamp'] = 0             # <<<<<<<<<<<<<<
 *             return binance_api_status
 *         binance_api_status['timestamp'] = date_time_obj.timestamp()
 */
      if (unlikely((PyDict_SetItem(__pyx_v_binance_api_status, __pyx_n_s_timestamp, __pyx_int_0) < 0))) __PYX_ERR(0, 6040, __pyx_L6_except_error)

      /* "unicorn_binance_rest_api/manager.py":6041
 *         except ValueError:
 *             binance_api_status['timestamp'] = 0
 *             return binance_api_status             # <<<<<<<<<<<<<<
 *         binance_api_status['timestamp'] = date_time_obj.timestamp()
 *         return binance_api_status
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_binance_api_status);
      __pyx_r = __pyx_v_binance_api_status;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L7_except_return;
    }
    goto __pyx_L6_except_error;

    /* "unicorn_binance_rest_api/manager.py":6037
 *         binance_api_status['weight'] = self.response.headers.get('X-MBX-USED-WEIGHT')
 *         binance_api_status['status_code'] = self.response.status_code
 *         try:             # <<<<<<<<<<<<<<
 *             date_time_obj = datetime.datetime.strptime(self.response.headers.get('Date'), '%a, %d %b %Y %I:%M:%S %Z')
 *         except ValueError:
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L7_except_return:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L0;
    __pyx_L9_try_end:;
  }

  /* "unicorn_binance_rest_api/manager.py":6042
 *             binance_api_status['timestamp'] = 0
 *             return binance_api_status
 *         binance_api_status['timestamp'] = date_time_obj.timestamp()             # <<<<<<<<<<<<<<
 *         return binance_api_status
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_date_time_obj, __pyx_n_s_timestamp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 6042, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_binance_api_status, __pyx_n_s_timestamp, __pyx_t_4) < 0))) __PYX_ERR(0, 6042, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "unicorn_binance_rest_api/manager.py":6043
 *             return binance_api_status
 *         binance_api_status['timestamp'] = date_time_obj.timestamp()
 *         return binance_api_status             # <<<<<<<<<<<<<<
 * 
 *     # Futures API
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_binance_api_status);
  __pyx_r = __pyx_v_binance_api_status;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6014
 *         return self._request_margin_api('get', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_used_weight(self, make_new_request=False):             # <<<<<<<<<<<<<<
 *         """Get the used weight from Binance endpoints
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_used_weight", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_binance_api_status);
  __Pyx_XDECREF(__pyx_v_date_time_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6047
 *     # Futures API
 * 
 *     def futures_ping(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_325futures_ping(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_324futures_ping, "Test connectivity to the Rest API\n\n        https://binance-docs.github.io/apidocs/futures/en/#test-connectivity\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_325futures_ping = {"futures_ping", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_325futures_ping, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_324futures_ping};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_325futures_ping(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_ping (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6047, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_ping") < 0)) __PYX_ERR(0, 6047, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_ping", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6047, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_ping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_324futures_ping(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_324futures_ping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_ping", 1);

  /* "unicorn_binance_rest_api/manager.py":6053
 * 
 *         """
 *         return self._request_futures_api('get', 'ping')             # <<<<<<<<<<<<<<
 * 
 *     def futures_time(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6047
 *     # Futures API
 * 
 *     def futures_ping(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_ping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6055
 *         return self._request_futures_api('get', 'ping')
 * 
 *     def futures_time(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API and get the current server time.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_327futures_time(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_326futures_time, "Test connectivity to the Rest API and get the current server time.\n\n        https://binance-docs.github.io/apidocs/futures/en/#check-server-time\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_327futures_time = {"futures_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_327futures_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_326futures_time};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_327futures_time(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_time (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6055, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_time") < 0)) __PYX_ERR(0, 6055, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_time", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6055, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_326futures_time(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_326futures_time(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_time", 1);

  /* "unicorn_binance_rest_api/manager.py":6061
 * 
 *         """
 *         return self._request_futures_api('get', 'time')             # <<<<<<<<<<<<<<
 * 
 *     def futures_exchange_info(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__121, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6055
 *         return self._request_futures_api('get', 'ping')
 * 
 *     def futures_time(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API and get the current server time.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6063
 *         return self._request_futures_api('get', 'time')
 * 
 *     def futures_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """Current exchange trading rules and symbol information
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_329futures_exchange_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_328futures_exchange_info, "Current exchange trading rules and symbol information\n\n        https://binance-docs.github.io/apidocs/futures/en/#exchange-information-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_329futures_exchange_info = {"futures_exchange_info", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_329futures_exchange_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_328futures_exchange_info};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_329futures_exchange_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_exchange_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6063, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_exchange_info") < 0)) __PYX_ERR(0, 6063, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_exchange_info", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6063, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_exchange_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_328futures_exchange_info(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_328futures_exchange_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_exchange_info", 1);

  /* "unicorn_binance_rest_api/manager.py":6069
 * 
 *         """
 *         return self._request_futures_api('get', 'exchangeInfo')             # <<<<<<<<<<<<<<
 * 
 *     def futures_order_book(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__122, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6063
 *         return self._request_futures_api('get', 'time')
 * 
 *     def futures_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """Current exchange trading rules and symbol information
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_exchange_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6071
 *         return self._request_futures_api('get', 'exchangeInfo')
 * 
 *     def futures_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """Get the Order Book for the market
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_331futures_order_book(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_330futures_order_book, "Get the Order Book for the market\n\n        https://binance-docs.github.io/apidocs/futures/en/#order-book-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_331futures_order_book = {"futures_order_book", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_331futures_order_book, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_330futures_order_book};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_331futures_order_book(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_order_book (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6071, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_order_book") < 0)) __PYX_ERR(0, 6071, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_order_book", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6071, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_order_book", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_330futures_order_book(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_330futures_order_book(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_order_book", 1);

  /* "unicorn_binance_rest_api/manager.py":6077
 * 
 *         """
 *         return self._request_futures_api('get', 'depth', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_recent_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6077, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__123, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6071
 *         return self._request_futures_api('get', 'exchangeInfo')
 * 
 *     def futures_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """Get the Order Book for the market
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_order_book", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6079
 *         return self._request_futures_api('get', 'depth', data=params)
 * 
 *     def futures_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_333futures_recent_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_332futures_recent_trades, "Get recent trades (up to last 500).\n\n        https://binance-docs.github.io/apidocs/futures/en/#recent-trades-list-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_333futures_recent_trades = {"futures_recent_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_333futures_recent_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_332futures_recent_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_333futures_recent_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_recent_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6079, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_recent_trades") < 0)) __PYX_ERR(0, 6079, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_recent_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6079, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_recent_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_332futures_recent_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_332futures_recent_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_recent_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6085
 * 
 *         """
 *         return self._request_futures_api('get', 'trades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_historical_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6085, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__124, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6079
 *         return self._request_futures_api('get', 'depth', data=params)
 * 
 *     def futures_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_recent_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6087
 *         return self._request_futures_api('get', 'trades', data=params)
 * 
 *     def futures_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get older market historical trades.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_335futures_historical_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_334futures_historical_trades, "Get older market historical trades.\n\n        https://binance-docs.github.io/apidocs/futures/en/#old-trades-lookup-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_335futures_historical_trades = {"futures_historical_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_335futures_historical_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_334futures_historical_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_335futures_historical_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_historical_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6087, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_historical_trades") < 0)) __PYX_ERR(0, 6087, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_historical_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6087, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_historical_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_334futures_historical_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_334futures_historical_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_historical_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6093
 * 
 *         """
 *         return self._request_futures_api('get', 'historicalTrades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_aggregate_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6093, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__125, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6087
 *         return self._request_futures_api('get', 'trades', data=params)
 * 
 *     def futures_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get older market historical trades.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_historical_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6095
 *         return self._request_futures_api('get', 'historicalTrades', data=params)
 * 
 *     def futures_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 *         price will have the quantity aggregated.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_337futures_aggregate_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_336futures_aggregate_trades, "Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same\n        price will have the quantity aggregated.\n\n        https://binance-docs.github.io/apidocs/futures/en/#compressed-aggregate-trades-list-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_337futures_aggregate_trades = {"futures_aggregate_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_337futures_aggregate_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_336futures_aggregate_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_337futures_aggregate_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_aggregate_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6095, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_aggregate_trades") < 0)) __PYX_ERR(0, 6095, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_aggregate_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6095, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_aggregate_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_336futures_aggregate_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_336futures_aggregate_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_aggregate_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6102
 * 
 *         """
 *         return self._request_futures_api('get', 'aggTrades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_klines(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6102, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__126, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6095
 *         return self._request_futures_api('get', 'historicalTrades', data=params)
 * 
 *     def futures_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 *         price will have the quantity aggregated.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_aggregate_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6104
 *         return self._request_futures_api('get', 'aggTrades', data=params)
 * 
 *     def futures_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_339futures_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_338futures_klines, "Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.\n\n        https://binance-docs.github.io/apidocs/futures/en/#kline-candlestick-data-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_339futures_klines = {"futures_klines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_339futures_klines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_338futures_klines};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_339futures_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_klines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6104, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_klines") < 0)) __PYX_ERR(0, 6104, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_klines", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6104, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_338futures_klines(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_338futures_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_klines", 1);

  /* "unicorn_binance_rest_api/manager.py":6110
 * 
 *         """
 *         return self._request_futures_api('get', 'klines', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_mark_price(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6110, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__127, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6104
 *         return self._request_futures_api('get', 'aggTrades', data=params)
 * 
 *     def futures_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6112
 *         return self._request_futures_api('get', 'klines', data=params)
 * 
 *     def futures_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Mark Price and Funding Rate
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_341futures_mark_price(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_340futures_mark_price, "Get Mark Price and Funding Rate\n\n        https://binance-docs.github.io/apidocs/futures/en/#mark-price-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_341futures_mark_price = {"futures_mark_price", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_341futures_mark_price, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_340futures_mark_price};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_341futures_mark_price(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_mark_price (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6112, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_mark_price") < 0)) __PYX_ERR(0, 6112, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_mark_price", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6112, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_mark_price", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_340futures_mark_price(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_340futures_mark_price(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_mark_price", 1);

  /* "unicorn_binance_rest_api/manager.py":6118
 * 
 *         """
 *         return self._request_futures_api('get', 'premiumIndex', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_funding_rate(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6118, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__128, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6112
 *         return self._request_futures_api('get', 'klines', data=params)
 * 
 *     def futures_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Mark Price and Funding Rate
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_mark_price", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6120
 *         return self._request_futures_api('get', 'premiumIndex', data=params)
 * 
 *     def futures_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_343futures_funding_rate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_342futures_funding_rate, "Get funding rate history\n\n        https://binance-docs.github.io/apidocs/futures/en/#get-funding-rate-history-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_343futures_funding_rate = {"futures_funding_rate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_343futures_funding_rate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_342futures_funding_rate};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_343futures_funding_rate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_funding_rate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6120, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_funding_rate") < 0)) __PYX_ERR(0, 6120, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_funding_rate", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6120, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_funding_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_342futures_funding_rate(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_342futures_funding_rate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_funding_rate", 1);

  /* "unicorn_binance_rest_api/manager.py":6126
 * 
 *         """
 *         return self._request_futures_api('get', 'fundingRate', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6126, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__129, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6120
 *         return self._request_futures_api('get', 'premiumIndex', data=params)
 * 
 *     def futures_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_funding_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6128
 *         return self._request_futures_api('get', 'fundingRate', data=params)
 * 
 *     def futures_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour rolling window price change statistics.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_345futures_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_344futures_ticker, "24 hour rolling window price change statistics.\n\n        https://binance-docs.github.io/apidocs/futures/en/#24hr-ticker-price-change-statistics-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_345futures_ticker = {"futures_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_345futures_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_344futures_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_345futures_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6128, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_ticker") < 0)) __PYX_ERR(0, 6128, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6128, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_344futures_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_344futures_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":6134
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/24hr', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_symbol_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6134, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__130, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6128
 *         return self._request_futures_api('get', 'fundingRate', data=params)
 * 
 *     def futures_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour rolling window price change statistics.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6136
 *         return self._request_futures_api('get', 'ticker/24hr', data=params)
 * 
 *     def futures_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_347futures_symbol_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_346futures_symbol_ticker, "Latest price for a symbol or symbols.\n\n        https://binance-docs.github.io/apidocs/futures/en/#symbol-price-ticker-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_347futures_symbol_ticker = {"futures_symbol_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_347futures_symbol_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_346futures_symbol_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_347futures_symbol_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_symbol_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6136, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_symbol_ticker") < 0)) __PYX_ERR(0, 6136, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_symbol_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6136, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_symbol_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_346futures_symbol_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_346futures_symbol_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_symbol_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":6142
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/price', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_orderbook_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6142, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__131, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6136
 *         return self._request_futures_api('get', 'ticker/24hr', data=params)
 * 
 *     def futures_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_symbol_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6144
 *         return self._request_futures_api('get', 'ticker/price', data=params)
 * 
 *     def futures_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Best price/qty on the order book for a symbol or symbols.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_349futures_orderbook_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_348futures_orderbook_ticker, "Best price/qty on the order book for a symbol or symbols.\n\n        https://binance-docs.github.io/apidocs/futures/en/#symbol-order-book-ticker-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_349futures_orderbook_ticker = {"futures_orderbook_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_349futures_orderbook_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_348futures_orderbook_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_349futures_orderbook_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_orderbook_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6144, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_orderbook_ticker") < 0)) __PYX_ERR(0, 6144, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_orderbook_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6144, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_orderbook_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_348futures_orderbook_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_348futures_orderbook_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_orderbook_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":6150
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/bookTicker', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_liquidation_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6150, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__132, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6144
 *         return self._request_futures_api('get', 'ticker/price', data=params)
 * 
 *     def futures_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Best price/qty on the order book for a symbol or symbols.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_orderbook_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6152
 *         return self._request_futures_api('get', 'ticker/bookTicker', data=params)
 * 
 *     def futures_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all liquidation orders
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_351futures_liquidation_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_350futures_liquidation_orders, "Get all liquidation orders\n\n        https://binance-docs.github.io/apidocs/futures/en/#get-all-liquidation-orders-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_351futures_liquidation_orders = {"futures_liquidation_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_351futures_liquidation_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_350futures_liquidation_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_351futures_liquidation_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_liquidation_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6152, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_liquidation_orders") < 0)) __PYX_ERR(0, 6152, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_liquidation_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6152, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_liquidation_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_350futures_liquidation_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_350futures_liquidation_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_liquidation_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6158
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/allForceOrders', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_open_interest(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6158, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__133, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6152
 *         return self._request_futures_api('get', 'ticker/bookTicker', data=params)
 * 
 *     def futures_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all liquidation orders
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_liquidation_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6160
 *         return self._request_futures_api('get', 'ticker/allForceOrders', data=params)
 * 
 *     def futures_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """Get present open interest of a specific symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_353futures_open_interest(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_352futures_open_interest, "Get present open interest of a specific symbol.\n\n        https://binance-docs.github.io/apidocs/futures/en/#open-interest-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_353futures_open_interest = {"futures_open_interest", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_353futures_open_interest, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_352futures_open_interest};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_353futures_open_interest(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_open_interest (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6160, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_open_interest") < 0)) __PYX_ERR(0, 6160, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_open_interest", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6160, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_open_interest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_352futures_open_interest(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_352futures_open_interest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_open_interest", 1);

  /* "unicorn_binance_rest_api/manager.py":6166
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/openInterest', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_open_interest_hist(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6166, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__134, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6160
 *         return self._request_futures_api('get', 'ticker/allForceOrders', data=params)
 * 
 *     def futures_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """Get present open interest of a specific symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_open_interest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6168
 *         return self._request_futures_api('get', 'ticker/openInterest', data=params)
 * 
 *     def futures_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """Get open interest statistics of a specific symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_355futures_open_interest_hist(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_354futures_open_interest_hist, "Get open interest statistics of a specific symbol.\n\n        https://binance-docs.github.io/apidocs/futures/en/#open-interest-statistics\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_355futures_open_interest_hist = {"futures_open_interest_hist", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_355futures_open_interest_hist, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_354futures_open_interest_hist};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_355futures_open_interest_hist(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_open_interest_hist (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6168, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_open_interest_hist") < 0)) __PYX_ERR(0, 6168, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_open_interest_hist", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6168, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_open_interest_hist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_354futures_open_interest_hist(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_354futures_open_interest_hist(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_open_interest_hist", 1);

  /* "unicorn_binance_rest_api/manager.py":6174
 * 
 *         """
 *         return self._request_futures_data_api('get', 'openInterestHist', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_leverage_bracket(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_data_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6174, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__135, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6168
 *         return self._request_futures_api('get', 'ticker/openInterest', data=params)
 * 
 *     def futures_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """Get open interest statistics of a specific symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_open_interest_hist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6176
 *         return self._request_futures_data_api('get', 'openInterestHist', data=params)
 * 
 *     def futures_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """Notional and Leverage Brackets
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_357futures_leverage_bracket(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_356futures_leverage_bracket, "Notional and Leverage Brackets\n\n        https://binance-docs.github.io/apidocs/futures/en/#notional-and-leverage-brackets-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_357futures_leverage_bracket = {"futures_leverage_bracket", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_357futures_leverage_bracket, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_356futures_leverage_bracket};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_357futures_leverage_bracket(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_leverage_bracket (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6176, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_leverage_bracket") < 0)) __PYX_ERR(0, 6176, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_leverage_bracket", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6176, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_leverage_bracket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_356futures_leverage_bracket(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_356futures_leverage_bracket(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_leverage_bracket", 1);

  /* "unicorn_binance_rest_api/manager.py":6182
 * 
 *         """
 *         return self._request_futures_api('get', 'leverageBracket', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account_transfer(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6182, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__136, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6176
 *         return self._request_futures_data_api('get', 'openInterestHist', data=params)
 * 
 *     def futures_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """Notional and Leverage Brackets
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_leverage_bracket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6184
 *         return self._request_futures_api('get', 'leverageBracket', True, data=params)
 * 
 *     def futures_account_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and futures account.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_359futures_account_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_358futures_account_transfer, "Execute transfer between spot account and futures account.\n\n        https://binance-docs.github.io/apidocs/futures/en/#new-future-account-transfer\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_359futures_account_transfer = {"futures_account_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_359futures_account_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_358futures_account_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_359futures_account_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_account_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6184, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_account_transfer") < 0)) __PYX_ERR(0, 6184, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_account_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6184, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_358futures_account_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_358futures_account_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_account_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":6190
 * 
 *         """
 *         return self._request_margin_api('post', 'futures/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_auto_cancel_all_open_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6190, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__137, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6184
 *         return self._request_futures_api('get', 'leverageBracket', True, data=params)
 * 
 *     def futures_account_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and futures account.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6192
 *         return self._request_margin_api('post', 'futures/transfer', True, data=params)
 * 
 *     def futures_auto_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open orders of the specified symbol at the end of the specified countdown.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_361futures_auto_cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_360futures_auto_cancel_all_open_orders, "\n        Cancel all open orders of the specified symbol at the end of the specified countdown.\n\n        https://binance-docs.github.io/apidocs/futures/en/#auto-cancel-all-open-orders-trade\n\n        :param symbol: mandatory\n        :type symbol: str\n        :param countdownTime: mandatory\n        :type countdownTime: int\n        :param recvWindow: optional\n        :type recvWindow: int\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"symbol\": \"BTCUSDT\",\n                \"countdownTime\": \"100000\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_361futures_auto_cancel_all_open_orders = {"futures_auto_cancel_all_open_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_361futures_auto_cancel_all_open_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_360futures_auto_cancel_all_open_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_361futures_auto_cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_auto_cancel_all_open_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6192, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_auto_cancel_all_open_orders") < 0)) __PYX_ERR(0, 6192, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_auto_cancel_all_open_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6192, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_auto_cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_360futures_auto_cancel_all_open_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_360futures_auto_cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_auto_cancel_all_open_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6216
 * 
 *         """
 *         return self._request_futures_api('post', 'countdownCancelAll', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_commission_rate(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6216, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__138, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6192
 *         return self._request_margin_api('post', 'futures/transfer', True, data=params)
 * 
 *     def futures_auto_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open orders of the specified symbol at the end of the specified countdown.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_auto_cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6218
 *         return self._request_futures_api('post', 'countdownCancelAll', True, data=params)
 * 
 *     def futures_commission_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get commission rate (user data)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_363futures_commission_rate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_362futures_commission_rate, "Get commission rate (user data)\n\n        https://binance-docs.github.io/apidocs/futures/en/#user-commission-rate-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_363futures_commission_rate = {"futures_commission_rate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_363futures_commission_rate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_362futures_commission_rate};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_363futures_commission_rate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_commission_rate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6218, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_commission_rate") < 0)) __PYX_ERR(0, 6218, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_commission_rate", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6218, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_commission_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_362futures_commission_rate(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_362futures_commission_rate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_commission_rate", 1);

  /* "unicorn_binance_rest_api/manager.py":6224
 * 
 *         """
 *         return self._request_futures_coin_api("get", "commissionRate", version=1, signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_int_1) < 0) __PYX_ERR(0, 6224, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6224, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6224, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__139, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6218
 *         return self._request_futures_api('post', 'countdownCancelAll', True, data=params)
 * 
 *     def futures_commission_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get commission rate (user data)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_commission_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6226
 *         return self._request_futures_coin_api("get", "commissionRate", version=1, signed=True, data=params)
 * 
 *     def transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get future account transaction history list
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_365transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_364transfer_history, "Get future account transaction history list\n\n        https://binance-docs.github.io/apidocs/futures/en/#get-future-account-transaction-history-list-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_365transfer_history = {"transfer_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_365transfer_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_364transfer_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_365transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transfer_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6226, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "transfer_history") < 0)) __PYX_ERR(0, 6226, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transfer_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6226, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_364transfer_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_364transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transfer_history", 1);

  /* "unicorn_binance_rest_api/manager.py":6232
 * 
 *         """
 *         return self._request_margin_api('get', 'futures/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_create_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6232, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__140, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6226
 *         return self._request_futures_coin_api("get", "commissionRate", version=1, signed=True, data=params)
 * 
 *     def transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get future account transaction history list
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6234
 *         return self._request_margin_api('get', 'futures/transfer', True, data=params)
 * 
 *     def futures_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_367futures_create_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_366futures_create_order, "Send in a new order.\n\n        https://binance-docs.github.io/apidocs/futures/en/#new-order-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_367futures_create_order = {"futures_create_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_367futures_create_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_366futures_create_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_367futures_create_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_create_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6234, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_create_order") < 0)) __PYX_ERR(0, 6234, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_create_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6234, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_create_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_366futures_create_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_366futures_create_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_create_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6240
 * 
 *         """
 *         return self._request_futures_api('post', 'order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_place_batch_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6240, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__141, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6234
 *         return self._request_margin_api('get', 'futures/transfer', True, data=params)
 * 
 *     def futures_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_create_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6242
 *         return self._request_futures_api('post', 'order', True, data=params)
 * 
 *     def futures_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_369futures_place_batch_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_368futures_place_batch_order, "Send in new orders.\n        https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade\n        To avoid modifying the existing signature generation and parameter order logic,\n        the url encoding is done on the special query param, batchOrders, in the early stage.\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_369futures_place_batch_order = {"futures_place_batch_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_369futures_place_batch_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_368futures_place_batch_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_369futures_place_batch_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_place_batch_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6242, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_place_batch_order") < 0)) __PYX_ERR(0, 6242, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_place_batch_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6242, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_place_batch_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_368futures_place_batch_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_368futures_place_batch_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_query_string = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_place_batch_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6248
 *         the url encoding is done on the special query param, batchOrders, in the early stage.
 *         """
 *         query_string = urlencode(params)             # <<<<<<<<<<<<<<
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_urlencode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_params};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_query_string = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6249
 *         """
 *         query_string = urlencode(params)
 *         query_string = query_string.replace('%27', '%22')             # <<<<<<<<<<<<<<
 *         params['batchOrders'] = query_string[12:]
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_query_string, __pyx_n_s_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__142, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_query_string, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":6250
 *         query_string = urlencode(params)
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]             # <<<<<<<<<<<<<<
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_query_string, 12, 0, NULL, NULL, &__pyx_slice__143, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_batchOrders, __pyx_t_2) < 0))) __PYX_ERR(0, 6250, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":6251
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6251, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__144, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6242
 *         return self._request_futures_api('post', 'order', True, data=params)
 * 
 *     def futures_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_place_batch_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_query_string);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6253
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_371futures_get_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_370futures_get_order, "\n        Check an order's status.\n\n        https://binance-docs.github.io/apidocs/futures/en/#query-order-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_371futures_get_order = {"futures_get_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_371futures_get_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_370futures_get_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_371futures_get_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_get_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6253, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_get_order") < 0)) __PYX_ERR(0, 6253, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_get_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6253, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_370futures_get_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_370futures_get_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_get_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6260
 * 
 *         """
 *         return self._request_futures_api('get', 'order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_open_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6260, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__145, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6253
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6262
 *         return self._request_futures_api('get', 'order', True, data=params)
 * 
 *     def futures_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_373futures_get_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_372futures_get_open_orders, "\n        Get all open orders on a symbol.\n\n        https://binance-docs.github.io/apidocs/futures/en/#current-open-orders-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_373futures_get_open_orders = {"futures_get_open_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_373futures_get_open_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_372futures_get_open_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_373futures_get_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_get_open_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6262, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_get_open_orders") < 0)) __PYX_ERR(0, 6262, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_get_open_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6262, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_372futures_get_open_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_372futures_get_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_get_open_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6269
 * 
 *         """
 *         return self._request_futures_api('get', 'openOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_all_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6269, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__146, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6262
 *         return self._request_futures_api('get', 'order', True, data=params)
 * 
 *     def futures_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6271
 *         return self._request_futures_api('get', 'openOrders', True, data=params)
 * 
 *     def futures_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_375futures_get_all_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_374futures_get_all_orders, "\n        Get all futures account orders; active, canceled, or filled.\n\n        https://binance-docs.github.io/apidocs/futures/en/#all-orders-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_375futures_get_all_orders = {"futures_get_all_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_375futures_get_all_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_374futures_get_all_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_375futures_get_all_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_get_all_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6271, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_get_all_orders") < 0)) __PYX_ERR(0, 6271, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_get_all_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6271, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_all_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_374futures_get_all_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_374futures_get_all_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_get_all_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6278
 * 
 *         """
 *         return self._request_futures_api('get', 'allOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_cancel_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6278, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__147, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6271
 *         return self._request_futures_api('get', 'openOrders', True, data=params)
 * 
 *     def futures_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_all_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6280
 *         return self._request_futures_api('get', 'allOrders', True, data=params)
 * 
 *     def futures_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_377futures_cancel_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_376futures_cancel_order, "\n        Cancel an active futures order.\n\n        https://binance-docs.github.io/apidocs/futures/en/#cancel-order-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_377futures_cancel_order = {"futures_cancel_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_377futures_cancel_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_376futures_cancel_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_377futures_cancel_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_cancel_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6280, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_cancel_order") < 0)) __PYX_ERR(0, 6280, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_cancel_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6280, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_cancel_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_376futures_cancel_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_376futures_cancel_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_cancel_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6287
 * 
 *         """
 *         return self._request_futures_api('delete', 'order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_cancel_all_open_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6287, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__148, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6280
 *         return self._request_futures_api('get', 'allOrders', True, data=params)
 * 
 *     def futures_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_cancel_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6289
 *         return self._request_futures_api('delete', 'order', True, data=params)
 * 
 *     def futures_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_379futures_cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_378futures_cancel_all_open_orders, "\n        Cancel all open futures orders\n\n        https://binance-docs.github.io/apidocs/futures/en/#cancel-all-open-orders-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_379futures_cancel_all_open_orders = {"futures_cancel_all_open_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_379futures_cancel_all_open_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_378futures_cancel_all_open_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_379futures_cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_cancel_all_open_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6289, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_cancel_all_open_orders") < 0)) __PYX_ERR(0, 6289, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_cancel_all_open_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6289, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_378futures_cancel_all_open_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_378futures_cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_cancel_all_open_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6296
 * 
 *         """
 *         return self._request_futures_api('delete', 'allOpenOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_cancel_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6296, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__149, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6289
 *         return self._request_futures_api('delete', 'order', True, data=params)
 * 
 *     def futures_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6298
 *         return self._request_futures_api('delete', 'allOpenOrders', True, data=params)
 * 
 *     def futures_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_381futures_cancel_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_380futures_cancel_orders, "\n        Cancel multiple futures orders\n\n        https://binance-docs.github.io/apidocs/futures/en/#cancel-multiple-orders-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_381futures_cancel_orders = {"futures_cancel_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_381futures_cancel_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_380futures_cancel_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_381futures_cancel_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_cancel_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6298, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_cancel_orders") < 0)) __PYX_ERR(0, 6298, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_cancel_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6298, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_cancel_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_380futures_cancel_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_380futures_cancel_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_cancel_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6305
 * 
 *         """
 *         return self._request_futures_api('delete', 'batchOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account_balance(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6305, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__150, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6298
 *         return self._request_futures_api('delete', 'allOpenOrders', True, data=params)
 * 
 *     def futures_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_cancel_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6307
 *         return self._request_futures_api('delete', 'batchOrders', True, data=params)
 * 
 *     def futures_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_383futures_account_balance(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_382futures_account_balance, "\n        Get futures account balance\n\n        https://binance-docs.github.io/apidocs/futures/en/#future-account-balance-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_383futures_account_balance = {"futures_account_balance", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_383futures_account_balance, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_382futures_account_balance};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_383futures_account_balance(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_account_balance (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6307, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_account_balance") < 0)) __PYX_ERR(0, 6307, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_account_balance", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6307, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account_balance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_382futures_account_balance(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_382futures_account_balance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_account_balance", 1);

  /* "unicorn_binance_rest_api/manager.py":6314
 * 
 *         """
 *         return self._request_futures_api('get', 'balance', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6314, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__151, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6307
 *         return self._request_futures_api('delete', 'batchOrders', True, data=params)
 * 
 *     def futures_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account_balance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6316
 *         return self._request_futures_api('get', 'balance', True, data=params)
 * 
 *     def futures_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_385futures_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_384futures_account, "\n        Get current account information.\n\n        https://binance-docs.github.io/apidocs/futures/en/#account-information-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_385futures_account = {"futures_account", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_385futures_account, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_384futures_account};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_385futures_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_account (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6316, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_account") < 0)) __PYX_ERR(0, 6316, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_account", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6316, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_384futures_account(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_384futures_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_account", 1);

  /* "unicorn_binance_rest_api/manager.py":6323
 * 
 *         """
 *         return self._request_futures_api('get', 'account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_leverage(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6323, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__152, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6316
 *         return self._request_futures_api('get', 'balance', True, data=params)
 * 
 *     def futures_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6325
 *         return self._request_futures_api('get', 'account', True, data=params)
 * 
 *     def futures_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_387futures_change_leverage(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_386futures_change_leverage, "\n        Change user's initial leverage of specific symbol market\n\n        https://binance-docs.github.io/apidocs/futures/en/#change-initial-leverage-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_387futures_change_leverage = {"futures_change_leverage", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_387futures_change_leverage, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_386futures_change_leverage};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_387futures_change_leverage(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_change_leverage (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6325, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_change_leverage") < 0)) __PYX_ERR(0, 6325, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_change_leverage", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6325, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_leverage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_386futures_change_leverage(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_386futures_change_leverage(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_change_leverage", 1);

  /* "unicorn_binance_rest_api/manager.py":6332
 * 
 *         """
 *         return self._request_futures_api('post', 'leverage', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_margin_type(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6332, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__153, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6325
 *         return self._request_futures_api('get', 'account', True, data=params)
 * 
 *     def futures_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_leverage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6334
 *         return self._request_futures_api('post', 'leverage', True, data=params)
 * 
 *     def futures_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """Change the margin type for a symbol
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_389futures_change_margin_type(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_388futures_change_margin_type, "Change the margin type for a symbol\n\n        https://binance-docs.github.io/apidocs/futures/en/#change-margin-type-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_389futures_change_margin_type = {"futures_change_margin_type", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_389futures_change_margin_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_388futures_change_margin_type};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_389futures_change_margin_type(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_change_margin_type (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6334, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_change_margin_type") < 0)) __PYX_ERR(0, 6334, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_change_margin_type", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6334, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_margin_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_388futures_change_margin_type(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_388futures_change_margin_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_change_margin_type", 1);

  /* "unicorn_binance_rest_api/manager.py":6340
 * 
 *         """
 *         return self._request_futures_api('post', 'marginType', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_position_margin(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6340, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__154, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6334
 *         return self._request_futures_api('post', 'leverage', True, data=params)
 * 
 *     def futures_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """Change the margin type for a symbol
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_margin_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6342
 *         return self._request_futures_api('post', 'marginType', True, data=params)
 * 
 *     def futures_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_391futures_change_position_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_390futures_change_position_margin, "\n        Change the position margin for a symbol\n\n        https://binance-docs.github.io/apidocs/futures/en/#modify-isolated-position-margin-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_391futures_change_position_margin = {"futures_change_position_margin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_391futures_change_position_margin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_390futures_change_position_margin};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_391futures_change_position_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_change_position_margin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6342, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_change_position_margin") < 0)) __PYX_ERR(0, 6342, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_change_position_margin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6342, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_position_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_390futures_change_position_margin(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_390futures_change_position_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_change_position_margin", 1);

  /* "unicorn_binance_rest_api/manager.py":6349
 * 
 *         """
 *         return self._request_futures_api('post', 'positionMargin', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_position_margin_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6349, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__155, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6342
 *         return self._request_futures_api('post', 'marginType', True, data=params)
 * 
 *     def futures_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_position_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6351
 *         return self._request_futures_api('post', 'positionMargin', True, data=params)
 * 
 *     def futures_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position margin change history
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_393futures_position_margin_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_392futures_position_margin_history, "\n        Get position margin change history\n\n        https://binance-docs.github.io/apidocs/futures/en/#get-postion-margin-change-history-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_393futures_position_margin_history = {"futures_position_margin_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_393futures_position_margin_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_392futures_position_margin_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_393futures_position_margin_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_position_margin_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6351, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_position_margin_history") < 0)) __PYX_ERR(0, 6351, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_position_margin_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6351, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_position_margin_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_392futures_position_margin_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_392futures_position_margin_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_position_margin_history", 1);

  /* "unicorn_binance_rest_api/manager.py":6358
 * 
 *         """
 *         return self._request_futures_api('get', 'positionMargin/history', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_position_information(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6358, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__156, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6351
 *         return self._request_futures_api('post', 'positionMargin', True, data=params)
 * 
 *     def futures_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position margin change history
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_position_margin_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6360
 *         return self._request_futures_api('get', 'positionMargin/history', True, data=params)
 * 
 *     def futures_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_395futures_position_information(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_394futures_position_information, "\n        Get position information\n\n        https://binance-docs.github.io/apidocs/futures/en/#position-information-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_395futures_position_information = {"futures_position_information", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_395futures_position_information, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_394futures_position_information};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_395futures_position_information(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_position_information (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6360, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_position_information") < 0)) __PYX_ERR(0, 6360, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_position_information", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6360, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_position_information", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_394futures_position_information(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_394futures_position_information(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_position_information", 1);

  /* "unicorn_binance_rest_api/manager.py":6367
 * 
 *         """
 *         return self._request_futures_api('get', 'positionRisk', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6367, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__157, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6360
 *         return self._request_futures_api('get', 'positionMargin/history', True, data=params)
 * 
 *     def futures_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_position_information", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6369
 *         return self._request_futures_api('get', 'positionRisk', True, data=params)
 * 
 *     def futures_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get trades for the authenticated account and symbol.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_397futures_account_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_396futures_account_trades, "\n        Get trades for the authenticated account and symbol.\n\n        https://binance-docs.github.io/apidocs/futures/en/#account-trade-list-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_397futures_account_trades = {"futures_account_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_397futures_account_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_396futures_account_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_397futures_account_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_account_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6369, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_account_trades") < 0)) __PYX_ERR(0, 6369, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_account_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6369, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_396futures_account_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_396futures_account_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_account_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6376
 * 
 *         """
 *         return self._request_futures_api('get', 'userTrades', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_income_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6376, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__158, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6369
 *         return self._request_futures_api('get', 'positionRisk', True, data=params)
 * 
 *     def futures_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get trades for the authenticated account and symbol.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_account_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6378
 *         return self._request_futures_api('get', 'userTrades', True, data=params)
 * 
 *     def futures_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get income history for authenticated account
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_399futures_income_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_398futures_income_history, "\n        Get income history for authenticated account\n\n        https://binance-docs.github.io/apidocs/futures/en/#get-income-history-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_399futures_income_history = {"futures_income_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_399futures_income_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_398futures_income_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_399futures_income_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_income_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6378, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_income_history") < 0)) __PYX_ERR(0, 6378, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_income_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6378, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_income_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_398futures_income_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_398futures_income_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_income_history", 1);

  /* "unicorn_binance_rest_api/manager.py":6385
 * 
 *         """
 *         return self._request_futures_api('get', 'income', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_position_mode(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6385, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__159, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6378
 *         return self._request_futures_api('get', 'userTrades', True, data=params)
 * 
 *     def futures_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get income history for authenticated account
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_income_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6387
 *         return self._request_futures_api('get', 'income', True, data=params)
 * 
 *     def futures_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change position mode for authenticated account
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_401futures_change_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_400futures_change_position_mode, "\n        Change position mode for authenticated account\n\n        https://binance-docs.github.io/apidocs/futures/en/#change-position-mode-trade\n        \n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_401futures_change_position_mode = {"futures_change_position_mode", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_401futures_change_position_mode, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_400futures_change_position_mode};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_401futures_change_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_change_position_mode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6387, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_change_position_mode") < 0)) __PYX_ERR(0, 6387, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_change_position_mode", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6387, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_400futures_change_position_mode(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_400futures_change_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_change_position_mode", 1);

  /* "unicorn_binance_rest_api/manager.py":6394
 * 
 *         """
 *         return self._request_futures_api('post', 'positionSide/dual', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_position_mode(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6394, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__160, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6387
 *         return self._request_futures_api('get', 'income', True, data=params)
 * 
 *     def futures_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change position mode for authenticated account
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_change_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6396
 *         return self._request_futures_api('post', 'positionSide/dual', True, data=params)
 * 
 *     def futures_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position mode for authenticated account
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_403futures_get_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_402futures_get_position_mode, "\n        Get position mode for authenticated account\n\n        https://binance-docs.github.io/apidocs/futures/en/#get-current-position-mode-user_data\n        \n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_403futures_get_position_mode = {"futures_get_position_mode", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_403futures_get_position_mode, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_402futures_get_position_mode};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_403futures_get_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_get_position_mode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6396, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_get_position_mode") < 0)) __PYX_ERR(0, 6396, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_get_position_mode", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6396, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_402futures_get_position_mode(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_402futures_get_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_get_position_mode", 1);

  /* "unicorn_binance_rest_api/manager.py":6403
 * 
 *         """
 *         return self._request_futures_api('get', 'positionSide/dual', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_stream_get_listen_key(self, output="value", throw_exception=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6403, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__161, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6396
 *         return self._request_futures_api('post', 'positionSide/dual', True, data=params)
 * 
 *     def futures_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position mode for authenticated account
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_get_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6405
 *         return self._request_futures_api('get', 'positionSide/dual', True, data=params)
 * 
 *     def futures_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_405futures_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_404futures_stream_get_listen_key, "Start a new futures data stream and return the listen key\n        If a stream already exists it should return the same key.\n        If the stream becomes invalid a new key is returned.\n\n        Can be used to keep the stream alive.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param output: Set `output` to \"raw_data\" to receive the request resource, default is \"value\" which returns\n                        the plain listenKey.\n        :type output: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"listenKey\": \"pqia91ma19a5s61cv6a81va65sdf19v8a65a1a5s61cv6a81va65sdf19v8a65a1\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_405futures_stream_get_listen_key = {"futures_stream_get_listen_key", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_405futures_stream_get_listen_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_404futures_stream_get_listen_key};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_405futures_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_output = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_stream_get_listen_key (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_output,&__pyx_n_s_throw_exception,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_value)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6405, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_output);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6405, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6405, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_stream_get_listen_key") < 0)) __PYX_ERR(0, 6405, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_output = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_stream_get_listen_key", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 6405, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_404futures_stream_get_listen_key(__pyx_self, __pyx_v_self, __pyx_v_output, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_404futures_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_stream_get_listen_key", 1);

  /* "unicorn_binance_rest_api/manager.py":6430
 * 
 *         """
 *         res = self._request_futures_api('post', 'listenKey', signed=False, data={}, throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 *         if output == "value":
 *             return res['listenKey']
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 6430, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_t_3) < 0) __PYX_ERR(0, 6430, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 6430, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__162, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":6431
 *         """
 *         res = self._request_futures_api('post', 'listenKey', signed=False, data={}, throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_value, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 6431, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":6432
 *         res = self._request_futures_api('post', 'listenKey', signed=False, data={}, throw_exception=throw_exception)
 *         if output == "value":
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 *         elif output == "raw_data":
 *             return res
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":6431
 *         """
 *         res = self._request_futures_api('post', 'listenKey', signed=False, data={}, throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  }

  /* "unicorn_binance_rest_api/manager.py":6433
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_raw_data, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 6433, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":6434
 *             return res['listenKey']
 *         elif output == "raw_data":
 *             return res             # <<<<<<<<<<<<<<
 *         else:
 *             return res['listenKey']
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_res);
    __pyx_r = __pyx_v_res;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":6433
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  }

  /* "unicorn_binance_rest_api/manager.py":6436
 *             return res
 *         else:
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 * 
 *     def futures_stream_keepalive(self, listenKey, throw_exception=True):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6436, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":6405
 *         return self._request_futures_api('get', 'positionSide/dual', True, data=params)
 * 
 *     def futures_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6438
 *             return res['listenKey']
 * 
 *     def futures_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a futures data stream to prevent a time out.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_407futures_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_406futures_stream_keepalive, "PING a futures data stream to prevent a time out.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_407futures_stream_keepalive = {"futures_stream_keepalive", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_407futures_stream_keepalive, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_406futures_stream_keepalive};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_407futures_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_stream_keepalive (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6438, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6438, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("futures_stream_keepalive", 0, 2, 3, 1); __PYX_ERR(0, 6438, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6438, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_stream_keepalive") < 0)) __PYX_ERR(0, 6438, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_stream_keepalive", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 6438, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_406futures_stream_keepalive(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_406futures_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_stream_keepalive", 1);

  /* "unicorn_binance_rest_api/manager.py":6458
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_futures_api('put', 'listenKey', signed=False, data=params,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 6458, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6460
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_api('put', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                          throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 6460, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6460, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6461
 *         }
 *         return self._request_futures_api('put', 'listenKey', signed=False, data=params,
 *                                          throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     def futures_stream_close(self, listenKey, throw_exception=True):
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 6460, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6460
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_api('put', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                          throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__163, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6438
 *             return res['listenKey']
 * 
 *     def futures_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a futures data stream to prevent a time out.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6463
 *                                          throw_exception=throw_exception)
 * 
 *     def futures_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a futures data stream.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_409futures_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_408futures_stream_close, "Close out a futures data stream.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_409futures_stream_close = {"futures_stream_close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_409futures_stream_close, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_408futures_stream_close};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_409futures_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_stream_close (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6463, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6463, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("futures_stream_close", 0, 2, 3, 1); __PYX_ERR(0, 6463, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6463, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_stream_close") < 0)) __PYX_ERR(0, 6463, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_stream_close", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 6463, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_408futures_stream_close(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_408futures_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_stream_close", 1);

  /* "unicorn_binance_rest_api/manager.py":6483
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_futures_api('delete', 'listenKey', signed=False, data=params,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 6483, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6485
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_api('delete', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                          throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 6485, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6485, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6486
 *         }
 *         return self._request_futures_api('delete', 'listenKey', signed=False, data=params,
 *                                          throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     # COIN Futures API
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 6485, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6485
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_api('delete', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                          throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__164, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6463
 *                                          throw_exception=throw_exception)
 * 
 *     def futures_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a futures data stream.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6489
 * 
 *     # COIN Futures API
 *     def futures_coin_ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_411futures_coin_ping(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_410futures_coin_ping, "\n        Test connectivity to the Rest API\n\n        https://binance-docs.github.io/apidocs/delivery/en/#test-connectivity\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_411futures_coin_ping = {"futures_coin_ping", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_411futures_coin_ping, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_410futures_coin_ping};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_411futures_coin_ping(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_ping (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6489, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_coin_ping") < 0)) __PYX_ERR(0, 6489, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_ping", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6489, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_ping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_410futures_coin_ping(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_410futures_coin_ping(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_ping", 1);

  /* "unicorn_binance_rest_api/manager.py":6496
 * 
 *         """
 *         return self._request_futures_coin_api("get", "ping")             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_time(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6489
 * 
 *     # COIN Futures API
 *     def futures_coin_ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_ping", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6498
 *         return self._request_futures_coin_api("get", "ping")
 * 
 *     def futures_coin_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_413futures_coin_time(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_412futures_coin_time, "\n        Test connectivity to the Rest API and get the current server time.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#check-server-time\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_413futures_coin_time = {"futures_coin_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_413futures_coin_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_412futures_coin_time};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_413futures_coin_time(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_time (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6498, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_coin_time") < 0)) __PYX_ERR(0, 6498, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_time", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6498, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_412futures_coin_time(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_412futures_coin_time(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_time", 1);

  /* "unicorn_binance_rest_api/manager.py":6505
 * 
 *         """
 *         return self._request_futures_coin_api("get", "time")             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_exchange_info(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__121, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6498
 *         return self._request_futures_coin_api("get", "ping")
 * 
 *     def futures_coin_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6507
 *         return self._request_futures_coin_api("get", "time")
 * 
 *     def futures_coin_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Current exchange trading rules and symbol information
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_415futures_coin_exchange_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_414futures_coin_exchange_info, "\n        Current exchange trading rules and symbol information\n\n        https://binance-docs.github.io/apidocs/delivery/en/#exchange-information\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_415futures_coin_exchange_info = {"futures_coin_exchange_info", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_415futures_coin_exchange_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_414futures_coin_exchange_info};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_415futures_coin_exchange_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_exchange_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6507, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_coin_exchange_info") < 0)) __PYX_ERR(0, 6507, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_exchange_info", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6507, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_exchange_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_414futures_coin_exchange_info(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_414futures_coin_exchange_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_exchange_info", 1);

  /* "unicorn_binance_rest_api/manager.py":6514
 * 
 *         """
 *         return self._request_futures_coin_api("get", "exchangeInfo")             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_order_book(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__122, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6507
 *         return self._request_futures_coin_api("get", "time")
 * 
 *     def futures_coin_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Current exchange trading rules and symbol information
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_exchange_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6516
 *         return self._request_futures_coin_api("get", "exchangeInfo")
 * 
 *     def futures_coin_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_417futures_coin_order_book(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_416futures_coin_order_book, "\n        Get the Order Book for the market\n\n        https://binance-docs.github.io/apidocs/delivery/en/#order-book\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_417futures_coin_order_book = {"futures_coin_order_book", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_417futures_coin_order_book, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_416futures_coin_order_book};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_417futures_coin_order_book(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_order_book (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6516, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_order_book") < 0)) __PYX_ERR(0, 6516, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_order_book", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6516, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_order_book", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_416futures_coin_order_book(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_416futures_coin_order_book(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_order_book", 1);

  /* "unicorn_binance_rest_api/manager.py":6523
 * 
 *         """
 *         return self._request_futures_coin_api("get", "depth", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_recent_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6523, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__123, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6516
 *         return self._request_futures_coin_api("get", "exchangeInfo")
 * 
 *     def futures_coin_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_order_book", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6525
 *         return self._request_futures_coin_api("get", "depth", data=params)
 * 
 *     def futures_coin_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_419futures_coin_recent_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_418futures_coin_recent_trades, "Get recent trades (up to last 500).\n\n        https://binance-docs.github.io/apidocs/delivery/en/#recent-trades-list\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_419futures_coin_recent_trades = {"futures_coin_recent_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_419futures_coin_recent_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_418futures_coin_recent_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_419futures_coin_recent_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_recent_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6525, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_recent_trades") < 0)) __PYX_ERR(0, 6525, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_recent_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6525, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_recent_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_418futures_coin_recent_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_418futures_coin_recent_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_recent_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6531
 * 
 *         """
 *         return self._request_futures_coin_api("get", "trades", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_historical_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6531, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__124, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6525
 *         return self._request_futures_coin_api("get", "depth", data=params)
 * 
 *     def futures_coin_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_recent_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6533
 *         return self._request_futures_coin_api("get", "trades", data=params)
 * 
 *     def futures_coin_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older market historical trades.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_421futures_coin_historical_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_420futures_coin_historical_trades, "\n        Get older market historical trades.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#old-trades-lookup-market_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_421futures_coin_historical_trades = {"futures_coin_historical_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_421futures_coin_historical_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_420futures_coin_historical_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_421futures_coin_historical_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_historical_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6533, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_historical_trades") < 0)) __PYX_ERR(0, 6533, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_historical_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6533, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_historical_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_420futures_coin_historical_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_420futures_coin_historical_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_historical_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6540
 * 
 *         """
 *         return self._request_futures_coin_api("get", "historicalTrades", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_aggregate_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6540, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__125, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6533
 *         return self._request_futures_coin_api("get", "trades", data=params)
 * 
 *     def futures_coin_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older market historical trades.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_historical_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6542
 *         return self._request_futures_coin_api("get", "historicalTrades", data=params)
 * 
 *     def futures_coin_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_423futures_coin_aggregate_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_422futures_coin_aggregate_trades, "\n        Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same\n        price will have the quantity aggregated.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#compressed-aggregate-trades-list\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_423futures_coin_aggregate_trades = {"futures_coin_aggregate_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_423futures_coin_aggregate_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_422futures_coin_aggregate_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_423futures_coin_aggregate_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_aggregate_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6542, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_aggregate_trades") < 0)) __PYX_ERR(0, 6542, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_aggregate_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6542, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_aggregate_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_422futures_coin_aggregate_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_422futures_coin_aggregate_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_aggregate_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6550
 * 
 *         """
 *         return self._request_futures_coin_api("get", "aggTrades", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_klines(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6550, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__126, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6542
 *         return self._request_futures_coin_api("get", "historicalTrades", data=params)
 * 
 *     def futures_coin_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_aggregate_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6552
 *         return self._request_futures_coin_api("get", "aggTrades", data=params)
 * 
 *     def futures_coin_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_425futures_coin_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_424futures_coin_klines, "\n        Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#kline-candlestick-data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_425futures_coin_klines = {"futures_coin_klines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_425futures_coin_klines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_424futures_coin_klines};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_425futures_coin_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_klines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6552, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_klines") < 0)) __PYX_ERR(0, 6552, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_klines", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6552, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_424futures_coin_klines(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_424futures_coin_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_klines", 1);

  /* "unicorn_binance_rest_api/manager.py":6559
 * 
 *         """
 *         return self._request_futures_coin_api("get", "klines", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_continous_klines(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6559, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__127, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6552
 *         return self._request_futures_coin_api("get", "aggTrades", data=params)
 * 
 *     def futures_coin_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6561
 *         return self._request_futures_coin_api("get", "klines", data=params)
 * 
 *     def futures_coin_continous_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a specific contract type. Klines are uniquely identified by their open time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_427futures_coin_continous_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_426futures_coin_continous_klines, "\n        Kline/candlestick bars for a specific contract type. Klines are uniquely identified by their open time.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#continuous-contract-kline-candlestick-data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_427futures_coin_continous_klines = {"futures_coin_continous_klines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_427futures_coin_continous_klines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_426futures_coin_continous_klines};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_427futures_coin_continous_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_continous_klines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6561, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_continous_klines") < 0)) __PYX_ERR(0, 6561, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_continous_klines", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6561, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_continous_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_426futures_coin_continous_klines(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_426futures_coin_continous_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_continous_klines", 1);

  /* "unicorn_binance_rest_api/manager.py":6568
 * 
 *         """
 *         return self._request_futures_coin_api("get", "continuousKlines", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_index_price_klines(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6568, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__165, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6561
 *         return self._request_futures_coin_api("get", "klines", data=params)
 * 
 *     def futures_coin_continous_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a specific contract type. Klines are uniquely identified by their open time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_continous_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6570
 *         return self._request_futures_coin_api("get", "continuousKlines", data=params)
 * 
 *     def futures_coin_index_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_429futures_coin_index_price_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_428futures_coin_index_price_klines, "Kline/candlestick bars for the index price of a pair..\n\n        https://binance-docs.github.io/apidocs/delivery/en/#index-price-kline-candlestick-data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_429futures_coin_index_price_klines = {"futures_coin_index_price_klines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_429futures_coin_index_price_klines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_428futures_coin_index_price_klines};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_429futures_coin_index_price_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_index_price_klines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6570, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_index_price_klines") < 0)) __PYX_ERR(0, 6570, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_index_price_klines", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6570, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_index_price_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_428futures_coin_index_price_klines(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_428futures_coin_index_price_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_index_price_klines", 1);

  /* "unicorn_binance_rest_api/manager.py":6576
 * 
 *         """
 *         return self._request_futures_coin_api("get", "indexPriceKlines", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_mark_price_klines(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6576, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__166, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6570
 *         return self._request_futures_coin_api("get", "continuousKlines", data=params)
 * 
 *     def futures_coin_index_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_index_price_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6578
 *         return self._request_futures_coin_api("get", "indexPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_431futures_coin_mark_price_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_430futures_coin_mark_price_klines, "Kline/candlestick bars for the index price of a pair..\n\n        https://binance-docs.github.io/apidocs/delivery/en/#mark-price-kline-candlestick-data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_431futures_coin_mark_price_klines = {"futures_coin_mark_price_klines", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_431futures_coin_mark_price_klines, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_430futures_coin_mark_price_klines};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_431futures_coin_mark_price_klines(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_mark_price_klines (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6578, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_mark_price_klines") < 0)) __PYX_ERR(0, 6578, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_mark_price_klines", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6578, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_mark_price_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_430futures_coin_mark_price_klines(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_430futures_coin_mark_price_klines(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_mark_price_klines", 1);

  /* "unicorn_binance_rest_api/manager.py":6584
 * 
 *         """
 *         return self._request_futures_coin_api("get", "markPriceKlines", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_mark_price(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6584, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__167, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6578
 *         return self._request_futures_coin_api("get", "indexPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_mark_price_klines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6586
 *         return self._request_futures_coin_api("get", "markPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get Mark Price and Funding Rate
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_433futures_coin_mark_price(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_432futures_coin_mark_price, "\n        Get Mark Price and Funding Rate\n\n        https://binance-docs.github.io/apidocs/delivery/en/#index-price-and-mark-price\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_433futures_coin_mark_price = {"futures_coin_mark_price", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_433futures_coin_mark_price, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_432futures_coin_mark_price};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_433futures_coin_mark_price(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_mark_price (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6586, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_mark_price") < 0)) __PYX_ERR(0, 6586, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_mark_price", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6586, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_mark_price", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_432futures_coin_mark_price(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_432futures_coin_mark_price(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_mark_price", 1);

  /* "unicorn_binance_rest_api/manager.py":6593
 * 
 *         """
 *         return self._request_futures_coin_api("get", "premiumIndex", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_funding_rate(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6593, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__128, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6586
 *         return self._request_futures_coin_api("get", "markPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get Mark Price and Funding Rate
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_mark_price", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6595
 *         return self._request_futures_coin_api("get", "premiumIndex", data=params)
 * 
 *     def futures_coin_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_435futures_coin_funding_rate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_434futures_coin_funding_rate, "Get funding rate history\n\n        https://binance-docs.github.io/apidocs/delivery/en/#get-funding-rate-history-of-perpetual-futures\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_435futures_coin_funding_rate = {"futures_coin_funding_rate", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_435futures_coin_funding_rate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_434futures_coin_funding_rate};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_435futures_coin_funding_rate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_funding_rate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6595, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_funding_rate") < 0)) __PYX_ERR(0, 6595, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_funding_rate", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6595, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_funding_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_434futures_coin_funding_rate(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_434futures_coin_funding_rate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_funding_rate", 1);

  /* "unicorn_binance_rest_api/manager.py":6601
 * 
 *         """
 *         return self._request_futures_coin_api("get", "fundingRate", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6601, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__129, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6595
 *         return self._request_futures_coin_api("get", "premiumIndex", data=params)
 * 
 *     def futures_coin_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_funding_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6603
 *         return self._request_futures_coin_api("get", "fundingRate", data=params)
 * 
 *     def futures_coin_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         24 hour rolling window price change statistics.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_437futures_coin_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_436futures_coin_ticker, "\n        24 hour rolling window price change statistics.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#24hr-ticker-price-change-statistics\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_437futures_coin_ticker = {"futures_coin_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_437futures_coin_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_436futures_coin_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_437futures_coin_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6603, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_ticker") < 0)) __PYX_ERR(0, 6603, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6603, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_436futures_coin_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_436futures_coin_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":6610
 * 
 *         """
 *         return self._request_futures_coin_api("get", "ticker/24hr", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_symbol_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6610, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__130, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6603
 *         return self._request_futures_coin_api("get", "fundingRate", data=params)
 * 
 *     def futures_coin_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         24 hour rolling window price change statistics.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6612
 *         return self._request_futures_coin_api("get", "ticker/24hr", data=params)
 * 
 *     def futures_coin_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for a symbol or symbols.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_439futures_coin_symbol_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_438futures_coin_symbol_ticker, "\n        Latest price for a symbol or symbols.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#symbol-price-ticker\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_439futures_coin_symbol_ticker = {"futures_coin_symbol_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_439futures_coin_symbol_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_438futures_coin_symbol_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_439futures_coin_symbol_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_symbol_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6612, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_symbol_ticker") < 0)) __PYX_ERR(0, 6612, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_symbol_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6612, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_symbol_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_438futures_coin_symbol_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_438futures_coin_symbol_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_symbol_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":6619
 * 
 *         """
 *         return self._request_futures_coin_api("get", "ticker/price", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_orderbook_ticker(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6619, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__131, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6612
 *         return self._request_futures_coin_api("get", "ticker/24hr", data=params)
 * 
 *     def futures_coin_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for a symbol or symbols.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_symbol_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6621
 *         return self._request_futures_coin_api("get", "ticker/price", data=params)
 * 
 *     def futures_coin_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for a symbol or symbols.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_441futures_coin_orderbook_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_440futures_coin_orderbook_ticker, "\n        Best price/qty on the order book for a symbol or symbols.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#symbol-order-book-ticker\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_441futures_coin_orderbook_ticker = {"futures_coin_orderbook_ticker", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_441futures_coin_orderbook_ticker, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_440futures_coin_orderbook_ticker};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_441futures_coin_orderbook_ticker(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_orderbook_ticker (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6621, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_orderbook_ticker") < 0)) __PYX_ERR(0, 6621, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_orderbook_ticker", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6621, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_orderbook_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_440futures_coin_orderbook_ticker(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_440futures_coin_orderbook_ticker(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_orderbook_ticker", 1);

  /* "unicorn_binance_rest_api/manager.py":6628
 * 
 *         """
 *         return self._request_futures_coin_api("get", "ticker/bookTicker", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_liquidation_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6628, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__132, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6621
 *         return self._request_futures_coin_api("get", "ticker/price", data=params)
 * 
 *     def futures_coin_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for a symbol or symbols.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_orderbook_ticker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6630
 *         return self._request_futures_coin_api("get", "ticker/bookTicker", data=params)
 * 
 *     def futures_coin_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all liquidation orders
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_443futures_coin_liquidation_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_442futures_coin_liquidation_orders, "\n        Get all liquidation orders\n\n        https://binance-docs.github.io/apidocs/delivery/en/#get-all-liquidation-orders\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_443futures_coin_liquidation_orders = {"futures_coin_liquidation_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_443futures_coin_liquidation_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_442futures_coin_liquidation_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_443futures_coin_liquidation_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_liquidation_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6630, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_liquidation_orders") < 0)) __PYX_ERR(0, 6630, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_liquidation_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6630, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_liquidation_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_442futures_coin_liquidation_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_442futures_coin_liquidation_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_liquidation_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6637
 * 
 *         """
 *         return self._request_futures_coin_api("get", "allForceOrders", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_open_interest(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6637, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__168, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6630
 *         return self._request_futures_coin_api("get", "ticker/bookTicker", data=params)
 * 
 *     def futures_coin_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all liquidation orders
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_liquidation_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6639
 *         return self._request_futures_coin_api("get", "allForceOrders", data=params)
 * 
 *     def futures_coin_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get present open interest of a specific symbol.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_445futures_coin_open_interest(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_444futures_coin_open_interest, "\n        Get present open interest of a specific symbol.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#open-interest\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_445futures_coin_open_interest = {"futures_coin_open_interest", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_445futures_coin_open_interest, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_444futures_coin_open_interest};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_445futures_coin_open_interest(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_open_interest (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6639, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_open_interest") < 0)) __PYX_ERR(0, 6639, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_open_interest", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6639, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_open_interest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_444futures_coin_open_interest(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_444futures_coin_open_interest(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_open_interest", 1);

  /* "unicorn_binance_rest_api/manager.py":6646
 * 
 *         """
 *         return self._request_futures_coin_api("get", "openInterest", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_open_interest_hist(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6646, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__169, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6639
 *         return self._request_futures_coin_api("get", "allForceOrders", data=params)
 * 
 *     def futures_coin_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get present open interest of a specific symbol.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_open_interest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6648
 *         return self._request_futures_coin_api("get", "openInterest", data=params)
 * 
 *     def futures_coin_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get open interest statistics of a specific symbol.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_447futures_coin_open_interest_hist(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_446futures_coin_open_interest_hist, "\n        Get open interest statistics of a specific symbol.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#open-interest-statistics-market-data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_447futures_coin_open_interest_hist = {"futures_coin_open_interest_hist", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_447futures_coin_open_interest_hist, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_446futures_coin_open_interest_hist};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_447futures_coin_open_interest_hist(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_open_interest_hist (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6648, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_open_interest_hist") < 0)) __PYX_ERR(0, 6648, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_open_interest_hist", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6648, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_open_interest_hist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_446futures_coin_open_interest_hist(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_446futures_coin_open_interest_hist(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_open_interest_hist", 1);

  /* "unicorn_binance_rest_api/manager.py":6655
 * 
 *         """
 *         return self._request_futures_coin_data_api("get", "openInterestHist", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_leverage_bracket(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_data_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6655, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__135, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6648
 *         return self._request_futures_coin_api("get", "openInterest", data=params)
 * 
 *     def futures_coin_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get open interest statistics of a specific symbol.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_open_interest_hist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6657
 *         return self._request_futures_coin_data_api("get", "openInterestHist", data=params)
 * 
 *     def futures_coin_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Notional and Leverage Brackets
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_449futures_coin_leverage_bracket(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_448futures_coin_leverage_bracket, "\n        Notional and Leverage Brackets\n\n        https://binance-docs.github.io/apidocs/delivery/en/#notional-bracket-for-pair-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_449futures_coin_leverage_bracket = {"futures_coin_leverage_bracket", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_449futures_coin_leverage_bracket, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_448futures_coin_leverage_bracket};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_449futures_coin_leverage_bracket(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_leverage_bracket (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6657, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_leverage_bracket") < 0)) __PYX_ERR(0, 6657, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_leverage_bracket", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6657, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_leverage_bracket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_448futures_coin_leverage_bracket(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_448futures_coin_leverage_bracket(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_leverage_bracket", 1);

  /* "unicorn_binance_rest_api/manager.py":6664
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "leverageBracket", version=2, signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6665
 *         """
 *         return self._request_futures_coin_api(
 *             "get", "leverageBracket", version=2, signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_version, __pyx_int_2) < 0) __PYX_ERR(0, 6665, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6665, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6665, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6664
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "leverageBracket", version=2, signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__170, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6657
 *         return self._request_futures_coin_data_api("get", "openInterestHist", data=params)
 * 
 *     def futures_coin_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Notional and Leverage Brackets
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_leverage_bracket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6668
 *         )
 * 
 *     def new_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get future account transaction history list
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_451new_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_450new_transfer_history, "\n        Get future account transaction history list\n\n        https://binance-docs.github.io/apidocs/delivery/en/#new-future-account-transfer\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_451new_transfer_history = {"new_transfer_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_451new_transfer_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_450new_transfer_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_451new_transfer_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_transfer_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6668, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "new_transfer_history") < 0)) __PYX_ERR(0, 6668, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("new_transfer_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6668, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.new_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_450new_transfer_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_450new_transfer_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("new_transfer_history", 1);

  /* "unicorn_binance_rest_api/manager.py":6675
 * 
 *         """
 *         return self._request_margin_api("get", "asset/transfer", True, data=params)             # <<<<<<<<<<<<<<
 *         # return self._request_margin_api("get", "futures/transfer", True, data=params)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6675, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__171, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6668
 *         )
 * 
 *     def new_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get future account transaction history list
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.new_transfer_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6678
 *         # return self._request_margin_api("get", "futures/transfer", True, data=params)
 * 
 *     def universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Unviversal transfer api accross different unicorn_binance_rest_api account types
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_453universal_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_452universal_transfer, "\n        Unviversal transfer api accross different unicorn_binance_rest_api account types\n\n        https://binance-docs.github.io/apidocs/spot/en/#user-universal-transfer\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_453universal_transfer = {"universal_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_453universal_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_452universal_transfer};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_453universal_transfer(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("universal_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6678, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "universal_transfer") < 0)) __PYX_ERR(0, 6678, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("universal_transfer", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6678, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.universal_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_452universal_transfer(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_452universal_transfer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("universal_transfer", 1);

  /* "unicorn_binance_rest_api/manager.py":6684
 *         https://binance-docs.github.io/apidocs/spot/en/#user-universal-transfer
 *         """
 *         return self._request_margin_api(             # <<<<<<<<<<<<<<
 *             "post", "asset/transfer", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6685
 *         """
 *         return self._request_margin_api(
 *             "post", "asset/transfer", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6685, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6685, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6684
 *         https://binance-docs.github.io/apidocs/spot/en/#user-universal-transfer
 *         """
 *         return self._request_margin_api(             # <<<<<<<<<<<<<<
 *             "post", "asset/transfer", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__172, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6678
 *         # return self._request_margin_api("get", "futures/transfer", True, data=params)
 * 
 *     def universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Unviversal transfer api accross different unicorn_binance_rest_api account types
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.universal_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6688
 *         )
 * 
 *     def futures_coin_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Send in a new order.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_455futures_coin_create_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_454futures_coin_create_order, "\n        Send in a new order.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#new-order-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_455futures_coin_create_order = {"futures_coin_create_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_455futures_coin_create_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_454futures_coin_create_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_455futures_coin_create_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_create_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6688, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_create_order") < 0)) __PYX_ERR(0, 6688, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_create_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6688, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_create_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_454futures_coin_create_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_454futures_coin_create_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_create_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6695
 * 
 *         """
 *         return self._request_futures_coin_api("post", "order", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_place_batch_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6695, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__141, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6688
 *         )
 * 
 *     def futures_coin_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Send in a new order.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_create_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6697
 *         return self._request_futures_coin_api("post", "order", True, data=params)
 * 
 *     def futures_coin_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_457futures_coin_place_batch_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_456futures_coin_place_batch_order, "Send in new orders.\n        https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade\n        To avoid modifying the existing signature generation and parameter order logic,\n        the url encoding is done on the special query param, batchOrders, in the early stage.\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_457futures_coin_place_batch_order = {"futures_coin_place_batch_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_457futures_coin_place_batch_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_456futures_coin_place_batch_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_457futures_coin_place_batch_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_place_batch_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6697, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_place_batch_order") < 0)) __PYX_ERR(0, 6697, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_place_batch_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6697, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_place_batch_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_456futures_coin_place_batch_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_456futures_coin_place_batch_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_v_query_string = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_place_batch_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6703
 *         the url encoding is done on the special query param, batchOrders, in the early stage.
 *         """
 *         query_string = urlencode(params)             # <<<<<<<<<<<<<<
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_urlencode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_params};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_query_string = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6704
 *         """
 *         query_string = urlencode(params)
 *         query_string = query_string.replace('%27', '%22')             # <<<<<<<<<<<<<<
 *         params['batchOrders'] = query_string[12:]
 *         return self._request_futures_coin_api('post', 'batchOrders', True, data=params)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_query_string, __pyx_n_s_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__142, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_query_string, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":6705
 *         query_string = urlencode(params)
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]             # <<<<<<<<<<<<<<
 *         return self._request_futures_coin_api('post', 'batchOrders', True, data=params)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_query_string, 12, 0, NULL, NULL, &__pyx_slice__143, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyDict_SetItem(__pyx_v_params, __pyx_n_s_batchOrders, __pyx_t_2) < 0))) __PYX_ERR(0, 6705, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":6706
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]
 *         return self._request_futures_coin_api('post', 'batchOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_get_order(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6706, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__144, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6697
 *         return self._request_futures_coin_api("post", "order", True, data=params)
 * 
 *     def futures_coin_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_place_batch_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_query_string);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6708
 *         return self._request_futures_coin_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_coin_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_459futures_coin_get_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_458futures_coin_get_order, "\n        Check an order's status.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#query-order-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_459futures_coin_get_order = {"futures_coin_get_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_459futures_coin_get_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_458futures_coin_get_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_459futures_coin_get_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_get_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6708, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_get_order") < 0)) __PYX_ERR(0, 6708, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_get_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6708, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_458futures_coin_get_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_458futures_coin_get_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_get_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6715
 * 
 *         """
 *         return self._request_futures_coin_api("get", "order", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_get_open_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6715, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__145, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6708
 *         return self._request_futures_coin_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_coin_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6717
 *         return self._request_futures_coin_api("get", "order", True, data=params)
 * 
 *     def futures_coin_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_461futures_coin_get_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_460futures_coin_get_open_orders, "\n        Get all open orders on a symbol.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#current-all-open-orders-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_461futures_coin_get_open_orders = {"futures_coin_get_open_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_461futures_coin_get_open_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_460futures_coin_get_open_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_461futures_coin_get_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_get_open_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6717, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_get_open_orders") < 0)) __PYX_ERR(0, 6717, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_get_open_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6717, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_460futures_coin_get_open_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_460futures_coin_get_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_get_open_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6724
 * 
 *         """
 *         return self._request_futures_coin_api("get", "openOrders", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_get_all_orders(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6724, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__146, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6717
 *         return self._request_futures_coin_api("get", "order", True, data=params)
 * 
 *     def futures_coin_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6726
 *         return self._request_futures_coin_api("get", "openOrders", True, data=params)
 * 
 *     def futures_coin_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_463futures_coin_get_all_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_462futures_coin_get_all_orders, "\n        Get all futures account orders; active, canceled, or filled.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#all-orders-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_463futures_coin_get_all_orders = {"futures_coin_get_all_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_463futures_coin_get_all_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_462futures_coin_get_all_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_463futures_coin_get_all_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_get_all_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6726, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_get_all_orders") < 0)) __PYX_ERR(0, 6726, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_get_all_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6726, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_all_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_462futures_coin_get_all_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_462futures_coin_get_all_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_get_all_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6733
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "allOrders", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6734
 *         """
 *         return self._request_futures_coin_api(
 *             "get", "allOrders", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6734, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6734, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6733
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "allOrders", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__173, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6726
 *         return self._request_futures_coin_api("get", "openOrders", True, data=params)
 * 
 *     def futures_coin_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_all_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6737
 *         )
 * 
 *     def futures_coin_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_465futures_coin_cancel_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_464futures_coin_cancel_order, "\n        Cancel an active futures order.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#cancel-order-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_465futures_coin_cancel_order = {"futures_coin_cancel_order", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_465futures_coin_cancel_order, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_464futures_coin_cancel_order};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_465futures_coin_cancel_order(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_cancel_order (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6737, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_cancel_order") < 0)) __PYX_ERR(0, 6737, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_cancel_order", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6737, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_cancel_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_464futures_coin_cancel_order(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_464futures_coin_cancel_order(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_cancel_order", 1);

  /* "unicorn_binance_rest_api/manager.py":6744
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "order", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6745
 *         """
 *         return self._request_futures_coin_api(
 *             "delete", "order", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6745, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6745, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6744
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "order", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__174, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6737
 *         )
 * 
 *     def futures_coin_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_cancel_order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6748
 *         )
 * 
 *     def futures_coin_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_467futures_coin_cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_466futures_coin_cancel_all_open_orders, "\n        Cancel all open futures orders\n\n        https://binance-docs.github.io/apidocs/delivery/en/#cancel-all-open-orders-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_467futures_coin_cancel_all_open_orders = {"futures_coin_cancel_all_open_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_467futures_coin_cancel_all_open_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_466futures_coin_cancel_all_open_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_467futures_coin_cancel_all_open_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_cancel_all_open_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6748, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_cancel_all_open_orders") < 0)) __PYX_ERR(0, 6748, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_cancel_all_open_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6748, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_466futures_coin_cancel_all_open_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_466futures_coin_cancel_all_open_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_cancel_all_open_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6755
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "allOpenOrders", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6756
 *         """
 *         return self._request_futures_coin_api(
 *             "delete", "allOpenOrders", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6756, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6756, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6755
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "allOpenOrders", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__175, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6748
 *         )
 * 
 *     def futures_coin_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_cancel_all_open_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6759
 *         )
 * 
 *     def futures_coin_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_469futures_coin_cancel_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_468futures_coin_cancel_orders, "\n        Cancel multiple futures orders\n\n        https://binance-docs.github.io/apidocs/delivery/en/#cancel-multiple-orders-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_469futures_coin_cancel_orders = {"futures_coin_cancel_orders", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_469futures_coin_cancel_orders, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_468futures_coin_cancel_orders};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_469futures_coin_cancel_orders(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_cancel_orders (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6759, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_cancel_orders") < 0)) __PYX_ERR(0, 6759, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_cancel_orders", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6759, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_cancel_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_468futures_coin_cancel_orders(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_468futures_coin_cancel_orders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_cancel_orders", 1);

  /* "unicorn_binance_rest_api/manager.py":6766
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "batchOrders", True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6767
 *         """
 *         return self._request_futures_coin_api(
 *             "delete", "batchOrders", True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6767, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6766
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "batchOrders", True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__150, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6759
 *         )
 * 
 *     def futures_coin_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_cancel_orders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6770
 *         )
 * 
 *     def futures_coin_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_471futures_coin_account_balance(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_470futures_coin_account_balance, "\n        Get futures account balance\n\n        https://binance-docs.github.io/apidocs/delivery/en/#futures-account-balance-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_471futures_coin_account_balance = {"futures_coin_account_balance", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_471futures_coin_account_balance, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_470futures_coin_account_balance};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_471futures_coin_account_balance(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_account_balance (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6770, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_account_balance") < 0)) __PYX_ERR(0, 6770, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_account_balance", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6770, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_account_balance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_470futures_coin_account_balance(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_470futures_coin_account_balance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_account_balance", 1);

  /* "unicorn_binance_rest_api/manager.py":6777
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "balance", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6778
 *         """
 *         return self._request_futures_coin_api(
 *             "get", "balance", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6778, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6778, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6777
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "balance", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__176, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6770
 *         )
 * 
 *     def futures_coin_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_account_balance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6781
 *         )
 * 
 *     def futures_coin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_473futures_coin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_472futures_coin_account, "\n        Get current account information.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#account-information-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_473futures_coin_account = {"futures_coin_account", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_473futures_coin_account, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_472futures_coin_account};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_473futures_coin_account(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_account (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6781, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_account") < 0)) __PYX_ERR(0, 6781, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_account", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6781, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_472futures_coin_account(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_472futures_coin_account(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_account", 1);

  /* "unicorn_binance_rest_api/manager.py":6788
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "account", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6789
 *         """
 *         return self._request_futures_coin_api(
 *             "get", "account", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6789, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6789, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6788
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "account", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__177, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6781
 *         )
 * 
 *     def futures_coin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_account", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6792
 *         )
 * 
 *     def futures_coin_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_475futures_coin_change_leverage(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_474futures_coin_change_leverage, "\n        Change user's initial leverage of specific symbol market\n\n        https://binance-docs.github.io/apidocs/delivery/en/#change-initial-leverage-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_475futures_coin_change_leverage = {"futures_coin_change_leverage", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_475futures_coin_change_leverage, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_474futures_coin_change_leverage};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_475futures_coin_change_leverage(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_change_leverage (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6792, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_change_leverage") < 0)) __PYX_ERR(0, 6792, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_change_leverage", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6792, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_leverage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_474futures_coin_change_leverage(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_474futures_coin_change_leverage(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_change_leverage", 1);

  /* "unicorn_binance_rest_api/manager.py":6799
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "leverage", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6800
 *         """
 *         return self._request_futures_coin_api(
 *             "post", "leverage", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6800, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6800, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6799
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "leverage", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__178, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6792
 *         )
 * 
 *     def futures_coin_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_leverage", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6803
 *         )
 * 
 *     def futures_coin_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the margin type for a symbol
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_477futures_coin_change_margin_type(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_476futures_coin_change_margin_type, "\n        Change the margin type for a symbol\n\n        https://binance-docs.github.io/apidocs/delivery/en/#change-margin-type-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_477futures_coin_change_margin_type = {"futures_coin_change_margin_type", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_477futures_coin_change_margin_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_476futures_coin_change_margin_type};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_477futures_coin_change_margin_type(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_change_margin_type (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6803, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_change_margin_type") < 0)) __PYX_ERR(0, 6803, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_change_margin_type", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6803, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_margin_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_476futures_coin_change_margin_type(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_476futures_coin_change_margin_type(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_change_margin_type", 1);

  /* "unicorn_binance_rest_api/manager.py":6810
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "marginType", signed=True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6811
 *         """
 *         return self._request_futures_coin_api(
 *             "post", "marginType", signed=True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_True) < 0) __PYX_ERR(0, 6811, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6811, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6810
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "marginType", signed=True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__179, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6803
 *         )
 * 
 *     def futures_coin_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the margin type for a symbol
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_margin_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6814
 *         )
 * 
 *     def futures_coin_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_479futures_coin_change_position_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_478futures_coin_change_position_margin, "\n        Change the position margin for a symbol\n\n        https://binance-docs.github.io/apidocs/delivery/en/#modify-isolated-position-margin-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_479futures_coin_change_position_margin = {"futures_coin_change_position_margin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_479futures_coin_change_position_margin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_478futures_coin_change_position_margin};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_479futures_coin_change_position_margin(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_change_position_margin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6814, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_change_position_margin") < 0)) __PYX_ERR(0, 6814, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_change_position_margin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6814, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_position_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_478futures_coin_change_position_margin(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_478futures_coin_change_position_margin(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_change_position_margin", 1);

  /* "unicorn_binance_rest_api/manager.py":6821
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "positionMargin", True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6822
 *         """
 *         return self._request_futures_coin_api(
 *             "post", "positionMargin", True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6822, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6821
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "positionMargin", True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__155, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6814
 *         )
 * 
 *     def futures_coin_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_position_margin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6825
 *         )
 * 
 *     def futures_coin_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get position margin change history
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_481futures_coin_position_margin_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_480futures_coin_position_margin_history, "Get position margin change history\n\n        https://binance-docs.github.io/apidocs/delivery/en/#get-position-margin-change-history-trade\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_481futures_coin_position_margin_history = {"futures_coin_position_margin_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_481futures_coin_position_margin_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_480futures_coin_position_margin_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_481futures_coin_position_margin_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_position_margin_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6825, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_position_margin_history") < 0)) __PYX_ERR(0, 6825, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_position_margin_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6825, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_position_margin_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_480futures_coin_position_margin_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_480futures_coin_position_margin_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_position_margin_history", 1);

  /* "unicorn_binance_rest_api/manager.py":6831
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "positionMargin/history", True, data=params
 *         )
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "unicorn_binance_rest_api/manager.py":6832
 *         """
 *         return self._request_futures_coin_api(
 *             "get", "positionMargin/history", True, data=params             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6832, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6831
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "positionMargin/history", True, data=params
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__156, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6825
 *         )
 * 
 *     def futures_coin_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get position margin change history
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_position_margin_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6835
 *         )
 * 
 *     def futures_coin_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_483futures_coin_position_information(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_482futures_coin_position_information, "\n        Get position information\n\n        https://binance-docs.github.io/apidocs/delivery/en/#position-information-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_483futures_coin_position_information = {"futures_coin_position_information", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_483futures_coin_position_information, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_482futures_coin_position_information};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_483futures_coin_position_information(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_position_information (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6835, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_position_information") < 0)) __PYX_ERR(0, 6835, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_position_information", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6835, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_position_information", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_482futures_coin_position_information(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_482futures_coin_position_information(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_position_information", 1);

  /* "unicorn_binance_rest_api/manager.py":6842
 * 
 *         """
 *         return self._request_futures_coin_api("get", "positionRisk", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_account_trades(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6842, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__157, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6835
 *         )
 * 
 *     def futures_coin_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_position_information", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6844
 *         return self._request_futures_coin_api("get", "positionRisk", True, data=params)
 * 
 *     def futures_coin_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for the authenticated account and symbol.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_485futures_coin_account_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_484futures_coin_account_trades, "Get trades for the authenticated account and symbol.\n\n        https://binance-docs.github.io/apidocs/delivery/en/#account-trade-list-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_485futures_coin_account_trades = {"futures_coin_account_trades", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_485futures_coin_account_trades, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_484futures_coin_account_trades};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_485futures_coin_account_trades(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_account_trades (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6844, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_account_trades") < 0)) __PYX_ERR(0, 6844, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_account_trades", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6844, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_account_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_484futures_coin_account_trades(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_484futures_coin_account_trades(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_account_trades", 1);

  /* "unicorn_binance_rest_api/manager.py":6850
 * 
 *         """
 *         return self._request_futures_coin_api("get", "userTrades", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_income_history(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6850, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__158, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6844
 *         return self._request_futures_coin_api("get", "positionRisk", True, data=params)
 * 
 *     def futures_coin_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for the authenticated account and symbol.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_account_trades", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6852
 *         return self._request_futures_coin_api("get", "userTrades", True, data=params)
 * 
 *     def futures_coin_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get income history for authenticated account
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_487futures_coin_income_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_486futures_coin_income_history, "Get income history for authenticated account\n\n        https://binance-docs.github.io/apidocs/delivery/en/#get-income-history-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_487futures_coin_income_history = {"futures_coin_income_history", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_487futures_coin_income_history, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_486futures_coin_income_history};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_487futures_coin_income_history(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_income_history (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6852, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_income_history") < 0)) __PYX_ERR(0, 6852, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_income_history", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6852, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_income_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_486futures_coin_income_history(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_486futures_coin_income_history(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_income_history", 1);

  /* "unicorn_binance_rest_api/manager.py":6858
 * 
 *         """
 *         return self._request_futures_coin_api("get", "income", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_change_position_mode(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6858, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__159, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6852
 *         return self._request_futures_coin_api("get", "userTrades", True, data=params)
 * 
 *     def futures_coin_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get income history for authenticated account
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_income_history", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6860
 *         return self._request_futures_coin_api("get", "income", True, data=params)
 * 
 *     def futures_coin_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_489futures_coin_change_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_488futures_coin_change_position_mode, "\n        Change user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol\n\n        https://binance-docs.github.io/apidocs/delivery/en/#change-position-mode-trade\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_489futures_coin_change_position_mode = {"futures_coin_change_position_mode", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_489futures_coin_change_position_mode, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_488futures_coin_change_position_mode};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_489futures_coin_change_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_change_position_mode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6860, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_change_position_mode") < 0)) __PYX_ERR(0, 6860, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_change_position_mode", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6860, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_488futures_coin_change_position_mode(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_488futures_coin_change_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_change_position_mode", 1);

  /* "unicorn_binance_rest_api/manager.py":6866
 *         https://binance-docs.github.io/apidocs/delivery/en/#change-position-mode-trade
 *         """
 *         return self._request_futures_coin_api("post", "positionSide/dual", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_get_position_mode(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6866, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__160, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6860
 *         return self._request_futures_coin_api("get", "income", True, data=params)
 * 
 *     def futures_coin_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_change_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6868
 *         return self._request_futures_coin_api("post", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_491futures_coin_get_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_490futures_coin_get_position_mode, "\n        Get user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol\n\n        https://binance-docs.github.io/apidocs/delivery/en/#get-current-position-mode-user_data\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_491futures_coin_get_position_mode = {"futures_coin_get_position_mode", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_491futures_coin_get_position_mode, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_490futures_coin_get_position_mode};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_491futures_coin_get_position_mode(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_get_position_mode (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6868, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "futures_coin_get_position_mode") < 0)) __PYX_ERR(0, 6868, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_get_position_mode", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6868, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_490futures_coin_get_position_mode(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_490futures_coin_get_position_mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_get_position_mode", 1);

  /* "unicorn_binance_rest_api/manager.py":6875
 * 
 *         """
 *         return self._request_futures_coin_api("get", "positionSide/dual", True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_stream_get_listen_key(self, output="value", throw_exception=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6875, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__161, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6868
 *         return self._request_futures_coin_api("post", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_get_position_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6877
 *         return self._request_futures_coin_api("get", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new coin futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_493futures_coin_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_492futures_coin_stream_get_listen_key, "Start a new coin futures data stream and return the listen key\n        If a stream already exists it should return the same key.\n        If the stream becomes invalid a new key is returned.\n\n        Can be used to keep the stream alive.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param output: Set `output` to \"raw_data\" to receive the request resource, default is \"value\" which returns\n                        the plain listenKey.\n        :type output: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"listenKey\": \"pqia91ma19a5s61cv6a81va65sdf19v8a65a1a5s61cv6a81va65sdf19v8a65a1\"\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_493futures_coin_stream_get_listen_key = {"futures_coin_stream_get_listen_key", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_493futures_coin_stream_get_listen_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_492futures_coin_stream_get_listen_key};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_493futures_coin_stream_get_listen_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_output = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_stream_get_listen_key (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_output,&__pyx_n_s_throw_exception,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_value)));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6877, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_output);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6877, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6877, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_coin_stream_get_listen_key") < 0)) __PYX_ERR(0, 6877, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_output = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_stream_get_listen_key", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 6877, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_492futures_coin_stream_get_listen_key(__pyx_self, __pyx_v_self, __pyx_v_output, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_492futures_coin_stream_get_listen_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_output, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_stream_get_listen_key", 1);

  /* "unicorn_binance_rest_api/manager.py":6902
 * 
 *         """
 *         res = self._request_futures_coin_api('post', 'listenKey', signed=False, data={},             # <<<<<<<<<<<<<<
 *                                              throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 6902, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_t_3) < 0) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":6903
 *         """
 *         res = self._request_futures_coin_api('post', 'listenKey', signed=False, data={},
 *                                              throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 *         if output == "value":
 *             return res['listenKey']
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 6902, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6902
 * 
 *         """
 *         res = self._request_futures_coin_api('post', 'listenKey', signed=False, data={},             # <<<<<<<<<<<<<<
 *                                              throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__162, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":6904
 *         res = self._request_futures_coin_api('post', 'listenKey', signed=False, data={},
 *                                              throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_value, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 6904, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":6905
 *                                              throw_exception=throw_exception)
 *         if output == "value":
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 *         elif output == "raw_data":
 *             return res
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":6904
 *         res = self._request_futures_coin_api('post', 'listenKey', signed=False, data={},
 *                                              throw_exception=throw_exception)
 *         if output == "value":             # <<<<<<<<<<<<<<
 *             return res['listenKey']
 *         elif output == "raw_data":
 */
  }

  /* "unicorn_binance_rest_api/manager.py":6906
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_output, __pyx_n_s_raw_data, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 6906, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "unicorn_binance_rest_api/manager.py":6907
 *             return res['listenKey']
 *         elif output == "raw_data":
 *             return res             # <<<<<<<<<<<<<<
 *         else:
 *             return res['listenKey']
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_res);
    __pyx_r = __pyx_v_res;
    goto __pyx_L0;

    /* "unicorn_binance_rest_api/manager.py":6906
 *         if output == "value":
 *             return res['listenKey']
 *         elif output == "raw_data":             # <<<<<<<<<<<<<<
 *             return res
 *         else:
 */
  }

  /* "unicorn_binance_rest_api/manager.py":6909
 *             return res
 *         else:
 *             return res['listenKey']             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_stream_keepalive(self, listenKey, throw_exception=True):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_listenKey); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "unicorn_binance_rest_api/manager.py":6877
 *         return self._request_futures_coin_api("get", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new coin futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_stream_get_listen_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6911
 *             return res['listenKey']
 * 
 *     def futures_coin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a coin futures data stream to prevent a time out.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_495futures_coin_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_494futures_coin_stream_keepalive, "PING a coin futures data stream to prevent a time out.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_495futures_coin_stream_keepalive = {"futures_coin_stream_keepalive", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_495futures_coin_stream_keepalive, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_494futures_coin_stream_keepalive};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_495futures_coin_stream_keepalive(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_stream_keepalive (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6911, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6911, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("futures_coin_stream_keepalive", 0, 2, 3, 1); __PYX_ERR(0, 6911, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6911, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_coin_stream_keepalive") < 0)) __PYX_ERR(0, 6911, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_stream_keepalive", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 6911, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_494futures_coin_stream_keepalive(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_494futures_coin_stream_keepalive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_stream_keepalive", 1);

  /* "unicorn_binance_rest_api/manager.py":6931
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_futures_coin_api('put', 'listenKey', signed=False, data=params,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 6931, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6933
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_coin_api('put', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                               throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 6933, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6933, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6934
 *         }
 *         return self._request_futures_coin_api('put', 'listenKey', signed=False, data=params,
 *                                               throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_stream_close(self, listenKey, throw_exception=True):
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 6933, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6933
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_coin_api('put', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                               throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__163, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6911
 *             return res['listenKey']
 * 
 *     def futures_coin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a coin futures data stream to prevent a time out.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_stream_keepalive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6936
 *                                               throw_exception=throw_exception)
 * 
 *     def futures_coin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a coin futures data stream.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_497futures_coin_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_496futures_coin_stream_close, "Close out a coin futures data stream.\n\n        https://binance-docs.github.io/apidocs/spot/en/#listen-key-margin\n\n        :param listenKey: required\n        :type listenKey: str\n        :param throw_exception: Default `True`, if `False` the raw response will be returned.\n        :type throw_exception: bool\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {}\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_497futures_coin_stream_close = {"futures_coin_stream_close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_497futures_coin_stream_close, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_496futures_coin_stream_close};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_497futures_coin_stream_close(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_listenKey = 0;
  PyObject *__pyx_v_throw_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("futures_coin_stream_close (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_listenKey,&__pyx_n_s_throw_exception,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6936, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_listenKey)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6936, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("futures_coin_stream_close", 0, 2, 3, 1); __PYX_ERR(0, 6936, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_throw_exception);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6936, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "futures_coin_stream_close") < 0)) __PYX_ERR(0, 6936, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_listenKey = values[1];
    __pyx_v_throw_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("futures_coin_stream_close", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 6936, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_496futures_coin_stream_close(__pyx_self, __pyx_v_self, __pyx_v_listenKey, __pyx_v_throw_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_496futures_coin_stream_close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_listenKey, PyObject *__pyx_v_throw_exception) {
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("futures_coin_stream_close", 1);

  /* "unicorn_binance_rest_api/manager.py":6956
 *         """
 *         params = {
 *             'listenKey': listenKey             # <<<<<<<<<<<<<<
 *         }
 *         return self._request_futures_coin_api('delete', 'listenKey', signed=False, data=params,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_listenKey, __pyx_v_listenKey) < 0) __PYX_ERR(0, 6956, __pyx_L1_error)
  __pyx_v_params = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":6958
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_coin_api('delete', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                               throw_exception=throw_exception)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_futures_coin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_signed, Py_False) < 0) __PYX_ERR(0, 6958, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 6958, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6959
 *         }
 *         return self._request_futures_coin_api('delete', 'listenKey', signed=False, data=params,
 *                                               throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_throw_exception, __pyx_v_throw_exception) < 0) __PYX_ERR(0, 6958, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6958
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_coin_api('delete', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                               throw_exception=throw_exception)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__164, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 6958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6936
 *                                               throw_exception=throw_exception)
 * 
 *     def futures_coin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a coin futures data stream.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.futures_coin_stream_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":6962
 * 
 * 
 *     def get_all_coins_info(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get information of coins (available for deposit and withdraw) for user.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_499get_all_coins_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_498get_all_coins_info, "\n        Get information of coins (available for deposit and withdraw) for user.\n\n        https://binance-docs.github.io/apidocs/spot/en/#all-coins-39-information-user_data\n\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n                \"coin\": \"BTC\",\n                \"depositAllEnable\": true,\n                \"withdrawAllEnable\": true,\n                \"name\": \"Bitcoin\",\n                \"free\": \"0\",\n                \"locked\": \"0\",\n                \"freeze\": \"0\",\n                \"withdrawing\": \"0\",\n                \"ipoing\": \"0\",\n                \"ipoable\": \"0\",\n                \"storage\": \"0\",\n                \"isLegalMoney\": false,\n                \"trading\": true,\n                \"networkList\": [\n                    {\n                        \"network\": \"BNB\",\n                        \"coin\": \"BTC\",\n                        \"withdrawIntegerMultiple\": \"0.00000001\",\n                        \"isDefault\": false,\n                        \"depositEnable\": true,\n                        \"withdrawEnable\": true,\n                        \"depositDesc\": \"\",\n                        \"withdrawDesc\": \"\",\n                        \"specialTips\": \"Both a MEMO and an Address are required to successfully deposit your BEP2-BTCB tokens to Binance.\",\n                        \"name\": \"BEP2\",\n                        \"resetAddressStatus\": false,\n                        \"addressRegex\": \"^(bnb1)[0-9a-z]{38}$\",\n                        \"memoRegex\": \"^[0-9A-Za-z-_]{1,120}$\",\n                        \"withdrawFee\": \"0.0000026\",\n                        \"withdrawMin\": \"0.0000052\",\n                        \"withdrawMax\": \"0\",\n                        \"minConfirm\": 1,\n                        \"unLockConfirm\": 0\n                    },\n                    {\n                  ""      \"network\": \"BTC\",\n                        \"coin\": \"BTC\",\n                        \"withdrawIntegerMultiple\": \"0.00000001\",\n                        \"isDefault\": true,\n                        \"depositEnable\": true,\n                        \"withdrawEnable\": true,\n                        \"depositDesc\": \"\",\n                        \"withdrawDesc\": \"\",\n                        \"specialTips\": \"\",\n                        \"name\": \"BTC\",\n                        \"resetAddressStatus\": false,\n                        \"addressRegex\": \"^[13][a-km-zA-HJ-NP-Z1-9]{25,34}$|^(bc1)[0-9A-Za-z]{39,59}$\",\n                        \"memoRegex\": \"\",\n                        \"withdrawFee\": \"0.0005\",\n                        \"withdrawMin\": \"0.001\",\n                        \"withdrawMax\": \"0\",\n                        \"minConfirm\": 1,\n                        \"unLockConfirm\": 2\n                    }\n                ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_499get_all_coins_info = {"get_all_coins_info", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_499get_all_coins_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_498get_all_coins_info};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_499get_all_coins_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_coins_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6962, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_all_coins_info") < 0)) __PYX_ERR(0, 6962, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_coins_info", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6962, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_coins_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_498get_all_coins_info(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_498get_all_coins_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_all_coins_info", 1);

  /* "unicorn_binance_rest_api/manager.py":7036
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/config/getall', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_account_snapshot(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 7036, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__180, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":6962
 * 
 * 
 *     def get_all_coins_info(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get information of coins (available for deposit and withdraw) for user.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_all_coins_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":7038
 *         return self._request_margin_api('get', 'capital/config/getall', True, data=params)
 * 
 *     def get_account_snapshot(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get daily account snapshot of specific type.
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_501get_account_snapshot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_500get_account_snapshot, "\n        Get daily account snapshot of specific type.\n\n        https://binance-docs.github.io/apidocs/spot/en/#daily-account-snapshot-user_data\n\n        :param type: required. Valid values are SPOT/MARGIN/FUTURES.\n        :type type: string\n        :param startTime: optional\n        :type startTime: int\n        :param endTime: optional\n        :type endTime: int\n        :param limit: optional\n        :type limit: int\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        .. code-block:: python\n\n            {\n               \"code\":200, // 200 for success; others are error codes\n               \"msg\":\"\", // error message\n               \"snapshotVos\":[\n                  {\n                     \"data\":{\n                        \"balances\":[\n                           {\n                              \"asset\":\"BTC\",\n                              \"free\":\"0.09905021\",\n                              \"locked\":\"0.00000000\"\n                           },\n                           {\n                              \"asset\":\"USDT\",\n                              \"free\":\"1.89109409\",\n                              \"locked\":\"0.00000000\"\n                           }\n                        ],\n                        \"totalAssetOfBtc\":\"0.09942700\"\n                     },\n                     \"type\":\"spot\",\n                     \"updateTime\":1576281599000\n                  }\n               ]\n            }\n\n        OR\n\n        .. code-block:: python\n\n            {\n               \"code\":200, // 200 for success; others are error codes\n               \"msg\":\"\", // error message\n               \"snapshotVos\":[\n                  {\n                     \"data\":{\n                        \"marginLevel\":\"2748.02909813\",\n                        \"totalAssetOfBtc\":\"0.00274803\",\n                        \"totalLiabilityOfBtc\":\"0.00000100""\",\n                        \"totalNetAssetOfBtc\":\"0.00274750\",\n                        \"userAssets\":[\n                           {\n                              \"asset\":\"XRP\",\n                              \"borrowed\":\"0.00000000\",\n                              \"free\":\"1.00000000\",\n                              \"interest\":\"0.00000000\",\n                              \"locked\":\"0.00000000\",\n                              \"netAsset\":\"1.00000000\"\n                           }\n                        ]\n                     },\n                     \"type\":\"margin\",\n                     \"updateTime\":1576281599000\n                  }\n               ]\n            }\n\n        OR\n\n        .. code-block:: python\n\n            {\n               \"code\":200, // 200 for success; others are error codes\n               \"msg\":\"\", // error message\n               \"snapshotVos\":[\n                  {\n                     \"data\":{\n                        \"assets\":[\n                           {\n                              \"asset\":\"USDT\",\n                              \"marginBalance\":\"118.99782335\",\n                              \"walletBalance\":\"120.23811389\"\n                           }\n                        ],\n                        \"position\":[\n                           {\n                              \"entryPrice\":\"7130.41000000\",\n                              \"markPrice\":\"7257.66239673\",\n                              \"positionAmt\":\"0.01000000\",\n                              \"symbol\":\"BTCUSDT\",\n                              \"unRealizedProfit\":\"1.24029054\"\n                           }\n                        ]\n                     },\n                     \"type\":\"futures\",\n                     \"updateTime\":1576281599000\n                  }\n               ]\n            }\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_501get_account_snapshot = {"get_account_snapshot", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_501get_account_snapshot, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_500get_account_snapshot};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_501get_account_snapshot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_account_snapshot (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7038, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "get_account_snapshot") < 0)) __PYX_ERR(0, 7038, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_account_snapshot", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7038, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account_snapshot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_500get_account_snapshot(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_500get_account_snapshot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_account_snapshot", 1);

  /* "unicorn_binance_rest_api/manager.py":7152
 * 
 *         """
 *         return self._request_margin_api('get', 'accountSnapshot', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def disable_fast_withdraw_switch(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 7152, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__181, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":7038
 *         return self._request_margin_api('get', 'capital/config/getall', True, data=params)
 * 
 *     def get_account_snapshot(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get daily account snapshot of specific type.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.get_account_snapshot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":7154
 *         return self._request_margin_api('get', 'accountSnapshot', True, data=params)
 * 
 *     def disable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Disable Fast Withdraw Switch
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_503disable_fast_withdraw_switch(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_502disable_fast_withdraw_switch, "\n        Disable Fast Withdraw Switch\n\n        https://binance-docs.github.io/apidocs/spot/en/#disable-fast-withdraw-switch-user_data\n\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_503disable_fast_withdraw_switch = {"disable_fast_withdraw_switch", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_503disable_fast_withdraw_switch, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_502disable_fast_withdraw_switch};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_503disable_fast_withdraw_switch(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("disable_fast_withdraw_switch (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7154, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "disable_fast_withdraw_switch") < 0)) __PYX_ERR(0, 7154, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("disable_fast_withdraw_switch", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7154, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.disable_fast_withdraw_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_502disable_fast_withdraw_switch(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_502disable_fast_withdraw_switch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("disable_fast_withdraw_switch", 1);

  /* "unicorn_binance_rest_api/manager.py":7168
 * 
 *         """
 *         return self._request_margin_api('post', 'disableFastWithdrawSwitch', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def enable_fast_withdraw_switch(self, **params):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 7168, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__182, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":7154
 *         return self._request_margin_api('get', 'accountSnapshot', True, data=params)
 * 
 *     def disable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Disable Fast Withdraw Switch
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.disable_fast_withdraw_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":7170
 *         return self._request_margin_api('post', 'disableFastWithdrawSwitch', True, data=params)
 * 
 *     def enable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Enable Fast Withdraw Switch
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_505enable_fast_withdraw_switch(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_504enable_fast_withdraw_switch, "\n        Enable Fast Withdraw Switch\n\n        https://binance-docs.github.io/apidocs/spot/en/#enable-fast-withdraw-switch-user_data\n\n        :param recvWindow: optional\n        :type recvWindow: int\n\n        :returns: API response\n\n        :raises: BinanceRequestException, BinanceAPIException\n\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_505enable_fast_withdraw_switch = {"enable_fast_withdraw_switch", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_505enable_fast_withdraw_switch, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_504enable_fast_withdraw_switch};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_505enable_fast_withdraw_switch(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_params = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enable_fast_withdraw_switch (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_params = PyDict_New(); if (unlikely(!__pyx_v_params)) return NULL;
  __Pyx_GOTREF(__pyx_v_params);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7170, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_params, values + 0, kwd_pos_args, "enable_fast_withdraw_switch") < 0)) __PYX_ERR(0, 7170, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enable_fast_withdraw_switch", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 7170, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_params); __pyx_v_params = 0;
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.enable_fast_withdraw_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_504enable_fast_withdraw_switch(__pyx_self, __pyx_v_self, __pyx_v_params);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_params);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_504enable_fast_withdraw_switch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_params) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enable_fast_withdraw_switch", 1);

  /* "unicorn_binance_rest_api/manager.py":7184
 * 
 *         """
 *         return self._request_margin_api('post', 'enableFastWithdrawSwitch', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def stop_manager(self, close_api_session=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_request_margin_api); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_data, __pyx_v_params) < 0) __PYX_ERR(0, 7184, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__183, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":7170
 *         return self._request_margin_api('post', 'disableFastWithdrawSwitch', True, data=params)
 * 
 *     def enable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Enable Fast Withdraw Switch
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.enable_fast_withdraw_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "unicorn_binance_rest_api/manager.py":7186
 *         return self._request_margin_api('post', 'enableFastWithdrawSwitch', True, data=params)
 * 
 *     def stop_manager(self, close_api_session=True):             # <<<<<<<<<<<<<<
 *         """
 *         Stop the BinanceRestApiManager
 */

/* Python wrapper */
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_507stop_manager(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_506stop_manager, "\n        Stop the BinanceRestApiManager\n        ");
static PyMethodDef __pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_507stop_manager = {"stop_manager", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_507stop_manager, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_506stop_manager};
static PyObject *__pyx_pw_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_507stop_manager(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_close_api_session = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stop_manager (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_close_api_session,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject *)Py_True)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7186, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_close_api_session);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 7186, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "stop_manager") < 0)) __PYX_ERR(0, 7186, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_close_api_session = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stop_manager", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 7186, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stop_manager", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_506stop_manager(__pyx_self, __pyx_v_self, __pyx_v_close_api_session);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_506stop_manager(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_close_api_session) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stop_manager", 1);

  /* "unicorn_binance_rest_api/manager.py":7190
 *         Stop the BinanceRestApiManager
 *         """
 *         logger.info("BinanceWebSocketApiManager.stop_manager() - Stopping "             # <<<<<<<<<<<<<<
 *                     "unicorn_binance_rest_api_manager " + self.version + " ...")
 *         # close the request session
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":7191
 *         """
 *         logger.info("BinanceWebSocketApiManager.stop_manager() - Stopping "
 *                     "unicorn_binance_rest_api_manager " + self.version + " ...")             # <<<<<<<<<<<<<<
 *         # close the request session
 *         self.session.close()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_version); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Add(__pyx_kp_s_BinanceWebSocketApiManager_stop, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 7191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_kp_s__184); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":7193
 *                     "unicorn_binance_rest_api_manager " + self.version + " ...")
 *         # close the request session
 *         self.session.close()             # <<<<<<<<<<<<<<
 *         # close lucit license manger and the api session
 *         if close_api_session is True:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_close); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "unicorn_binance_rest_api/manager.py":7195
 *         self.session.close()
 *         # close lucit license manger and the api session
 *         if close_api_session is True:             # <<<<<<<<<<<<<<
 *             self.llm.close()
 *         return True
 */
  __pyx_t_6 = (__pyx_v_close_api_session == Py_True);
  if (__pyx_t_6) {

    /* "unicorn_binance_rest_api/manager.py":7196
 *         # close lucit license manger and the api session
 *         if close_api_session is True:
 *             self.llm.close()             # <<<<<<<<<<<<<<
 *         return True
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_llm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 7196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "unicorn_binance_rest_api/manager.py":7195
 *         self.session.close()
 *         # close lucit license manger and the api session
 *         if close_api_session is True:             # <<<<<<<<<<<<<<
 *             self.llm.close()
 *         return True
 */
  }

  /* "unicorn_binance_rest_api/manager.py":7197
 *         if close_api_session is True:
 *             self.llm.close()
 *         return True             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "unicorn_binance_rest_api/manager.py":7186
 *         return self._request_margin_api('post', 'enableFastWithdrawSwitch', True, data=params)
 * 
 *     def stop_manager(self, close_api_session=True):             # <<<<<<<<<<<<<<
 *         """
 *         Stop the BinanceRestApiManager
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("unicorn_binance_rest_api.manager.BinanceRestApiManager.stop_manager", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *__pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr[8];
static int __pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr = 0;

static PyObject *__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr)))) {
    o = (PyObject*)__pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr[--__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr(PyObject *o) {
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *p = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_data);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr)))) {
    __pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr[__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr++] = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *p = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_data) {
    e = (*v)(p->__pyx_v_data, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr_spec = {
  "unicorn_binance_rest_api.manager.__pyx_scope_struct__genexpr",
  sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr_slots,
};
#else

static PyTypeObject __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "unicorn_binance_rest_api.manager.""__pyx_scope_struct__genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *__pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter[8];
static int __pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter = 0;

static PyObject *__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter)))) {
    o = (PyObject*)__pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter[--__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter];
    memset(o, 0, sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter(PyObject *o) {
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *p = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_end_ts);
  Py_CLEAR(p->__pyx_v_last_id);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_start_str);
  Py_CLEAR(p->__pyx_v_start_ts);
  Py_CLEAR(p->__pyx_v_symbol);
  Py_CLEAR(p->__pyx_v_t);
  Py_CLEAR(p->__pyx_v_trades);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter)))) {
    __pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter[__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter++] = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *p = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter *)o;
  if (p->__pyx_v_end_ts) {
    e = (*v)(p->__pyx_v_end_ts, a); if (e) return e;
  }
  if (p->__pyx_v_last_id) {
    e = (*v)(p->__pyx_v_last_id, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_start_str) {
    e = (*v)(p->__pyx_v_start_str, a); if (e) return e;
  }
  if (p->__pyx_v_start_ts) {
    e = (*v)(p->__pyx_v_start_ts, a); if (e) return e;
  }
  if (p->__pyx_v_symbol) {
    e = (*v)(p->__pyx_v_symbol, a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  if (p->__pyx_v_trades) {
    e = (*v)(p->__pyx_v_trades, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter},
  {Py_tp_new, (void *)__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter},
  {0, 0},
};
static PyType_Spec __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter_spec = {
  "unicorn_binance_rest_api.manager.__pyx_scope_struct_1_aggregate_trade_iter",
  sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter_slots,
};
#else

static PyTypeObject __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter = {
  PyVarObject_HEAD_INIT(0, 0)
  "unicorn_binance_rest_api.manager.""__pyx_scope_struct_1_aggregate_trade_iter", /*tp_name*/
  sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *__pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator[8];
static int __pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator = 0;

static PyObject *__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator)))) {
    o = (PyObject*)__pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator[--__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator];
    memset(o, 0, sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator(PyObject *o) {
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *p = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_end_str);
  Py_CLEAR(p->__pyx_v_end_ts);
  Py_CLEAR(p->__pyx_v_first_valid_ts);
  Py_CLEAR(p->__pyx_v_idx);
  Py_CLEAR(p->__pyx_v_interval);
  Py_CLEAR(p->__pyx_v_o);
  Py_CLEAR(p->__pyx_v_output_data);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_start_str);
  Py_CLEAR(p->__pyx_v_start_ts);
  Py_CLEAR(p->__pyx_v_symbol);
  Py_CLEAR(p->__pyx_v_timeframe);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator)))) {
    __pyx_freelist_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator[__pyx_freecount_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator++] = ((struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *p = (struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator *)o;
  if (p->__pyx_v_end_str) {
    e = (*v)(p->__pyx_v_end_str, a); if (e) return e;
  }
  if (p->__pyx_v_end_ts) {
    e = (*v)(p->__pyx_v_end_ts, a); if (e) return e;
  }
  if (p->__pyx_v_first_valid_ts) {
    e = (*v)(p->__pyx_v_first_valid_ts, a); if (e) return e;
  }
  if (p->__pyx_v_idx) {
    e = (*v)(p->__pyx_v_idx, a); if (e) return e;
  }
  if (p->__pyx_v_interval) {
    e = (*v)(p->__pyx_v_interval, a); if (e) return e;
  }
  if (p->__pyx_v_o) {
    e = (*v)(p->__pyx_v_o, a); if (e) return e;
  }
  if (p->__pyx_v_output_data) {
    e = (*v)(p->__pyx_v_output_data, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_start_str) {
    e = (*v)(p->__pyx_v_start_str, a); if (e) return e;
  }
  if (p->__pyx_v_start_ts) {
    e = (*v)(p->__pyx_v_start_ts, a); if (e) return e;
  }
  if (p->__pyx_v_symbol) {
    e = (*v)(p->__pyx_v_symbol, a); if (e) return e;
  }
  if (p->__pyx_v_timeframe) {
    e = (*v)(p->__pyx_v_timeframe, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator},
  {Py_tp_new, (void *)__pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator},
  {0, 0},
};
static PyType_Spec __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator_spec = {
  "unicorn_binance_rest_api.manager.__pyx_scope_struct_2_get_historical_klines_generator",
  sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator_slots,
};
#else

static PyTypeObject __pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator = {
  PyVarObject_HEAD_INIT(0, 0)
  "unicorn_binance_rest_api.manager.""__pyx_scope_struct_2_get_historical_klines_generator", /*tp_name*/
  sizeof(struct __pyx_obj_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
    {&__pyx_kp_s_12h, __pyx_k_12h, sizeof(__pyx_k_12h), 0, 0, 1, 0},
    {&__pyx_kp_s_15m, __pyx_k_15m, sizeof(__pyx_k_15m), 0, 0, 1, 0},
    {&__pyx_kp_s_1M, __pyx_k_1M, sizeof(__pyx_k_1M), 0, 0, 1, 0},
    {&__pyx_kp_s_1d, __pyx_k_1d, sizeof(__pyx_k_1d), 0, 0, 1, 0},
    {&__pyx_kp_s_1h, __pyx_k_1h, sizeof(__pyx_k_1h), 0, 0, 1, 0},
    {&__pyx_kp_s_1m, __pyx_k_1m, sizeof(__pyx_k_1m), 0, 0, 1, 0},
    {&__pyx_kp_s_1s, __pyx_k_1s, sizeof(__pyx_k_1s), 0, 0, 1, 0},
    {&__pyx_kp_s_1w, __pyx_k_1w, sizeof(__pyx_k_1w), 0, 0, 1, 0},
    {&__pyx_kp_s_22, __pyx_k_22, sizeof(__pyx_k_22), 0, 0, 1, 0},
    {&__pyx_kp_s_27, __pyx_k_27, sizeof(__pyx_k_27), 0, 0, 1, 0},
    {&__pyx_kp_s_2_0_0, __pyx_k_2_0_0, sizeof(__pyx_k_2_0_0), 0, 0, 1, 0},
    {&__pyx_kp_s_2h, __pyx_k_2h, sizeof(__pyx_k_2h), 0, 0, 1, 0},
    {&__pyx_kp_s_30m, __pyx_k_30m, sizeof(__pyx_k_30m), 0, 0, 1, 0},
    {&__pyx_kp_s_3d, __pyx_k_3d, sizeof(__pyx_k_3d), 0, 0, 1, 0},
    {&__pyx_kp_s_3m, __pyx_k_3m, sizeof(__pyx_k_3m), 0, 0, 1, 0},
    {&__pyx_kp_s_4h, __pyx_k_4h, sizeof(__pyx_k_4h), 0, 0, 1, 0},
    {&__pyx_kp_s_5m, __pyx_k_5m, sizeof(__pyx_k_5m), 0, 0, 1, 0},
    {&__pyx_kp_s_6h, __pyx_k_6h, sizeof(__pyx_k_6h), 0, 0, 1, 0},
    {&__pyx_kp_s_8h, __pyx_k_8h, sizeof(__pyx_k_8h), 0, 0, 1, 0},
    {&__pyx_n_s_ACK, __pyx_k_ACK, sizeof(__pyx_k_ACK), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_BEST_MATCH, __pyx_k_AGG_BEST_MATCH, sizeof(__pyx_k_AGG_BEST_MATCH), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_BUYER_MAKES, __pyx_k_AGG_BUYER_MAKES, sizeof(__pyx_k_AGG_BUYER_MAKES), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_FIRST_TRADE_ID, __pyx_k_AGG_FIRST_TRADE_ID, sizeof(__pyx_k_AGG_FIRST_TRADE_ID), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_ID, __pyx_k_AGG_ID, sizeof(__pyx_k_AGG_ID), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_LAST_TRADE_ID, __pyx_k_AGG_LAST_TRADE_ID, sizeof(__pyx_k_AGG_LAST_TRADE_ID), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_PRICE, __pyx_k_AGG_PRICE, sizeof(__pyx_k_AGG_PRICE), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_QUANTITY, __pyx_k_AGG_QUANTITY, sizeof(__pyx_k_AGG_QUANTITY), 0, 0, 1, 1},
    {&__pyx_n_s_AGG_TIME, __pyx_k_AGG_TIME, sizeof(__pyx_k_AGG_TIME), 0, 0, 1, 1},
    {&__pyx_n_s_API_KEY, __pyx_k_API_KEY, sizeof(__pyx_k_API_KEY), 0, 0, 1, 1},
    {&__pyx_n_s_API_SECRET, __pyx_k_API_SECRET, sizeof(__pyx_k_API_SECRET), 0, 0, 1, 1},
    {&__pyx_n_s_API_URL, __pyx_k_API_URL, sizeof(__pyx_k_API_URL), 0, 0, 1, 1},
    {&__pyx_n_s_Accept, __pyx_k_Accept, sizeof(__pyx_k_Accept), 0, 0, 1, 1},
    {&__pyx_kp_u_An_exception_occurred, __pyx_k_An_exception_occurred, sizeof(__pyx_k_An_exception_occurred), 0, 1, 0, 0},
    {&__pyx_kp_s_An_unofficial_Python_API_to_use, __pyx_k_An_unofficial_Python_API_to_use, sizeof(__pyx_k_An_unofficial_Python_API_to_use), 0, 0, 1, 0},
    {&__pyx_n_s_BUY, __pyx_k_BUY, sizeof(__pyx_k_BUY), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceAPIException, __pyx_k_BinanceAPIException, sizeof(__pyx_k_BinanceAPIException), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRequestException, __pyx_k_BinanceRequestException, sizeof(__pyx_k_BinanceRequestException), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager, __pyx_k_BinanceRestApiManager, sizeof(__pyx_k_BinanceRestApiManager), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager___enter, __pyx_k_BinanceRestApiManager___enter, sizeof(__pyx_k_BinanceRestApiManager___enter), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager___exit, __pyx_k_BinanceRestApiManager___exit, sizeof(__pyx_k_BinanceRestApiManager___exit), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager___init, __pyx_k_BinanceRestApiManager___init, sizeof(__pyx_k_BinanceRestApiManager___init), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__create_ap, __pyx_k_BinanceRestApiManager__create_ap, sizeof(__pyx_k_BinanceRestApiManager__create_ap), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__create_fu, __pyx_k_BinanceRestApiManager__create_fu, sizeof(__pyx_k_BinanceRestApiManager__create_fu), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__create_fu_2, __pyx_k_BinanceRestApiManager__create_fu_2, sizeof(__pyx_k_BinanceRestApiManager__create_fu_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__create_fu_3, __pyx_k_BinanceRestApiManager__create_fu_3, sizeof(__pyx_k_BinanceRestApiManager__create_fu_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__create_fu_4, __pyx_k_BinanceRestApiManager__create_fu_4, sizeof(__pyx_k_BinanceRestApiManager__create_fu_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__create_ma, __pyx_k_BinanceRestApiManager__create_ma, sizeof(__pyx_k_BinanceRestApiManager__create_ma), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__create_we, __pyx_k_BinanceRestApiManager__create_we, sizeof(__pyx_k_BinanceRestApiManager__create_we), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__delete, __pyx_k_BinanceRestApiManager__delete, sizeof(__pyx_k_BinanceRestApiManager__delete), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__generate, __pyx_k_BinanceRestApiManager__generate, sizeof(__pyx_k_BinanceRestApiManager__generate), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__get, __pyx_k_BinanceRestApiManager__get, sizeof(__pyx_k_BinanceRestApiManager__get), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__get_earli, __pyx_k_BinanceRestApiManager__get_earli, sizeof(__pyx_k_BinanceRestApiManager__get_earli), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__handle_re, __pyx_k_BinanceRestApiManager__handle_re, sizeof(__pyx_k_BinanceRestApiManager__handle_re), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__init_sess, __pyx_k_BinanceRestApiManager__init_sess, sizeof(__pyx_k_BinanceRestApiManager__init_sess), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__order_par, __pyx_k_BinanceRestApiManager__order_par, sizeof(__pyx_k_BinanceRestApiManager__order_par), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__post, __pyx_k_BinanceRestApiManager__post, sizeof(__pyx_k_BinanceRestApiManager__post), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__put, __pyx_k_BinanceRestApiManager__put, sizeof(__pyx_k_BinanceRestApiManager__put), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request, __pyx_k_BinanceRestApiManager__request, sizeof(__pyx_k_BinanceRestApiManager__request), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_a, __pyx_k_BinanceRestApiManager__request_a, sizeof(__pyx_k_BinanceRestApiManager__request_a), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_f, __pyx_k_BinanceRestApiManager__request_f, sizeof(__pyx_k_BinanceRestApiManager__request_f), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_f_2, __pyx_k_BinanceRestApiManager__request_f_2, sizeof(__pyx_k_BinanceRestApiManager__request_f_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_f_3, __pyx_k_BinanceRestApiManager__request_f_3, sizeof(__pyx_k_BinanceRestApiManager__request_f_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_f_4, __pyx_k_BinanceRestApiManager__request_f_4, sizeof(__pyx_k_BinanceRestApiManager__request_f_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_l, __pyx_k_BinanceRestApiManager__request_l, sizeof(__pyx_k_BinanceRestApiManager__request_l), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_m, __pyx_k_BinanceRestApiManager__request_m, sizeof(__pyx_k_BinanceRestApiManager__request_m), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager__request_w, __pyx_k_BinanceRestApiManager__request_w, sizeof(__pyx_k_BinanceRestApiManager__request_w), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_aggregate, __pyx_k_BinanceRestApiManager_aggregate, sizeof(__pyx_k_BinanceRestApiManager_aggregate), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_cancel_all, __pyx_k_BinanceRestApiManager_cancel_all, sizeof(__pyx_k_BinanceRestApiManager_cancel_all), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_cancel_all_2, __pyx_k_BinanceRestApiManager_cancel_all_2, sizeof(__pyx_k_BinanceRestApiManager_cancel_all_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_cancel_mar, __pyx_k_BinanceRestApiManager_cancel_mar, sizeof(__pyx_k_BinanceRestApiManager_cancel_mar), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_cancel_mar_2, __pyx_k_BinanceRestApiManager_cancel_mar_2, sizeof(__pyx_k_BinanceRestApiManager_cancel_mar_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_cancel_ord, __pyx_k_BinanceRestApiManager_cancel_ord, sizeof(__pyx_k_BinanceRestApiManager_cancel_ord), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_change_fix, __pyx_k_BinanceRestApiManager_change_fix, sizeof(__pyx_k_BinanceRestApiManager_change_fix), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_iso, __pyx_k_BinanceRestApiManager_create_iso, sizeof(__pyx_k_BinanceRestApiManager_create_iso), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_mar, __pyx_k_BinanceRestApiManager_create_mar, sizeof(__pyx_k_BinanceRestApiManager_create_mar), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_mar_2, __pyx_k_BinanceRestApiManager_create_mar_2, sizeof(__pyx_k_BinanceRestApiManager_create_mar_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_mar_3, __pyx_k_BinanceRestApiManager_create_mar_3, sizeof(__pyx_k_BinanceRestApiManager_create_mar_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_oco, __pyx_k_BinanceRestApiManager_create_oco, sizeof(__pyx_k_BinanceRestApiManager_create_oco), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_ord, __pyx_k_BinanceRestApiManager_create_ord, sizeof(__pyx_k_BinanceRestApiManager_create_ord), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_sub, __pyx_k_BinanceRestApiManager_create_sub, sizeof(__pyx_k_BinanceRestApiManager_create_sub), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_create_tes, __pyx_k_BinanceRestApiManager_create_tes, sizeof(__pyx_k_BinanceRestApiManager_create_tes), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_disable_fa, __pyx_k_BinanceRestApiManager_disable_fa, sizeof(__pyx_k_BinanceRestApiManager_disable_fa), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_enable_fas, __pyx_k_BinanceRestApiManager_enable_fas, sizeof(__pyx_k_BinanceRestApiManager_enable_fas), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_enable_sub, __pyx_k_BinanceRestApiManager_enable_sub, sizeof(__pyx_k_BinanceRestApiManager_enable_sub), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_enable_sub_2, __pyx_k_BinanceRestApiManager_enable_sub_2, sizeof(__pyx_k_BinanceRestApiManager_enable_sub_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ac, __pyx_k_BinanceRestApiManager_futures_ac, sizeof(__pyx_k_BinanceRestApiManager_futures_ac), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ac_2, __pyx_k_BinanceRestApiManager_futures_ac_2, sizeof(__pyx_k_BinanceRestApiManager_futures_ac_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ac_3, __pyx_k_BinanceRestApiManager_futures_ac_3, sizeof(__pyx_k_BinanceRestApiManager_futures_ac_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ac_4, __pyx_k_BinanceRestApiManager_futures_ac_4, sizeof(__pyx_k_BinanceRestApiManager_futures_ac_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ag, __pyx_k_BinanceRestApiManager_futures_ag, sizeof(__pyx_k_BinanceRestApiManager_futures_ag), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_au, __pyx_k_BinanceRestApiManager_futures_au, sizeof(__pyx_k_BinanceRestApiManager_futures_au), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ca, __pyx_k_BinanceRestApiManager_futures_ca, sizeof(__pyx_k_BinanceRestApiManager_futures_ca), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ca_2, __pyx_k_BinanceRestApiManager_futures_ca_2, sizeof(__pyx_k_BinanceRestApiManager_futures_ca_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ca_3, __pyx_k_BinanceRestApiManager_futures_ca_3, sizeof(__pyx_k_BinanceRestApiManager_futures_ca_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ch, __pyx_k_BinanceRestApiManager_futures_ch, sizeof(__pyx_k_BinanceRestApiManager_futures_ch), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ch_2, __pyx_k_BinanceRestApiManager_futures_ch_2, sizeof(__pyx_k_BinanceRestApiManager_futures_ch_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ch_3, __pyx_k_BinanceRestApiManager_futures_ch_3, sizeof(__pyx_k_BinanceRestApiManager_futures_ch_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ch_4, __pyx_k_BinanceRestApiManager_futures_ch_4, sizeof(__pyx_k_BinanceRestApiManager_futures_ch_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co, __pyx_k_BinanceRestApiManager_futures_co, sizeof(__pyx_k_BinanceRestApiManager_futures_co), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_10, __pyx_k_BinanceRestApiManager_futures_co_10, sizeof(__pyx_k_BinanceRestApiManager_futures_co_10), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_11, __pyx_k_BinanceRestApiManager_futures_co_11, sizeof(__pyx_k_BinanceRestApiManager_futures_co_11), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_12, __pyx_k_BinanceRestApiManager_futures_co_12, sizeof(__pyx_k_BinanceRestApiManager_futures_co_12), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_13, __pyx_k_BinanceRestApiManager_futures_co_13, sizeof(__pyx_k_BinanceRestApiManager_futures_co_13), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_14, __pyx_k_BinanceRestApiManager_futures_co_14, sizeof(__pyx_k_BinanceRestApiManager_futures_co_14), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_15, __pyx_k_BinanceRestApiManager_futures_co_15, sizeof(__pyx_k_BinanceRestApiManager_futures_co_15), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_16, __pyx_k_BinanceRestApiManager_futures_co_16, sizeof(__pyx_k_BinanceRestApiManager_futures_co_16), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_17, __pyx_k_BinanceRestApiManager_futures_co_17, sizeof(__pyx_k_BinanceRestApiManager_futures_co_17), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_18, __pyx_k_BinanceRestApiManager_futures_co_18, sizeof(__pyx_k_BinanceRestApiManager_futures_co_18), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_19, __pyx_k_BinanceRestApiManager_futures_co_19, sizeof(__pyx_k_BinanceRestApiManager_futures_co_19), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_2, __pyx_k_BinanceRestApiManager_futures_co_2, sizeof(__pyx_k_BinanceRestApiManager_futures_co_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_20, __pyx_k_BinanceRestApiManager_futures_co_20, sizeof(__pyx_k_BinanceRestApiManager_futures_co_20), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_21, __pyx_k_BinanceRestApiManager_futures_co_21, sizeof(__pyx_k_BinanceRestApiManager_futures_co_21), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_22, __pyx_k_BinanceRestApiManager_futures_co_22, sizeof(__pyx_k_BinanceRestApiManager_futures_co_22), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_23, __pyx_k_BinanceRestApiManager_futures_co_23, sizeof(__pyx_k_BinanceRestApiManager_futures_co_23), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_24, __pyx_k_BinanceRestApiManager_futures_co_24, sizeof(__pyx_k_BinanceRestApiManager_futures_co_24), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_25, __pyx_k_BinanceRestApiManager_futures_co_25, sizeof(__pyx_k_BinanceRestApiManager_futures_co_25), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_26, __pyx_k_BinanceRestApiManager_futures_co_26, sizeof(__pyx_k_BinanceRestApiManager_futures_co_26), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_27, __pyx_k_BinanceRestApiManager_futures_co_27, sizeof(__pyx_k_BinanceRestApiManager_futures_co_27), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_28, __pyx_k_BinanceRestApiManager_futures_co_28, sizeof(__pyx_k_BinanceRestApiManager_futures_co_28), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_29, __pyx_k_BinanceRestApiManager_futures_co_29, sizeof(__pyx_k_BinanceRestApiManager_futures_co_29), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_3, __pyx_k_BinanceRestApiManager_futures_co_3, sizeof(__pyx_k_BinanceRestApiManager_futures_co_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_30, __pyx_k_BinanceRestApiManager_futures_co_30, sizeof(__pyx_k_BinanceRestApiManager_futures_co_30), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_31, __pyx_k_BinanceRestApiManager_futures_co_31, sizeof(__pyx_k_BinanceRestApiManager_futures_co_31), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_32, __pyx_k_BinanceRestApiManager_futures_co_32, sizeof(__pyx_k_BinanceRestApiManager_futures_co_32), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_33, __pyx_k_BinanceRestApiManager_futures_co_33, sizeof(__pyx_k_BinanceRestApiManager_futures_co_33), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_34, __pyx_k_BinanceRestApiManager_futures_co_34, sizeof(__pyx_k_BinanceRestApiManager_futures_co_34), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_35, __pyx_k_BinanceRestApiManager_futures_co_35, sizeof(__pyx_k_BinanceRestApiManager_futures_co_35), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_36, __pyx_k_BinanceRestApiManager_futures_co_36, sizeof(__pyx_k_BinanceRestApiManager_futures_co_36), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_37, __pyx_k_BinanceRestApiManager_futures_co_37, sizeof(__pyx_k_BinanceRestApiManager_futures_co_37), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_38, __pyx_k_BinanceRestApiManager_futures_co_38, sizeof(__pyx_k_BinanceRestApiManager_futures_co_38), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_39, __pyx_k_BinanceRestApiManager_futures_co_39, sizeof(__pyx_k_BinanceRestApiManager_futures_co_39), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_4, __pyx_k_BinanceRestApiManager_futures_co_4, sizeof(__pyx_k_BinanceRestApiManager_futures_co_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_40, __pyx_k_BinanceRestApiManager_futures_co_40, sizeof(__pyx_k_BinanceRestApiManager_futures_co_40), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_41, __pyx_k_BinanceRestApiManager_futures_co_41, sizeof(__pyx_k_BinanceRestApiManager_futures_co_41), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_42, __pyx_k_BinanceRestApiManager_futures_co_42, sizeof(__pyx_k_BinanceRestApiManager_futures_co_42), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_43, __pyx_k_BinanceRestApiManager_futures_co_43, sizeof(__pyx_k_BinanceRestApiManager_futures_co_43), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_5, __pyx_k_BinanceRestApiManager_futures_co_5, sizeof(__pyx_k_BinanceRestApiManager_futures_co_5), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_6, __pyx_k_BinanceRestApiManager_futures_co_6, sizeof(__pyx_k_BinanceRestApiManager_futures_co_6), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_7, __pyx_k_BinanceRestApiManager_futures_co_7, sizeof(__pyx_k_BinanceRestApiManager_futures_co_7), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_8, __pyx_k_BinanceRestApiManager_futures_co_8, sizeof(__pyx_k_BinanceRestApiManager_futures_co_8), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_co_9, __pyx_k_BinanceRestApiManager_futures_co_9, sizeof(__pyx_k_BinanceRestApiManager_futures_co_9), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_cr, __pyx_k_BinanceRestApiManager_futures_cr, sizeof(__pyx_k_BinanceRestApiManager_futures_cr), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ex, __pyx_k_BinanceRestApiManager_futures_ex, sizeof(__pyx_k_BinanceRestApiManager_futures_ex), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_fu, __pyx_k_BinanceRestApiManager_futures_fu, sizeof(__pyx_k_BinanceRestApiManager_futures_fu), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ge, __pyx_k_BinanceRestApiManager_futures_ge, sizeof(__pyx_k_BinanceRestApiManager_futures_ge), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ge_2, __pyx_k_BinanceRestApiManager_futures_ge_2, sizeof(__pyx_k_BinanceRestApiManager_futures_ge_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ge_3, __pyx_k_BinanceRestApiManager_futures_ge_3, sizeof(__pyx_k_BinanceRestApiManager_futures_ge_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ge_4, __pyx_k_BinanceRestApiManager_futures_ge_4, sizeof(__pyx_k_BinanceRestApiManager_futures_ge_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_hi, __pyx_k_BinanceRestApiManager_futures_hi, sizeof(__pyx_k_BinanceRestApiManager_futures_hi), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_in, __pyx_k_BinanceRestApiManager_futures_in, sizeof(__pyx_k_BinanceRestApiManager_futures_in), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_kl, __pyx_k_BinanceRestApiManager_futures_kl, sizeof(__pyx_k_BinanceRestApiManager_futures_kl), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_le, __pyx_k_BinanceRestApiManager_futures_le, sizeof(__pyx_k_BinanceRestApiManager_futures_le), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_li, __pyx_k_BinanceRestApiManager_futures_li, sizeof(__pyx_k_BinanceRestApiManager_futures_li), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ma, __pyx_k_BinanceRestApiManager_futures_ma, sizeof(__pyx_k_BinanceRestApiManager_futures_ma), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_op, __pyx_k_BinanceRestApiManager_futures_op, sizeof(__pyx_k_BinanceRestApiManager_futures_op), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_op_2, __pyx_k_BinanceRestApiManager_futures_op_2, sizeof(__pyx_k_BinanceRestApiManager_futures_op_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_or, __pyx_k_BinanceRestApiManager_futures_or, sizeof(__pyx_k_BinanceRestApiManager_futures_or), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_or_2, __pyx_k_BinanceRestApiManager_futures_or_2, sizeof(__pyx_k_BinanceRestApiManager_futures_or_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_pi, __pyx_k_BinanceRestApiManager_futures_pi, sizeof(__pyx_k_BinanceRestApiManager_futures_pi), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_pl, __pyx_k_BinanceRestApiManager_futures_pl, sizeof(__pyx_k_BinanceRestApiManager_futures_pl), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_po, __pyx_k_BinanceRestApiManager_futures_po, sizeof(__pyx_k_BinanceRestApiManager_futures_po), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_po_2, __pyx_k_BinanceRestApiManager_futures_po_2, sizeof(__pyx_k_BinanceRestApiManager_futures_po_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_re, __pyx_k_BinanceRestApiManager_futures_re, sizeof(__pyx_k_BinanceRestApiManager_futures_re), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_st, __pyx_k_BinanceRestApiManager_futures_st, sizeof(__pyx_k_BinanceRestApiManager_futures_st), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_st_2, __pyx_k_BinanceRestApiManager_futures_st_2, sizeof(__pyx_k_BinanceRestApiManager_futures_st_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_st_3, __pyx_k_BinanceRestApiManager_futures_st_3, sizeof(__pyx_k_BinanceRestApiManager_futures_st_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_sy, __pyx_k_BinanceRestApiManager_futures_sy, sizeof(__pyx_k_BinanceRestApiManager_futures_sy), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ti, __pyx_k_BinanceRestApiManager_futures_ti, sizeof(__pyx_k_BinanceRestApiManager_futures_ti), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_futures_ti_2, __pyx_k_BinanceRestApiManager_futures_ti_2, sizeof(__pyx_k_BinanceRestApiManager_futures_ti_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_accoun, __pyx_k_BinanceRestApiManager_get_accoun, sizeof(__pyx_k_BinanceRestApiManager_get_accoun), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_accoun_2, __pyx_k_BinanceRestApiManager_get_accoun_2, sizeof(__pyx_k_BinanceRestApiManager_get_accoun_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_accoun_3, __pyx_k_BinanceRestApiManager_get_accoun_3, sizeof(__pyx_k_BinanceRestApiManager_get_accoun_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_accoun_4, __pyx_k_BinanceRestApiManager_get_accoun_4, sizeof(__pyx_k_BinanceRestApiManager_get_accoun_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_aggreg, __pyx_k_BinanceRestApiManager_get_aggreg, sizeof(__pyx_k_BinanceRestApiManager_get_aggreg), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_all_co, __pyx_k_BinanceRestApiManager_get_all_co, sizeof(__pyx_k_BinanceRestApiManager_get_all_co), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_all_is, __pyx_k_BinanceRestApiManager_get_all_is, sizeof(__pyx_k_BinanceRestApiManager_get_all_is), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_all_ma, __pyx_k_BinanceRestApiManager_get_all_ma, sizeof(__pyx_k_BinanceRestApiManager_get_all_ma), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_all_or, __pyx_k_BinanceRestApiManager_get_all_or, sizeof(__pyx_k_BinanceRestApiManager_get_all_or), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_all_ti, __pyx_k_BinanceRestApiManager_get_all_ti, sizeof(__pyx_k_BinanceRestApiManager_get_all_ti), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_asset, __pyx_k_BinanceRestApiManager_get_asset, sizeof(__pyx_k_BinanceRestApiManager_get_asset), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_asset_2, __pyx_k_BinanceRestApiManager_get_asset_2, sizeof(__pyx_k_BinanceRestApiManager_get_asset_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_asset_3, __pyx_k_BinanceRestApiManager_get_asset_3, sizeof(__pyx_k_BinanceRestApiManager_get_asset_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_avg_pr, __pyx_k_BinanceRestApiManager_get_avg_pr, sizeof(__pyx_k_BinanceRestApiManager_get_avg_pr), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_bnb_bu, __pyx_k_BinanceRestApiManager_get_bnb_bu, sizeof(__pyx_k_BinanceRestApiManager_get_bnb_bu), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_deposi, __pyx_k_BinanceRestApiManager_get_deposi, sizeof(__pyx_k_BinanceRestApiManager_get_deposi), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_deposi_2, __pyx_k_BinanceRestApiManager_get_deposi_2, sizeof(__pyx_k_BinanceRestApiManager_get_deposi_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_dust_l, __pyx_k_BinanceRestApiManager_get_dust_l, sizeof(__pyx_k_BinanceRestApiManager_get_dust_l), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_exchan, __pyx_k_BinanceRestApiManager_get_exchan, sizeof(__pyx_k_BinanceRestApiManager_get_exchan), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_fixed, __pyx_k_BinanceRestApiManager_get_fixed, sizeof(__pyx_k_BinanceRestApiManager_get_fixed), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_histor, __pyx_k_BinanceRestApiManager_get_histor, sizeof(__pyx_k_BinanceRestApiManager_get_histor), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_histor_2, __pyx_k_BinanceRestApiManager_get_histor_2, sizeof(__pyx_k_BinanceRestApiManager_get_histor_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_histor_3, __pyx_k_BinanceRestApiManager_get_histor_3, sizeof(__pyx_k_BinanceRestApiManager_get_histor_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_isolat, __pyx_k_BinanceRestApiManager_get_isolat, sizeof(__pyx_k_BinanceRestApiManager_get_isolat), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_isolat_2, __pyx_k_BinanceRestApiManager_get_isolat_2, sizeof(__pyx_k_BinanceRestApiManager_get_isolat_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_klines, __pyx_k_BinanceRestApiManager_get_klines, sizeof(__pyx_k_BinanceRestApiManager_get_klines), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_latest, __pyx_k_BinanceRestApiManager_get_latest, sizeof(__pyx_k_BinanceRestApiManager_get_latest), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_latest_2, __pyx_k_BinanceRestApiManager_get_latest_2, sizeof(__pyx_k_BinanceRestApiManager_get_latest_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin, __pyx_k_BinanceRestApiManager_get_lendin, sizeof(__pyx_k_BinanceRestApiManager_get_lendin), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin_2, __pyx_k_BinanceRestApiManager_get_lendin_2, sizeof(__pyx_k_BinanceRestApiManager_get_lendin_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin_3, __pyx_k_BinanceRestApiManager_get_lendin_3, sizeof(__pyx_k_BinanceRestApiManager_get_lendin_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin_4, __pyx_k_BinanceRestApiManager_get_lendin_4, sizeof(__pyx_k_BinanceRestApiManager_get_lendin_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin_5, __pyx_k_BinanceRestApiManager_get_lendin_5, sizeof(__pyx_k_BinanceRestApiManager_get_lendin_5), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin_6, __pyx_k_BinanceRestApiManager_get_lendin_6, sizeof(__pyx_k_BinanceRestApiManager_get_lendin_6), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin_7, __pyx_k_BinanceRestApiManager_get_lendin_7, sizeof(__pyx_k_BinanceRestApiManager_get_lendin_7), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_lendin_8, __pyx_k_BinanceRestApiManager_get_lendin_8, sizeof(__pyx_k_BinanceRestApiManager_get_lendin_8), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin, __pyx_k_BinanceRestApiManager_get_margin, sizeof(__pyx_k_BinanceRestApiManager_get_margin), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_2, __pyx_k_BinanceRestApiManager_get_margin_2, sizeof(__pyx_k_BinanceRestApiManager_get_margin_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_3, __pyx_k_BinanceRestApiManager_get_margin_3, sizeof(__pyx_k_BinanceRestApiManager_get_margin_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_4, __pyx_k_BinanceRestApiManager_get_margin_4, sizeof(__pyx_k_BinanceRestApiManager_get_margin_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_5, __pyx_k_BinanceRestApiManager_get_margin_5, sizeof(__pyx_k_BinanceRestApiManager_get_margin_5), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_6, __pyx_k_BinanceRestApiManager_get_margin_6, sizeof(__pyx_k_BinanceRestApiManager_get_margin_6), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_7, __pyx_k_BinanceRestApiManager_get_margin_7, sizeof(__pyx_k_BinanceRestApiManager_get_margin_7), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_8, __pyx_k_BinanceRestApiManager_get_margin_8, sizeof(__pyx_k_BinanceRestApiManager_get_margin_8), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_margin_9, __pyx_k_BinanceRestApiManager_get_margin_9, sizeof(__pyx_k_BinanceRestApiManager_get_margin_9), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_max_ma, __pyx_k_BinanceRestApiManager_get_max_ma, sizeof(__pyx_k_BinanceRestApiManager_get_max_ma), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_max_ma_2, __pyx_k_BinanceRestApiManager_get_max_ma_2, sizeof(__pyx_k_BinanceRestApiManager_get_max_ma_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_my_tra, __pyx_k_BinanceRestApiManager_get_my_tra, sizeof(__pyx_k_BinanceRestApiManager_get_my_tra), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_open_i, __pyx_k_BinanceRestApiManager_get_open_i, sizeof(__pyx_k_BinanceRestApiManager_get_open_i), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_open_m, __pyx_k_BinanceRestApiManager_get_open_m, sizeof(__pyx_k_BinanceRestApiManager_get_open_m), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_open_m_2, __pyx_k_BinanceRestApiManager_get_open_m_2, sizeof(__pyx_k_BinanceRestApiManager_get_open_m_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_open_o, __pyx_k_BinanceRestApiManager_get_open_o, sizeof(__pyx_k_BinanceRestApiManager_get_open_o), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_order, __pyx_k_BinanceRestApiManager_get_order, sizeof(__pyx_k_BinanceRestApiManager_get_order), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_order_2, __pyx_k_BinanceRestApiManager_get_order_2, sizeof(__pyx_k_BinanceRestApiManager_get_order_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_orderb, __pyx_k_BinanceRestApiManager_get_orderb, sizeof(__pyx_k_BinanceRestApiManager_get_orderb), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_orderb_2, __pyx_k_BinanceRestApiManager_get_orderb_2, sizeof(__pyx_k_BinanceRestApiManager_get_orderb_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_produc, __pyx_k_BinanceRestApiManager_get_produc, sizeof(__pyx_k_BinanceRestApiManager_get_produc), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_recent, __pyx_k_BinanceRestApiManager_get_recent, sizeof(__pyx_k_BinanceRestApiManager_get_recent), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_server, __pyx_k_BinanceRestApiManager_get_server, sizeof(__pyx_k_BinanceRestApiManager_get_server), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_sub_ac, __pyx_k_BinanceRestApiManager_get_sub_ac, sizeof(__pyx_k_BinanceRestApiManager_get_sub_ac), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_sub_ac_2, __pyx_k_BinanceRestApiManager_get_sub_ac_2, sizeof(__pyx_k_BinanceRestApiManager_get_sub_ac_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_sub_ac_3, __pyx_k_BinanceRestApiManager_get_sub_ac_3, sizeof(__pyx_k_BinanceRestApiManager_get_sub_ac_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_sub_ac_4, __pyx_k_BinanceRestApiManager_get_sub_ac_4, sizeof(__pyx_k_BinanceRestApiManager_get_sub_ac_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc, __pyx_k_BinanceRestApiManager_get_subacc, sizeof(__pyx_k_BinanceRestApiManager_get_subacc), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_2, __pyx_k_BinanceRestApiManager_get_subacc_2, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_3, __pyx_k_BinanceRestApiManager_get_subacc_3, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_4, __pyx_k_BinanceRestApiManager_get_subacc_4, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_5, __pyx_k_BinanceRestApiManager_get_subacc_5, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_5), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_6, __pyx_k_BinanceRestApiManager_get_subacc_6, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_6), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_7, __pyx_k_BinanceRestApiManager_get_subacc_7, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_7), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_8, __pyx_k_BinanceRestApiManager_get_subacc_8, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_8), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_subacc_9, __pyx_k_BinanceRestApiManager_get_subacc_9, sizeof(__pyx_k_BinanceRestApiManager_get_subacc_9), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_symbol, __pyx_k_BinanceRestApiManager_get_symbol, sizeof(__pyx_k_BinanceRestApiManager_get_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_symbol_2, __pyx_k_BinanceRestApiManager_get_symbol_2, sizeof(__pyx_k_BinanceRestApiManager_get_symbol_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_system, __pyx_k_BinanceRestApiManager_get_system, sizeof(__pyx_k_BinanceRestApiManager_get_system), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_ticker, __pyx_k_BinanceRestApiManager_get_ticker, sizeof(__pyx_k_BinanceRestApiManager_get_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_trade, __pyx_k_BinanceRestApiManager_get_trade, sizeof(__pyx_k_BinanceRestApiManager_get_trade), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_univer, __pyx_k_BinanceRestApiManager_get_univer, sizeof(__pyx_k_BinanceRestApiManager_get_univer), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_used_w, __pyx_k_BinanceRestApiManager_get_used_w, sizeof(__pyx_k_BinanceRestApiManager_get_used_w), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_user_a, __pyx_k_BinanceRestApiManager_get_user_a, sizeof(__pyx_k_BinanceRestApiManager_get_user_a), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_versio, __pyx_k_BinanceRestApiManager_get_versio, sizeof(__pyx_k_BinanceRestApiManager_get_versio), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_withdr, __pyx_k_BinanceRestApiManager_get_withdr, sizeof(__pyx_k_BinanceRestApiManager_get_withdr), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_get_withdr_2, __pyx_k_BinanceRestApiManager_get_withdr_2, sizeof(__pyx_k_BinanceRestApiManager_get_withdr_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_is_update, __pyx_k_BinanceRestApiManager_is_update, sizeof(__pyx_k_BinanceRestApiManager_is_update), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_isolated_m, __pyx_k_BinanceRestApiManager_isolated_m, sizeof(__pyx_k_BinanceRestApiManager_isolated_m), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_isolated_m_2, __pyx_k_BinanceRestApiManager_isolated_m_2, sizeof(__pyx_k_BinanceRestApiManager_isolated_m_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_isolated_m_3, __pyx_k_BinanceRestApiManager_isolated_m_3, sizeof(__pyx_k_BinanceRestApiManager_isolated_m_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_make_subac, __pyx_k_BinanceRestApiManager_make_subac, sizeof(__pyx_k_BinanceRestApiManager_make_subac), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_make_subac_2, __pyx_k_BinanceRestApiManager_make_subac_2, sizeof(__pyx_k_BinanceRestApiManager_make_subac_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_make_subac_3, __pyx_k_BinanceRestApiManager_make_subac_3, sizeof(__pyx_k_BinanceRestApiManager_make_subac_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_make_subac_4, __pyx_k_BinanceRestApiManager_make_subac_4, sizeof(__pyx_k_BinanceRestApiManager_make_subac_4), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_make_unive, __pyx_k_BinanceRestApiManager_make_unive, sizeof(__pyx_k_BinanceRestApiManager_make_unive), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_margin_str, __pyx_k_BinanceRestApiManager_margin_str, sizeof(__pyx_k_BinanceRestApiManager_margin_str), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_margin_str_2, __pyx_k_BinanceRestApiManager_margin_str_2, sizeof(__pyx_k_BinanceRestApiManager_margin_str_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_margin_str_3, __pyx_k_BinanceRestApiManager_margin_str_3, sizeof(__pyx_k_BinanceRestApiManager_margin_str_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_new_transf, __pyx_k_BinanceRestApiManager_new_transf, sizeof(__pyx_k_BinanceRestApiManager_new_transf), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_limi, __pyx_k_BinanceRestApiManager_order_limi, sizeof(__pyx_k_BinanceRestApiManager_order_limi), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_limi_2, __pyx_k_BinanceRestApiManager_order_limi_2, sizeof(__pyx_k_BinanceRestApiManager_order_limi_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_limi_3, __pyx_k_BinanceRestApiManager_order_limi_3, sizeof(__pyx_k_BinanceRestApiManager_order_limi_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_mark, __pyx_k_BinanceRestApiManager_order_mark, sizeof(__pyx_k_BinanceRestApiManager_order_mark), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_mark_2, __pyx_k_BinanceRestApiManager_order_mark_2, sizeof(__pyx_k_BinanceRestApiManager_order_mark_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_mark_3, __pyx_k_BinanceRestApiManager_order_mark_3, sizeof(__pyx_k_BinanceRestApiManager_order_mark_3), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_oco, __pyx_k_BinanceRestApiManager_order_oco, sizeof(__pyx_k_BinanceRestApiManager_order_oco), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_order_oco_2, __pyx_k_BinanceRestApiManager_order_oco_2, sizeof(__pyx_k_BinanceRestApiManager_order_oco_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_ping, __pyx_k_BinanceRestApiManager_ping, sizeof(__pyx_k_BinanceRestApiManager_ping), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_purchase_l, __pyx_k_BinanceRestApiManager_purchase_l, sizeof(__pyx_k_BinanceRestApiManager_purchase_l), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_query_suba, __pyx_k_BinanceRestApiManager_query_suba, sizeof(__pyx_k_BinanceRestApiManager_query_suba), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_query_univ, __pyx_k_BinanceRestApiManager_query_univ, sizeof(__pyx_k_BinanceRestApiManager_query_univ), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_redeem_len, __pyx_k_BinanceRestApiManager_redeem_len, sizeof(__pyx_k_BinanceRestApiManager_redeem_len), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_repay_marg, __pyx_k_BinanceRestApiManager_repay_marg, sizeof(__pyx_k_BinanceRestApiManager_repay_marg), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_stop_manag, __pyx_k_BinanceRestApiManager_stop_manag, sizeof(__pyx_k_BinanceRestApiManager_stop_manag), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_stream_clo, __pyx_k_BinanceRestApiManager_stream_clo, sizeof(__pyx_k_BinanceRestApiManager_stream_clo), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_stream_get, __pyx_k_BinanceRestApiManager_stream_get, sizeof(__pyx_k_BinanceRestApiManager_stream_get), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_stream_kee, __pyx_k_BinanceRestApiManager_stream_kee, sizeof(__pyx_k_BinanceRestApiManager_stream_kee), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_toggle_bnb, __pyx_k_BinanceRestApiManager_toggle_bnb, sizeof(__pyx_k_BinanceRestApiManager_toggle_bnb), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_transfer_d, __pyx_k_BinanceRestApiManager_transfer_d, sizeof(__pyx_k_BinanceRestApiManager_transfer_d), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_transfer_h, __pyx_k_BinanceRestApiManager_transfer_h, sizeof(__pyx_k_BinanceRestApiManager_transfer_h), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_transfer_i, __pyx_k_BinanceRestApiManager_transfer_i, sizeof(__pyx_k_BinanceRestApiManager_transfer_i), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_transfer_m, __pyx_k_BinanceRestApiManager_transfer_m, sizeof(__pyx_k_BinanceRestApiManager_transfer_m), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_transfer_s, __pyx_k_BinanceRestApiManager_transfer_s, sizeof(__pyx_k_BinanceRestApiManager_transfer_s), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_transfer_s_2, __pyx_k_BinanceRestApiManager_transfer_s_2, sizeof(__pyx_k_BinanceRestApiManager_transfer_s_2), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_universal, __pyx_k_BinanceRestApiManager_universal, sizeof(__pyx_k_BinanceRestApiManager_universal), 0, 0, 1, 1},
    {&__pyx_n_s_BinanceRestApiManager_withdraw, __pyx_k_BinanceRestApiManager_withdraw, sizeof(__pyx_k_BinanceRestApiManager_withdraw), 0, 0, 1, 1},
    {&__pyx_kp_s_BinanceWebSocketApiManager_stop, __pyx_k_BinanceWebSocketApiManager_stop, sizeof(__pyx_k_BinanceWebSocketApiManager_stop), 0, 0, 1, 0},
    {&__pyx_n_s_BinanceWithdrawException, __pyx_k_BinanceWithdrawException, sizeof(__pyx_k_BinanceWithdrawException), 0, 0, 1, 1},
    {&__pyx_n_s_C2C_MAIN, __pyx_k_C2C_MAIN, sizeof(__pyx_k_C2C_MAIN), 0, 0, 1, 1},
    {&__pyx_n_s_C2C_MINING, __pyx_k_C2C_MINING, sizeof(__pyx_k_C2C_MINING), 0, 0, 1, 1},
    {&__pyx_n_s_C2C_UMFUTURE, __pyx_k_C2C_UMFUTURE, sizeof(__pyx_k_C2C_UMFUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_CANCELED, __pyx_k_CANCELED, sizeof(__pyx_k_CANCELED), 0, 0, 1, 1},
    {&__pyx_n_s_CMFUTURE_MAIN, __pyx_k_CMFUTURE_MAIN, sizeof(__pyx_k_CMFUTURE_MAIN), 0, 0, 1, 1},
    {&__pyx_n_s_COIN_FUTURE_TO_SPOT, __pyx_k_COIN_FUTURE_TO_SPOT, sizeof(__pyx_k_COIN_FUTURE_TO_SPOT), 0, 0, 1, 1},
    {&__pyx_kp_u_Created_SOCKS5_proxy_URI, __pyx_k_Created_SOCKS5_proxy_URI, sizeof(__pyx_k_Created_SOCKS5_proxy_URI), 0, 1, 0, 0},
    {&__pyx_n_s_Date, __pyx_k_Date, sizeof(__pyx_k_Date), 0, 0, 1, 1},
    {&__pyx_n_s_EXPIRED, __pyx_k_EXPIRED, sizeof(__pyx_k_EXPIRED), 0, 0, 1, 1},
    {&__pyx_kp_u_Entering_with_context, __pyx_k_Entering_with_context, sizeof(__pyx_k_Entering_with_context), 0, 1, 0, 0},
    {&__pyx_n_s_FIAT_TO_MINING, __pyx_k_FIAT_TO_MINING, sizeof(__pyx_k_FIAT_TO_MINING), 0, 0, 1, 1},
    {&__pyx_n_s_FIAT_TO_SPOT, __pyx_k_FIAT_TO_SPOT, sizeof(__pyx_k_FIAT_TO_SPOT), 0, 0, 1, 1},
    {&__pyx_n_s_FIAT_TO_USDT_FUTURE, __pyx_k_FIAT_TO_USDT_FUTURE, sizeof(__pyx_k_FIAT_TO_USDT_FUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_FILLED, __pyx_k_FILLED, sizeof(__pyx_k_FILLED), 0, 0, 1, 1},
    {&__pyx_n_s_FOK, __pyx_k_FOK, sizeof(__pyx_k_FOK), 0, 0, 1, 1},
    {&__pyx_n_s_FULL, __pyx_k_FULL, sizeof(__pyx_k_FULL), 0, 0, 1, 1},
    {&__pyx_n_s_FUTURES_API_VERSION, __pyx_k_FUTURES_API_VERSION, sizeof(__pyx_k_FUTURES_API_VERSION), 0, 0, 1, 1},
    {&__pyx_n_s_FUTURES_API_VERSION2, __pyx_k_FUTURES_API_VERSION2, sizeof(__pyx_k_FUTURES_API_VERSION2), 0, 0, 1, 1},
    {&__pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_k_FUTURES_COIN_DATA_URL, sizeof(__pyx_k_FUTURES_COIN_DATA_URL), 0, 0, 1, 1},
    {&__pyx_n_s_FUTURES_COIN_URL, __pyx_k_FUTURES_COIN_URL, sizeof(__pyx_k_FUTURES_COIN_URL), 0, 0, 1, 1},
    {&__pyx_n_s_FUTURES_DATA_URL, __pyx_k_FUTURES_DATA_URL, sizeof(__pyx_k_FUTURES_DATA_URL), 0, 0, 1, 1},
    {&__pyx_n_s_FUTURES_URL, __pyx_k_FUTURES_URL, sizeof(__pyx_k_FUTURES_URL), 0, 0, 1, 1},
    {&__pyx_n_s_GTC, __pyx_k_GTC, sizeof(__pyx_k_GTC), 0, 0, 1, 1},
    {&__pyx_n_s_IOC, __pyx_k_IOC, sizeof(__pyx_k_IOC), 0, 0, 1, 1},
    {&__pyx_n_s_ISOLATED_MARGIN, __pyx_k_ISOLATED_MARGIN, sizeof(__pyx_k_ISOLATED_MARGIN), 0, 0, 1, 1},
    {&__pyx_kp_u_Initiating_colorama, __pyx_k_Initiating_colorama, sizeof(__pyx_k_Initiating_colorama), 0, 1, 0, 0},
    {&__pyx_kp_s_Invalid_Response_s, __pyx_k_Invalid_Response_s, sizeof(__pyx_k_Invalid_Response_s), 0, 0, 1, 0},
    {&__pyx_n_s_KLINE_INTERVAL_12HOUR, __pyx_k_KLINE_INTERVAL_12HOUR, sizeof(__pyx_k_KLINE_INTERVAL_12HOUR), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_15MINUTE, __pyx_k_KLINE_INTERVAL_15MINUTE, sizeof(__pyx_k_KLINE_INTERVAL_15MINUTE), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_1DAY, __pyx_k_KLINE_INTERVAL_1DAY, sizeof(__pyx_k_KLINE_INTERVAL_1DAY), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_1HOUR, __pyx_k_KLINE_INTERVAL_1HOUR, sizeof(__pyx_k_KLINE_INTERVAL_1HOUR), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_1MINUTE, __pyx_k_KLINE_INTERVAL_1MINUTE, sizeof(__pyx_k_KLINE_INTERVAL_1MINUTE), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_1MONTH, __pyx_k_KLINE_INTERVAL_1MONTH, sizeof(__pyx_k_KLINE_INTERVAL_1MONTH), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_1SECOND, __pyx_k_KLINE_INTERVAL_1SECOND, sizeof(__pyx_k_KLINE_INTERVAL_1SECOND), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_1WEEK, __pyx_k_KLINE_INTERVAL_1WEEK, sizeof(__pyx_k_KLINE_INTERVAL_1WEEK), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_2HOUR, __pyx_k_KLINE_INTERVAL_2HOUR, sizeof(__pyx_k_KLINE_INTERVAL_2HOUR), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_30MINUTE, __pyx_k_KLINE_INTERVAL_30MINUTE, sizeof(__pyx_k_KLINE_INTERVAL_30MINUTE), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_3DAY, __pyx_k_KLINE_INTERVAL_3DAY, sizeof(__pyx_k_KLINE_INTERVAL_3DAY), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_3MINUTE, __pyx_k_KLINE_INTERVAL_3MINUTE, sizeof(__pyx_k_KLINE_INTERVAL_3MINUTE), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_4HOUR, __pyx_k_KLINE_INTERVAL_4HOUR, sizeof(__pyx_k_KLINE_INTERVAL_4HOUR), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_5MINUTE, __pyx_k_KLINE_INTERVAL_5MINUTE, sizeof(__pyx_k_KLINE_INTERVAL_5MINUTE), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_6HOUR, __pyx_k_KLINE_INTERVAL_6HOUR, sizeof(__pyx_k_KLINE_INTERVAL_6HOUR), 0, 0, 1, 1},
    {&__pyx_n_s_KLINE_INTERVAL_8HOUR, __pyx_k_KLINE_INTERVAL_8HOUR, sizeof(__pyx_k_KLINE_INTERVAL_8HOUR), 0, 0, 1, 1},
    {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
    {&__pyx_n_s_LIMIT, __pyx_k_LIMIT, sizeof(__pyx_k_LIMIT), 0, 0, 1, 1},
    {&__pyx_n_s_LIMIT_MAKER, __pyx_k_LIMIT_MAKER, sizeof(__pyx_k_LIMIT_MAKER), 0, 0, 1, 1},
    {&__pyx_kp_u_Leaving_with_context, __pyx_k_Leaving_with_context, sizeof(__pyx_k_Leaving_with_context), 0, 1, 0, 0},
    {&__pyx_n_s_LucitLicensingManager, __pyx_k_LucitLicensingManager, sizeof(__pyx_k_LucitLicensingManager), 0, 0, 1, 1},
    {&__pyx_n_s_M, __pyx_k_M, sizeof(__pyx_k_M), 0, 0, 1, 1},
    {&__pyx_n_s_MAIN_C2C, __pyx_k_MAIN_C2C, sizeof(__pyx_k_MAIN_C2C), 0, 0, 1, 1},
    {&__pyx_n_s_MAIN_CMFUTURE, __pyx_k_MAIN_CMFUTURE, sizeof(__pyx_k_MAIN_CMFUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_MAIN_MARGIN, __pyx_k_MAIN_MARGIN, sizeof(__pyx_k_MAIN_MARGIN), 0, 0, 1, 1},
    {&__pyx_n_s_MAIN_MINING, __pyx_k_MAIN_MINING, sizeof(__pyx_k_MAIN_MINING), 0, 0, 1, 1},
    {&__pyx_n_s_MAIN_UMFUTURE, __pyx_k_MAIN_UMFUTURE, sizeof(__pyx_k_MAIN_UMFUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_MARGIN_API_URL, __pyx_k_MARGIN_API_URL, sizeof(__pyx_k_MARGIN_API_URL), 0, 0, 1, 1},
    {&__pyx_n_s_MARGIN_API_VERSION, __pyx_k_MARGIN_API_VERSION, sizeof(__pyx_k_MARGIN_API_VERSION), 0, 0, 1, 1},
    {&__pyx_n_s_MARGIN_CROSS_TO_SPOT, __pyx_k_MARGIN_CROSS_TO_SPOT, sizeof(__pyx_k_MARGIN_CROSS_TO_SPOT), 0, 0, 1, 1},
    {&__pyx_n_s_MARGIN_CROSS_TO_USDT_FUTURE, __pyx_k_MARGIN_CROSS_TO_USDT_FUTURE, sizeof(__pyx_k_MARGIN_CROSS_TO_USDT_FUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_MARGIN_MAIN, __pyx_k_MARGIN_MAIN, sizeof(__pyx_k_MARGIN_MAIN), 0, 0, 1, 1},
    {&__pyx_n_s_MARGIN_UMFUTURE, __pyx_k_MARGIN_UMFUTURE, sizeof(__pyx_k_MARGIN_UMFUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_MARKET, __pyx_k_MARKET, sizeof(__pyx_k_MARKET), 0, 0, 1, 1},
    {&__pyx_n_s_MINING_C2C, __pyx_k_MINING_C2C, sizeof(__pyx_k_MINING_C2C), 0, 0, 1, 1},
    {&__pyx_n_s_MINING_MAIN, __pyx_k_MINING_MAIN, sizeof(__pyx_k_MINING_MAIN), 0, 0, 1, 1},
    {&__pyx_n_s_MINING_TO_FIAT, __pyx_k_MINING_TO_FIAT, sizeof(__pyx_k_MINING_TO_FIAT), 0, 0, 1, 1},
    {&__pyx_n_s_MINING_TO_SPOT, __pyx_k_MINING_TO_SPOT, sizeof(__pyx_k_MINING_TO_SPOT), 0, 0, 1, 1},
    {&__pyx_n_s_MINING_TO_USDT_FUTURE, __pyx_k_MINING_TO_USDT_FUTURE, sizeof(__pyx_k_MINING_TO_USDT_FUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_MINING_UMFUTURE, __pyx_k_MINING_UMFUTURE, sizeof(__pyx_k_MINING_UMFUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_NEW, __pyx_k_NEW, sizeof(__pyx_k_NEW), 0, 0, 1, 1},
    {&__pyx_kp_u_New_instance_of, __pyx_k_New_instance_of, sizeof(__pyx_k_New_instance_of), 0, 1, 0, 0},
    {&__pyx_n_s_ORDER_RESP_TYPE_ACK, __pyx_k_ORDER_RESP_TYPE_ACK, sizeof(__pyx_k_ORDER_RESP_TYPE_ACK), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_RESP_TYPE_FULL, __pyx_k_ORDER_RESP_TYPE_FULL, sizeof(__pyx_k_ORDER_RESP_TYPE_FULL), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_RESP_TYPE_RESULT, __pyx_k_ORDER_RESP_TYPE_RESULT, sizeof(__pyx_k_ORDER_RESP_TYPE_RESULT), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_STATUS_CANCELED, __pyx_k_ORDER_STATUS_CANCELED, sizeof(__pyx_k_ORDER_STATUS_CANCELED), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_STATUS_EXPIRED, __pyx_k_ORDER_STATUS_EXPIRED, sizeof(__pyx_k_ORDER_STATUS_EXPIRED), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_STATUS_FILLED, __pyx_k_ORDER_STATUS_FILLED, sizeof(__pyx_k_ORDER_STATUS_FILLED), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_STATUS_NEW, __pyx_k_ORDER_STATUS_NEW, sizeof(__pyx_k_ORDER_STATUS_NEW), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_STATUS_PARTIALLY_FILLED, __pyx_k_ORDER_STATUS_PARTIALLY_FILLED, sizeof(__pyx_k_ORDER_STATUS_PARTIALLY_FILLED), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_STATUS_PENDING_CANCEL, __pyx_k_ORDER_STATUS_PENDING_CANCEL, sizeof(__pyx_k_ORDER_STATUS_PENDING_CANCEL), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_STATUS_REJECTED, __pyx_k_ORDER_STATUS_REJECTED, sizeof(__pyx_k_ORDER_STATUS_REJECTED), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_TYPE_LIMIT, __pyx_k_ORDER_TYPE_LIMIT, sizeof(__pyx_k_ORDER_TYPE_LIMIT), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_TYPE_LIMIT_MAKER, __pyx_k_ORDER_TYPE_LIMIT_MAKER, sizeof(__pyx_k_ORDER_TYPE_LIMIT_MAKER), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_TYPE_MARKET, __pyx_k_ORDER_TYPE_MARKET, sizeof(__pyx_k_ORDER_TYPE_MARKET), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_TYPE_STOP_LOSS, __pyx_k_ORDER_TYPE_STOP_LOSS, sizeof(__pyx_k_ORDER_TYPE_STOP_LOSS), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_TYPE_STOP_LOSS_LIMIT, __pyx_k_ORDER_TYPE_STOP_LOSS_LIMIT, sizeof(__pyx_k_ORDER_TYPE_STOP_LOSS_LIMIT), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_TYPE_TAKE_PROFIT, __pyx_k_ORDER_TYPE_TAKE_PROFIT, sizeof(__pyx_k_ORDER_TYPE_TAKE_PROFIT), 0, 0, 1, 1},
    {&__pyx_n_s_ORDER_TYPE_TAKE_PROFIT_LIMIT, __pyx_k_ORDER_TYPE_TAKE_PROFIT_LIMIT, sizeof(__pyx_k_ORDER_TYPE_TAKE_PROFIT_LIMIT), 0, 0, 1, 1},
    {&__pyx_n_s_Optional, __pyx_k_Optional, sizeof(__pyx_k_Optional), 0, 0, 1, 1},
    {&__pyx_kp_s_Optional_bool, __pyx_k_Optional_bool, sizeof(__pyx_k_Optional_bool), 0, 0, 1, 0},
    {&__pyx_kp_s_Optional_str, __pyx_k_Optional_str, sizeof(__pyx_k_Optional_str), 0, 0, 1, 0},
    {&__pyx_n_s_PARTIALLY_FILLED, __pyx_k_PARTIALLY_FILLED, sizeof(__pyx_k_PARTIALLY_FILLED), 0, 0, 1, 1},
    {&__pyx_n_s_PENDING_CANCEL, __pyx_k_PENDING_CANCEL, sizeof(__pyx_k_PENDING_CANCEL), 0, 0, 1, 1},
    {&__pyx_n_s_PRIVATE_API_VERSION, __pyx_k_PRIVATE_API_VERSION, sizeof(__pyx_k_PRIVATE_API_VERSION), 0, 0, 1, 1},
    {&__pyx_n_s_PUBLIC_API_VERSION, __pyx_k_PUBLIC_API_VERSION, sizeof(__pyx_k_PUBLIC_API_VERSION), 0, 0, 1, 1},
    {&__pyx_n_s_REJECTED, __pyx_k_REJECTED, sizeof(__pyx_k_REJECTED), 0, 0, 1, 1},
    {&__pyx_n_s_RESULT, __pyx_k_RESULT, sizeof(__pyx_k_RESULT), 0, 0, 1, 1},
    {&__pyx_kp_u_Read_the_docs_to_see_a_list_of, __pyx_k_Read_the_docs_to_see_a_list_of, sizeof(__pyx_k_Read_the_docs_to_see_a_list_of), 0, 1, 0, 0},
    {&__pyx_kp_u_Release, __pyx_k_Release, sizeof(__pyx_k_Release), 0, 1, 0, 0},
    {&__pyx_n_s_SELL, __pyx_k_SELL, sizeof(__pyx_k_SELL), 0, 0, 1, 1},
    {&__pyx_n_s_SIDE_BUY, __pyx_k_SIDE_BUY, sizeof(__pyx_k_SIDE_BUY), 0, 0, 1, 1},
    {&__pyx_n_s_SIDE_SELL, __pyx_k_SIDE_SELL, sizeof(__pyx_k_SIDE_SELL), 0, 0, 1, 1},
    {&__pyx_n_s_SPOT, __pyx_k_SPOT, sizeof(__pyx_k_SPOT), 0, 0, 1, 1},
    {&__pyx_n_s_SPOT_TO_COIN_FUTURE, __pyx_k_SPOT_TO_COIN_FUTURE, sizeof(__pyx_k_SPOT_TO_COIN_FUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_SPOT_TO_FIAT, __pyx_k_SPOT_TO_FIAT, sizeof(__pyx_k_SPOT_TO_FIAT), 0, 0, 1, 1},
    {&__pyx_n_s_SPOT_TO_MARGIN_CROSS, __pyx_k_SPOT_TO_MARGIN_CROSS, sizeof(__pyx_k_SPOT_TO_MARGIN_CROSS), 0, 0, 1, 1},
    {&__pyx_n_s_SPOT_TO_MINING, __pyx_k_SPOT_TO_MINING, sizeof(__pyx_k_SPOT_TO_MINING), 0, 0, 1, 1},
    {&__pyx_n_s_SPOT_TO_USDT_FUTURE, __pyx_k_SPOT_TO_USDT_FUTURE, sizeof(__pyx_k_SPOT_TO_USDT_FUTURE), 0, 0, 1, 1},
    {&__pyx_n_s_STOP_LOSS, __pyx_k_STOP_LOSS, sizeof(__pyx_k_STOP_LOSS), 0, 0, 1, 1},
    {&__pyx_n_s_STOP_LOSS_LIMIT, __pyx_k_STOP_LOSS_LIMIT, sizeof(__pyx_k_STOP_LOSS_LIMIT), 0, 0, 1, 1},
    {&__pyx_n_s_SYMBOL_TYPE_SPOT, __pyx_k_SYMBOL_TYPE_SPOT, sizeof(__pyx_k_SYMBOL_TYPE_SPOT), 0, 0, 1, 1},
    {&__pyx_n_s_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 0, 1, 1},
    {&__pyx_n_s_TAKE_PROFIT, __pyx_k_TAKE_PROFIT, sizeof(__pyx_k_TAKE_PROFIT), 0, 0, 1, 1},
    {&__pyx_n_s_TAKE_PROFIT_LIMIT, __pyx_k_TAKE_PROFIT_LIMIT, sizeof(__pyx_k_TAKE_PROFIT_LIMIT), 0, 0, 1, 1},
    {&__pyx_n_s_TIME_IN_FORCE_FOK, __pyx_k_TIME_IN_FORCE_FOK, sizeof(__pyx_k_TIME_IN_FORCE_FOK), 0, 0, 1, 1},
    {&__pyx_n_s_TIME_IN_FORCE_GTC, __pyx_k_TIME_IN_FORCE_GTC, sizeof(__pyx_k_TIME_IN_FORCE_GTC), 0, 0, 1, 1},
    {&__pyx_n_s_TIME_IN_FORCE_IOC, __pyx_k_TIME_IN_FORCE_IOC, sizeof(__pyx_k_TIME_IN_FORCE_IOC), 0, 0, 1, 1},
    {&__pyx_kp_s_The_parameter_BinanceRestApiMana, __pyx_k_The_parameter_BinanceRestApiMana, sizeof(__pyx_k_The_parameter_BinanceRestApiMana), 0, 0, 1, 0},
    {&__pyx_kp_s_There_is_no_entry_with_withdraw, __pyx_k_There_is_no_entry_with_withdraw, sizeof(__pyx_k_There_is_no_entry_with_withdraw), 0, 0, 1, 0},
    {&__pyx_n_s_UMFUTURE_C2C, __pyx_k_UMFUTURE_C2C, sizeof(__pyx_k_UMFUTURE_C2C), 0, 0, 1, 1},
    {&__pyx_n_s_UMFUTURE_MAIN, __pyx_k_UMFUTURE_MAIN, sizeof(__pyx_k_UMFUTURE_MAIN), 0, 0, 1, 1},
    {&__pyx_n_s_UMFUTURE_MARGIN, __pyx_k_UMFUTURE_MARGIN, sizeof(__pyx_k_UMFUTURE_MARGIN), 0, 0, 1, 1},
    {&__pyx_kp_s_UNICORN_BINANCE_SUITE, __pyx_k_UNICORN_BINANCE_SUITE, sizeof(__pyx_k_UNICORN_BINANCE_SUITE), 0, 0, 1, 0},
    {&__pyx_n_s_USDT_FUTURE_TO_FIAT, __pyx_k_USDT_FUTURE_TO_FIAT, sizeof(__pyx_k_USDT_FUTURE_TO_FIAT), 0, 0, 1, 1},
    {&__pyx_n_s_USDT_FUTURE_TO_MARGIN_CROSS, __pyx_k_USDT_FUTURE_TO_MARGIN_CROSS, sizeof(__pyx_k_USDT_FUTURE_TO_MARGIN_CROSS), 0, 0, 1, 1},
    {&__pyx_n_s_USDT_FUTURE_TO_SPOT, __pyx_k_USDT_FUTURE_TO_SPOT, sizeof(__pyx_k_USDT_FUTURE_TO_SPOT), 0, 0, 1, 1},
    {&__pyx_n_s_UnknownExchange, __pyx_k_UnknownExchange, sizeof(__pyx_k_UnknownExchange), 0, 0, 1, 1},
    {&__pyx_kp_u_Unknown_exchange, __pyx_k_Unknown_exchange, sizeof(__pyx_k_Unknown_exchange), 0, 1, 0, 0},
    {&__pyx_kp_s_User_Agent, __pyx_k_User_Agent, sizeof(__pyx_k_User_Agent), 0, 0, 1, 0},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_s_WEBSITE_URL, __pyx_k_WEBSITE_URL, sizeof(__pyx_k_WEBSITE_URL), 0, 0, 1, 1},
    {&__pyx_kp_s_X_MBX_APIKEY, __pyx_k_X_MBX_APIKEY, sizeof(__pyx_k_X_MBX_APIKEY), 0, 0, 1, 0},
    {&__pyx_kp_s_X_MBX_USED_WEIGHT, __pyx_k_X_MBX_USED_WEIGHT, sizeof(__pyx_k_X_MBX_USED_WEIGHT), 0, 0, 1, 0},
    {&__pyx_kp_s__184, __pyx_k__184, sizeof(__pyx_k__184), 0, 0, 1, 0},
    {&__pyx_kp_u__185, __pyx_k__185, sizeof(__pyx_k__185), 0, 1, 0, 0},
    {&__pyx_n_s__186, __pyx_k__186, sizeof(__pyx_k__186), 0, 0, 1, 1},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_kp_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 0},
    {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
    {&__pyx_kp_s__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
    {&__pyx_n_s__488, __pyx_k__488, sizeof(__pyx_k__488), 0, 0, 1, 1},
    {&__pyx_n_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 1},
    {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
    {&__pyx_kp_s__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 0, 1, 0},
    {&__pyx_kp_s__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 0, 1, 0},
    {&__pyx_kp_s__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 0, 1, 0},
    {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
    {&__pyx_kp_s_a_d_b_Y_I_M_S_Z, __pyx_k_a_d_b_Y_I_M_S_Z, sizeof(__pyx_k_a_d_b_Y_I_M_S_Z), 0, 0, 1, 0},
    {&__pyx_n_s_account, __pyx_k_account, sizeof(__pyx_k_account), 0, 0, 1, 1},
    {&__pyx_n_s_accountSnapshot, __pyx_k_accountSnapshot, sizeof(__pyx_k_accountSnapshot), 0, 0, 1, 1},
    {&__pyx_kp_s_account_apiTradingStatus, __pyx_k_account_apiTradingStatus, sizeof(__pyx_k_account_apiTradingStatus), 0, 0, 1, 0},
    {&__pyx_kp_s_account_status, __pyx_k_account_status, sizeof(__pyx_k_account_status), 0, 0, 1, 0},
    {&__pyx_n_s_aggTrades, __pyx_k_aggTrades, sizeof(__pyx_k_aggTrades), 0, 0, 1, 1},
    {&__pyx_n_s_aggregate_trade_iter, __pyx_k_aggregate_trade_iter, sizeof(__pyx_k_aggregate_trade_iter), 0, 0, 1, 1},
    {&__pyx_n_s_allForceOrders, __pyx_k_allForceOrders, sizeof(__pyx_k_allForceOrders), 0, 0, 1, 1},
    {&__pyx_n_s_allOpenOrders, __pyx_k_allOpenOrders, sizeof(__pyx_k_allOpenOrders), 0, 0, 1, 1},
    {&__pyx_n_s_allOrders, __pyx_k_allOrders, sizeof(__pyx_k_allOrders), 0, 0, 1, 1},
    {&__pyx_n_s_api_key, __pyx_k_api_key, sizeof(__pyx_k_api_key), 0, 0, 1, 1},
    {&__pyx_n_s_api_secret, __pyx_k_api_secret, sizeof(__pyx_k_api_secret), 0, 0, 1, 1},
    {&__pyx_kp_s_application_json, __pyx_k_application_json, sizeof(__pyx_k_application_json), 0, 0, 1, 0},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_s_asset, __pyx_k_asset, sizeof(__pyx_k_asset), 0, 0, 1, 1},
    {&__pyx_kp_s_asset_assetDetail, __pyx_k_asset_assetDetail, sizeof(__pyx_k_asset_assetDetail), 0, 0, 1, 0},
    {&__pyx_kp_s_asset_assetDividend, __pyx_k_asset_assetDividend, sizeof(__pyx_k_asset_assetDividend), 0, 0, 1, 0},
    {&__pyx_kp_s_asset_dribblet, __pyx_k_asset_dribblet, sizeof(__pyx_k_asset_dribblet), 0, 0, 1, 0},
    {&__pyx_kp_s_asset_dust, __pyx_k_asset_dust, sizeof(__pyx_k_asset_dust), 0, 0, 1, 0},
    {&__pyx_kp_s_asset_tradeFee, __pyx_k_asset_tradeFee, sizeof(__pyx_k_asset_tradeFee), 0, 0, 1, 0},
    {&__pyx_kp_s_asset_transfer, __pyx_k_asset_transfer, sizeof(__pyx_k_asset_transfer), 0, 0, 1, 0},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_avgPrice, __pyx_k_avgPrice, sizeof(__pyx_k_avgPrice), 0, 0, 1, 1},
    {&__pyx_n_s_bal, __pyx_k_bal, sizeof(__pyx_k_bal), 0, 0, 1, 1},
    {&__pyx_n_s_balance, __pyx_k_balance, sizeof(__pyx_k_balance), 0, 0, 1, 1},
    {&__pyx_n_s_balances, __pyx_k_balances, sizeof(__pyx_k_balances), 0, 0, 1, 1},
    {&__pyx_n_s_batchOrders, __pyx_k_batchOrders, sizeof(__pyx_k_batchOrders), 0, 0, 1, 1},
    {&__pyx_n_s_binance_api_status, __pyx_k_binance_api_status, sizeof(__pyx_k_binance_api_status), 0, 0, 1, 1},
    {&__pyx_kp_s_binance_com, __pyx_k_binance_com, sizeof(__pyx_k_binance_com), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_coin_futures, __pyx_k_binance_com_coin_futures, sizeof(__pyx_k_binance_com_coin_futures), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_futures, __pyx_k_binance_com_futures, sizeof(__pyx_k_binance_com_futures), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_futures_testnet, __pyx_k_binance_com_futures_testnet, sizeof(__pyx_k_binance_com_futures_testnet), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_isolated_margin, __pyx_k_binance_com_isolated_margin, sizeof(__pyx_k_binance_com_isolated_margin), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_isolated_margin_test, __pyx_k_binance_com_isolated_margin_test, sizeof(__pyx_k_binance_com_isolated_margin_test), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_margin, __pyx_k_binance_com_margin, sizeof(__pyx_k_binance_com_margin), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_margin_testnet, __pyx_k_binance_com_margin_testnet, sizeof(__pyx_k_binance_com_margin_testnet), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_com_testnet, __pyx_k_binance_com_testnet, sizeof(__pyx_k_binance_com_testnet), 0, 0, 1, 0},
    {&__pyx_kp_s_binance_us, __pyx_k_binance_us, sizeof(__pyx_k_binance_us), 0, 0, 1, 0},
    {&__pyx_n_s_bnbBurn, __pyx_k_bnbBurn, sizeof(__pyx_k_bnbBurn), 0, 0, 1, 1},
    {&__pyx_n_s_cancel_all_open_margin_orders, __pyx_k_cancel_all_open_margin_orders, sizeof(__pyx_k_cancel_all_open_margin_orders), 0, 0, 1, 1},
    {&__pyx_n_s_cancel_all_open_orders, __pyx_k_cancel_all_open_orders, sizeof(__pyx_k_cancel_all_open_orders), 0, 0, 1, 1},
    {&__pyx_n_s_cancel_margin_oco_order, __pyx_k_cancel_margin_oco_order, sizeof(__pyx_k_cancel_margin_oco_order), 0, 0, 1, 1},
    {&__pyx_n_s_cancel_margin_order, __pyx_k_cancel_margin_order, sizeof(__pyx_k_cancel_margin_order), 0, 0, 1, 1},
    {&__pyx_n_s_cancel_order, __pyx_k_cancel_order, sizeof(__pyx_k_cancel_order), 0, 0, 1, 1},
    {&__pyx_kp_s_capital_config_getall, __pyx_k_capital_config_getall, sizeof(__pyx_k_capital_config_getall), 0, 0, 1, 0},
    {&__pyx_kp_s_capital_deposit_address, __pyx_k_capital_deposit_address, sizeof(__pyx_k_capital_deposit_address), 0, 0, 1, 0},
    {&__pyx_kp_s_capital_deposit_hisrec, __pyx_k_capital_deposit_hisrec, sizeof(__pyx_k_capital_deposit_hisrec), 0, 0, 1, 0},
    {&__pyx_kp_s_capital_deposit_subAddress, __pyx_k_capital_deposit_subAddress, sizeof(__pyx_k_capital_deposit_subAddress), 0, 0, 1, 0},
    {&__pyx_kp_s_capital_deposit_subHisrec, __pyx_k_capital_deposit_subHisrec, sizeof(__pyx_k_capital_deposit_subHisrec), 0, 0, 1, 0},
    {&__pyx_kp_s_capital_withdraw_apply, __pyx_k_capital_withdraw_apply, sizeof(__pyx_k_capital_withdraw_apply), 0, 0, 1, 0},
    {&__pyx_kp_s_capital_withdraw_history, __pyx_k_capital_withdraw_history, sizeof(__pyx_k_capital_withdraw_history), 0, 0, 1, 0},
    {&__pyx_n_s_change_fixed_activity_to_daily_p, __pyx_k_change_fixed_activity_to_daily_p, sizeof(__pyx_k_change_fixed_activity_to_daily_p), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_close_api_session, __pyx_k_close_api_session, sizeof(__pyx_k_close_api_session), 0, 0, 1, 1},
    {&__pyx_n_s_colorama, __pyx_k_colorama, sizeof(__pyx_k_colorama), 0, 0, 1, 1},
    {&__pyx_n_s_commissionRate, __pyx_k_commissionRate, sizeof(__pyx_k_commissionRate), 0, 0, 1, 1},
    {&__pyx_kp_u_compiled_on, __pyx_k_compiled_on, sizeof(__pyx_k_compiled_on), 0, 1, 0, 0},
    {&__pyx_n_s_continuousKlines, __pyx_k_continuousKlines, sizeof(__pyx_k_continuousKlines), 0, 0, 1, 1},
    {&__pyx_n_s_countdownCancelAll, __pyx_k_countdownCancelAll, sizeof(__pyx_k_countdownCancelAll), 0, 0, 1, 1},
    {&__pyx_n_s_create_api_uri, __pyx_k_create_api_uri, sizeof(__pyx_k_create_api_uri), 0, 0, 1, 1},
    {&__pyx_n_s_create_futures_api_uri, __pyx_k_create_futures_api_uri, sizeof(__pyx_k_create_futures_api_uri), 0, 0, 1, 1},
    {&__pyx_n_s_create_futures_coin_api_url, __pyx_k_create_futures_coin_api_url, sizeof(__pyx_k_create_futures_coin_api_url), 0, 0, 1, 1},
    {&__pyx_n_s_create_futures_coin_data_api_ur, __pyx_k_create_futures_coin_data_api_ur, sizeof(__pyx_k_create_futures_coin_data_api_ur), 0, 0, 1, 1},
    {&__pyx_n_s_create_futures_data_api_uri, __pyx_k_create_futures_data_api_uri, sizeof(__pyx_k_create_futures_data_api_uri), 0, 0, 1, 1},
    {&__pyx_n_s_create_isolated_margin_account, __pyx_k_create_isolated_margin_account, sizeof(__pyx_k_create_isolated_margin_account), 0, 0, 1, 1},
    {&__pyx_n_s_create_margin_api_uri, __pyx_k_create_margin_api_uri, sizeof(__pyx_k_create_margin_api_uri), 0, 0, 1, 1},
    {&__pyx_n_s_create_margin_loan, __pyx_k_create_margin_loan, sizeof(__pyx_k_create_margin_loan), 0, 0, 1, 1},
    {&__pyx_n_s_create_margin_oco_order, __pyx_k_create_margin_oco_order, sizeof(__pyx_k_create_margin_oco_order), 0, 0, 1, 1},
    {&__pyx_n_s_create_margin_order, __pyx_k_create_margin_order, sizeof(__pyx_k_create_margin_order), 0, 0, 1, 1},
    {&__pyx_n_s_create_oco_order, __pyx_k_create_oco_order, sizeof(__pyx_k_create_oco_order), 0, 0, 1, 1},
    {&__pyx_n_s_create_order, __pyx_k_create_order, sizeof(__pyx_k_create_order), 0, 0, 1, 1},
    {&__pyx_n_s_create_sub_account_futures_trans, __pyx_k_create_sub_account_futures_trans, sizeof(__pyx_k_create_sub_account_futures_trans), 0, 0, 1, 1},
    {&__pyx_n_s_create_test_order, __pyx_k_create_test_order, sizeof(__pyx_k_create_test_order), 0, 0, 1, 1},
    {&__pyx_n_s_create_website_uri, __pyx_k_create_website_uri, sizeof(__pyx_k_create_website_uri), 0, 0, 1, 1},
    {&__pyx_n_s_critical, __pyx_k_critical, sizeof(__pyx_k_critical), 0, 0, 1, 1},
    {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
    {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
    {&__pyx_n_s_date_time_obj, __pyx_k_date_time_obj, sizeof(__pyx_k_date_time_obj), 0, 0, 1, 1},
    {&__pyx_n_s_date_to_milliseconds, __pyx_k_date_to_milliseconds, sizeof(__pyx_k_date_to_milliseconds), 0, 0, 1, 1},
    {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
    {&__pyx_n_s_delete, __pyx_k_delete, sizeof(__pyx_k_delete), 0, 0, 1, 1},
    {&__pyx_n_s_delete_2, __pyx_k_delete_2, sizeof(__pyx_k_delete_2), 0, 0, 1, 1},
    {&__pyx_n_s_depth, __pyx_k_depth, sizeof(__pyx_k_depth), 0, 0, 1, 1},
    {&__pyx_kp_s_dev, __pyx_k_dev, sizeof(__pyx_k_dev), 0, 0, 1, 0},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_disableFastWithdrawSwitch, __pyx_k_disableFastWithdrawSwitch, sizeof(__pyx_k_disableFastWithdrawSwitch), 0, 0, 1, 1},
    {&__pyx_n_s_disable_colorama, __pyx_k_disable_colorama, sizeof(__pyx_k_disable_colorama), 0, 0, 1, 1},
    {&__pyx_n_s_disable_fast_withdraw_switch, __pyx_k_disable_fast_withdraw_switch, sizeof(__pyx_k_disable_fast_withdraw_switch), 0, 0, 1, 1},
    {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_enableFastWithdrawSwitch, __pyx_k_enableFastWithdrawSwitch, sizeof(__pyx_k_enableFastWithdrawSwitch), 0, 0, 1, 1},
    {&__pyx_n_s_enable_fast_withdraw_switch, __pyx_k_enable_fast_withdraw_switch, sizeof(__pyx_k_enable_fast_withdraw_switch), 0, 0, 1, 1},
    {&__pyx_n_s_enable_subaccount_futures, __pyx_k_enable_subaccount_futures, sizeof(__pyx_k_enable_subaccount_futures), 0, 0, 1, 1},
    {&__pyx_n_s_enable_subaccount_margin, __pyx_k_enable_subaccount_margin, sizeof(__pyx_k_enable_subaccount_margin), 0, 0, 1, 1},
    {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
    {&__pyx_n_s_endTime, __pyx_k_endTime, sizeof(__pyx_k_endTime), 0, 0, 1, 1},
    {&__pyx_n_s_end_str, __pyx_k_end_str, sizeof(__pyx_k_end_str), 0, 0, 1, 1},
    {&__pyx_n_s_end_ts, __pyx_k_end_ts, sizeof(__pyx_k_end_ts), 0, 0, 1, 1},
    {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
    {&__pyx_n_s_entry, __pyx_k_entry, sizeof(__pyx_k_entry), 0, 0, 1, 1},
    {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
    {&__pyx_n_s_error_msg, __pyx_k_error_msg, sizeof(__pyx_k_error_msg), 0, 0, 1, 1},
    {&__pyx_n_s_error_traceback, __pyx_k_error_traceback, sizeof(__pyx_k_error_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_exc_type, __pyx_k_exc_type, sizeof(__pyx_k_exc_type), 0, 0, 1, 1},
    {&__pyx_n_s_exc_value, __pyx_k_exc_value, sizeof(__pyx_k_exc_value), 0, 0, 1, 1},
    {&__pyx_n_s_exceptions, __pyx_k_exceptions, sizeof(__pyx_k_exceptions), 0, 0, 1, 1},
    {&__pyx_n_s_exchange, __pyx_k_exchange, sizeof(__pyx_k_exchange), 0, 0, 1, 1},
    {&__pyx_n_s_exchangeInfo, __pyx_k_exchangeInfo, sizeof(__pyx_k_exchangeInfo), 0, 0, 1, 1},
    {&__pyx_kp_u_exchange_2, __pyx_k_exchange_2, sizeof(__pyx_k_exchange_2), 0, 1, 0, 0},
    {&__pyx_kp_s_exchange_api_v1_public_asset_ser, __pyx_k_exchange_api_v1_public_asset_ser, sizeof(__pyx_k_exchange_api_v1_public_asset_ser), 0, 0, 1, 0},
    {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
    {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
    {&__pyx_n_s_first_valid_ts, __pyx_k_first_valid_ts, sizeof(__pyx_k_first_valid_ts), 0, 0, 1, 1},
    {&__pyx_kp_u_for_exchange, __pyx_k_for_exchange, sizeof(__pyx_k_for_exchange), 0, 1, 0, 0},
    {&__pyx_n_s_force_params, __pyx_k_force_params, sizeof(__pyx_k_force_params), 0, 0, 1, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_s_fromId, __pyx_k_fromId, sizeof(__pyx_k_fromId), 0, 0, 1, 1},
    {&__pyx_n_s_fundingRate, __pyx_k_fundingRate, sizeof(__pyx_k_fundingRate), 0, 0, 1, 1},
    {&__pyx_n_s_futures_account, __pyx_k_futures_account, sizeof(__pyx_k_futures_account), 0, 0, 1, 1},
    {&__pyx_n_s_futures_account_balance, __pyx_k_futures_account_balance, sizeof(__pyx_k_futures_account_balance), 0, 0, 1, 1},
    {&__pyx_n_s_futures_account_trades, __pyx_k_futures_account_trades, sizeof(__pyx_k_futures_account_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_account_transfer, __pyx_k_futures_account_transfer, sizeof(__pyx_k_futures_account_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_futures_aggregate_trades, __pyx_k_futures_aggregate_trades, sizeof(__pyx_k_futures_aggregate_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_auto_cancel_all_open_ord, __pyx_k_futures_auto_cancel_all_open_ord, sizeof(__pyx_k_futures_auto_cancel_all_open_ord), 0, 0, 1, 1},
    {&__pyx_n_s_futures_cancel_all_open_orders, __pyx_k_futures_cancel_all_open_orders, sizeof(__pyx_k_futures_cancel_all_open_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_cancel_order, __pyx_k_futures_cancel_order, sizeof(__pyx_k_futures_cancel_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_cancel_orders, __pyx_k_futures_cancel_orders, sizeof(__pyx_k_futures_cancel_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_change_leverage, __pyx_k_futures_change_leverage, sizeof(__pyx_k_futures_change_leverage), 0, 0, 1, 1},
    {&__pyx_n_s_futures_change_margin_type, __pyx_k_futures_change_margin_type, sizeof(__pyx_k_futures_change_margin_type), 0, 0, 1, 1},
    {&__pyx_n_s_futures_change_position_margin, __pyx_k_futures_change_position_margin, sizeof(__pyx_k_futures_change_position_margin), 0, 0, 1, 1},
    {&__pyx_n_s_futures_change_position_mode, __pyx_k_futures_change_position_mode, sizeof(__pyx_k_futures_change_position_mode), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_account, __pyx_k_futures_coin_account, sizeof(__pyx_k_futures_coin_account), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_account_balance, __pyx_k_futures_coin_account_balance, sizeof(__pyx_k_futures_coin_account_balance), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_account_trades, __pyx_k_futures_coin_account_trades, sizeof(__pyx_k_futures_coin_account_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_aggregate_trades, __pyx_k_futures_coin_aggregate_trades, sizeof(__pyx_k_futures_coin_aggregate_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_cancel_all_open_ord, __pyx_k_futures_coin_cancel_all_open_ord, sizeof(__pyx_k_futures_coin_cancel_all_open_ord), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_cancel_order, __pyx_k_futures_coin_cancel_order, sizeof(__pyx_k_futures_coin_cancel_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_cancel_orders, __pyx_k_futures_coin_cancel_orders, sizeof(__pyx_k_futures_coin_cancel_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_change_leverage, __pyx_k_futures_coin_change_leverage, sizeof(__pyx_k_futures_coin_change_leverage), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_change_margin_type, __pyx_k_futures_coin_change_margin_type, sizeof(__pyx_k_futures_coin_change_margin_type), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_change_position_mar, __pyx_k_futures_coin_change_position_mar, sizeof(__pyx_k_futures_coin_change_position_mar), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_change_position_mod, __pyx_k_futures_coin_change_position_mod, sizeof(__pyx_k_futures_coin_change_position_mod), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_continous_klines, __pyx_k_futures_coin_continous_klines, sizeof(__pyx_k_futures_coin_continous_klines), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_create_order, __pyx_k_futures_coin_create_order, sizeof(__pyx_k_futures_coin_create_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_exchange_info, __pyx_k_futures_coin_exchange_info, sizeof(__pyx_k_futures_coin_exchange_info), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_funding_rate, __pyx_k_futures_coin_funding_rate, sizeof(__pyx_k_futures_coin_funding_rate), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_get_all_orders, __pyx_k_futures_coin_get_all_orders, sizeof(__pyx_k_futures_coin_get_all_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_get_open_orders, __pyx_k_futures_coin_get_open_orders, sizeof(__pyx_k_futures_coin_get_open_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_get_order, __pyx_k_futures_coin_get_order, sizeof(__pyx_k_futures_coin_get_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_get_position_mode, __pyx_k_futures_coin_get_position_mode, sizeof(__pyx_k_futures_coin_get_position_mode), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_historical_trades, __pyx_k_futures_coin_historical_trades, sizeof(__pyx_k_futures_coin_historical_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_income_history, __pyx_k_futures_coin_income_history, sizeof(__pyx_k_futures_coin_income_history), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_index_price_klines, __pyx_k_futures_coin_index_price_klines, sizeof(__pyx_k_futures_coin_index_price_klines), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_klines, __pyx_k_futures_coin_klines, sizeof(__pyx_k_futures_coin_klines), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_leverage_bracket, __pyx_k_futures_coin_leverage_bracket, sizeof(__pyx_k_futures_coin_leverage_bracket), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_liquidation_orders, __pyx_k_futures_coin_liquidation_orders, sizeof(__pyx_k_futures_coin_liquidation_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_mark_price, __pyx_k_futures_coin_mark_price, sizeof(__pyx_k_futures_coin_mark_price), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_mark_price_klines, __pyx_k_futures_coin_mark_price_klines, sizeof(__pyx_k_futures_coin_mark_price_klines), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_open_interest, __pyx_k_futures_coin_open_interest, sizeof(__pyx_k_futures_coin_open_interest), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_open_interest_hist, __pyx_k_futures_coin_open_interest_hist, sizeof(__pyx_k_futures_coin_open_interest_hist), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_order_book, __pyx_k_futures_coin_order_book, sizeof(__pyx_k_futures_coin_order_book), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_orderbook_ticker, __pyx_k_futures_coin_orderbook_ticker, sizeof(__pyx_k_futures_coin_orderbook_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_ping, __pyx_k_futures_coin_ping, sizeof(__pyx_k_futures_coin_ping), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_place_batch_order, __pyx_k_futures_coin_place_batch_order, sizeof(__pyx_k_futures_coin_place_batch_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_position_informatio, __pyx_k_futures_coin_position_informatio, sizeof(__pyx_k_futures_coin_position_informatio), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_position_margin_his, __pyx_k_futures_coin_position_margin_his, sizeof(__pyx_k_futures_coin_position_margin_his), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_recent_trades, __pyx_k_futures_coin_recent_trades, sizeof(__pyx_k_futures_coin_recent_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_stream_close, __pyx_k_futures_coin_stream_close, sizeof(__pyx_k_futures_coin_stream_close), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_stream_get_listen_k, __pyx_k_futures_coin_stream_get_listen_k, sizeof(__pyx_k_futures_coin_stream_get_listen_k), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_stream_keepalive, __pyx_k_futures_coin_stream_keepalive, sizeof(__pyx_k_futures_coin_stream_keepalive), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_symbol_ticker, __pyx_k_futures_coin_symbol_ticker, sizeof(__pyx_k_futures_coin_symbol_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_ticker, __pyx_k_futures_coin_ticker, sizeof(__pyx_k_futures_coin_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_futures_coin_time, __pyx_k_futures_coin_time, sizeof(__pyx_k_futures_coin_time), 0, 0, 1, 1},
    {&__pyx_n_s_futures_commission_rate, __pyx_k_futures_commission_rate, sizeof(__pyx_k_futures_commission_rate), 0, 0, 1, 1},
    {&__pyx_n_s_futures_create_order, __pyx_k_futures_create_order, sizeof(__pyx_k_futures_create_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_exchange_info, __pyx_k_futures_exchange_info, sizeof(__pyx_k_futures_exchange_info), 0, 0, 1, 1},
    {&__pyx_n_s_futures_funding_rate, __pyx_k_futures_funding_rate, sizeof(__pyx_k_futures_funding_rate), 0, 0, 1, 1},
    {&__pyx_n_s_futures_get_all_orders, __pyx_k_futures_get_all_orders, sizeof(__pyx_k_futures_get_all_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_get_open_orders, __pyx_k_futures_get_open_orders, sizeof(__pyx_k_futures_get_open_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_get_order, __pyx_k_futures_get_order, sizeof(__pyx_k_futures_get_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_get_position_mode, __pyx_k_futures_get_position_mode, sizeof(__pyx_k_futures_get_position_mode), 0, 0, 1, 1},
    {&__pyx_n_s_futures_historical_trades, __pyx_k_futures_historical_trades, sizeof(__pyx_k_futures_historical_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_income_history, __pyx_k_futures_income_history, sizeof(__pyx_k_futures_income_history), 0, 0, 1, 1},
    {&__pyx_n_s_futures_klines, __pyx_k_futures_klines, sizeof(__pyx_k_futures_klines), 0, 0, 1, 1},
    {&__pyx_n_s_futures_leverage_bracket, __pyx_k_futures_leverage_bracket, sizeof(__pyx_k_futures_leverage_bracket), 0, 0, 1, 1},
    {&__pyx_n_s_futures_liquidation_orders, __pyx_k_futures_liquidation_orders, sizeof(__pyx_k_futures_liquidation_orders), 0, 0, 1, 1},
    {&__pyx_n_s_futures_mark_price, __pyx_k_futures_mark_price, sizeof(__pyx_k_futures_mark_price), 0, 0, 1, 1},
    {&__pyx_n_s_futures_open_interest, __pyx_k_futures_open_interest, sizeof(__pyx_k_futures_open_interest), 0, 0, 1, 1},
    {&__pyx_n_s_futures_open_interest_hist, __pyx_k_futures_open_interest_hist, sizeof(__pyx_k_futures_open_interest_hist), 0, 0, 1, 1},
    {&__pyx_n_s_futures_order_book, __pyx_k_futures_order_book, sizeof(__pyx_k_futures_order_book), 0, 0, 1, 1},
    {&__pyx_n_s_futures_orderbook_ticker, __pyx_k_futures_orderbook_ticker, sizeof(__pyx_k_futures_orderbook_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_futures_ping, __pyx_k_futures_ping, sizeof(__pyx_k_futures_ping), 0, 0, 1, 1},
    {&__pyx_n_s_futures_place_batch_order, __pyx_k_futures_place_batch_order, sizeof(__pyx_k_futures_place_batch_order), 0, 0, 1, 1},
    {&__pyx_n_s_futures_position_information, __pyx_k_futures_position_information, sizeof(__pyx_k_futures_position_information), 0, 0, 1, 1},
    {&__pyx_n_s_futures_position_margin_history, __pyx_k_futures_position_margin_history, sizeof(__pyx_k_futures_position_margin_history), 0, 0, 1, 1},
    {&__pyx_n_s_futures_recent_trades, __pyx_k_futures_recent_trades, sizeof(__pyx_k_futures_recent_trades), 0, 0, 1, 1},
    {&__pyx_n_s_futures_stream_close, __pyx_k_futures_stream_close, sizeof(__pyx_k_futures_stream_close), 0, 0, 1, 1},
    {&__pyx_n_s_futures_stream_get_listen_key, __pyx_k_futures_stream_get_listen_key, sizeof(__pyx_k_futures_stream_get_listen_key), 0, 0, 1, 1},
    {&__pyx_n_s_futures_stream_keepalive, __pyx_k_futures_stream_keepalive, sizeof(__pyx_k_futures_stream_keepalive), 0, 0, 1, 1},
    {&__pyx_n_s_futures_symbol_ticker, __pyx_k_futures_symbol_ticker, sizeof(__pyx_k_futures_symbol_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_futures_ticker, __pyx_k_futures_ticker, sizeof(__pyx_k_futures_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_futures_time, __pyx_k_futures_time, sizeof(__pyx_k_futures_time), 0, 0, 1, 1},
    {&__pyx_kp_s_futures_transfer, __pyx_k_futures_transfer, sizeof(__pyx_k_futures_transfer), 0, 0, 1, 0},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_generate_signature, __pyx_k_generate_signature, sizeof(__pyx_k_generate_signature), 0, 0, 1, 1},
    {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_getLogger, __pyx_k_getLogger, sizeof(__pyx_k_getLogger), 0, 0, 1, 1},
    {&__pyx_n_s_get_2, __pyx_k_get_2, sizeof(__pyx_k_get_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_account, __pyx_k_get_account, sizeof(__pyx_k_get_account), 0, 0, 1, 1},
    {&__pyx_n_s_get_account_api_trading_status, __pyx_k_get_account_api_trading_status, sizeof(__pyx_k_get_account_api_trading_status), 0, 0, 1, 1},
    {&__pyx_n_s_get_account_snapshot, __pyx_k_get_account_snapshot, sizeof(__pyx_k_get_account_snapshot), 0, 0, 1, 1},
    {&__pyx_n_s_get_account_status, __pyx_k_get_account_status, sizeof(__pyx_k_get_account_status), 0, 0, 1, 1},
    {&__pyx_n_s_get_aggregate_trades, __pyx_k_get_aggregate_trades, sizeof(__pyx_k_get_aggregate_trades), 0, 0, 1, 1},
    {&__pyx_n_s_get_all_coins_info, __pyx_k_get_all_coins_info, sizeof(__pyx_k_get_all_coins_info), 0, 0, 1, 1},
    {&__pyx_n_s_get_all_isolated_margin_symbols, __pyx_k_get_all_isolated_margin_symbols, sizeof(__pyx_k_get_all_isolated_margin_symbols), 0, 0, 1, 1},
    {&__pyx_n_s_get_all_margin_orders, __pyx_k_get_all_margin_orders, sizeof(__pyx_k_get_all_margin_orders), 0, 0, 1, 1},
    {&__pyx_n_s_get_all_orders, __pyx_k_get_all_orders, sizeof(__pyx_k_get_all_orders), 0, 0, 1, 1},
    {&__pyx_n_s_get_all_tickers, __pyx_k_get_all_tickers, sizeof(__pyx_k_get_all_tickers), 0, 0, 1, 1},
    {&__pyx_n_s_get_asset_balance, __pyx_k_get_asset_balance, sizeof(__pyx_k_get_asset_balance), 0, 0, 1, 1},
    {&__pyx_n_s_get_asset_details, __pyx_k_get_asset_details, sizeof(__pyx_k_get_asset_details), 0, 0, 1, 1},
    {&__pyx_n_s_get_asset_dividend_history, __pyx_k_get_asset_dividend_history, sizeof(__pyx_k_get_asset_dividend_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_avg_price, __pyx_k_get_avg_price, sizeof(__pyx_k_get_avg_price), 0, 0, 1, 1},
    {&__pyx_n_s_get_bnb_burn_spot_margin, __pyx_k_get_bnb_burn_spot_margin, sizeof(__pyx_k_get_bnb_burn_spot_margin), 0, 0, 1, 1},
    {&__pyx_n_s_get_deposit_address, __pyx_k_get_deposit_address, sizeof(__pyx_k_get_deposit_address), 0, 0, 1, 1},
    {&__pyx_n_s_get_deposit_history, __pyx_k_get_deposit_history, sizeof(__pyx_k_get_deposit_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_dust_log, __pyx_k_get_dust_log, sizeof(__pyx_k_get_dust_log), 0, 0, 1, 1},
    {&__pyx_n_s_get_earliest_valid_timestamp, __pyx_k_get_earliest_valid_timestamp, sizeof(__pyx_k_get_earliest_valid_timestamp), 0, 0, 1, 1},
    {&__pyx_n_s_get_exchange_info, __pyx_k_get_exchange_info, sizeof(__pyx_k_get_exchange_info), 0, 0, 1, 1},
    {&__pyx_n_s_get_fixed_activity_project_list, __pyx_k_get_fixed_activity_project_list, sizeof(__pyx_k_get_fixed_activity_project_list), 0, 0, 1, 1},
    {&__pyx_n_s_get_historical_klines, __pyx_k_get_historical_klines, sizeof(__pyx_k_get_historical_klines), 0, 0, 1, 1},
    {&__pyx_n_s_get_historical_klines_generator, __pyx_k_get_historical_klines_generator, sizeof(__pyx_k_get_historical_klines_generator), 0, 0, 1, 1},
    {&__pyx_n_s_get_historical_trades, __pyx_k_get_historical_trades, sizeof(__pyx_k_get_historical_trades), 0, 0, 1, 1},
    {&__pyx_n_s_get_isolated_margin_account, __pyx_k_get_isolated_margin_account, sizeof(__pyx_k_get_isolated_margin_account), 0, 0, 1, 1},
    {&__pyx_n_s_get_isolated_margin_symbol, __pyx_k_get_isolated_margin_symbol, sizeof(__pyx_k_get_isolated_margin_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_get_klines, __pyx_k_get_klines, sizeof(__pyx_k_get_klines), 0, 0, 1, 1},
    {&__pyx_n_s_get_latest_release_info, __pyx_k_get_latest_release_info, sizeof(__pyx_k_get_latest_release_info), 0, 0, 1, 1},
    {&__pyx_n_s_get_latest_version, __pyx_k_get_latest_version, sizeof(__pyx_k_get_latest_version), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_account, __pyx_k_get_lending_account, sizeof(__pyx_k_get_lending_account), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_daily_quota_left, __pyx_k_get_lending_daily_quota_left, sizeof(__pyx_k_get_lending_daily_quota_left), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_daily_redemption_quo, __pyx_k_get_lending_daily_redemption_quo, sizeof(__pyx_k_get_lending_daily_redemption_quo), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_interest_history, __pyx_k_get_lending_interest_history, sizeof(__pyx_k_get_lending_interest_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_position, __pyx_k_get_lending_position, sizeof(__pyx_k_get_lending_position), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_product_list, __pyx_k_get_lending_product_list, sizeof(__pyx_k_get_lending_product_list), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_purchase_history, __pyx_k_get_lending_purchase_history, sizeof(__pyx_k_get_lending_purchase_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_lending_redemption_history, __pyx_k_get_lending_redemption_history, sizeof(__pyx_k_get_lending_redemption_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_account, __pyx_k_get_margin_account, sizeof(__pyx_k_get_margin_account), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_asset, __pyx_k_get_margin_asset, sizeof(__pyx_k_get_margin_asset), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_loan_details, __pyx_k_get_margin_loan_details, sizeof(__pyx_k_get_margin_loan_details), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_oco_order, __pyx_k_get_margin_oco_order, sizeof(__pyx_k_get_margin_oco_order), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_order, __pyx_k_get_margin_order, sizeof(__pyx_k_get_margin_order), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_price_index, __pyx_k_get_margin_price_index, sizeof(__pyx_k_get_margin_price_index), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_repay_details, __pyx_k_get_margin_repay_details, sizeof(__pyx_k_get_margin_repay_details), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_symbol, __pyx_k_get_margin_symbol, sizeof(__pyx_k_get_margin_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_get_margin_trades, __pyx_k_get_margin_trades, sizeof(__pyx_k_get_margin_trades), 0, 0, 1, 1},
    {&__pyx_n_s_get_max_margin_loan, __pyx_k_get_max_margin_loan, sizeof(__pyx_k_get_max_margin_loan), 0, 0, 1, 1},
    {&__pyx_n_s_get_max_margin_transfer, __pyx_k_get_max_margin_transfer, sizeof(__pyx_k_get_max_margin_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_get_my_trades, __pyx_k_get_my_trades, sizeof(__pyx_k_get_my_trades), 0, 0, 1, 1},
    {&__pyx_n_s_get_open_isolated_margin_orders, __pyx_k_get_open_isolated_margin_orders, sizeof(__pyx_k_get_open_isolated_margin_orders), 0, 0, 1, 1},
    {&__pyx_n_s_get_open_margin_oco_orders, __pyx_k_get_open_margin_oco_orders, sizeof(__pyx_k_get_open_margin_oco_orders), 0, 0, 1, 1},
    {&__pyx_n_s_get_open_margin_orders, __pyx_k_get_open_margin_orders, sizeof(__pyx_k_get_open_margin_orders), 0, 0, 1, 1},
    {&__pyx_n_s_get_open_orders, __pyx_k_get_open_orders, sizeof(__pyx_k_get_open_orders), 0, 0, 1, 1},
    {&__pyx_n_s_get_order, __pyx_k_get_order, sizeof(__pyx_k_get_order), 0, 0, 1, 1},
    {&__pyx_n_s_get_order_book, __pyx_k_get_order_book, sizeof(__pyx_k_get_order_book), 0, 0, 1, 1},
    {&__pyx_n_s_get_orderbook_ticker, __pyx_k_get_orderbook_ticker, sizeof(__pyx_k_get_orderbook_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_get_orderbook_tickers, __pyx_k_get_orderbook_tickers, sizeof(__pyx_k_get_orderbook_tickers), 0, 0, 1, 1},
    {&__pyx_n_s_get_products, __pyx_k_get_products, sizeof(__pyx_k_get_products), 0, 0, 1, 1},
    {&__pyx_n_s_get_recent_trades, __pyx_k_get_recent_trades, sizeof(__pyx_k_get_recent_trades), 0, 0, 1, 1},
    {&__pyx_n_s_get_server_time, __pyx_k_get_server_time, sizeof(__pyx_k_get_server_time), 0, 0, 1, 1},
    {&__pyx_n_s_get_sub_account_assets, __pyx_k_get_sub_account_assets, sizeof(__pyx_k_get_sub_account_assets), 0, 0, 1, 1},
    {&__pyx_n_s_get_sub_account_futures_transfer, __pyx_k_get_sub_account_futures_transfer, sizeof(__pyx_k_get_sub_account_futures_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_get_sub_account_list, __pyx_k_get_sub_account_list, sizeof(__pyx_k_get_sub_account_list), 0, 0, 1, 1},
    {&__pyx_n_s_get_sub_account_transfer_history, __pyx_k_get_sub_account_transfer_history, sizeof(__pyx_k_get_sub_account_transfer_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_deposit_address, __pyx_k_get_subaccount_deposit_address, sizeof(__pyx_k_get_subaccount_deposit_address), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_deposit_history, __pyx_k_get_subaccount_deposit_history, sizeof(__pyx_k_get_subaccount_deposit_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_futures_details, __pyx_k_get_subaccount_futures_details, sizeof(__pyx_k_get_subaccount_futures_details), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_futures_margin_st, __pyx_k_get_subaccount_futures_margin_st, sizeof(__pyx_k_get_subaccount_futures_margin_st), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_futures_positionr, __pyx_k_get_subaccount_futures_positionr, sizeof(__pyx_k_get_subaccount_futures_positionr), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_futures_summary, __pyx_k_get_subaccount_futures_summary, sizeof(__pyx_k_get_subaccount_futures_summary), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_margin_details, __pyx_k_get_subaccount_margin_details, sizeof(__pyx_k_get_subaccount_margin_details), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_margin_summary, __pyx_k_get_subaccount_margin_summary, sizeof(__pyx_k_get_subaccount_margin_summary), 0, 0, 1, 1},
    {&__pyx_n_s_get_subaccount_transfer_history, __pyx_k_get_subaccount_transfer_history, sizeof(__pyx_k_get_subaccount_transfer_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_symbol_info, __pyx_k_get_symbol_info, sizeof(__pyx_k_get_symbol_info), 0, 0, 1, 1},
    {&__pyx_n_s_get_symbol_ticker, __pyx_k_get_symbol_ticker, sizeof(__pyx_k_get_symbol_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_get_system_status, __pyx_k_get_system_status, sizeof(__pyx_k_get_system_status), 0, 0, 1, 1},
    {&__pyx_n_s_get_ticker, __pyx_k_get_ticker, sizeof(__pyx_k_get_ticker), 0, 0, 1, 1},
    {&__pyx_n_s_get_trade_fee, __pyx_k_get_trade_fee, sizeof(__pyx_k_get_trade_fee), 0, 0, 1, 1},
    {&__pyx_n_s_get_universal_transfer_history, __pyx_k_get_universal_transfer_history, sizeof(__pyx_k_get_universal_transfer_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_used_weight, __pyx_k_get_used_weight, sizeof(__pyx_k_get_used_weight), 0, 0, 1, 1},
    {&__pyx_n_s_get_user_agent, __pyx_k_get_user_agent, sizeof(__pyx_k_get_user_agent), 0, 0, 1, 1},
    {&__pyx_n_s_get_version, __pyx_k_get_version, sizeof(__pyx_k_get_version), 0, 0, 1, 1},
    {&__pyx_n_s_get_withdraw_history, __pyx_k_get_withdraw_history, sizeof(__pyx_k_get_withdraw_history), 0, 0, 1, 1},
    {&__pyx_n_s_get_withdraw_history_id, __pyx_k_get_withdraw_history_id, sizeof(__pyx_k_get_withdraw_history_id), 0, 0, 1, 1},
    {&__pyx_n_s_handle_response, __pyx_k_handle_response, sizeof(__pyx_k_handle_response), 0, 0, 1, 1},
    {&__pyx_n_s_has_signature, __pyx_k_has_signature, sizeof(__pyx_k_has_signature), 0, 0, 1, 1},
    {&__pyx_n_s_hashlib, __pyx_k_hashlib, sizeof(__pyx_k_hashlib), 0, 0, 1, 1},
    {&__pyx_n_s_headers, __pyx_k_headers, sizeof(__pyx_k_headers), 0, 0, 1, 1},
    {&__pyx_n_s_helpers, __pyx_k_helpers, sizeof(__pyx_k_helpers), 0, 0, 1, 1},
    {&__pyx_n_s_hexdigest, __pyx_k_hexdigest, sizeof(__pyx_k_hexdigest), 0, 0, 1, 1},
    {&__pyx_n_s_historicalTrades, __pyx_k_historicalTrades, sizeof(__pyx_k_historicalTrades), 0, 0, 1, 1},
    {&__pyx_n_s_hmac, __pyx_k_hmac, sizeof(__pyx_k_hmac), 0, 0, 1, 1},
    {&__pyx_n_s_http, __pyx_k_http, sizeof(__pyx_k_http), 0, 0, 1, 1},
    {&__pyx_n_s_https, __pyx_k_https, sizeof(__pyx_k_https), 0, 0, 1, 1},
    {&__pyx_kp_s_https_api_binance_api, __pyx_k_https_api_binance_api, sizeof(__pyx_k_https_api_binance_api), 0, 0, 1, 0},
    {&__pyx_kp_s_https_api_binance_com_api, __pyx_k_https_api_binance_com_api, sizeof(__pyx_k_https_api_binance_com_api), 0, 0, 1, 0},
    {&__pyx_kp_s_https_api_binance_com_sapi, __pyx_k_https_api_binance_com_sapi, sizeof(__pyx_k_https_api_binance_com_sapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_api_binance_sapi, __pyx_k_https_api_binance_sapi, sizeof(__pyx_k_https_api_binance_sapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_api_binance_us_api, __pyx_k_https_api_binance_us_api, sizeof(__pyx_k_https_api_binance_us_api), 0, 0, 1, 0},
    {&__pyx_kp_s_https_api_binance_us_sapi, __pyx_k_https_api_binance_us_sapi, sizeof(__pyx_k_https_api_binance_us_sapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_api_github_com_repos_LUCIT, __pyx_k_https_api_github_com_repos_LUCIT, sizeof(__pyx_k_https_api_github_com_repos_LUCIT), 0, 0, 1, 0},
    {&__pyx_kp_s_https_api_trbinance_com_sapi, __pyx_k_https_api_trbinance_com_sapi, sizeof(__pyx_k_https_api_trbinance_com_sapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_dapi_binance_com_futures_d, __pyx_k_https_dapi_binance_com_futures_d, sizeof(__pyx_k_https_dapi_binance_com_futures_d), 0, 0, 1, 0},
    {&__pyx_kp_s_https_dapi_binance_futures_data, __pyx_k_https_dapi_binance_futures_data, sizeof(__pyx_k_https_dapi_binance_futures_data), 0, 0, 1, 0},
    {&__pyx_kp_s_https_dapi_binance_us_futures_da, __pyx_k_https_dapi_binance_us_futures_da, sizeof(__pyx_k_https_dapi_binance_us_futures_da), 0, 0, 1, 0},
    {&__pyx_kp_s_https_dapi_trbinance_com_futures, __pyx_k_https_dapi_trbinance_com_futures, sizeof(__pyx_k_https_dapi_trbinance_com_futures), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_binance_com_fapi, __pyx_k_https_fapi_binance_com_fapi, sizeof(__pyx_k_https_fapi_binance_com_fapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_binance_com_futures_d, __pyx_k_https_fapi_binance_com_futures_d, sizeof(__pyx_k_https_fapi_binance_com_futures_d), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_binance_fapi, __pyx_k_https_fapi_binance_fapi, sizeof(__pyx_k_https_fapi_binance_fapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_binance_futures_data, __pyx_k_https_fapi_binance_futures_data, sizeof(__pyx_k_https_fapi_binance_futures_data), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_binance_us_fapi, __pyx_k_https_fapi_binance_us_fapi, sizeof(__pyx_k_https_fapi_binance_us_fapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_binance_us_futures_da, __pyx_k_https_fapi_binance_us_futures_da, sizeof(__pyx_k_https_fapi_binance_us_futures_da), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_trbinance_com_fapi, __pyx_k_https_fapi_trbinance_com_fapi, sizeof(__pyx_k_https_fapi_trbinance_com_fapi), 0, 0, 1, 0},
    {&__pyx_kp_s_https_fapi_trbinance_com_futures, __pyx_k_https_fapi_trbinance_com_futures, sizeof(__pyx_k_https_fapi_trbinance_com_futures), 0, 0, 1, 0},
    {&__pyx_kp_s_https_testnet_binance_vision, __pyx_k_https_testnet_binance_vision, sizeof(__pyx_k_https_testnet_binance_vision), 0, 0, 1, 0},
    {&__pyx_kp_s_https_testnet_binance_vision_api, __pyx_k_https_testnet_binance_vision_api, sizeof(__pyx_k_https_testnet_binance_vision_api), 0, 0, 1, 0},
    {&__pyx_kp_s_https_testnet_binancefuture_com, __pyx_k_https_testnet_binancefuture_com, sizeof(__pyx_k_https_testnet_binancefuture_com), 0, 0, 1, 0},
    {&__pyx_kp_s_https_testnet_binancefuture_com_2, __pyx_k_https_testnet_binancefuture_com_2, sizeof(__pyx_k_https_testnet_binancefuture_com_2), 0, 0, 1, 0},
    {&__pyx_kp_s_https_testnet_binancefuture_com_3, __pyx_k_https_testnet_binancefuture_com_3, sizeof(__pyx_k_https_testnet_binancefuture_com_3), 0, 0, 1, 0},
    {&__pyx_kp_s_https_www_binance, __pyx_k_https_www_binance, sizeof(__pyx_k_https_www_binance), 0, 0, 1, 0},
    {&__pyx_kp_s_https_www_binance_com, __pyx_k_https_www_binance_com, sizeof(__pyx_k_https_www_binance_com), 0, 0, 1, 0},
    {&__pyx_kp_s_https_www_binance_us, __pyx_k_https_www_binance_us, sizeof(__pyx_k_https_www_binance_us), 0, 0, 1, 0},
    {&__pyx_kp_s_https_www_trbinance_com, __pyx_k_https_www_trbinance_com, sizeof(__pyx_k_https_www_trbinance_com), 0, 0, 1, 0},
    {&__pyx_kp_s_https_www_trbinance_com_api, __pyx_k_https_www_trbinance_com_api, sizeof(__pyx_k_https_www_trbinance_com_api), 0, 0, 1, 0},
    {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
    {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
    {&__pyx_n_s_idx, __pyx_k_idx, sizeof(__pyx_k_idx), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_income, __pyx_k_income, sizeof(__pyx_k_income), 0, 0, 1, 1},
    {&__pyx_n_s_indexPriceKlines, __pyx_k_indexPriceKlines, sizeof(__pyx_k_indexPriceKlines), 0, 0, 1, 1},
    {&__pyx_n_s_info, __pyx_k_info, sizeof(__pyx_k_info), 0, 0, 1, 1},
    {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
    {&__pyx_n_s_init_2, __pyx_k_init_2, sizeof(__pyx_k_init_2), 0, 0, 1, 1},
    {&__pyx_n_s_init_session, __pyx_k_init_session, sizeof(__pyx_k_init_session), 0, 0, 1, 1},
    {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_installed_version, __pyx_k_installed_version, sizeof(__pyx_k_installed_version), 0, 0, 1, 1},
    {&__pyx_n_s_interval, __pyx_k_interval, sizeof(__pyx_k_interval), 0, 0, 1, 1},
    {&__pyx_n_s_interval_to_milliseconds, __pyx_k_interval_to_milliseconds, sizeof(__pyx_k_interval_to_milliseconds), 0, 0, 1, 1},
    {&__pyx_kp_u_is_available_please_consider_up, __pyx_k_is_available_please_consider_up, sizeof(__pyx_k_is_available_please_consider_up), 0, 1, 0, 0},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_n_s_is_update_availabe, __pyx_k_is_update_availabe, sizeof(__pyx_k_is_update_availabe), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_isolated_margin_stream_close, __pyx_k_isolated_margin_stream_close, sizeof(__pyx_k_isolated_margin_stream_close), 0, 0, 1, 1},
    {&__pyx_n_s_isolated_margin_stream_get_liste, __pyx_k_isolated_margin_stream_get_liste, sizeof(__pyx_k_isolated_margin_stream_get_liste), 0, 0, 1, 1},
    {&__pyx_n_s_isolated_margin_stream_keepalive, __pyx_k_isolated_margin_stream_keepalive, sizeof(__pyx_k_isolated_margin_stream_keepalive), 0, 0, 1, 1},
    {&__pyx_n_s_item, __pyx_k_item, sizeof(__pyx_k_item), 0, 0, 1, 1},
    {&__pyx_n_s_itemgetter, __pyx_k_itemgetter, sizeof(__pyx_k_itemgetter), 0, 0, 1, 1},
    {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
    {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
    {&__pyx_n_s_json, __pyx_k_json, sizeof(__pyx_k_json), 0, 0, 1, 1},
    {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
    {&__pyx_n_s_kline, __pyx_k_kline, sizeof(__pyx_k_kline), 0, 0, 1, 1},
    {&__pyx_n_s_klines, __pyx_k_klines, sizeof(__pyx_k_klines), 0, 0, 1, 1},
    {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
    {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
    {&__pyx_n_s_last_id, __pyx_k_last_id, sizeof(__pyx_k_last_id), 0, 0, 1, 1},
    {&__pyx_n_s_last_update_check_github, __pyx_k_last_update_check_github, sizeof(__pyx_k_last_update_check_github), 0, 0, 1, 1},
    {&__pyx_n_s_latest_release_info, __pyx_k_latest_release_info, sizeof(__pyx_k_latest_release_info), 0, 0, 1, 1},
    {&__pyx_kp_s_lending_daily_product_list, __pyx_k_lending_daily_product_list, sizeof(__pyx_k_lending_daily_product_list), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_daily_purchase, __pyx_k_lending_daily_purchase, sizeof(__pyx_k_lending_daily_purchase), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_daily_redeem, __pyx_k_lending_daily_redeem, sizeof(__pyx_k_lending_daily_redeem), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_daily_token_position, __pyx_k_lending_daily_token_position, sizeof(__pyx_k_lending_daily_token_position), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_daily_userLeftQuota, __pyx_k_lending_daily_userLeftQuota, sizeof(__pyx_k_lending_daily_userLeftQuota), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_daily_userRedemptionQuot, __pyx_k_lending_daily_userRedemptionQuot, sizeof(__pyx_k_lending_daily_userRedemptionQuot), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_positionChanged, __pyx_k_lending_positionChanged, sizeof(__pyx_k_lending_positionChanged), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_project_list, __pyx_k_lending_project_list, sizeof(__pyx_k_lending_project_list), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_union_account, __pyx_k_lending_union_account, sizeof(__pyx_k_lending_union_account), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_union_interestHistory, __pyx_k_lending_union_interestHistory, sizeof(__pyx_k_lending_union_interestHistory), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_union_purchaseRecord, __pyx_k_lending_union_purchaseRecord, sizeof(__pyx_k_lending_union_purchaseRecord), 0, 0, 1, 0},
    {&__pyx_kp_s_lending_union_redemptionRecord, __pyx_k_lending_union_redemptionRecord, sizeof(__pyx_k_lending_union_redemptionRecord), 0, 0, 1, 0},
    {&__pyx_n_s_leverage, __pyx_k_leverage, sizeof(__pyx_k_leverage), 0, 0, 1, 1},
    {&__pyx_n_s_leverageBracket, __pyx_k_leverageBracket, sizeof(__pyx_k_leverageBracket), 0, 0, 1, 1},
    {&__pyx_n_s_license_ini, __pyx_k_license_ini, sizeof(__pyx_k_license_ini), 0, 0, 1, 1},
    {&__pyx_n_s_license_profile, __pyx_k_license_profile, sizeof(__pyx_k_license_profile), 0, 0, 1, 1},
    {&__pyx_n_s_license_token, __pyx_k_license_token, sizeof(__pyx_k_license_token), 0, 0, 1, 1},
    {&__pyx_n_s_limit, __pyx_k_limit, sizeof(__pyx_k_limit), 0, 0, 1, 1},
    {&__pyx_n_s_listenKey, __pyx_k_listenKey, sizeof(__pyx_k_listenKey), 0, 0, 1, 1},
    {&__pyx_n_s_llm, __pyx_k_llm, sizeof(__pyx_k_llm), 0, 0, 1, 1},
    {&__pyx_n_s_logger, __pyx_k_logger, sizeof(__pyx_k_logger), 0, 0, 1, 1},
    {&__pyx_n_s_logging, __pyx_k_logging, sizeof(__pyx_k_logging), 0, 0, 1, 1},
    {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
    {&__pyx_n_s_lucit_api_secret, __pyx_k_lucit_api_secret, sizeof(__pyx_k_lucit_api_secret), 0, 0, 1, 1},
    {&__pyx_n_s_lucit_license_ini, __pyx_k_lucit_license_ini, sizeof(__pyx_k_lucit_license_ini), 0, 0, 1, 1},
    {&__pyx_n_s_lucit_license_profile, __pyx_k_lucit_license_profile, sizeof(__pyx_k_lucit_license_profile), 0, 0, 1, 1},
    {&__pyx_n_s_lucit_license_token, __pyx_k_lucit_license_token, sizeof(__pyx_k_lucit_license_token), 0, 0, 1, 1},
    {&__pyx_n_s_lucit_licensing_python_manager, __pyx_k_lucit_licensing_python_manager, sizeof(__pyx_k_lucit_licensing_python_manager), 0, 0, 1, 1},
    {&__pyx_n_s_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_make_new_request, __pyx_k_make_new_request, sizeof(__pyx_k_make_new_request), 0, 0, 1, 1},
    {&__pyx_n_s_make_subaccount_futures_transfer, __pyx_k_make_subaccount_futures_transfer, sizeof(__pyx_k_make_subaccount_futures_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_make_subaccount_margin_transfer, __pyx_k_make_subaccount_margin_transfer, sizeof(__pyx_k_make_subaccount_margin_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_make_subaccount_to_master_transf, __pyx_k_make_subaccount_to_master_transf, sizeof(__pyx_k_make_subaccount_to_master_transf), 0, 0, 1, 1},
    {&__pyx_n_s_make_subaccount_to_subaccount_tr, __pyx_k_make_subaccount_to_subaccount_tr, sizeof(__pyx_k_make_subaccount_to_subaccount_tr), 0, 0, 1, 1},
    {&__pyx_n_s_make_universal_transfer, __pyx_k_make_universal_transfer, sizeof(__pyx_k_make_universal_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_marginType, __pyx_k_marginType, sizeof(__pyx_k_marginType), 0, 0, 1, 1},
    {&__pyx_kp_s_margin_account, __pyx_k_margin_account, sizeof(__pyx_k_margin_account), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_allOrderList, __pyx_k_margin_allOrderList, sizeof(__pyx_k_margin_allOrderList), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_allOrders, __pyx_k_margin_allOrders, sizeof(__pyx_k_margin_allOrders), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_asset, __pyx_k_margin_asset, sizeof(__pyx_k_margin_asset), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_isolated_account, __pyx_k_margin_isolated_account, sizeof(__pyx_k_margin_isolated_account), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_isolated_allPairs, __pyx_k_margin_isolated_allPairs, sizeof(__pyx_k_margin_isolated_allPairs), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_isolated_create, __pyx_k_margin_isolated_create, sizeof(__pyx_k_margin_isolated_create), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_isolated_pair, __pyx_k_margin_isolated_pair, sizeof(__pyx_k_margin_isolated_pair), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_isolated_transfer, __pyx_k_margin_isolated_transfer, sizeof(__pyx_k_margin_isolated_transfer), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_loan, __pyx_k_margin_loan, sizeof(__pyx_k_margin_loan), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_maxBorrowable, __pyx_k_margin_maxBorrowable, sizeof(__pyx_k_margin_maxBorrowable), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_maxTransferable, __pyx_k_margin_maxTransferable, sizeof(__pyx_k_margin_maxTransferable), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_myTrades, __pyx_k_margin_myTrades, sizeof(__pyx_k_margin_myTrades), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_openOrders, __pyx_k_margin_openOrders, sizeof(__pyx_k_margin_openOrders), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_order, __pyx_k_margin_order, sizeof(__pyx_k_margin_order), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_orderList, __pyx_k_margin_orderList, sizeof(__pyx_k_margin_orderList), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_order_oco, __pyx_k_margin_order_oco, sizeof(__pyx_k_margin_order_oco), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_pair, __pyx_k_margin_pair, sizeof(__pyx_k_margin_pair), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_priceIndex, __pyx_k_margin_priceIndex, sizeof(__pyx_k_margin_priceIndex), 0, 0, 1, 0},
    {&__pyx_kp_s_margin_repay, __pyx_k_margin_repay, sizeof(__pyx_k_margin_repay), 0, 0, 1, 0},
    {&__pyx_n_s_margin_stream_close, __pyx_k_margin_stream_close, sizeof(__pyx_k_margin_stream_close), 0, 0, 1, 1},
    {&__pyx_n_s_margin_stream_get_listen_key, __pyx_k_margin_stream_get_listen_key, sizeof(__pyx_k_margin_stream_get_listen_key), 0, 0, 1, 1},
    {&__pyx_n_s_margin_stream_keepalive, __pyx_k_margin_stream_keepalive, sizeof(__pyx_k_margin_stream_keepalive), 0, 0, 1, 1},
    {&__pyx_kp_s_margin_transfer, __pyx_k_margin_transfer, sizeof(__pyx_k_margin_transfer), 0, 0, 1, 0},
    {&__pyx_n_s_markPriceKlines, __pyx_k_markPriceKlines, sizeof(__pyx_k_markPriceKlines), 0, 0, 1, 1},
    {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
    {&__pyx_n_s_method, __pyx_k_method, sizeof(__pyx_k_method), 0, 0, 1, 1},
    {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
    {&__pyx_n_s_mro_entries, __pyx_k_mro_entries, sizeof(__pyx_k_mro_entries), 0, 0, 1, 1},
    {&__pyx_n_s_msg, __pyx_k_msg, sizeof(__pyx_k_msg), 0, 0, 1, 1},
    {&__pyx_n_s_myTrades, __pyx_k_myTrades, sizeof(__pyx_k_myTrades), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_needed_license_type, __pyx_k_needed_license_type, sizeof(__pyx_k_needed_license_type), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_n_s_new_transfer_history, __pyx_k_new_transfer_history, sizeof(__pyx_k_new_transfer_history), 0, 0, 1, 1},
    {&__pyx_n_s_null_args, __pyx_k_null_args, sizeof(__pyx_k_null_args), 0, 0, 1, 1},
    {&__pyx_n_s_o, __pyx_k_o, sizeof(__pyx_k_o), 0, 0, 1, 1},
    {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
    {&__pyx_n_s_openInterest, __pyx_k_openInterest, sizeof(__pyx_k_openInterest), 0, 0, 1, 1},
    {&__pyx_n_s_openInterestHist, __pyx_k_openInterestHist, sizeof(__pyx_k_openInterestHist), 0, 0, 1, 1},
    {&__pyx_n_s_openOrders, __pyx_k_openOrders, sizeof(__pyx_k_openOrders), 0, 0, 1, 1},
    {&__pyx_n_s_operator, __pyx_k_operator, sizeof(__pyx_k_operator), 0, 0, 1, 1},
    {&__pyx_n_s_options, __pyx_k_options, sizeof(__pyx_k_options), 0, 0, 1, 1},
    {&__pyx_n_s_order, __pyx_k_order, sizeof(__pyx_k_order), 0, 0, 1, 1},
    {&__pyx_n_s_order_limit, __pyx_k_order_limit, sizeof(__pyx_k_order_limit), 0, 0, 1, 1},
    {&__pyx_n_s_order_limit_buy, __pyx_k_order_limit_buy, sizeof(__pyx_k_order_limit_buy), 0, 0, 1, 1},
    {&__pyx_n_s_order_limit_sell, __pyx_k_order_limit_sell, sizeof(__pyx_k_order_limit_sell), 0, 0, 1, 1},
    {&__pyx_n_s_order_market, __pyx_k_order_market, sizeof(__pyx_k_order_market), 0, 0, 1, 1},
    {&__pyx_n_s_order_market_buy, __pyx_k_order_market_buy, sizeof(__pyx_k_order_market_buy), 0, 0, 1, 1},
    {&__pyx_n_s_order_market_sell, __pyx_k_order_market_sell, sizeof(__pyx_k_order_market_sell), 0, 0, 1, 1},
    {&__pyx_kp_s_order_oco, __pyx_k_order_oco, sizeof(__pyx_k_order_oco), 0, 0, 1, 0},
    {&__pyx_n_s_order_oco_buy, __pyx_k_order_oco_buy, sizeof(__pyx_k_order_oco_buy), 0, 0, 1, 1},
    {&__pyx_n_s_order_oco_sell, __pyx_k_order_oco_sell, sizeof(__pyx_k_order_oco_sell), 0, 0, 1, 1},
    {&__pyx_n_s_order_params, __pyx_k_order_params, sizeof(__pyx_k_order_params), 0, 0, 1, 1},
    {&__pyx_kp_s_order_test, __pyx_k_order_test, sizeof(__pyx_k_order_test), 0, 0, 1, 0},
    {&__pyx_n_s_ordered_data, __pyx_k_ordered_data, sizeof(__pyx_k_ordered_data), 0, 0, 1, 1},
    {&__pyx_n_s_output, __pyx_k_output, sizeof(__pyx_k_output), 0, 0, 1, 1},
    {&__pyx_n_s_output_data, __pyx_k_output_data, sizeof(__pyx_k_output_data), 0, 0, 1, 1},
    {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
    {&__pyx_n_s_params, __pyx_k_params, sizeof(__pyx_k_params), 0, 0, 1, 1},
    {&__pyx_n_s_parent_shutdown_function, __pyx_k_parent_shutdown_function, sizeof(__pyx_k_parent_shutdown_function), 0, 0, 1, 1},
    {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
    {&__pyx_n_s_ping, __pyx_k_ping, sizeof(__pyx_k_ping), 0, 0, 1, 1},
    {&__pyx_n_s_platform, __pyx_k_platform, sizeof(__pyx_k_platform), 0, 0, 1, 1},
    {&__pyx_n_s_positionMargin, __pyx_k_positionMargin, sizeof(__pyx_k_positionMargin), 0, 0, 1, 1},
    {&__pyx_kp_s_positionMargin_history, __pyx_k_positionMargin_history, sizeof(__pyx_k_positionMargin_history), 0, 0, 1, 0},
    {&__pyx_n_s_positionRisk, __pyx_k_positionRisk, sizeof(__pyx_k_positionRisk), 0, 0, 1, 1},
    {&__pyx_kp_s_positionSide_dual, __pyx_k_positionSide_dual, sizeof(__pyx_k_positionSide_dual), 0, 0, 1, 0},
    {&__pyx_n_s_post, __pyx_k_post, sizeof(__pyx_k_post), 0, 0, 1, 1},
    {&__pyx_n_s_post_2, __pyx_k_post_2, sizeof(__pyx_k_post_2), 0, 0, 1, 1},
    {&__pyx_n_s_premiumIndex, __pyx_k_premiumIndex, sizeof(__pyx_k_premiumIndex), 0, 0, 1, 1},
    {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
    {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
    {&__pyx_n_s_products, __pyx_k_products, sizeof(__pyx_k_products), 0, 0, 1, 1},
    {&__pyx_n_s_program_used, __pyx_k_program_used, sizeof(__pyx_k_program_used), 0, 0, 1, 1},
    {&__pyx_n_s_proxies, __pyx_k_proxies, sizeof(__pyx_k_proxies), 0, 0, 1, 1},
    {&__pyx_n_s_purchase_lending_product, __pyx_k_purchase_lending_product, sizeof(__pyx_k_purchase_lending_product), 0, 0, 1, 1},
    {&__pyx_n_s_put, __pyx_k_put, sizeof(__pyx_k_put), 0, 0, 1, 1},
    {&__pyx_n_s_put_2, __pyx_k_put_2, sizeof(__pyx_k_put_2), 0, 0, 1, 1},
    {&__pyx_kp_u_python, __pyx_k_python, sizeof(__pyx_k_python), 0, 1, 0, 0},
    {&__pyx_n_s_python_version, __pyx_k_python_version, sizeof(__pyx_k_python_version), 0, 0, 1, 1},
    {&__pyx_n_s_q, __pyx_k_q, sizeof(__pyx_k_q), 0, 0, 1, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_query_string, __pyx_k_query_string, sizeof(__pyx_k_query_string), 0, 0, 1, 1},
    {&__pyx_n_s_query_subaccount_spot_summary, __pyx_k_query_subaccount_spot_summary, sizeof(__pyx_k_query_subaccount_spot_summary), 0, 0, 1, 1},
    {&__pyx_n_s_query_universal_transfer_history, __pyx_k_query_universal_transfer_history, sizeof(__pyx_k_query_universal_transfer_history), 0, 0, 1, 1},
    {&__pyx_n_s_raw_data, __pyx_k_raw_data, sizeof(__pyx_k_raw_data), 0, 0, 1, 1},
    {&__pyx_n_s_redeem_lending_product, __pyx_k_redeem_lending_product, sizeof(__pyx_k_redeem_lending_product), 0, 0, 1, 1},
    {&__pyx_n_s_release, __pyx_k_release, sizeof(__pyx_k_release), 0, 0, 1, 1},
    {&__pyx_n_s_repay_margin_loan, __pyx_k_repay_margin_loan, sizeof(__pyx_k_repay_margin_loan), 0, 0, 1, 1},
    {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
    {&__pyx_n_s_request, __pyx_k_request, sizeof(__pyx_k_request), 0, 0, 1, 1},
    {&__pyx_n_s_request_api, __pyx_k_request_api, sizeof(__pyx_k_request_api), 0, 0, 1, 1},
    {&__pyx_n_s_request_futures_api, __pyx_k_request_futures_api, sizeof(__pyx_k_request_futures_api), 0, 0, 1, 1},
    {&__pyx_n_s_request_futures_coin_api, __pyx_k_request_futures_coin_api, sizeof(__pyx_k_request_futures_coin_api), 0, 0, 1, 1},
    {&__pyx_n_s_request_futures_coin_data_api, __pyx_k_request_futures_coin_data_api, sizeof(__pyx_k_request_futures_coin_data_api), 0, 0, 1, 1},
    {&__pyx_n_s_request_futures_data_api, __pyx_k_request_futures_data_api, sizeof(__pyx_k_request_futures_data_api), 0, 0, 1, 1},
    {&__pyx_n_s_request_margin_api, __pyx_k_request_margin_api, sizeof(__pyx_k_request_margin_api), 0, 0, 1, 1},
    {&__pyx_n_s_request_socks5_proxies, __pyx_k_request_socks5_proxies, sizeof(__pyx_k_request_socks5_proxies), 0, 0, 1, 1},
    {&__pyx_n_s_request_website, __pyx_k_request_website, sizeof(__pyx_k_request_website), 0, 0, 1, 1},
    {&__pyx_n_s_requests, __pyx_k_requests, sizeof(__pyx_k_requests), 0, 0, 1, 1},
    {&__pyx_n_s_requests_params, __pyx_k_requests_params, sizeof(__pyx_k_requests_params), 0, 0, 1, 1},
    {&__pyx_n_s_requests_params_2, __pyx_k_requests_params_2, sizeof(__pyx_k_requests_params_2), 0, 0, 1, 1},
    {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
    {&__pyx_n_s_respond, __pyx_k_respond, sizeof(__pyx_k_respond), 0, 0, 1, 1},
    {&__pyx_n_s_response, __pyx_k_response, sizeof(__pyx_k_response), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_reversed, __pyx_k_reversed, sizeof(__pyx_k_reversed), 0, 0, 1, 1},
    {&__pyx_kp_s_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 0, 1, 0},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_kp_u_self_API_URL, __pyx_k_self_API_URL, sizeof(__pyx_k_self_API_URL), 0, 1, 0, 0},
    {&__pyx_kp_u_self_FUTURES_COIN_DATA_URL, __pyx_k_self_FUTURES_COIN_DATA_URL, sizeof(__pyx_k_self_FUTURES_COIN_DATA_URL), 0, 1, 0, 0},
    {&__pyx_kp_u_self_FUTURES_COIN_URL, __pyx_k_self_FUTURES_COIN_URL, sizeof(__pyx_k_self_FUTURES_COIN_URL), 0, 1, 0, 0},
    {&__pyx_kp_u_self_FUTURES_DATA_URL, __pyx_k_self_FUTURES_DATA_URL, sizeof(__pyx_k_self_FUTURES_DATA_URL), 0, 1, 0, 0},
    {&__pyx_kp_u_self_FUTURES_URL, __pyx_k_self_FUTURES_URL, sizeof(__pyx_k_self_FUTURES_URL), 0, 1, 0, 0},
    {&__pyx_kp_u_self_MARGIN_API_URL, __pyx_k_self_MARGIN_API_URL, sizeof(__pyx_k_self_MARGIN_API_URL), 0, 1, 0, 0},
    {&__pyx_kp_u_self_WEBSITE_URL, __pyx_k_self_WEBSITE_URL, sizeof(__pyx_k_self_WEBSITE_URL), 0, 1, 0, 0},
    {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
    {&__pyx_n_s_serverTime, __pyx_k_serverTime, sizeof(__pyx_k_serverTime), 0, 0, 1, 1},
    {&__pyx_n_s_session, __pyx_k_session, sizeof(__pyx_k_session), 0, 0, 1, 1},
    {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
    {&__pyx_n_s_sha256, __pyx_k_sha256, sizeof(__pyx_k_sha256), 0, 0, 1, 1},
    {&__pyx_n_s_side, __pyx_k_side, sizeof(__pyx_k_side), 0, 0, 1, 1},
    {&__pyx_n_s_signature, __pyx_k_signature, sizeof(__pyx_k_signature), 0, 0, 1, 1},
    {&__pyx_n_s_signed, __pyx_k_signed, sizeof(__pyx_k_signed), 0, 0, 1, 1},
    {&__pyx_n_s_sleep, __pyx_k_sleep, sizeof(__pyx_k_sleep), 0, 0, 1, 1},
    {&__pyx_kp_s_socks5, __pyx_k_socks5, sizeof(__pyx_k_socks5), 0, 0, 1, 0},
    {&__pyx_n_s_socks5_proxy_address, __pyx_k_socks5_proxy_address, sizeof(__pyx_k_socks5_proxy_address), 0, 0, 1, 1},
    {&__pyx_n_s_socks5_proxy_pass, __pyx_k_socks5_proxy_pass, sizeof(__pyx_k_socks5_proxy_pass), 0, 0, 1, 1},
    {&__pyx_n_s_socks5_proxy_port, __pyx_k_socks5_proxy_port, sizeof(__pyx_k_socks5_proxy_port), 0, 0, 1, 1},
    {&__pyx_n_s_socks5_proxy_server, __pyx_k_socks5_proxy_server, sizeof(__pyx_k_socks5_proxy_server), 0, 0, 1, 1},
    {&__pyx_n_s_socks5_proxy_ssl_verification, __pyx_k_socks5_proxy_ssl_verification, sizeof(__pyx_k_socks5_proxy_ssl_verification), 0, 0, 1, 1},
    {&__pyx_n_s_socks5_proxy_user, __pyx_k_socks5_proxy_user, sizeof(__pyx_k_socks5_proxy_user), 0, 0, 1, 1},
    {&__pyx_n_s_socks_proxy_uri, __pyx_k_socks_proxy_uri, sizeof(__pyx_k_socks_proxy_uri), 0, 0, 1, 1},
    {&__pyx_n_s_sort, __pyx_k_sort, sizeof(__pyx_k_sort), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
    {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
    {&__pyx_n_s_startTime, __pyx_k_startTime, sizeof(__pyx_k_startTime), 0, 0, 1, 1},
    {&__pyx_n_s_start_str, __pyx_k_start_str, sizeof(__pyx_k_start_str), 0, 0, 1, 1},
    {&__pyx_kp_s_start_time_and_last_id_may_not_b, __pyx_k_start_time_and_last_id_may_not_b, sizeof(__pyx_k_start_time_and_last_id_may_not_b), 0, 0, 1, 0},
    {&__pyx_n_s_start_ts, __pyx_k_start_ts, sizeof(__pyx_k_start_ts), 0, 0, 1, 1},
    {&__pyx_kp_u_started, __pyx_k_started, sizeof(__pyx_k_started), 0, 1, 0, 0},
    {&__pyx_n_s_status, __pyx_k_status, sizeof(__pyx_k_status), 0, 0, 1, 1},
    {&__pyx_n_s_status_code, __pyx_k_status_code, sizeof(__pyx_k_status_code), 0, 0, 1, 1},
    {&__pyx_n_s_stop_manager, __pyx_k_stop_manager, sizeof(__pyx_k_stop_manager), 0, 0, 1, 1},
    {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
    {&__pyx_n_s_stream_close, __pyx_k_stream_close, sizeof(__pyx_k_stream_close), 0, 0, 1, 1},
    {&__pyx_n_s_stream_get_listen_key, __pyx_k_stream_get_listen_key, sizeof(__pyx_k_stream_get_listen_key), 0, 0, 1, 1},
    {&__pyx_n_s_stream_keepalive, __pyx_k_stream_keepalive, sizeof(__pyx_k_stream_keepalive), 0, 0, 1, 1},
    {&__pyx_n_s_strptime, __pyx_k_strptime, sizeof(__pyx_k_strptime), 0, 0, 1, 1},
    {&__pyx_kp_s_sub_account_assets, __pyx_k_sub_account_assets, sizeof(__pyx_k_sub_account_assets), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_futures_account, __pyx_k_sub_account_futures_account, sizeof(__pyx_k_sub_account_futures_account), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_futures_accountSumma, __pyx_k_sub_account_futures_accountSumma, sizeof(__pyx_k_sub_account_futures_accountSumma), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_futures_enable, __pyx_k_sub_account_futures_enable, sizeof(__pyx_k_sub_account_futures_enable), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_futures_internalTran, __pyx_k_sub_account_futures_internalTran, sizeof(__pyx_k_sub_account_futures_internalTran), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_futures_positionRisk, __pyx_k_sub_account_futures_positionRisk, sizeof(__pyx_k_sub_account_futures_positionRisk), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_futures_transfer, __pyx_k_sub_account_futures_transfer, sizeof(__pyx_k_sub_account_futures_transfer), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_list, __pyx_k_sub_account_list, sizeof(__pyx_k_sub_account_list), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_margin_account, __pyx_k_sub_account_margin_account, sizeof(__pyx_k_sub_account_margin_account), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_margin_accountSummar, __pyx_k_sub_account_margin_accountSummar, sizeof(__pyx_k_sub_account_margin_accountSummar), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_margin_enable, __pyx_k_sub_account_margin_enable, sizeof(__pyx_k_sub_account_margin_enable), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_margin_transfer, __pyx_k_sub_account_margin_transfer, sizeof(__pyx_k_sub_account_margin_transfer), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_spotSummary, __pyx_k_sub_account_spotSummary, sizeof(__pyx_k_sub_account_spotSummary), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_status, __pyx_k_sub_account_status, sizeof(__pyx_k_sub_account_status), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_sub_transfer_history, __pyx_k_sub_account_sub_transfer_history, sizeof(__pyx_k_sub_account_sub_transfer_history), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_transfer_subToMaster, __pyx_k_sub_account_transfer_subToMaster, sizeof(__pyx_k_sub_account_transfer_subToMaster), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_transfer_subToSub, __pyx_k_sub_account_transfer_subToSub, sizeof(__pyx_k_sub_account_transfer_subToSub), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_transfer_subUserHist, __pyx_k_sub_account_transfer_subUserHist, sizeof(__pyx_k_sub_account_transfer_subUserHist), 0, 0, 1, 0},
    {&__pyx_kp_s_sub_account_universalTransfer, __pyx_k_sub_account_universalTransfer, sizeof(__pyx_k_sub_account_universalTransfer), 0, 0, 1, 0},
    {&__pyx_n_s_success, __pyx_k_success, sizeof(__pyx_k_success), 0, 0, 1, 1},
    {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
    {&__pyx_n_s_symbol, __pyx_k_symbol, sizeof(__pyx_k_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_symbols, __pyx_k_symbols, sizeof(__pyx_k_symbols), 0, 0, 1, 1},
    {&__pyx_n_s_system, __pyx_k_system, sizeof(__pyx_k_system), 0, 0, 1, 1},
    {&__pyx_kp_s_system_status, __pyx_k_system_status, sizeof(__pyx_k_system_status), 0, 0, 1, 0},
    {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
    {&__pyx_n_s_tag_name, __pyx_k_tag_name, sizeof(__pyx_k_tag_name), 0, 0, 1, 1},
    {&__pyx_n_s_temp_data, __pyx_k_temp_data, sizeof(__pyx_k_temp_data), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
    {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
    {&__pyx_n_s_throw_exception, __pyx_k_throw_exception, sizeof(__pyx_k_throw_exception), 0, 0, 1, 1},
    {&__pyx_kp_s_ticker_24hr, __pyx_k_ticker_24hr, sizeof(__pyx_k_ticker_24hr), 0, 0, 1, 0},
    {&__pyx_kp_s_ticker_allForceOrders, __pyx_k_ticker_allForceOrders, sizeof(__pyx_k_ticker_allForceOrders), 0, 0, 1, 0},
    {&__pyx_kp_s_ticker_bookTicker, __pyx_k_ticker_bookTicker, sizeof(__pyx_k_ticker_bookTicker), 0, 0, 1, 0},
    {&__pyx_kp_s_ticker_openInterest, __pyx_k_ticker_openInterest, sizeof(__pyx_k_ticker_openInterest), 0, 0, 1, 0},
    {&__pyx_kp_s_ticker_price, __pyx_k_ticker_price, sizeof(__pyx_k_ticker_price), 0, 0, 1, 0},
    {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
    {&__pyx_n_s_timeInForce, __pyx_k_timeInForce, sizeof(__pyx_k_timeInForce), 0, 0, 1, 1},
    {&__pyx_n_s_timeframe, __pyx_k_timeframe, sizeof(__pyx_k_timeframe), 0, 0, 1, 1},
    {&__pyx_n_s_timeout, __pyx_k_timeout, sizeof(__pyx_k_timeout), 0, 0, 1, 1},
    {&__pyx_n_s_timestamp, __pyx_k_timestamp, sizeof(__pyx_k_timestamp), 0, 0, 1, 1},
    {&__pyx_n_s_timestamp_offset, __pyx_k_timestamp_offset, sizeof(__pyx_k_timestamp_offset), 0, 0, 1, 1},
    {&__pyx_n_s_tld, __pyx_k_tld, sizeof(__pyx_k_tld), 0, 0, 1, 1},
    {&__pyx_kp_u_tld_2, __pyx_k_tld_2, sizeof(__pyx_k_tld_2), 0, 1, 0, 0},
    {&__pyx_n_s_toggle_bnb_burn_spot_margin, __pyx_k_toggle_bnb_burn_spot_margin, sizeof(__pyx_k_toggle_bnb_burn_spot_margin), 0, 0, 1, 1},
    {&__pyx_n_s_trades, __pyx_k_trades, sizeof(__pyx_k_trades), 0, 0, 1, 1},
    {&__pyx_n_s_transFrom, __pyx_k_transFrom, sizeof(__pyx_k_transFrom), 0, 0, 1, 1},
    {&__pyx_n_s_transTo, __pyx_k_transTo, sizeof(__pyx_k_transTo), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_dust, __pyx_k_transfer_dust, sizeof(__pyx_k_transfer_dust), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_history, __pyx_k_transfer_history, sizeof(__pyx_k_transfer_history), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_isolated_margin_to_spot, __pyx_k_transfer_isolated_margin_to_spot, sizeof(__pyx_k_transfer_isolated_margin_to_spot), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_margin_to_spot, __pyx_k_transfer_margin_to_spot, sizeof(__pyx_k_transfer_margin_to_spot), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_spot_to_isolated_margin, __pyx_k_transfer_spot_to_isolated_margin, sizeof(__pyx_k_transfer_spot_to_isolated_margin), 0, 0, 1, 1},
    {&__pyx_n_s_transfer_spot_to_margin, __pyx_k_transfer_spot_to_margin, sizeof(__pyx_k_transfer_spot_to_margin), 0, 0, 1, 1},
    {&__pyx_kp_s_trbinance_com, __pyx_k_trbinance_com, sizeof(__pyx_k_trbinance_com), 0, 0, 1, 0},
    {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
    {&__pyx_n_s_typing, __pyx_k_typing, sizeof(__pyx_k_typing), 0, 0, 1, 1},
    {&__pyx_kp_s_unicorn_binance_rest_api, __pyx_k_unicorn_binance_rest_api, sizeof(__pyx_k_unicorn_binance_rest_api), 0, 0, 1, 0},
    {&__pyx_n_s_unicorn_binance_rest_api_2, __pyx_k_unicorn_binance_rest_api_2, sizeof(__pyx_k_unicorn_binance_rest_api_2), 0, 0, 1, 1},
    {&__pyx_n_s_unicorn_binance_rest_api_manager, __pyx_k_unicorn_binance_rest_api_manager, sizeof(__pyx_k_unicorn_binance_rest_api_manager), 0, 0, 1, 1},
    {&__pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_k_unicorn_binance_rest_api_manager_2, sizeof(__pyx_k_unicorn_binance_rest_api_manager_2), 0, 0, 1, 0},
    {&__pyx_kp_s_unicorn_binance_websocket_api, __pyx_k_unicorn_binance_websocket_api, sizeof(__pyx_k_unicorn_binance_websocket_api), 0, 0, 1, 0},
    {&__pyx_n_s_universal_transfer, __pyx_k_universal_transfer, sizeof(__pyx_k_universal_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_unknown, __pyx_k_unknown, sizeof(__pyx_k_unknown), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_update_msg, __pyx_k_update_msg, sizeof(__pyx_k_update_msg), 0, 0, 1, 1},
    {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
    {&__pyx_n_s_uri, __pyx_k_uri, sizeof(__pyx_k_uri), 0, 0, 1, 1},
    {&__pyx_n_s_urlencode, __pyx_k_urlencode, sizeof(__pyx_k_urlencode), 0, 0, 1, 1},
    {&__pyx_n_s_urllib_parse, __pyx_k_urllib_parse, sizeof(__pyx_k_urllib_parse), 0, 0, 1, 1},
    {&__pyx_n_s_userDataStream, __pyx_k_userDataStream, sizeof(__pyx_k_userDataStream), 0, 0, 1, 1},
    {&__pyx_kp_s_userDataStream_isolated, __pyx_k_userDataStream_isolated, sizeof(__pyx_k_userDataStream_isolated), 0, 0, 1, 0},
    {&__pyx_n_s_userTrades, __pyx_k_userTrades, sizeof(__pyx_k_userTrades), 0, 0, 1, 1},
    {&__pyx_n_s_user_agent, __pyx_k_user_agent, sizeof(__pyx_k_user_agent), 0, 0, 1, 1},
    {&__pyx_kp_s_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 0, 1, 0},
    {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
    {&__pyx_n_s_v1, __pyx_k_v1, sizeof(__pyx_k_v1), 0, 0, 1, 1},
    {&__pyx_n_s_v2, __pyx_k_v2, sizeof(__pyx_k_v2), 0, 0, 1, 1},
    {&__pyx_n_s_v3, __pyx_k_v3, sizeof(__pyx_k_v3), 0, 0, 1, 1},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_n_s_verify, __pyx_k_verify, sizeof(__pyx_k_verify), 0, 0, 1, 1},
    {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
    {&__pyx_n_s_version_2, __pyx_k_version_2, sizeof(__pyx_k_version_2), 0, 0, 1, 1},
    {&__pyx_n_s_warn_on_update, __pyx_k_warn_on_update, sizeof(__pyx_k_warn_on_update), 0, 0, 1, 1},
    {&__pyx_n_s_warning, __pyx_k_warning, sizeof(__pyx_k_warning), 0, 0, 1, 1},
    {&__pyx_n_s_weight, __pyx_k_weight, sizeof(__pyx_k_weight), 0, 0, 1, 1},
    {&__pyx_n_s_withdraw, __pyx_k_withdraw, sizeof(__pyx_k_withdraw), 0, 0, 1, 1},
    {&__pyx_n_s_withdrawList, __pyx_k_withdrawList, sizeof(__pyx_k_withdrawList), 0, 0, 1, 1},
    {&__pyx_n_s_withdraw_id, __pyx_k_withdraw_id, sizeof(__pyx_k_withdraw_id), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 59, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 387, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 408, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_n_s_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 520, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 519, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 586, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "unicorn_binance_rest_api/manager.py":609
 *         installed_version = self.get_version()
 *         if ".dev" in installed_version:
 *             installed_version = installed_version[:-4]             # <<<<<<<<<<<<<<
 *         if self.get_latest_version() == installed_version:
 *             return False
 */
  __pyx_slice__10 = PySlice_New(Py_None, __pyx_int_neg_4, Py_None); if (unlikely(!__pyx_slice__10)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__10);
  __Pyx_GIVEREF(__pyx_slice__10);

  /* "unicorn_binance_rest_api/manager.py":649
 *         try:
 *             if self.socks5_proxy_address is not None and self.socks5_proxy_port is not None:
 *                 respond = requests.get('https://api.github.com/repos/LUCIT-Systems-and-Development/'             # <<<<<<<<<<<<<<
 *                                        'unicorn-binance-rest-api/releases/latest',
 *                                        proxies=self.request_socks5_proxies,
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_s_https_api_github_com_repos_LUCIT); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "unicorn_binance_rest_api/manager.py":682
 * 
 *         """
 *         products = self._request_website('get', 'exchange-api/v1/public/asset-service/product/get-products')             # <<<<<<<<<<<<<<
 *         return products
 * 
 */
  __pyx_tuple__12 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_exchange_api_v1_public_asset_ser); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "unicorn_binance_rest_api/manager.py":748
 *         """
 * 
 *         return self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_symbol_info(self, symbol):
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_n_s_exchangeInfo); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "unicorn_binance_rest_api/manager.py":817
 * 
 *         """
 *         return self._get('ping', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_server_time(self):
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_n_s_ping); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "unicorn_binance_rest_api/manager.py":836
 * 
 *         """
 *         return self._get('time', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     # Market Data Endpoints
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_n_s_time); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "unicorn_binance_rest_api/manager.py":864
 * 
 *         """
 *         return self._get('ticker/price', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_orderbook_tickers(self):
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_s_ticker_price); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "unicorn_binance_rest_api/manager.py":896
 * 
 *         """
 *         return self._get('ticker/bookTicker', version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_order_book(self, **params):
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_s_ticker_bookTicker); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "unicorn_binance_rest_api/manager.py":934
 * 
 *         """
 *         return self._get('depth', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_recent_trades(self, **params):
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_n_s_depth); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "unicorn_binance_rest_api/manager.py":965
 * 
 *         """
 *         return self._get('trades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_historical_trades(self, **params):
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_n_s_trades); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "unicorn_binance_rest_api/manager.py":998
 * 
 *         """
 *         return self._get('historicalTrades', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_aggregate_trades(self, **params):
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_n_s_historicalTrades); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "unicorn_binance_rest_api/manager.py":1037
 *         :raises: BinanceRequestException, BinanceAPIException
 *         """
 *         return self._get('aggTrades', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def aggregate_trade_iter(self, symbol, start_str=None, last_id=None):
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_n_s_aggTrades); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "unicorn_binance_rest_api/manager.py":1074
 *         """
 *         if start_str is not None and last_id is not None:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'start_time and last_id may not be simultaneously specified.')
 * 
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_s_start_time_and_last_id_may_not_b); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 1074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "unicorn_binance_rest_api/manager.py":1121
 *             # fromId=n returns a set starting with id n, but we already have
 *             # that one. So get rid of the first item in the result set.
 *             trades = trades[1:]             # <<<<<<<<<<<<<<
 *             if len(trades) == 0:
 *                 return
 */
  __pyx_slice__24 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__24)) __PYX_ERR(0, 1121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__24);
  __Pyx_GIVEREF(__pyx_slice__24);

  /* "unicorn_binance_rest_api/manager.py":1169
 * 
 *         """
 *         return self._get('klines', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def _get_earliest_valid_timestamp(self, symbol, interval):
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_n_s_klines); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "unicorn_binance_rest_api/manager.py":1374
 *             }
 *         """
 *         return self._get('avgPrice', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_ticker(self, **params):
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_n_s_avgPrice); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "unicorn_binance_rest_api/manager.py":1435
 * 
 *         """
 *         return self._get('ticker/24hr', data=params, version=self.PRIVATE_API_VERSION)             # <<<<<<<<<<<<<<
 * 
 *     def get_symbol_ticker(self, **params):
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_s_ticker_24hr); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "unicorn_binance_rest_api/manager.py":1638
 *                  BinanceOrderInactiveSymbolException
 *         """
 *         return self._post('order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def order_limit(self, timeInForce=TIME_IN_FORCE_GTC, **params):
 */
  __pyx_tuple__29 = PyTuple_Pack(2, __pyx_n_s_order, Py_True); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 1638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "unicorn_binance_rest_api/manager.py":1908
 * 
 *         """
 *         return self._post('order/oco', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def order_oco_buy(self, **params):
 */
  __pyx_tuple__30 = PyTuple_Pack(2, __pyx_kp_s_order_oco, Py_True); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "unicorn_binance_rest_api/manager.py":2036
 * 
 *         """
 *         return self._post('order/test', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_order(self, **params):
 */
  __pyx_tuple__31 = PyTuple_Pack(2, __pyx_kp_s_order_test, Py_True); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "unicorn_binance_rest_api/manager.py":2116
 * 
 *         """
 *         return self._get('allOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_all_open_orders(self, **params):
 */
  __pyx_tuple__32 = PyTuple_Pack(2, __pyx_n_s_allOrders, Py_True); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 2116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "unicorn_binance_rest_api/manager.py":2229
 * 
 *         """
 *         return self._delete('openOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_all_open_margin_orders(self, **params):
 */
  __pyx_tuple__33 = PyTuple_Pack(2, __pyx_n_s_openOrders, Py_True); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 2229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "unicorn_binance_rest_api/manager.py":2338
 * 
 *         """
 *         return self._request_margin_api('delete', 'margin/openOrders', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_order(self, **params):
 */
  __pyx_tuple__34 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_kp_s_margin_openOrders); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 2338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "unicorn_binance_rest_api/manager.py":2447
 * 
 *         """
 *         return self._get('account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_asset_balance(self, asset, **params):
 */
  __pyx_tuple__35 = PyTuple_Pack(2, __pyx_n_s_account, Py_True); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 2447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "unicorn_binance_rest_api/manager.py":2515
 * 
 *         """
 *         return self._get('myTrades', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_system_status(self):
 */
  __pyx_tuple__36 = PyTuple_Pack(2, __pyx_n_s_myTrades, Py_True); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 2515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "unicorn_binance_rest_api/manager.py":2534
 * 
 *         """
 *         return self._request_margin_api('get', 'system/status')             # <<<<<<<<<<<<<<
 * 
 *     def get_account_status(self, **params):
 */
  __pyx_tuple__37 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_system_status); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 2534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "unicorn_binance_rest_api/manager.py":2555
 * 
 *         """
 *         res = self._request_margin_api('get', 'account/status', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_tuple__38 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_account_status, Py_True); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "unicorn_binance_rest_api/manager.py":2630
 * 
 *         """
 *         res = self._request_margin_api('get', 'account/apiTradingStatus', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_tuple__39 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_account_apiTradingStatus, Py_True); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 2630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "unicorn_binance_rest_api/manager.py":2707
 * 
 *         """
 *         res = self._request_margin_api('get', 'asset/dribblet', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_tuple__40 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_asset_dribblet, Py_True); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "unicorn_binance_rest_api/manager.py":2749
 * 
 *         """
 *         return self._request_margin_api('post', 'asset/dust', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_asset_dividend_history(self, **params):
 */
  __pyx_tuple__41 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_asset_dust, Py_True); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 2749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "unicorn_binance_rest_api/manager.py":2797
 * 
 *         """
 *         return self._request_margin_api('get', 'asset/assetDividend', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def query_universal_transfer_history(self, **params):
 */
  __pyx_tuple__42 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_asset_assetDividend, Py_True); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 2797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "unicorn_binance_rest_api/manager.py":2852
 * 
 *         """
 *         return self._request_margin_api('get', 'asset/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_trade_fee(self, **params):
 */
  __pyx_tuple__43 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_asset_transfer); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 2852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "unicorn_binance_rest_api/manager.py":2884
 * 
 *         """
 *         res = self._request_margin_api('get', 'asset/tradeFee', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_tuple__44 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_asset_tradeFee, Py_True); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 2884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "unicorn_binance_rest_api/manager.py":2923
 * 
 *         """
 *         res = self._request_margin_api('get', 'asset/assetDetail', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_tuple__45 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_asset_assetDetail, Py_True); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "unicorn_binance_rest_api/manager.py":2974
 *         if 'asset' in params and 'name' not in params:
 *             params['name'] = params['asset']
 *         res = self._request_margin_api('post', 'capital/withdraw/apply', True, data=params)             # <<<<<<<<<<<<<<
 *         if not res.get('success'):
 *             raise BinanceWithdrawException(res['msg'])
 */
  __pyx_tuple__46 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_capital_withdraw_apply, Py_True); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 2974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "unicorn_binance_rest_api/manager.py":3033
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/hisrec', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_withdraw_history(self, **params):
 */
  __pyx_tuple__47 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_capital_deposit_hisrec, Py_True); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "unicorn_binance_rest_api/manager.py":3089
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/withdraw/history', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_withdraw_history_id(self, withdraw_id, **params):
 */
  __pyx_tuple__48 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_capital_withdraw_history, Py_True); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "unicorn_binance_rest_api/manager.py":3163
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/address', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     # User Stream Endpoints
 */
  __pyx_tuple__49 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_capital_deposit_address, Py_True); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "unicorn_binance_rest_api/manager.py":3192
 * 
 *         """
 *         res = self._post('userDataStream', False, data={}, version=self.PRIVATE_API_VERSION,             # <<<<<<<<<<<<<<
 *                          throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_tuple__50 = PyTuple_Pack(2, __pyx_n_s_userDataStream, Py_False); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "unicorn_binance_rest_api/manager.py":3309
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_isolated_margin_account(self, **params):
 */
  __pyx_tuple__51 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_margin_account, Py_True); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "unicorn_binance_rest_api/manager.py":3420
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/isolated/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_asset(self, **params):
 */
  __pyx_tuple__52 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_margin_isolated_account, Py_True); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 3420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "unicorn_binance_rest_api/manager.py":3451
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/asset', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_symbol(self, **params):
 */
  __pyx_tuple__53 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_asset); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 3451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "unicorn_binance_rest_api/manager.py":3483
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/pair', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def create_isolated_margin_account(self, **params):
 */
  __pyx_tuple__54 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_pair); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "unicorn_binance_rest_api/manager.py":3512
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/isolated/create', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__55 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_margin_isolated_create); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 3512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "unicorn_binance_rest_api/manager.py":3544
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/isolated/pair', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_all_isolated_margin_symbols(self, **params):
 */
  __pyx_tuple__56 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_isolated_pair); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 3544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "unicorn_binance_rest_api/manager.py":3582
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/isolated/allPairs', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def toggle_bnb_burn_spot_margin(self, **params):
 */
  __pyx_tuple__57 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_isolated_allPairs); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 3582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "unicorn_binance_rest_api/manager.py":3611
 * 
 *         """
 *         return self._request_margin_api('post', 'bnbBurn', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_bnb_burn_spot_margin(self, **params):
 */
  __pyx_tuple__58 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_n_s_bnbBurn); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 3611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "unicorn_binance_rest_api/manager.py":3635
 * 
 *         """
 *         return self._request_margin_api('get', 'bnbBurn', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_price_index(self, **params):
 */
  __pyx_tuple__59 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_bnbBurn); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 3635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "unicorn_binance_rest_api/manager.py":3662
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/priceIndex', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_margin_to_spot(self, **params):
 */
  __pyx_tuple__60 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_priceIndex); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "unicorn_binance_rest_api/manager.py":3693
 *         """
 *         params['type'] = 2
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_spot_to_margin(self, **params):
 */
  __pyx_tuple__61 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_margin_transfer); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "unicorn_binance_rest_api/manager.py":3760
 *         params['transFrom'] = "ISOLATED_MARGIN"
 *         params['transTo'] = "SPOT"
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_spot_to_isolated_margin(self, **params):
 */
  __pyx_tuple__62 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_margin_isolated_transfer); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 3760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "unicorn_binance_rest_api/manager.py":3832
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/loan', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def repay_margin_loan(self, **params):
 */
  __pyx_tuple__63 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_margin_loan); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "unicorn_binance_rest_api/manager.py":3871
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/repay', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__64 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_margin_repay); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(0, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "unicorn_binance_rest_api/manager.py":3983
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/order/oco', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_margin_oco_order(self, **params):
 */
  __pyx_tuple__65 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_margin_order_oco); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 3983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "unicorn_binance_rest_api/manager.py":4064
 * 
 *     """
 *         return self._request_margin_api('delete', 'margin/orderList', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_oco_order(self, **params):
 */
  __pyx_tuple__66 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_kp_s_margin_orderList); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "unicorn_binance_rest_api/manager.py":4110
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/orderList', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_open_margin_oco_orders(self, **params):
 */
  __pyx_tuple__67 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_orderList); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 4110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "unicorn_binance_rest_api/manager.py":4183
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/allOrderList', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def create_margin_order(self, **params):
 */
  __pyx_tuple__68 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_allOrderList); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 4183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "unicorn_binance_rest_api/manager.py":4304
 * 
 *         """
 *         return self._request_margin_api('post', 'margin/order', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def cancel_margin_order(self, **params):
 */
  __pyx_tuple__69 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_margin_order); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 4304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "unicorn_binance_rest_api/manager.py":4351
 *         """
 * 
 *         return self._request_margin_api('delete', 'margin/order', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_loan_details(self, **params):
 */
  __pyx_tuple__70 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_kp_s_margin_order); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(0, 4351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "unicorn_binance_rest_api/manager.py":4398
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/loan', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_repay_details(self, **params):
 */
  __pyx_tuple__71 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_loan); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 4398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "unicorn_binance_rest_api/manager.py":4451
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/repay', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_order(self, **params):
 */
  __pyx_tuple__72 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_repay); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "unicorn_binance_rest_api/manager.py":4499
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/order', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_open_margin_orders(self, **params):
 */
  __pyx_tuple__73 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_order); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "unicorn_binance_rest_api/manager.py":4549
 *         """
 * 
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_open_isolated_margin_orders(self, **params):
 */
  __pyx_tuple__74 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_openOrders); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 4549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "unicorn_binance_rest_api/manager.py":4660
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/allOrders', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_margin_trades(self, **params):
 */
  __pyx_tuple__75 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_allOrders); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 4660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "unicorn_binance_rest_api/manager.py":4720
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/myTrades', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_max_margin_loan(self, **params):
 */
  __pyx_tuple__76 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_myTrades); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 4720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "unicorn_binance_rest_api/manager.py":4745
 * 
 *         """
 *         return self._request_margin_api('get', 'margin/maxBorrowable', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_max_margin_transfer(self, **params):
 */
  __pyx_tuple__77 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_maxBorrowable); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 4745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "unicorn_binance_rest_api/manager.py":4771
 *         """
 * 
 *         return self._request_margin_api('get', 'margin/maxTransferable', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     # Cross-margin
 */
  __pyx_tuple__78 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_margin_maxTransferable); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 4771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "unicorn_binance_rest_api/manager.py":4800
 * 
 *         """
 *         res = self._request_margin_api('post', 'userDataStream', signed=False, data={}, throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 *         if output == "value":
 *             return res['listenKey']
 */
  __pyx_tuple__79 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_n_s_userDataStream); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);

  /* "unicorn_binance_rest_api/manager.py":4830
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('put', 'userDataStream', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_tuple__80 = PyTuple_Pack(2, __pyx_n_s_put, __pyx_n_s_userDataStream); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 4830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);

  /* "unicorn_binance_rest_api/manager.py":4855
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('delete', 'userDataStream', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_tuple__81 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_n_s_userDataStream); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(0, 4855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "unicorn_binance_rest_api/manager.py":4891
 *             'symbol': symbol
 *         }
 *         res = self._request_margin_api('post', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                        throw_exception=throw_exception)
 *         if output == "value":
 */
  __pyx_tuple__82 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_userDataStream_isolated); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 4891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);

  /* "unicorn_binance_rest_api/manager.py":4925
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('put', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_tuple__83 = PyTuple_Pack(2, __pyx_n_s_put, __pyx_kp_s_userDataStream_isolated); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(0, 4925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "unicorn_binance_rest_api/manager.py":4953
 *             'listenKey': listenKey
 *         }
 *         return self._request_margin_api('delete', 'userDataStream/isolated', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                         throw_exception=throw_exception)
 * 
 */
  __pyx_tuple__84 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_kp_s_userDataStream_isolated); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);

  /* "unicorn_binance_rest_api/manager.py":4964
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/product/list', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_daily_quota_left(self, **params):
 */
  __pyx_tuple__85 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_daily_product_list); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(0, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);

  /* "unicorn_binance_rest_api/manager.py":4972
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/userLeftQuota', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def purchase_lending_product(self, **params):
 */
  __pyx_tuple__86 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_daily_userLeftQuota); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "unicorn_binance_rest_api/manager.py":4980
 * 
 *         """
 *         return self._request_margin_api('post', 'lending/daily/purchase', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_daily_redemption_quota(self, **params):
 */
  __pyx_tuple__87 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_lending_daily_purchase); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);

  /* "unicorn_binance_rest_api/manager.py":4988
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/userRedemptionQuota', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def redeem_lending_product(self, **params):
 */
  __pyx_tuple__88 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_daily_userRedemptionQuot); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 4988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);

  /* "unicorn_binance_rest_api/manager.py":4996
 * 
 *         """
 *         return self._request_margin_api('post', 'lending/daily/redeem', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_position(self, **params):
 */
  __pyx_tuple__89 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_lending_daily_redeem); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(0, 4996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);

  /* "unicorn_binance_rest_api/manager.py":5004
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/daily/token/position', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_fixed_activity_project_list(self, **params):
 */
  __pyx_tuple__90 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_daily_token_position); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(0, 5004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);

  /* "unicorn_binance_rest_api/manager.py":5054
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/project/list', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_account(self, **params):
 */
  __pyx_tuple__91 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_project_list); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 5054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);

  /* "unicorn_binance_rest_api/manager.py":5062
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/account', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_purchase_history(self, **params):
 */
  __pyx_tuple__92 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_union_account); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(0, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "unicorn_binance_rest_api/manager.py":5070
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/purchaseRecord', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_redemption_history(self, **params):
 */
  __pyx_tuple__93 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_union_purchaseRecord); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 5070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "unicorn_binance_rest_api/manager.py":5078
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/redemptionRecord', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_lending_interest_history(self, **params):
 */
  __pyx_tuple__94 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_union_redemptionRecord); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(0, 5078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);

  /* "unicorn_binance_rest_api/manager.py":5086
 * 
 *         """
 *         return self._request_margin_api('get', 'lending/union/interestHistory', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def change_fixed_activity_to_daily_position(self, **params):
 */
  __pyx_tuple__95 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_lending_union_interestHistory); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);

  /* "unicorn_binance_rest_api/manager.py":5094
 * 
 *         """
 *         return self._request_margin_api('post', 'lending/positionChanged', signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     # Sub Accounts
 */
  __pyx_tuple__96 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_lending_positionChanged); if (unlikely(!__pyx_tuple__96)) __PYX_ERR(0, 5094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__96);
  __Pyx_GIVEREF(__pyx_tuple__96);

  /* "unicorn_binance_rest_api/manager.py":5135
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/list', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_sub_account_transfer_history(self, **params):
 */
  __pyx_tuple__97 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_list, Py_True); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 5135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);

  /* "unicorn_binance_rest_api/manager.py":5185
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/sub/transfer/history', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_sub_account_futures_transfer_history(self, **params):
 */
  __pyx_tuple__98 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_sub_transfer_history, Py_True); if (unlikely(!__pyx_tuple__98)) __PYX_ERR(0, 5185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__98);
  __Pyx_GIVEREF(__pyx_tuple__98);

  /* "unicorn_binance_rest_api/manager.py":5235
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/internalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def create_sub_account_futures_transfer(self, **params):
 */
  __pyx_tuple__99 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_futures_internalTran, Py_True); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 5235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);

  /* "unicorn_binance_rest_api/manager.py":5267
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/futures/internalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_sub_account_assets(self, **params):
 */
  __pyx_tuple__100 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_futures_internalTran, Py_True); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(0, 5267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);

  /* "unicorn_binance_rest_api/manager.py":5316
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/assets', True, data=params, version='v3')             # <<<<<<<<<<<<<<
 * 
 *     def query_subaccount_spot_summary(self, **params):
 */
  __pyx_tuple__101 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_assets, Py_True); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "unicorn_binance_rest_api/manager.py":5354
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/spotSummary', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_deposit_address(self, **params):
 */
  __pyx_tuple__102 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_spotSummary, Py_True); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(0, 5354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);

  /* "unicorn_binance_rest_api/manager.py":5384
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/subAddress', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_deposit_history(self, **params):
 */
  __pyx_tuple__103 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_capital_deposit_subAddress, Py_True); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "unicorn_binance_rest_api/manager.py":5442
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/deposit/subHisrec', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_margin_status(self, **params):
 */
  __pyx_tuple__104 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_capital_deposit_subHisrec, Py_True); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(0, 5442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);

  /* "unicorn_binance_rest_api/manager.py":5473
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/status', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def enable_subaccount_margin(self, **params):
 */
  __pyx_tuple__105 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_status, Py_True); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 5473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);

  /* "unicorn_binance_rest_api/manager.py":5500
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/margin/enable', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_margin_details(self, **params):
 */
  __pyx_tuple__106 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_margin_enable, Py_True); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(0, 5500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "unicorn_binance_rest_api/manager.py":5567
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/margin/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_margin_summary(self, **params):
 */
  __pyx_tuple__107 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_margin_account, Py_True); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 5567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);

  /* "unicorn_binance_rest_api/manager.py":5604
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/margin/accountSummary', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def enable_subaccount_futures(self, **params):
 */
  __pyx_tuple__108 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_margin_accountSummar, Py_True); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(0, 5604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);

  /* "unicorn_binance_rest_api/manager.py":5631
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/futures/enable', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_details(self, **params):
 */
  __pyx_tuple__109 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_futures_enable, Py_True); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 5631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "unicorn_binance_rest_api/manager.py":5681
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_summary(self, **params):
 */
  __pyx_tuple__110 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_futures_account, Py_True); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(0, 5681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);

  /* "unicorn_binance_rest_api/manager.py":5733
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/accountSummary', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_futures_positionrisk(self, **params):
 */
  __pyx_tuple__111 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_futures_accountSumma, Py_True); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(0, 5733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);

  /* "unicorn_binance_rest_api/manager.py":5765
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/futures/positionRisk', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_futures_transfer(self, **params):
 */
  __pyx_tuple__112 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_futures_positionRisk, Py_True); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);

  /* "unicorn_binance_rest_api/manager.py":5795
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/futures/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_margin_transfer(self, **params):
 */
  __pyx_tuple__113 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_futures_transfer, Py_True); if (unlikely(!__pyx_tuple__113)) __PYX_ERR(0, 5795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__113);
  __Pyx_GIVEREF(__pyx_tuple__113);

  /* "unicorn_binance_rest_api/manager.py":5823
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/margin/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_to_subaccount_transfer(self, **params):
 */
  __pyx_tuple__114 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_margin_transfer, Py_True); if (unlikely(!__pyx_tuple__114)) __PYX_ERR(0, 5823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);

  /* "unicorn_binance_rest_api/manager.py":5850
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/transfer/subToSub', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_subaccount_to_master_transfer(self, **params):
 */
  __pyx_tuple__115 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_transfer_subToSub, Py_True); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(0, 5850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);

  /* "unicorn_binance_rest_api/manager.py":5875
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/transfer/subToMaster', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_subaccount_transfer_history(self, **params):
 */
  __pyx_tuple__116 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_transfer_subToMaster, Py_True); if (unlikely(!__pyx_tuple__116)) __PYX_ERR(0, 5875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__116);
  __Pyx_GIVEREF(__pyx_tuple__116);

  /* "unicorn_binance_rest_api/manager.py":5925
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/transfer/subUserHistory', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def make_universal_transfer(self, **params):
 */
  __pyx_tuple__117 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_transfer_subUserHist, Py_True); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 5925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);

  /* "unicorn_binance_rest_api/manager.py":5958
 * 
 *         """
 *         return self._request_margin_api('post', 'sub-account/universalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_universal_transfer_history(self, **params):
 */
  __pyx_tuple__118 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_sub_account_universalTransfer, Py_True); if (unlikely(!__pyx_tuple__118)) __PYX_ERR(0, 5958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__118);
  __Pyx_GIVEREF(__pyx_tuple__118);

  /* "unicorn_binance_rest_api/manager.py":6012
 * 
 *         """
 *         return self._request_margin_api('get', 'sub-account/universalTransfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_used_weight(self, make_new_request=False):
 */
  __pyx_tuple__119 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_sub_account_universalTransfer, Py_True); if (unlikely(!__pyx_tuple__119)) __PYX_ERR(0, 6012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);

  /* "unicorn_binance_rest_api/manager.py":6053
 * 
 *         """
 *         return self._request_futures_api('get', 'ping')             # <<<<<<<<<<<<<<
 * 
 *     def futures_time(self):
 */
  __pyx_tuple__120 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_ping); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(0, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "unicorn_binance_rest_api/manager.py":6061
 * 
 *         """
 *         return self._request_futures_api('get', 'time')             # <<<<<<<<<<<<<<
 * 
 *     def futures_exchange_info(self):
 */
  __pyx_tuple__121 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_time); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(0, 6061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);

  /* "unicorn_binance_rest_api/manager.py":6069
 * 
 *         """
 *         return self._request_futures_api('get', 'exchangeInfo')             # <<<<<<<<<<<<<<
 * 
 *     def futures_order_book(self, **params):
 */
  __pyx_tuple__122 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_exchangeInfo); if (unlikely(!__pyx_tuple__122)) __PYX_ERR(0, 6069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__122);
  __Pyx_GIVEREF(__pyx_tuple__122);

  /* "unicorn_binance_rest_api/manager.py":6077
 * 
 *         """
 *         return self._request_futures_api('get', 'depth', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_recent_trades(self, **params):
 */
  __pyx_tuple__123 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_depth); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 6077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);

  /* "unicorn_binance_rest_api/manager.py":6085
 * 
 *         """
 *         return self._request_futures_api('get', 'trades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_historical_trades(self, **params):
 */
  __pyx_tuple__124 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_trades); if (unlikely(!__pyx_tuple__124)) __PYX_ERR(0, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__124);
  __Pyx_GIVEREF(__pyx_tuple__124);

  /* "unicorn_binance_rest_api/manager.py":6093
 * 
 *         """
 *         return self._request_futures_api('get', 'historicalTrades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_aggregate_trades(self, **params):
 */
  __pyx_tuple__125 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_historicalTrades); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(0, 6093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);

  /* "unicorn_binance_rest_api/manager.py":6102
 * 
 *         """
 *         return self._request_futures_api('get', 'aggTrades', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_klines(self, **params):
 */
  __pyx_tuple__126 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_aggTrades); if (unlikely(!__pyx_tuple__126)) __PYX_ERR(0, 6102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__126);
  __Pyx_GIVEREF(__pyx_tuple__126);

  /* "unicorn_binance_rest_api/manager.py":6110
 * 
 *         """
 *         return self._request_futures_api('get', 'klines', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_mark_price(self, **params):
 */
  __pyx_tuple__127 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_klines); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(0, 6110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);

  /* "unicorn_binance_rest_api/manager.py":6118
 * 
 *         """
 *         return self._request_futures_api('get', 'premiumIndex', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_funding_rate(self, **params):
 */
  __pyx_tuple__128 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_premiumIndex); if (unlikely(!__pyx_tuple__128)) __PYX_ERR(0, 6118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__128);
  __Pyx_GIVEREF(__pyx_tuple__128);

  /* "unicorn_binance_rest_api/manager.py":6126
 * 
 *         """
 *         return self._request_futures_api('get', 'fundingRate', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_ticker(self, **params):
 */
  __pyx_tuple__129 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_fundingRate); if (unlikely(!__pyx_tuple__129)) __PYX_ERR(0, 6126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);

  /* "unicorn_binance_rest_api/manager.py":6134
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/24hr', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_symbol_ticker(self, **params):
 */
  __pyx_tuple__130 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_ticker_24hr); if (unlikely(!__pyx_tuple__130)) __PYX_ERR(0, 6134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__130);
  __Pyx_GIVEREF(__pyx_tuple__130);

  /* "unicorn_binance_rest_api/manager.py":6142
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/price', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_orderbook_ticker(self, **params):
 */
  __pyx_tuple__131 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_ticker_price); if (unlikely(!__pyx_tuple__131)) __PYX_ERR(0, 6142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__131);
  __Pyx_GIVEREF(__pyx_tuple__131);

  /* "unicorn_binance_rest_api/manager.py":6150
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/bookTicker', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_liquidation_orders(self, **params):
 */
  __pyx_tuple__132 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_ticker_bookTicker); if (unlikely(!__pyx_tuple__132)) __PYX_ERR(0, 6150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__132);
  __Pyx_GIVEREF(__pyx_tuple__132);

  /* "unicorn_binance_rest_api/manager.py":6158
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/allForceOrders', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_open_interest(self, **params):
 */
  __pyx_tuple__133 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_ticker_allForceOrders); if (unlikely(!__pyx_tuple__133)) __PYX_ERR(0, 6158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__133);
  __Pyx_GIVEREF(__pyx_tuple__133);

  /* "unicorn_binance_rest_api/manager.py":6166
 * 
 *         """
 *         return self._request_futures_api('get', 'ticker/openInterest', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_open_interest_hist(self, **params):
 */
  __pyx_tuple__134 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_kp_s_ticker_openInterest); if (unlikely(!__pyx_tuple__134)) __PYX_ERR(0, 6166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__134);
  __Pyx_GIVEREF(__pyx_tuple__134);

  /* "unicorn_binance_rest_api/manager.py":6174
 * 
 *         """
 *         return self._request_futures_data_api('get', 'openInterestHist', data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_leverage_bracket(self, **params):
 */
  __pyx_tuple__135 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_openInterestHist); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(0, 6174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);

  /* "unicorn_binance_rest_api/manager.py":6182
 * 
 *         """
 *         return self._request_futures_api('get', 'leverageBracket', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account_transfer(self, **params):
 */
  __pyx_tuple__136 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_leverageBracket, Py_True); if (unlikely(!__pyx_tuple__136)) __PYX_ERR(0, 6182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__136);
  __Pyx_GIVEREF(__pyx_tuple__136);

  /* "unicorn_binance_rest_api/manager.py":6190
 * 
 *         """
 *         return self._request_margin_api('post', 'futures/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_auto_cancel_all_open_orders(self, **params):
 */
  __pyx_tuple__137 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_futures_transfer, Py_True); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(0, 6190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);

  /* "unicorn_binance_rest_api/manager.py":6216
 * 
 *         """
 *         return self._request_futures_api('post', 'countdownCancelAll', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_commission_rate(self, **params):
 */
  __pyx_tuple__138 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_countdownCancelAll, Py_True); if (unlikely(!__pyx_tuple__138)) __PYX_ERR(0, 6216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__138);
  __Pyx_GIVEREF(__pyx_tuple__138);

  /* "unicorn_binance_rest_api/manager.py":6224
 * 
 *         """
 *         return self._request_futures_coin_api("get", "commissionRate", version=1, signed=True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def transfer_history(self, **params):
 */
  __pyx_tuple__139 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_commissionRate); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(0, 6224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);

  /* "unicorn_binance_rest_api/manager.py":6232
 * 
 *         """
 *         return self._request_margin_api('get', 'futures/transfer', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_create_order(self, **params):
 */
  __pyx_tuple__140 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_futures_transfer, Py_True); if (unlikely(!__pyx_tuple__140)) __PYX_ERR(0, 6232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__140);
  __Pyx_GIVEREF(__pyx_tuple__140);

  /* "unicorn_binance_rest_api/manager.py":6240
 * 
 *         """
 *         return self._request_futures_api('post', 'order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_place_batch_order(self, **params):
 */
  __pyx_tuple__141 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_order, Py_True); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(0, 6240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);

  /* "unicorn_binance_rest_api/manager.py":6249
 *         """
 *         query_string = urlencode(params)
 *         query_string = query_string.replace('%27', '%22')             # <<<<<<<<<<<<<<
 *         params['batchOrders'] = query_string[12:]
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 */
  __pyx_tuple__142 = PyTuple_Pack(2, __pyx_kp_s_27, __pyx_kp_s_22); if (unlikely(!__pyx_tuple__142)) __PYX_ERR(0, 6249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__142);
  __Pyx_GIVEREF(__pyx_tuple__142);

  /* "unicorn_binance_rest_api/manager.py":6250
 *         query_string = urlencode(params)
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]             # <<<<<<<<<<<<<<
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 * 
 */
  __pyx_slice__143 = PySlice_New(__pyx_int_12, Py_None, Py_None); if (unlikely(!__pyx_slice__143)) __PYX_ERR(0, 6250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__143);
  __Pyx_GIVEREF(__pyx_slice__143);

  /* "unicorn_binance_rest_api/manager.py":6251
 *         query_string = query_string.replace('%27', '%22')
 *         params['batchOrders'] = query_string[12:]
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_order(self, **params):
 */
  __pyx_tuple__144 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_batchOrders, Py_True); if (unlikely(!__pyx_tuple__144)) __PYX_ERR(0, 6251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__144);
  __Pyx_GIVEREF(__pyx_tuple__144);

  /* "unicorn_binance_rest_api/manager.py":6260
 * 
 *         """
 *         return self._request_futures_api('get', 'order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_open_orders(self, **params):
 */
  __pyx_tuple__145 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_order, Py_True); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(0, 6260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);

  /* "unicorn_binance_rest_api/manager.py":6269
 * 
 *         """
 *         return self._request_futures_api('get', 'openOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_all_orders(self, **params):
 */
  __pyx_tuple__146 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_openOrders, Py_True); if (unlikely(!__pyx_tuple__146)) __PYX_ERR(0, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__146);
  __Pyx_GIVEREF(__pyx_tuple__146);

  /* "unicorn_binance_rest_api/manager.py":6278
 * 
 *         """
 *         return self._request_futures_api('get', 'allOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_cancel_order(self, **params):
 */
  __pyx_tuple__147 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_allOrders, Py_True); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 6278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);

  /* "unicorn_binance_rest_api/manager.py":6287
 * 
 *         """
 *         return self._request_futures_api('delete', 'order', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_cancel_all_open_orders(self, **params):
 */
  __pyx_tuple__148 = PyTuple_Pack(3, __pyx_n_s_delete, __pyx_n_s_order, Py_True); if (unlikely(!__pyx_tuple__148)) __PYX_ERR(0, 6287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__148);
  __Pyx_GIVEREF(__pyx_tuple__148);

  /* "unicorn_binance_rest_api/manager.py":6296
 * 
 *         """
 *         return self._request_futures_api('delete', 'allOpenOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_cancel_orders(self, **params):
 */
  __pyx_tuple__149 = PyTuple_Pack(3, __pyx_n_s_delete, __pyx_n_s_allOpenOrders, Py_True); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(0, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);

  /* "unicorn_binance_rest_api/manager.py":6305
 * 
 *         """
 *         return self._request_futures_api('delete', 'batchOrders', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account_balance(self, **params):
 */
  __pyx_tuple__150 = PyTuple_Pack(3, __pyx_n_s_delete, __pyx_n_s_batchOrders, Py_True); if (unlikely(!__pyx_tuple__150)) __PYX_ERR(0, 6305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__150);
  __Pyx_GIVEREF(__pyx_tuple__150);

  /* "unicorn_binance_rest_api/manager.py":6314
 * 
 *         """
 *         return self._request_futures_api('get', 'balance', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account(self, **params):
 */
  __pyx_tuple__151 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_balance, Py_True); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(0, 6314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);

  /* "unicorn_binance_rest_api/manager.py":6323
 * 
 *         """
 *         return self._request_futures_api('get', 'account', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_leverage(self, **params):
 */
  __pyx_tuple__152 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_account, Py_True); if (unlikely(!__pyx_tuple__152)) __PYX_ERR(0, 6323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__152);
  __Pyx_GIVEREF(__pyx_tuple__152);

  /* "unicorn_binance_rest_api/manager.py":6332
 * 
 *         """
 *         return self._request_futures_api('post', 'leverage', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_margin_type(self, **params):
 */
  __pyx_tuple__153 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_leverage, Py_True); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(0, 6332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);

  /* "unicorn_binance_rest_api/manager.py":6340
 * 
 *         """
 *         return self._request_futures_api('post', 'marginType', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_position_margin(self, **params):
 */
  __pyx_tuple__154 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_marginType, Py_True); if (unlikely(!__pyx_tuple__154)) __PYX_ERR(0, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__154);
  __Pyx_GIVEREF(__pyx_tuple__154);

  /* "unicorn_binance_rest_api/manager.py":6349
 * 
 *         """
 *         return self._request_futures_api('post', 'positionMargin', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_position_margin_history(self, **params):
 */
  __pyx_tuple__155 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_positionMargin, Py_True); if (unlikely(!__pyx_tuple__155)) __PYX_ERR(0, 6349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__155);
  __Pyx_GIVEREF(__pyx_tuple__155);

  /* "unicorn_binance_rest_api/manager.py":6358
 * 
 *         """
 *         return self._request_futures_api('get', 'positionMargin/history', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_position_information(self, **params):
 */
  __pyx_tuple__156 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_positionMargin_history, Py_True); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(0, 6358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);

  /* "unicorn_binance_rest_api/manager.py":6367
 * 
 *         """
 *         return self._request_futures_api('get', 'positionRisk', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_account_trades(self, **params):
 */
  __pyx_tuple__157 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_positionRisk, Py_True); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(0, 6367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);

  /* "unicorn_binance_rest_api/manager.py":6376
 * 
 *         """
 *         return self._request_futures_api('get', 'userTrades', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_income_history(self, **params):
 */
  __pyx_tuple__158 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_userTrades, Py_True); if (unlikely(!__pyx_tuple__158)) __PYX_ERR(0, 6376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__158);
  __Pyx_GIVEREF(__pyx_tuple__158);

  /* "unicorn_binance_rest_api/manager.py":6385
 * 
 *         """
 *         return self._request_futures_api('get', 'income', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_change_position_mode(self, **params):
 */
  __pyx_tuple__159 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_income, Py_True); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 6385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);

  /* "unicorn_binance_rest_api/manager.py":6394
 * 
 *         """
 *         return self._request_futures_api('post', 'positionSide/dual', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_get_position_mode(self, **params):
 */
  __pyx_tuple__160 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_kp_s_positionSide_dual, Py_True); if (unlikely(!__pyx_tuple__160)) __PYX_ERR(0, 6394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__160);
  __Pyx_GIVEREF(__pyx_tuple__160);

  /* "unicorn_binance_rest_api/manager.py":6403
 * 
 *         """
 *         return self._request_futures_api('get', 'positionSide/dual', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_stream_get_listen_key(self, output="value", throw_exception=True):
 */
  __pyx_tuple__161 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_positionSide_dual, Py_True); if (unlikely(!__pyx_tuple__161)) __PYX_ERR(0, 6403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__161);
  __Pyx_GIVEREF(__pyx_tuple__161);

  /* "unicorn_binance_rest_api/manager.py":6430
 * 
 *         """
 *         res = self._request_futures_api('post', 'listenKey', signed=False, data={}, throw_exception=throw_exception)             # <<<<<<<<<<<<<<
 *         if output == "value":
 *             return res['listenKey']
 */
  __pyx_tuple__162 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_n_s_listenKey); if (unlikely(!__pyx_tuple__162)) __PYX_ERR(0, 6430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__162);
  __Pyx_GIVEREF(__pyx_tuple__162);

  /* "unicorn_binance_rest_api/manager.py":6460
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_api('put', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                          throw_exception=throw_exception)
 * 
 */
  __pyx_tuple__163 = PyTuple_Pack(2, __pyx_n_s_put, __pyx_n_s_listenKey); if (unlikely(!__pyx_tuple__163)) __PYX_ERR(0, 6460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__163);
  __Pyx_GIVEREF(__pyx_tuple__163);

  /* "unicorn_binance_rest_api/manager.py":6485
 *             'listenKey': listenKey
 *         }
 *         return self._request_futures_api('delete', 'listenKey', signed=False, data=params,             # <<<<<<<<<<<<<<
 *                                          throw_exception=throw_exception)
 * 
 */
  __pyx_tuple__164 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_n_s_listenKey); if (unlikely(!__pyx_tuple__164)) __PYX_ERR(0, 6485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__164);
  __Pyx_GIVEREF(__pyx_tuple__164);

  /* "unicorn_binance_rest_api/manager.py":6568
 * 
 *         """
 *         return self._request_futures_coin_api("get", "continuousKlines", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_index_price_klines(self, **params):
 */
  __pyx_tuple__165 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_continuousKlines); if (unlikely(!__pyx_tuple__165)) __PYX_ERR(0, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__165);
  __Pyx_GIVEREF(__pyx_tuple__165);

  /* "unicorn_binance_rest_api/manager.py":6576
 * 
 *         """
 *         return self._request_futures_coin_api("get", "indexPriceKlines", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_mark_price_klines(self, **params):
 */
  __pyx_tuple__166 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_indexPriceKlines); if (unlikely(!__pyx_tuple__166)) __PYX_ERR(0, 6576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__166);
  __Pyx_GIVEREF(__pyx_tuple__166);

  /* "unicorn_binance_rest_api/manager.py":6584
 * 
 *         """
 *         return self._request_futures_coin_api("get", "markPriceKlines", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_mark_price(self, **params):
 */
  __pyx_tuple__167 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_markPriceKlines); if (unlikely(!__pyx_tuple__167)) __PYX_ERR(0, 6584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__167);
  __Pyx_GIVEREF(__pyx_tuple__167);

  /* "unicorn_binance_rest_api/manager.py":6637
 * 
 *         """
 *         return self._request_futures_coin_api("get", "allForceOrders", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_open_interest(self, **params):
 */
  __pyx_tuple__168 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_allForceOrders); if (unlikely(!__pyx_tuple__168)) __PYX_ERR(0, 6637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__168);
  __Pyx_GIVEREF(__pyx_tuple__168);

  /* "unicorn_binance_rest_api/manager.py":6646
 * 
 *         """
 *         return self._request_futures_coin_api("get", "openInterest", data=params)             # <<<<<<<<<<<<<<
 * 
 *     def futures_coin_open_interest_hist(self, **params):
 */
  __pyx_tuple__169 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_openInterest); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(0, 6646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);

  /* "unicorn_binance_rest_api/manager.py":6664
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "leverageBracket", version=2, signed=True, data=params
 *         )
 */
  __pyx_tuple__170 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_leverageBracket); if (unlikely(!__pyx_tuple__170)) __PYX_ERR(0, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__170);
  __Pyx_GIVEREF(__pyx_tuple__170);

  /* "unicorn_binance_rest_api/manager.py":6675
 * 
 *         """
 *         return self._request_margin_api("get", "asset/transfer", True, data=params)             # <<<<<<<<<<<<<<
 *         # return self._request_margin_api("get", "futures/transfer", True, data=params)
 * 
 */
  __pyx_tuple__171 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_asset_transfer, Py_True); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 6675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);

  /* "unicorn_binance_rest_api/manager.py":6684
 *         https://binance-docs.github.io/apidocs/spot/en/#user-universal-transfer
 *         """
 *         return self._request_margin_api(             # <<<<<<<<<<<<<<
 *             "post", "asset/transfer", signed=True, data=params
 *         )
 */
  __pyx_tuple__172 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_kp_s_asset_transfer); if (unlikely(!__pyx_tuple__172)) __PYX_ERR(0, 6684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__172);
  __Pyx_GIVEREF(__pyx_tuple__172);

  /* "unicorn_binance_rest_api/manager.py":6733
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "allOrders", signed=True, data=params
 *         )
 */
  __pyx_tuple__173 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_allOrders); if (unlikely(!__pyx_tuple__173)) __PYX_ERR(0, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__173);
  __Pyx_GIVEREF(__pyx_tuple__173);

  /* "unicorn_binance_rest_api/manager.py":6744
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "order", signed=True, data=params
 *         )
 */
  __pyx_tuple__174 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_n_s_order); if (unlikely(!__pyx_tuple__174)) __PYX_ERR(0, 6744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__174);
  __Pyx_GIVEREF(__pyx_tuple__174);

  /* "unicorn_binance_rest_api/manager.py":6755
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "delete", "allOpenOrders", signed=True, data=params
 *         )
 */
  __pyx_tuple__175 = PyTuple_Pack(2, __pyx_n_s_delete, __pyx_n_s_allOpenOrders); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(0, 6755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);

  /* "unicorn_binance_rest_api/manager.py":6777
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "balance", signed=True, data=params
 *         )
 */
  __pyx_tuple__176 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_balance); if (unlikely(!__pyx_tuple__176)) __PYX_ERR(0, 6777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__176);
  __Pyx_GIVEREF(__pyx_tuple__176);

  /* "unicorn_binance_rest_api/manager.py":6788
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "get", "account", signed=True, data=params
 *         )
 */
  __pyx_tuple__177 = PyTuple_Pack(2, __pyx_n_s_get, __pyx_n_s_account); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 6788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);

  /* "unicorn_binance_rest_api/manager.py":6799
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "leverage", signed=True, data=params
 *         )
 */
  __pyx_tuple__178 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_n_s_leverage); if (unlikely(!__pyx_tuple__178)) __PYX_ERR(0, 6799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__178);
  __Pyx_GIVEREF(__pyx_tuple__178);

  /* "unicorn_binance_rest_api/manager.py":6810
 * 
 *         """
 *         return self._request_futures_coin_api(             # <<<<<<<<<<<<<<
 *             "post", "marginType", signed=True, data=params
 *         )
 */
  __pyx_tuple__179 = PyTuple_Pack(2, __pyx_n_s_post, __pyx_n_s_marginType); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(0, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);

  /* "unicorn_binance_rest_api/manager.py":7036
 * 
 *         """
 *         return self._request_margin_api('get', 'capital/config/getall', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def get_account_snapshot(self, **params):
 */
  __pyx_tuple__180 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_kp_s_capital_config_getall, Py_True); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(0, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);

  /* "unicorn_binance_rest_api/manager.py":7152
 * 
 *         """
 *         return self._request_margin_api('get', 'accountSnapshot', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def disable_fast_withdraw_switch(self, **params):
 */
  __pyx_tuple__181 = PyTuple_Pack(3, __pyx_n_s_get, __pyx_n_s_accountSnapshot, Py_True); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 7152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);

  /* "unicorn_binance_rest_api/manager.py":7168
 * 
 *         """
 *         return self._request_margin_api('post', 'disableFastWithdrawSwitch', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def enable_fast_withdraw_switch(self, **params):
 */
  __pyx_tuple__182 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_disableFastWithdrawSwitch, Py_True); if (unlikely(!__pyx_tuple__182)) __PYX_ERR(0, 7168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__182);
  __Pyx_GIVEREF(__pyx_tuple__182);

  /* "unicorn_binance_rest_api/manager.py":7184
 * 
 *         """
 *         return self._request_margin_api('post', 'enableFastWithdrawSwitch', True, data=params)             # <<<<<<<<<<<<<<
 * 
 *     def stop_manager(self, close_api_session=True):
 */
  __pyx_tuple__183 = PyTuple_Pack(3, __pyx_n_s_post, __pyx_n_s_enableFastWithdrawSwitch, Py_True); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 7184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);

  /* "unicorn_binance_rest_api/manager.py":56
 * import time
 * 
 * logger = logging.getLogger("unicorn_binance_rest_api")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__187 = PyTuple_Pack(1, __pyx_n_s_unicorn_binance_rest_api_2); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);

  /* "unicorn_binance_rest_api/manager.py":59
 * 
 * 
 * class BinanceRestApiManager(object):             # <<<<<<<<<<<<<<
 *     """
 *     An unofficial Python API to use the Binance REST API`s (com+testnet, com-margin+testnet,
 */
  __pyx_tuple__188 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__188)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__188);
  __Pyx_GIVEREF(__pyx_tuple__188);
  __pyx_tuple__189 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__189)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__189);
  __Pyx_GIVEREF(__pyx_tuple__189);

  /* "unicorn_binance_rest_api/manager.py":204
 *     MINING_TO_FIAT = "MINING_C2C"
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  api_key=None,
 *                  api_secret=None,
 */
  __pyx_tuple__190 = PyTuple_Pack(21, __pyx_n_s_self, __pyx_n_s_api_key, __pyx_n_s_api_secret, __pyx_n_s_requests_params, __pyx_n_s_tld, __pyx_n_s_warn_on_update, __pyx_n_s_exchange, __pyx_n_s_disable_colorama, __pyx_n_s_debug, __pyx_n_s_socks5_proxy_server, __pyx_n_s_socks5_proxy_user, __pyx_n_s_socks5_proxy_pass, __pyx_n_s_socks5_proxy_ssl_verification, __pyx_n_s_lucit_api_secret, __pyx_n_s_lucit_license_ini, __pyx_n_s_lucit_license_profile, __pyx_n_s_lucit_license_token, __pyx_n_s_socks_proxy_uri, __pyx_n_s_error_msg, __pyx_n_s_res, __pyx_n_s_update_msg); if (unlikely(!__pyx_tuple__190)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__190);
  __Pyx_GIVEREF(__pyx_tuple__190);
  __pyx_codeobj__191 = (PyObject*)__Pyx_PyCode_New(17, 0, 0, 21, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__190, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_init_2, 204, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__191)) __PYX_ERR(0, 204, __pyx_L1_error)
  __pyx_tuple__192 = PyTuple_Pack(16, Py_None, Py_None, Py_None, ((PyObject *)Py_False), ((PyObject *)Py_True), ((PyObject *)Py_False), ((PyObject *)Py_False), ((PyObject *)Py_False), Py_None, Py_None, Py_None, ((PyObject *)Py_True), Py_None, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);

  /* "unicorn_binance_rest_api/manager.py":421
 *             logger.warning(update_msg)
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Entering 'with-context' ...")
 *         return self
 */
  __pyx_tuple__193 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__193)) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__193);
  __Pyx_GIVEREF(__pyx_tuple__193);
  __pyx_codeobj__194 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_enter, 421, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__194)) __PYX_ERR(0, 421, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":425
 *         return self
 * 
 *     def __exit__(self, exc_type, exc_value, error_traceback):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Leaving 'with-context' ...")
 *         self.stop_manager()
 */
  __pyx_tuple__195 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_exc_type, __pyx_n_s_exc_value, __pyx_n_s_error_traceback); if (unlikely(!__pyx_tuple__195)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__195);
  __Pyx_GIVEREF(__pyx_tuple__195);
  __pyx_codeobj__196 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__195, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_exit, 425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__196)) __PYX_ERR(0, 425, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":431
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")
 * 
 *     def _init_session(self):             # <<<<<<<<<<<<<<
 *         session = requests.session()
 *         session.headers.update({'Accept': 'application/json',
 */
  __pyx_tuple__197 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_session); if (unlikely(!__pyx_tuple__197)) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__197);
  __Pyx_GIVEREF(__pyx_tuple__197);
  __pyx_codeobj__198 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_init_session, 431, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__198)) __PYX_ERR(0, 431, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":438
 *         return session
 * 
 *     def _create_api_uri(self, path, signed=True, version=PUBLIC_API_VERSION):             # <<<<<<<<<<<<<<
 *         v = self.PRIVATE_API_VERSION if signed else version
 *         return self.API_URL + '/' + v + '/' + path
 */
  __pyx_tuple__199 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_path, __pyx_n_s_signed, __pyx_n_s_version, __pyx_n_s_v); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);
  __pyx_codeobj__200 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__199, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_api_uri, 438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__200)) __PYX_ERR(0, 438, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":442
 *         return self.API_URL + '/' + v + '/' + path
 * 
 *     def _create_margin_api_uri(self, path, version=MARGIN_API_VERSION):             # <<<<<<<<<<<<<<
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 */
  __pyx_tuple__201 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_path, __pyx_n_s_version); if (unlikely(!__pyx_tuple__201)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__201);
  __Pyx_GIVEREF(__pyx_tuple__201);
  __pyx_codeobj__202 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__201, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_margin_api_uri, 442, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__202)) __PYX_ERR(0, 442, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":445
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 *     def _create_website_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.WEBSITE_URL + '/' + path
 * 
 */
  __pyx_tuple__203 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_path); if (unlikely(!__pyx_tuple__203)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__203);
  __Pyx_GIVEREF(__pyx_tuple__203);
  __pyx_codeobj__204 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__203, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_website_uri, 445, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__204)) __PYX_ERR(0, 445, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":448
 *         return self.WEBSITE_URL + '/' + path
 * 
 *     def _create_futures_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 */
  __pyx_codeobj__205 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__203, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_futures_api_uri, 448, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__205)) __PYX_ERR(0, 448, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":451
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 *     def _create_futures_data_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 */
  __pyx_codeobj__206 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__203, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_futures_data_api_uri, 451, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__206)) __PYX_ERR(0, 451, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":454
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 *     def _create_futures_coin_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         options = {1: self.FUTURES_API_VERSION, 2: self.FUTURES_API_VERSION2}
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 */
  __pyx_tuple__207 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_path, __pyx_n_s_version, __pyx_n_s_options); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);
  __pyx_codeobj__208 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__207, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_futures_coin_api_url, 454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__208)) __PYX_ERR(0, 454, __pyx_L1_error)
  __pyx_tuple__209 = PyTuple_Pack(1, ((PyObject *)__pyx_int_1)); if (unlikely(!__pyx_tuple__209)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__209);
  __Pyx_GIVEREF(__pyx_tuple__209);

  /* "unicorn_binance_rest_api/manager.py":458
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 * 
 *     def _create_futures_coin_data_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         # Todo: version is obsolete?
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 */
  __pyx_codeobj__210 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__201, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_futures_coin_data_api_ur, 458, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__210)) __PYX_ERR(0, 458, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":462
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 * 
 *     def _generate_signature(self, data):             # <<<<<<<<<<<<<<
 * 
 *         ordered_data = self._order_params(data)
 */
  __pyx_tuple__211 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_data, __pyx_n_s_ordered_data, __pyx_n_s_query_string, __pyx_n_s_m, __pyx_n_s_d); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);
  __pyx_codeobj__212 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__211, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_generate_signature, 462, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__212)) __PYX_ERR(0, 462, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":469
 *         return m.hexdigest()
 * 
 *     def _order_params(self, data):             # <<<<<<<<<<<<<<
 *         """
 *         Convert params to list with signature as last element
 */
  __pyx_tuple__213 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_data, __pyx_n_s_has_signature, __pyx_n_s_params, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__213)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__213);
  __Pyx_GIVEREF(__pyx_tuple__213);
  __pyx_codeobj__214 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__213, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_params, 469, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__214)) __PYX_ERR(0, 469, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":490
 *         return params
 * 
 *     def _request(self, method, uri, signed, force_params=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 * 
 *         # set default requests timeout
 */
  __pyx_tuple__215 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_method, __pyx_n_s_uri, __pyx_n_s_signed, __pyx_n_s_force_params, __pyx_n_s_throw_exception, __pyx_n_s_kwargs, __pyx_n_s_data, __pyx_n_s_null_args, __pyx_n_s_i, __pyx_n_s_i, __pyx_n_s_key, __pyx_n_s_value, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);
  __pyx_codeobj__216 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 15, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__215, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request, 490, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__216)) __PYX_ERR(0, 490, __pyx_L1_error)
  __pyx_tuple__217 = PyTuple_Pack(2, ((PyObject *)Py_False), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);

  /* "unicorn_binance_rest_api/manager.py":538
 *         return self._handle_response(throw_exception=throw_exception)
 * 
 *     def _request_api(self, method, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_api_uri(path, signed, version)
 * 
 */
  __pyx_tuple__218 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_method, __pyx_n_s_path, __pyx_n_s_signed, __pyx_n_s_version, __pyx_n_s_throw_exception, __pyx_n_s_kwargs, __pyx_n_s_uri); if (unlikely(!__pyx_tuple__218)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__218);
  __Pyx_GIVEREF(__pyx_tuple__218);
  __pyx_codeobj__219 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__218, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request_api, 538, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__219)) __PYX_ERR(0, 538, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":543
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_margin_api(self, method, path, signed=False,             # <<<<<<<<<<<<<<
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):
 *         uri = self._create_margin_api_uri(path, version)
 */
  __pyx_codeobj__220 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__218, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request_margin_api, 543, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__220)) __PYX_ERR(0, 543, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":549
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_website(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_website_uri(path)
 * 
 */
  __pyx_tuple__221 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_method, __pyx_n_s_path, __pyx_n_s_signed, __pyx_n_s_throw_exception, __pyx_n_s_kwargs, __pyx_n_s_uri); if (unlikely(!__pyx_tuple__221)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__221);
  __Pyx_GIVEREF(__pyx_tuple__221);
  __pyx_codeobj__222 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__221, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request_website, 549, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__222)) __PYX_ERR(0, 549, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":554
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_api_uri(path)
 * 
 */
  __pyx_codeobj__223 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__221, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request_futures_api, 554, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__223)) __PYX_ERR(0, 554, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":559
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_data_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_data_api_uri(path)
 * 
 */
  __pyx_codeobj__224 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__221, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request_futures_data_api, 559, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__224)) __PYX_ERR(0, 559, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":564
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_api_url(path, version=version)
 * 
 */
  __pyx_codeobj__225 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__218, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request_futures_coin_api, 564, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__225)) __PYX_ERR(0, 564, __pyx_L1_error)
  __pyx_tuple__226 = PyTuple_Pack(3, ((PyObject *)Py_False), ((PyObject *)__pyx_int_1), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__226)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__226);
  __Pyx_GIVEREF(__pyx_tuple__226);

  /* "unicorn_binance_rest_api/manager.py":569
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_data_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_data_api_url(path, version=version)
 * 
 */
  __pyx_codeobj__227 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__218, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_request_futures_coin_data_api, 569, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__227)) __PYX_ERR(0, 569, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":574
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _handle_response(self, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """
 *         Internal helper for handling API responses from the Binance server.
 */
  __pyx_tuple__228 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_throw_exception); if (unlikely(!__pyx_tuple__228)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__228);
  __Pyx_GIVEREF(__pyx_tuple__228);
  __pyx_codeobj__229 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__228, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_handle_response, 574, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__229)) __PYX_ERR(0, 574, __pyx_L1_error)
  __pyx_tuple__230 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__230)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__230);
  __Pyx_GIVEREF(__pyx_tuple__230);

  /* "unicorn_binance_rest_api/manager.py":589
 *             raise BinanceRequestException('Invalid Response: %s' % self.response.text)
 * 
 *     def _get(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 */
  __pyx_tuple__231 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_path, __pyx_n_s_signed, __pyx_n_s_version, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__231)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__231);
  __Pyx_GIVEREF(__pyx_tuple__231);
  __pyx_codeobj__232 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__231, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_2, 589, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__232)) __PYX_ERR(0, 589, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":592
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 *     def _post(self, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 */
  __pyx_tuple__233 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_path, __pyx_n_s_signed, __pyx_n_s_version, __pyx_n_s_throw_exception, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__233)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__233);
  __Pyx_GIVEREF(__pyx_tuple__233);
  __pyx_codeobj__234 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__233, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_post_2, 592, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__234)) __PYX_ERR(0, 592, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":595
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 *     def _put(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 */
  __pyx_codeobj__235 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__231, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_put_2, 595, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__235)) __PYX_ERR(0, 595, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":598
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 *     def _delete(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 */
  __pyx_codeobj__236 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__231, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_delete_2, 598, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__236)) __PYX_ERR(0, 598, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":601
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 *     def is_update_availabe(self):             # <<<<<<<<<<<<<<
 *         """
 *         Is a new release of this package available?
 */
  __pyx_tuple__237 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_installed_version); if (unlikely(!__pyx_tuple__237)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__237);
  __Pyx_GIVEREF(__pyx_tuple__237);
  __pyx_codeobj__238 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__237, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_is_update_availabe, 601, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__238)) __PYX_ERR(0, 601, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":617
 *             return True
 * 
 *     def get_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the package/module version
 */
  __pyx_codeobj__239 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_version, 617, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__239)) __PYX_ERR(0, 617, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":625
 *         return self.version
 * 
 *     def get_latest_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the version of the latest available release (cache time 1 hour)
 */
  __pyx_codeobj__240 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_latest_version, 625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__240)) __PYX_ERR(0, 625, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":642
 *             return "unknown"
 * 
 *     def get_latest_release_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get infos about the latest available release
 */
  __pyx_tuple__241 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_respond, __pyx_n_s_latest_release_info); if (unlikely(!__pyx_tuple__241)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__241);
  __Pyx_GIVEREF(__pyx_tuple__241);
  __pyx_codeobj__242 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__241, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_latest_release_info, 642, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__242)) __PYX_ERR(0, 642, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":661
 *             return False
 * 
 *     def get_user_agent(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the user_agent string "lib name + lib version + python version"
 */
  __pyx_tuple__243 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_user_agent); if (unlikely(!__pyx_tuple__243)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__243);
  __Pyx_GIVEREF(__pyx_tuple__243);
  __pyx_codeobj__244 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__243, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_user_agent, 661, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__244)) __PYX_ERR(0, 661, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":671
 * 
 *     # Exchange Endpoints
 *     def get_products(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return list of products currently listed on Binance
 */
  __pyx_tuple__245 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_products); if (unlikely(!__pyx_tuple__245)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__245);
  __Pyx_GIVEREF(__pyx_tuple__245);
  __pyx_codeobj__246 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__245, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_products, 671, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__246)) __PYX_ERR(0, 671, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":685
 *         return products
 * 
 *     def get_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return rate limits and list of symbols
 */
  __pyx_codeobj__247 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_exchange_info, 685, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__247)) __PYX_ERR(0, 685, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":750
 *         return self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_info(self, symbol):             # <<<<<<<<<<<<<<
 *         """
 *         Return information about a symbol
 */
  __pyx_tuple__248 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_symbol, __pyx_n_s_res, __pyx_n_s_item); if (unlikely(!__pyx_tuple__248)) __PYX_ERR(0, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__248);
  __Pyx_GIVEREF(__pyx_tuple__248);
  __pyx_codeobj__249 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__248, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_symbol_info, 750, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__249)) __PYX_ERR(0, 750, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":802
 *     # General Endpoints
 * 
 *     def ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API.
 */
  __pyx_codeobj__250 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_ping, 802, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__250)) __PYX_ERR(0, 802, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":819
 *         return self._get('ping', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_server_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */
  __pyx_codeobj__251 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_server_time, 819, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__251)) __PYX_ERR(0, 819, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":840
 *     # Market Data Endpoints
 * 
 *     def get_all_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for all symbols.
 */
  __pyx_codeobj__252 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_all_tickers, 840, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__252)) __PYX_ERR(0, 840, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":866
 *         return self._get('ticker/price', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for all symbols.
 */
  __pyx_codeobj__253 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_orderbook_tickers, 866, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__253)) __PYX_ERR(0, 866, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":898
 *         return self._get('ticker/bookTicker', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */
  __pyx_tuple__254 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_params); if (unlikely(!__pyx_tuple__254)) __PYX_ERR(0, 898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__254);
  __Pyx_GIVEREF(__pyx_tuple__254);
  __pyx_codeobj__255 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_order_book, 898, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__255)) __PYX_ERR(0, 898, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":936
 *         return self._get('depth', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get recent trades (up to last 500).
 */
  __pyx_codeobj__256 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_recent_trades, 936, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__256)) __PYX_ERR(0, 936, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":967
 *         return self._get('trades', data=params)
 * 
 *     def get_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older trades.
 */
  __pyx_codeobj__257 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_historical_trades, 967, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__257)) __PYX_ERR(0, 967, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1000
 *         return self._get('historicalTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time,
 */
  __pyx_codeobj__258 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_aggregate_trades, 1000, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__258)) __PYX_ERR(0, 1000, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1039
 *         return self._get('aggTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def aggregate_trade_iter(self, symbol, start_str=None, last_id=None):             # <<<<<<<<<<<<<<
 *         """
 *         Iterate over aggregate trade data from (start_time or last_id) to
 */
  __pyx_tuple__259 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_symbol, __pyx_n_s_start_str, __pyx_n_s_last_id, __pyx_n_s_trades, __pyx_n_s_start_ts, __pyx_n_s_end_ts, __pyx_n_s_t); if (unlikely(!__pyx_tuple__259)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__259);
  __Pyx_GIVEREF(__pyx_tuple__259);
  __pyx_codeobj__22 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__259, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_aggregate_trade_iter, 1039, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__22)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __pyx_tuple__260 = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_tuple__260)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__260);
  __Pyx_GIVEREF(__pyx_tuple__260);

  /* "unicorn_binance_rest_api/manager.py":1128
 *             last_id = trades[-1][self.AGG_ID]
 * 
 *     def get_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */
  __pyx_codeobj__261 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_klines, 1128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__261)) __PYX_ERR(0, 1128, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1171
 *         return self._get('klines', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def _get_earliest_valid_timestamp(self, symbol, interval):             # <<<<<<<<<<<<<<
 *         """
 *         Get the earliest valid open timestamp from Binance
 */
  __pyx_tuple__262 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_symbol, __pyx_n_s_interval, __pyx_n_s_kline); if (unlikely(!__pyx_tuple__262)) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__262);
  __Pyx_GIVEREF(__pyx_tuple__262);
  __pyx_codeobj__263 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__262, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_earliest_valid_timestamp, 1171, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__263)) __PYX_ERR(0, 1171, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1192
 *         return kline[0][0]
 * 
 *     def get_historical_klines(self, symbol, interval, start_str, end_str=None,             # <<<<<<<<<<<<<<
 *                               limit=500):
 *         """
 */
  __pyx_tuple__264 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_symbol, __pyx_n_s_interval, __pyx_n_s_start_str, __pyx_n_s_end_str, __pyx_n_s_limit, __pyx_n_s_output_data, __pyx_n_s_timeframe, __pyx_n_s_start_ts, __pyx_n_s_first_valid_ts, __pyx_n_s_end_ts, __pyx_n_s_idx, __pyx_n_s_temp_data); if (unlikely(!__pyx_tuple__264)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__264);
  __Pyx_GIVEREF(__pyx_tuple__264);
  __pyx_codeobj__265 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__264, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_historical_klines, 1192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__265)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __pyx_tuple__266 = PyTuple_Pack(2, Py_None, ((PyObject *)__pyx_int_500)); if (unlikely(!__pyx_tuple__266)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__266);
  __Pyx_GIVEREF(__pyx_tuple__266);

  /* "unicorn_binance_rest_api/manager.py":1276
 *         return output_data
 * 
 *     def get_historical_klines_generator(self, symbol, interval, start_str, end_str=None):             # <<<<<<<<<<<<<<
 *         """
 *         Get Historical Klines from Binance
 */
  __pyx_tuple__267 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_symbol, __pyx_n_s_interval, __pyx_n_s_start_str, __pyx_n_s_end_str, __pyx_n_s_limit, __pyx_n_s_timeframe, __pyx_n_s_start_ts, __pyx_n_s_first_valid_ts, __pyx_n_s_end_ts, __pyx_n_s_idx, __pyx_n_s_output_data, __pyx_n_s_o); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);
  __pyx_codeobj__26 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__267, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_historical_klines_generator, 1276, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__26)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __pyx_tuple__268 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__268)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__268);
  __Pyx_GIVEREF(__pyx_tuple__268);

  /* "unicorn_binance_rest_api/manager.py":1357
 *                 time.sleep(1)
 * 
 *     def get_avg_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Current average price for a symbol.
 * 
 */
  __pyx_codeobj__269 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_avg_price, 1357, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__269)) __PYX_ERR(0, 1357, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1376
 *         return self._get('avgPrice', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour price change statistics.
 * 
 */
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_ticker, 1376, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(0, 1376, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1437
 *         return self._get('ticker/24hr', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */
  __pyx_codeobj__271 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_symbol_ticker, 1437, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__271)) __PYX_ERR(0, 1437, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1474
 *         return self._get('ticker/price', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_orderbook_ticker, 1474, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(0, 1474, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1522
 *     # Account Endpoints
 * 
 *     def create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order
 * 
 */
  __pyx_codeobj__273 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_order, 1522, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__273)) __PYX_ERR(0, 1522, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1640
 *         return self._post('order', True, data=params)
 * 
 *     def order_limit(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit order
 * 
 */
  __pyx_tuple__274 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_timeInForce, __pyx_n_s_params); if (unlikely(!__pyx_tuple__274)) __PYX_ERR(0, 1640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__274);
  __Pyx_GIVEREF(__pyx_tuple__274);
  __pyx_codeobj__275 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__274, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_limit, 1640, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__275)) __PYX_ERR(0, 1640, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1679
 *         return self.create_order(**params)
 * 
 *     def order_limit_buy(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit buy order
 * 
 */
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__274, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_limit_buy, 1679, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(0, 1679, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1717
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_limit_sell(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit sell order
 * 
 */
  __pyx_codeobj__277 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__274, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_limit_sell, 1717, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__277)) __PYX_ERR(0, 1717, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1753
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_market(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market order
 * 
 */
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_market, 1753, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(0, 1753, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1786
 *         return self.create_order(**params)
 * 
 *     def order_market_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market buy order
 * 
 */
  __pyx_codeobj__279 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_market_buy, 1786, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__279)) __PYX_ERR(0, 1786, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1816
 *         return self.order_market(**params)
 * 
 *     def order_market_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market sell order
 * 
 */
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_market_sell, 1816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(0, 1816, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1846
 *         return self.order_market(**params)
 * 
 *     def create_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO order
 * 
 */
  __pyx_codeobj__281 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_oco_order, 1846, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__281)) __PYX_ERR(0, 1846, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1910
 *         return self._post('order/oco', True, data=params)
 * 
 *     def order_oco_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO buy order
 * 
 */
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_oco_buy, 1910, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(0, 1910, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1954
 *         return self.create_oco_order(**params)
 * 
 *     def order_oco_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO sell order
 * 
 */
  __pyx_codeobj__283 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_order_oco_sell, 1954, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__283)) __PYX_ERR(0, 1954, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":1997
 *         return self.create_oco_order(**params)
 * 
 *     def create_test_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Test new order creation and signature/recvWindow long. Creates and validates a new order but does not send
 *         it into the matching engine.
 */
  __pyx_codeobj__284 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_test_order, 1997, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__284)) __PYX_ERR(0, 1997, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2038
 *         return self._post('order/test', True, data=params)
 * 
 *     def get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Check an order's status. Either orderId or origClientOrderId must be sent.
 * 
 */
  __pyx_codeobj__285 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_order, 2038, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__285)) __PYX_ERR(0, 2038, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2077
 *         return self._get('order', True, data=params)
 * 
 *     def get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all account orders; active, canceled, or filled.
 * 
 */
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_all_orders, 2077, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(0, 2077, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2118
 *         return self._get('allOrders', True, data=params)
 * 
 *     def cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open orders of a symbol.
 * 
 */
  __pyx_codeobj__287 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_cancel_all_open_orders, 2118, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__287)) __PYX_ERR(0, 2118, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2231
 *         return self._delete('openOrders', True, data=params)
 * 
 *     def cancel_all_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open margin orders of a symbol.
 * 
 */
  __pyx_codeobj__288 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_cancel_all_open_margin_orders, 2231, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__288)) __PYX_ERR(0, 2231, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2340
 *         return self._request_margin_api('delete', 'margin/openOrders', signed=True, data=params)
 * 
 *     def cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an active order. Either orderId or origClientOrderId must be sent.
 * 
 */
  __pyx_codeobj__289 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_cancel_order, 2340, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__289)) __PYX_ERR(0, 2340, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2372
 *         return self._delete('order', True, data=params)
 * 
 *     def get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all open orders on a symbol.
 * 
 */
  __pyx_codeobj__290 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_open_orders, 2372, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__290)) __PYX_ERR(0, 2372, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2410
 * 
 *     # User Stream Endpoints
 *     def get_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get current account information.
 * 
 */
  __pyx_codeobj__291 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_account, 2410, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__291)) __PYX_ERR(0, 2410, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2449
 *         return self._get('account', True, data=params)
 * 
 *     def get_asset_balance(self, asset, **params):             # <<<<<<<<<<<<<<
 *         """Get current asset balance.
 * 
 */
  __pyx_tuple__292 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_asset, __pyx_n_s_params, __pyx_n_s_res, __pyx_n_s_bal); if (unlikely(!__pyx_tuple__292)) __PYX_ERR(0, 2449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__292);
  __Pyx_GIVEREF(__pyx_tuple__292);
  __pyx_codeobj__293 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__292, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_asset_balance, 2449, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__293)) __PYX_ERR(0, 2449, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2480
 *         return None
 * 
 *     def get_my_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for a specific symbol.
 * 
 */
  __pyx_codeobj__294 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_my_trades, 2480, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__294)) __PYX_ERR(0, 2480, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2517
 *         return self._get('myTrades', True, data=params)
 * 
 *     def get_system_status(self):             # <<<<<<<<<<<<<<
 *         """Get system status detail.
 * 
 */
  __pyx_codeobj__295 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_system_status, 2517, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__295)) __PYX_ERR(0, 2517, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2536
 *         return self._request_margin_api('get', 'system/status')
 * 
 *     def get_account_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get account status detail.
 * 
 */
  __pyx_tuple__296 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_params, __pyx_n_s_res); if (unlikely(!__pyx_tuple__296)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__296);
  __Pyx_GIVEREF(__pyx_tuple__296);
  __pyx_codeobj__297 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_account_status, 2536, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__297)) __PYX_ERR(0, 2536, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2560
 *         return res
 * 
 *     def get_account_api_trading_status(self, **params):             # <<<<<<<<<<<<<<
 *         r"""Fetch account api trading status detail.
 * 
 */
  __pyx_codeobj__298 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_account_api_trading_status, 2560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__298)) __PYX_ERR(0, 2560, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2635
 *         return res
 * 
 *     def get_dust_log(self, **params):             # <<<<<<<<<<<<<<
 *         """Get log of small amounts exchanged for BNB.
 * 
 */
  __pyx_codeobj__299 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_dust_log, 2635, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__299)) __PYX_ERR(0, 2635, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2712
 *         return res
 * 
 *     def transfer_dust(self, **params):             # <<<<<<<<<<<<<<
 *         """Convert dust assets to BNB.
 * 
 */
  __pyx_codeobj__300 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_transfer_dust, 2712, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__300)) __PYX_ERR(0, 2712, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2751
 *         return self._request_margin_api('post', 'asset/dust', True, data=params)
 * 
 *     def get_asset_dividend_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query asset dividend record.
 * 
 */
  __pyx_codeobj__301 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_asset_dividend_history, 2751, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__301)) __PYX_ERR(0, 2751, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2799
 *         return self._request_margin_api('get', 'asset/assetDividend', True, data=params)
 * 
 *     def query_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query User Universal Transfer History
 * 
 */
  __pyx_codeobj__302 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_query_universal_transfer_history, 2799, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__302)) __PYX_ERR(0, 2799, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2854
 *         return self._request_margin_api('get', 'asset/transfer', signed=True, data=params)
 * 
 *     def get_trade_fee(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trade fee.
 * 
 */
  __pyx_codeobj__303 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_trade_fee, 2854, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__303)) __PYX_ERR(0, 2854, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2889
 *         return res
 * 
 *     def get_asset_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch details on assets.
 * 
 */
  __pyx_codeobj__304 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_asset_details, 2889, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__304)) __PYX_ERR(0, 2889, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2930
 *     # Withdraw Endpoints
 * 
 *     def withdraw(self, **params):             # <<<<<<<<<<<<<<
 *         """Submit a withdraw request.
 * 
 */
  __pyx_codeobj__305 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_withdraw, 2930, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__305)) __PYX_ERR(0, 2930, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":2979
 *         return res
 * 
 *     def get_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch deposit history.
 * 
 */
  __pyx_codeobj__306 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_deposit_history, 2979, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__306)) __PYX_ERR(0, 2979, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3035
 *         return self._request_margin_api('get', 'capital/deposit/hisrec', True, data=params)
 * 
 *     def get_withdraw_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */
  __pyx_codeobj__307 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_withdraw_history, 3035, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__307)) __PYX_ERR(0, 3035, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3091
 *         return self._request_margin_api('get', 'capital/withdraw/history', True, data=params)
 * 
 *     def get_withdraw_history_id(self, withdraw_id, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */
  __pyx_tuple__308 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_withdraw_id, __pyx_n_s_params, __pyx_n_s_result, __pyx_n_s_entry); if (unlikely(!__pyx_tuple__308)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__308);
  __Pyx_GIVEREF(__pyx_tuple__308);
  __pyx_codeobj__309 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__308, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_withdraw_history_id, 3091, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__309)) __PYX_ERR(0, 3091, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3137
 *         raise Exception("There is no entry with withdraw id", result)
 * 
 *     def get_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch a deposit address for a symbol
 * 
 */
  __pyx_codeobj__310 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_deposit_address, 3137, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__310)) __PYX_ERR(0, 3137, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3167
 *     # User Stream Endpoints
 * 
 *     def stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new user data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_tuple__311 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_output, __pyx_n_s_throw_exception, __pyx_n_s_res); if (unlikely(!__pyx_tuple__311)) __PYX_ERR(0, 3167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__311);
  __Pyx_GIVEREF(__pyx_tuple__311);
  __pyx_codeobj__312 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__311, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_stream_get_listen_key, 3167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__312)) __PYX_ERR(0, 3167, __pyx_L1_error)
  __pyx_tuple__313 = PyTuple_Pack(2, ((PyObject*)__pyx_n_s_value), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__313)) __PYX_ERR(0, 3167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__313);
  __Pyx_GIVEREF(__pyx_tuple__313);

  /* "unicorn_binance_rest_api/manager.py":3201
 *             return res['listenKey']
 * 
 *     def stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a user data stream to prevent a time out.
 * 
 */
  __pyx_tuple__314 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_listenKey, __pyx_n_s_throw_exception, __pyx_n_s_params); if (unlikely(!__pyx_tuple__314)) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__314);
  __Pyx_GIVEREF(__pyx_tuple__314);
  __pyx_codeobj__315 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_stream_keepalive, 3201, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__315)) __PYX_ERR(0, 3201, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3226
 *                          throw_exception=throw_exception)
 * 
 *     def stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a user data stream.
 * 
 */
  __pyx_codeobj__316 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_stream_close, 3226, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__316)) __PYX_ERR(0, 3226, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3253
 *     # Margin Trading Endpoints
 * 
 *     def get_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin account details
 * 
 */
  __pyx_codeobj__317 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_account, 3253, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__317)) __PYX_ERR(0, 3253, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3311
 *         return self._request_margin_api('get', 'margin/account', True, data=params)
 * 
 *     def get_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin account details
 * 
 */
  __pyx_codeobj__318 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_isolated_margin_account, 3311, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__318)) __PYX_ERR(0, 3311, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3422
 *         return self._request_margin_api('get', 'margin/isolated/account', True, data=params)
 * 
 *     def get_margin_asset(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin asset
 * 
 */
  __pyx_codeobj__319 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_asset, 3422, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__319)) __PYX_ERR(0, 3422, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3453
 *         return self._request_margin_api('get', 'margin/asset', data=params)
 * 
 *     def get_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin symbol info
 * 
 */
  __pyx_codeobj__320 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_symbol, 3453, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__320)) __PYX_ERR(0, 3453, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3485
 *         return self._request_margin_api('get', 'margin/pair', data=params)
 * 
 *     def create_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Create isolated margin account for symbol
 * 
 */
  __pyx_codeobj__321 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_isolated_margin_account, 3485, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__321)) __PYX_ERR(0, 3485, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3515
 * 
 * 
 *     def get_isolated_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info
 * 
 */
  __pyx_codeobj__322 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_isolated_margin_symbol, 3515, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__322)) __PYX_ERR(0, 3515, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3546
 *         return self._request_margin_api('get', 'margin/isolated/pair', signed=True, data=params)
 * 
 *     def get_all_isolated_margin_symbols(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info for all pairs
 * 
 */
  __pyx_codeobj__323 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_all_isolated_margin_symbols, 3546, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__323)) __PYX_ERR(0, 3546, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3584
 *         return self._request_margin_api('get', 'margin/isolated/allPairs', signed=True, data=params)
 * 
 *     def toggle_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Toggle BNB Burn On Spot Trade And Margin Interest
 * 
 */
  __pyx_codeobj__324 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_toggle_bnb_burn_spot_margin, 3584, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__324)) __PYX_ERR(0, 3584, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3613
 *         return self._request_margin_api('post', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Get BNB Burn Status
 * 
 */
  __pyx_codeobj__325 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_bnb_burn_spot_margin, 3613, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__325)) __PYX_ERR(0, 3613, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3637
 *         return self._request_margin_api('get', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_margin_price_index(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin priceIndex
 * 
 */
  __pyx_codeobj__326 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_price_index, 3637, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__326)) __PYX_ERR(0, 3637, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3664
 *         return self._request_margin_api('get', 'margin/priceIndex', data=params)
 * 
 *     def transfer_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between cross-margin account and spot account.
 * 
 */
  __pyx_codeobj__327 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_transfer_margin_to_spot, 3664, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__327)) __PYX_ERR(0, 3664, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3695
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and cross-margin account.
 * 
 */
  __pyx_codeobj__328 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_transfer_spot_to_margin, 3695, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__328)) __PYX_ERR(0, 3695, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3727
 * 
 * 
 *     def transfer_isolated_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between isolated margin account and spot account.
 * 
 */
  __pyx_codeobj__329 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_transfer_isolated_margin_to_spot, 3727, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__329)) __PYX_ERR(0, 3727, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3762
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_isolated_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and isolated margin account.
 * 
 */
  __pyx_codeobj__330 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_transfer_spot_to_isolated_margin, 3762, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__330)) __PYX_ERR(0, 3762, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3797
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def create_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Apply for a loan in cross-margin or isolated-margin account.
 * 
 */
  __pyx_codeobj__331 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_margin_loan, 3797, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__331)) __PYX_ERR(0, 3797, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3834
 *         return self._request_margin_api('post', 'margin/loan', signed=True, data=params)
 * 
 *     def repay_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Repay loan in cross-margin or isolated-margin account.
 * 
 */
  __pyx_codeobj__332 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_repay_margin_loan, 3834, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__332)) __PYX_ERR(0, 3834, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3876
 *     # Margin OCO
 * 
 *     def create_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new OCO trade for margin account.
 * 
 */
  __pyx_codeobj__333 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_margin_oco_order, 3876, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__333)) __PYX_ERR(0, 3876, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":3985
 *         return self._request_margin_api('post', 'margin/order/oco', signed=True, data=params)
 * 
 *     def cancel_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an entire Order List for a margin account.
 * 
 */
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_cancel_margin_oco_order, 3985, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(0, 3985, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4066
 *         return self._request_margin_api('delete', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """ Retrieves a specific OCO based on provided optional parameters
 * 
 */
  __pyx_codeobj__335 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_oco_order, 4066, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__335)) __PYX_ERR(0, 4066, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4112
 *         return self._request_margin_api('get', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_open_margin_oco_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Retrieves open OCO trades
 * 
 */
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_open_margin_oco_orders, 4112, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(0, 4112, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4185
 *         return self._request_margin_api('get', 'margin/allOrderList', signed=True, data=params)
 * 
 *     def create_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new order for margin account.
 * 
 */
  __pyx_codeobj__337 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_margin_order, 4185, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__337)) __PYX_ERR(0, 4185, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4306
 *         return self._request_margin_api('post', 'margin/order', signed=True, data=params)
 * 
 *     def cancel_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active order for margin account.
 */
  __pyx_codeobj__338 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_cancel_margin_order, 4306, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__338)) __PYX_ERR(0, 4306, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4353
 *         return self._request_margin_api('delete', 'margin/order', signed=True, data=params)
 * 
 *     def get_margin_loan_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query loan record
 */
  __pyx_codeobj__339 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_loan_details, 4353, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__339)) __PYX_ERR(0, 4353, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4400
 *         return self._request_margin_api('get', 'margin/loan', signed=True, data=params)
 * 
 *     def get_margin_repay_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query repay record
 */
  __pyx_codeobj__340 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_repay_details, 4400, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__340)) __PYX_ERR(0, 4400, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4453
 *         return self._request_margin_api('get', 'margin/repay', signed=True, data=params)
 * 
 *     def get_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts order
 * 
 */
  __pyx_codeobj__341 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_order, 4453, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__341)) __PYX_ERR(0, 4453, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4501
 *         return self._request_margin_api('get', 'margin/order', signed=True, data=params)
 * 
 *     def get_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts open orders
 * 
 */
  __pyx_codeobj__342 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_open_margin_orders, 4501, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__342)) __PYX_ERR(0, 4501, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4551
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_open_isolated_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin accounts open orders
 * 
 */
  __pyx_codeobj__343 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_open_isolated_margin_orders, 4551, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__343)) __PYX_ERR(0, 4551, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4601
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_all_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query all margin accounts orders
 * 
 */
  __pyx_codeobj__344 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_all_margin_orders, 4601, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__344)) __PYX_ERR(0, 4601, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4662
 *         return self._request_margin_api('get', 'margin/allOrders', signed=True, data=params)
 * 
 *     def get_margin_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts trades
 * 
 */
  __pyx_codeobj__345 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_margin_trades, 4662, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__345)) __PYX_ERR(0, 4662, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4722
 *         return self._request_margin_api('get', 'margin/myTrades', signed=True, data=params)
 * 
 *     def get_max_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Query max borrow amount for an asset
 * 
 */
  __pyx_codeobj__346 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_max_margin_loan, 4722, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__346)) __PYX_ERR(0, 4722, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4747
 *         return self._request_margin_api('get', 'margin/maxBorrowable', signed=True, data=params)
 * 
 *     def get_max_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         r"""
 *         Query max transfer-out amount
 */
  __pyx_codeobj__347 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_max_margin_transfer, 4747, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__347)) __PYX_ERR(0, 4747, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4775
 *     # Cross-margin
 * 
 *     def margin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new cross-margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_codeobj__348 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__311, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_margin_stream_get_listen_key, 4775, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__348)) __PYX_ERR(0, 4775, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4808
 *             return res['listenKey']
 * 
 *     def margin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a cross-margin data stream to prevent a time out.
 * 
 */
  __pyx_codeobj__349 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_margin_stream_keepalive, 4808, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__349)) __PYX_ERR(0, 4808, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4833
 *                                         throw_exception=throw_exception)
 * 
 *     def margin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a cross-margin data stream.
 * 
 */
  __pyx_codeobj__350 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_margin_stream_close, 4833, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__350)) __PYX_ERR(0, 4833, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4860
 *     # Isolated margin
 * 
 *     def isolated_margin_stream_get_listen_key(self, symbol, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new isolated margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_tuple__351 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_symbol, __pyx_n_s_output, __pyx_n_s_throw_exception, __pyx_n_s_params, __pyx_n_s_res); if (unlikely(!__pyx_tuple__351)) __PYX_ERR(0, 4860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__351);
  __Pyx_GIVEREF(__pyx_tuple__351);
  __pyx_codeobj__352 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__351, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_isolated_margin_stream_get_liste, 4860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__352)) __PYX_ERR(0, 4860, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4900
 *             return res['listenKey']
 * 
 *     def isolated_margin_stream_keepalive(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING an isolated margin data stream to prevent a time out.
 * 
 */
  __pyx_tuple__353 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_symbol, __pyx_n_s_listenKey, __pyx_n_s_throw_exception, __pyx_n_s_params); if (unlikely(!__pyx_tuple__353)) __PYX_ERR(0, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__353);
  __Pyx_GIVEREF(__pyx_tuple__353);
  __pyx_codeobj__354 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__353, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_isolated_margin_stream_keepalive, 4900, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__354)) __PYX_ERR(0, 4900, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4928
 *                                         throw_exception=throw_exception)
 * 
 *     def isolated_margin_stream_close(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out an isolated margin data stream.
 * 
 */
  __pyx_codeobj__355 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__353, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_isolated_margin_stream_close, 4928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__355)) __PYX_ERR(0, 4928, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4958
 *     # Lending Endpoints
 * 
 *     def get_lending_product_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Product List
 * 
 */
  __pyx_codeobj__356 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_product_list, 4958, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__356)) __PYX_ERR(0, 4958, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4966
 *         return self._request_margin_api('get', 'lending/daily/product/list', signed=True, data=params)
 * 
 *     def get_lending_daily_quota_left(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Purchase Quota of Flexible Product.
 * 
 */
  __pyx_codeobj__357 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_daily_quota_left, 4966, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__357)) __PYX_ERR(0, 4966, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4974
 *         return self._request_margin_api('get', 'lending/daily/userLeftQuota', signed=True, data=params)
 * 
 *     def purchase_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Purchase Flexible Product
 * 
 */
  __pyx_codeobj__358 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_purchase_lending_product, 4974, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__358)) __PYX_ERR(0, 4974, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4982
 *         return self._request_margin_api('post', 'lending/daily/purchase', signed=True, data=params)
 * 
 *     def get_lending_daily_redemption_quota(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Redemption Quota of Flexible Product
 * 
 */
  __pyx_codeobj__359 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_daily_redemption_quo, 4982, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__359)) __PYX_ERR(0, 4982, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4990
 *         return self._request_margin_api('get', 'lending/daily/userRedemptionQuota', signed=True, data=params)
 * 
 *     def redeem_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Redeem Flexible Product
 * 
 */
  __pyx_codeobj__360 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_redeem_lending_product, 4990, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__360)) __PYX_ERR(0, 4990, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":4998
 *         return self._request_margin_api('post', 'lending/daily/redeem', signed=True, data=params)
 * 
 *     def get_lending_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Flexible Product Position
 * 
 */
  __pyx_codeobj__361 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_position, 4998, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__361)) __PYX_ERR(0, 4998, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5006
 *         return self._request_margin_api('get', 'lending/daily/token/position', signed=True, data=params)
 * 
 *     def get_fixed_activity_project_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Fixed and Activity Project List
 * 
 */
  __pyx_codeobj__362 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_fixed_activity_project_list, 5006, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__362)) __PYX_ERR(0, 5006, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5056
 *         return self._request_margin_api('get', 'lending/project/list', signed=True, data=params)
 * 
 *     def get_lending_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Account Details
 * 
 */
  __pyx_codeobj__363 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_account, 5056, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__363)) __PYX_ERR(0, 5056, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5064
 *         return self._request_margin_api('get', 'lending/union/account', signed=True, data=params)
 * 
 *     def get_lending_purchase_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Purchase History
 * 
 */
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_purchase_history, 5064, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(0, 5064, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5072
 *         return self._request_margin_api('get', 'lending/union/purchaseRecord', signed=True, data=params)
 * 
 *     def get_lending_redemption_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Redemption History
 * 
 */
  __pyx_codeobj__365 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_redemption_history, 5072, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__365)) __PYX_ERR(0, 5072, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5080
 *         return self._request_margin_api('get', 'lending/union/redemptionRecord', signed=True, data=params)
 * 
 *     def get_lending_interest_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Interest History
 * 
 */
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_lending_interest_history, 5080, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(0, 5080, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5088
 *         return self._request_margin_api('get', 'lending/union/interestHistory', signed=True, data=params)
 * 
 *     def change_fixed_activity_to_daily_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Change Fixed/Activity Position to Daily Position
 * 
 */
  __pyx_codeobj__367 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_change_fixed_activity_to_daily_p, 5088, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__367)) __PYX_ERR(0, 5088, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5098
 *     # Sub Accounts
 * 
 *     def get_sub_account_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account List.
 * 
 */
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_sub_account_list, 5098, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(0, 5098, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5137
 *         return self._request_margin_api('get', 'sub-account/list', True, data=params)
 * 
 *     def get_sub_account_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Transfer History.
 * 
 */
  __pyx_codeobj__369 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_sub_account_transfer_history, 5137, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__369)) __PYX_ERR(0, 5137, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5187
 *         return self._request_margin_api('get', 'sub-account/sub/transfer/history', True, data=params)
 * 
 *     def get_sub_account_futures_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Futures Transfer History.
 * 
 */
  __pyx_codeobj__370 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_sub_account_futures_transfer, 5187, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__370)) __PYX_ERR(0, 5187, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5237
 *         return self._request_margin_api('get', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def create_sub_account_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute sub-account Futures transfer
 * 
 */
  __pyx_codeobj__371 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_create_sub_account_futures_trans, 5237, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__371)) __PYX_ERR(0, 5237, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5269
 *         return self._request_margin_api('post', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def get_sub_account_assets(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch sub-account assets
 * 
 */
  __pyx_codeobj__372 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_sub_account_assets, 5269, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__372)) __PYX_ERR(0, 5269, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5318
 *         return self._request_margin_api('get', 'sub-account/assets', True, data=params, version='v3')
 * 
 *     def query_subaccount_spot_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Spot Assets Summary (For Master Account)
 * 
 */
  __pyx_codeobj__373 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_query_subaccount_spot_summary, 5318, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__373)) __PYX_ERR(0, 5318, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5356
 *         return self._request_margin_api('get', 'sub-account/spotSummary', True, data=params)
 * 
 *     def get_subaccount_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit Address (For Master Account)
 * 
 */
  __pyx_codeobj__374 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_deposit_address, 5356, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__374)) __PYX_ERR(0, 5356, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5386
 *         return self._request_margin_api('get', 'capital/deposit/subAddress', True, data=params)
 * 
 *     def get_subaccount_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit History (For Master Account)
 * 
 */
  __pyx_codeobj__375 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_deposit_history, 5386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__375)) __PYX_ERR(0, 5386, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5444
 *         return self._request_margin_api('get', 'capital/deposit/subHisrec', True, data=params)
 * 
 *     def get_subaccount_futures_margin_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account's Status on Margin/Futures (For Master Account)
 * 
 */
  __pyx_codeobj__376 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_futures_margin_st, 5444, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__376)) __PYX_ERR(0, 5444, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5475
 *         return self._request_margin_api('get', 'sub-account/status', True, data=params)
 * 
 *     def enable_subaccount_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Margin for Sub-account (For Master Account)
 * 
 */
  __pyx_codeobj__377 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_enable_subaccount_margin, 5475, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__377)) __PYX_ERR(0, 5475, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5502
 *         return self._request_margin_api('post', 'sub-account/margin/enable', True, data=params)
 * 
 *     def get_subaccount_margin_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Margin Account (For Master Account)
 * 
 */
  __pyx_codeobj__378 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_margin_details, 5502, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__378)) __PYX_ERR(0, 5502, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5569
 *         return self._request_margin_api('get', 'sub-account/margin/account', True, data=params)
 * 
 *     def get_subaccount_margin_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Margin Account (For Master Account)
 * 
 */
  __pyx_codeobj__379 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_margin_summary, 5569, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__379)) __PYX_ERR(0, 5569, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5606
 *         return self._request_margin_api('get', 'sub-account/margin/accountSummary', True, data=params)
 * 
 *     def enable_subaccount_futures(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Futures for Sub-account (For Master Account)
 * 
 */
  __pyx_codeobj__380 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_enable_subaccount_futures, 5606, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__380)) __PYX_ERR(0, 5606, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5633
 *         return self._request_margin_api('post', 'sub-account/futures/enable', True, data=params)
 * 
 *     def get_subaccount_futures_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Futures Account (For Master Account)
 * 
 */
  __pyx_codeobj__381 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_futures_details, 5633, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__381)) __PYX_ERR(0, 5633, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5683
 *         return self._request_margin_api('get', 'sub-account/futures/account', True, data=params)
 * 
 *     def get_subaccount_futures_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Futures Account (For Master Account)
 * 
 */
  __pyx_codeobj__382 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_futures_summary, 5683, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__382)) __PYX_ERR(0, 5683, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5735
 *         return self._request_margin_api('get', 'sub-account/futures/accountSummary', True, data=params)
 * 
 *     def get_subaccount_futures_positionrisk(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Futures Position-Risk of Sub-account (For Master Account)
 * 
 */
  __pyx_codeobj__383 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_futures_positionr, 5735, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__383)) __PYX_ERR(0, 5735, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5767
 *         return self._request_margin_api('get', 'sub-account/futures/positionRisk', True, data=params)
 * 
 *     def make_subaccount_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Futures Transfer for Sub-account (For Master Account)
 * 
 */
  __pyx_codeobj__384 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_make_subaccount_futures_transfer, 5767, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__384)) __PYX_ERR(0, 5767, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5797
 *         return self._request_margin_api('post', 'sub-account/futures/transfer', True, data=params)
 * 
 *     def make_subaccount_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Margin Transfer for Sub-account (For Master Account)
 * 
 */
  __pyx_codeobj__385 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_make_subaccount_margin_transfer, 5797, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__385)) __PYX_ERR(0, 5797, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5825
 *         return self._request_margin_api('post', 'sub-account/margin/transfer', True, data=params)
 * 
 *     def make_subaccount_to_subaccount_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Sub-account of Same Master (For Sub-account)
 * 
 */
  __pyx_codeobj__386 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_make_subaccount_to_subaccount_tr, 5825, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__386)) __PYX_ERR(0, 5825, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5852
 *         return self._request_margin_api('post', 'sub-account/transfer/subToSub', True, data=params)
 * 
 *     def make_subaccount_to_master_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Master (For Sub-account)
 * 
 */
  __pyx_codeobj__387 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_make_subaccount_to_master_transf, 5852, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__387)) __PYX_ERR(0, 5852, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5877
 *         return self._request_margin_api('post', 'sub-account/transfer/subToMaster', True, data=params)
 * 
 *     def get_subaccount_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Subaccount Transfer History (For Sub-account)
 * 
 */
  __pyx_codeobj__388 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_subaccount_transfer_history, 5877, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__388)) __PYX_ERR(0, 5877, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5927
 *         return self._request_margin_api('get', 'sub-account/transfer/subUserHistory', True, data=params)
 * 
 *     def make_universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */
  __pyx_codeobj__389 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_make_universal_transfer, 5927, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__389)) __PYX_ERR(0, 5927, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":5960
 *         return self._request_margin_api('post', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */
  __pyx_codeobj__390 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_universal_transfer_history, 5960, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__390)) __PYX_ERR(0, 5960, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6014
 *         return self._request_margin_api('get', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_used_weight(self, make_new_request=False):             # <<<<<<<<<<<<<<
 *         """Get the used weight from Binance endpoints
 * 
 */
  __pyx_tuple__391 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_make_new_request, __pyx_n_s_binance_api_status, __pyx_n_s_date_time_obj); if (unlikely(!__pyx_tuple__391)) __PYX_ERR(0, 6014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__391);
  __Pyx_GIVEREF(__pyx_tuple__391);
  __pyx_codeobj__392 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__391, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_used_weight, 6014, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__392)) __PYX_ERR(0, 6014, __pyx_L1_error)
  __pyx_tuple__393 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__393)) __PYX_ERR(0, 6014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__393);
  __Pyx_GIVEREF(__pyx_tuple__393);

  /* "unicorn_binance_rest_api/manager.py":6047
 *     # Futures API
 * 
 *     def futures_ping(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API
 * 
 */
  __pyx_codeobj__394 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_ping, 6047, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__394)) __PYX_ERR(0, 6047, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6055
 *         return self._request_futures_api('get', 'ping')
 * 
 *     def futures_time(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API and get the current server time.
 * 
 */
  __pyx_codeobj__395 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_time, 6055, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__395)) __PYX_ERR(0, 6055, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6063
 *         return self._request_futures_api('get', 'time')
 * 
 *     def futures_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """Current exchange trading rules and symbol information
 * 
 */
  __pyx_codeobj__396 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_exchange_info, 6063, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__396)) __PYX_ERR(0, 6063, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6071
 *         return self._request_futures_api('get', 'exchangeInfo')
 * 
 *     def futures_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """Get the Order Book for the market
 * 
 */
  __pyx_codeobj__397 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_order_book, 6071, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__397)) __PYX_ERR(0, 6071, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6079
 *         return self._request_futures_api('get', 'depth', data=params)
 * 
 *     def futures_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */
  __pyx_codeobj__398 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_recent_trades, 6079, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__398)) __PYX_ERR(0, 6079, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6087
 *         return self._request_futures_api('get', 'trades', data=params)
 * 
 *     def futures_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get older market historical trades.
 * 
 */
  __pyx_codeobj__399 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_historical_trades, 6087, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__399)) __PYX_ERR(0, 6087, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6095
 *         return self._request_futures_api('get', 'historicalTrades', data=params)
 * 
 *     def futures_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 *         price will have the quantity aggregated.
 */
  __pyx_codeobj__400 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_aggregate_trades, 6095, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__400)) __PYX_ERR(0, 6095, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6104
 *         return self._request_futures_api('get', 'aggTrades', data=params)
 * 
 *     def futures_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 * 
 */
  __pyx_codeobj__401 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_klines, 6104, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__401)) __PYX_ERR(0, 6104, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6112
 *         return self._request_futures_api('get', 'klines', data=params)
 * 
 *     def futures_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Mark Price and Funding Rate
 * 
 */
  __pyx_codeobj__402 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_mark_price, 6112, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__402)) __PYX_ERR(0, 6112, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6120
 *         return self._request_futures_api('get', 'premiumIndex', data=params)
 * 
 *     def futures_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */
  __pyx_codeobj__403 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_funding_rate, 6120, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__403)) __PYX_ERR(0, 6120, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6128
 *         return self._request_futures_api('get', 'fundingRate', data=params)
 * 
 *     def futures_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour rolling window price change statistics.
 * 
 */
  __pyx_codeobj__404 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_ticker, 6128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__404)) __PYX_ERR(0, 6128, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6136
 *         return self._request_futures_api('get', 'ticker/24hr', data=params)
 * 
 *     def futures_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */
  __pyx_codeobj__405 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_symbol_ticker, 6136, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__405)) __PYX_ERR(0, 6136, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6144
 *         return self._request_futures_api('get', 'ticker/price', data=params)
 * 
 *     def futures_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Best price/qty on the order book for a symbol or symbols.
 * 
 */
  __pyx_codeobj__406 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_orderbook_ticker, 6144, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__406)) __PYX_ERR(0, 6144, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6152
 *         return self._request_futures_api('get', 'ticker/bookTicker', data=params)
 * 
 *     def futures_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all liquidation orders
 * 
 */
  __pyx_codeobj__407 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_liquidation_orders, 6152, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__407)) __PYX_ERR(0, 6152, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6160
 *         return self._request_futures_api('get', 'ticker/allForceOrders', data=params)
 * 
 *     def futures_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """Get present open interest of a specific symbol.
 * 
 */
  __pyx_codeobj__408 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_open_interest, 6160, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__408)) __PYX_ERR(0, 6160, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6168
 *         return self._request_futures_api('get', 'ticker/openInterest', data=params)
 * 
 *     def futures_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """Get open interest statistics of a specific symbol.
 * 
 */
  __pyx_codeobj__409 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_open_interest_hist, 6168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__409)) __PYX_ERR(0, 6168, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6176
 *         return self._request_futures_data_api('get', 'openInterestHist', data=params)
 * 
 *     def futures_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """Notional and Leverage Brackets
 * 
 */
  __pyx_codeobj__410 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_leverage_bracket, 6176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__410)) __PYX_ERR(0, 6176, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6184
 *         return self._request_futures_api('get', 'leverageBracket', True, data=params)
 * 
 *     def futures_account_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and futures account.
 * 
 */
  __pyx_codeobj__411 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_account_transfer, 6184, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__411)) __PYX_ERR(0, 6184, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6192
 *         return self._request_margin_api('post', 'futures/transfer', True, data=params)
 * 
 *     def futures_auto_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open orders of the specified symbol at the end of the specified countdown.
 */
  __pyx_codeobj__412 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_auto_cancel_all_open_ord, 6192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__412)) __PYX_ERR(0, 6192, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6218
 *         return self._request_futures_api('post', 'countdownCancelAll', True, data=params)
 * 
 *     def futures_commission_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get commission rate (user data)
 * 
 */
  __pyx_codeobj__413 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_commission_rate, 6218, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__413)) __PYX_ERR(0, 6218, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6226
 *         return self._request_futures_coin_api("get", "commissionRate", version=1, signed=True, data=params)
 * 
 *     def transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get future account transaction history list
 * 
 */
  __pyx_codeobj__414 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_transfer_history, 6226, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__414)) __PYX_ERR(0, 6226, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6234
 *         return self._request_margin_api('get', 'futures/transfer', True, data=params)
 * 
 *     def futures_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order.
 * 
 */
  __pyx_codeobj__415 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_create_order, 6234, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__415)) __PYX_ERR(0, 6234, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6242
 *         return self._request_futures_api('post', 'order', True, data=params)
 * 
 *     def futures_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */
  __pyx_tuple__416 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_params, __pyx_n_s_query_string); if (unlikely(!__pyx_tuple__416)) __PYX_ERR(0, 6242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__416);
  __Pyx_GIVEREF(__pyx_tuple__416);
  __pyx_codeobj__417 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__416, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_place_batch_order, 6242, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__417)) __PYX_ERR(0, 6242, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6253
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */
  __pyx_codeobj__418 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_get_order, 6253, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__418)) __PYX_ERR(0, 6253, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6262
 *         return self._request_futures_api('get', 'order', True, data=params)
 * 
 *     def futures_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */
  __pyx_codeobj__419 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_get_open_orders, 6262, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__419)) __PYX_ERR(0, 6262, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6271
 *         return self._request_futures_api('get', 'openOrders', True, data=params)
 * 
 *     def futures_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */
  __pyx_codeobj__420 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_get_all_orders, 6271, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__420)) __PYX_ERR(0, 6271, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6280
 *         return self._request_futures_api('get', 'allOrders', True, data=params)
 * 
 *     def futures_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */
  __pyx_codeobj__421 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_cancel_order, 6280, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__421)) __PYX_ERR(0, 6280, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6289
 *         return self._request_futures_api('delete', 'order', True, data=params)
 * 
 *     def futures_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */
  __pyx_codeobj__422 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_cancel_all_open_orders, 6289, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__422)) __PYX_ERR(0, 6289, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6298
 *         return self._request_futures_api('delete', 'allOpenOrders', True, data=params)
 * 
 *     def futures_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */
  __pyx_codeobj__423 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_cancel_orders, 6298, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__423)) __PYX_ERR(0, 6298, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6307
 *         return self._request_futures_api('delete', 'batchOrders', True, data=params)
 * 
 *     def futures_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */
  __pyx_codeobj__424 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_account_balance, 6307, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__424)) __PYX_ERR(0, 6307, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6316
 *         return self._request_futures_api('get', 'balance', True, data=params)
 * 
 *     def futures_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */
  __pyx_codeobj__425 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_account, 6316, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__425)) __PYX_ERR(0, 6316, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6325
 *         return self._request_futures_api('get', 'account', True, data=params)
 * 
 *     def futures_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */
  __pyx_codeobj__426 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_change_leverage, 6325, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__426)) __PYX_ERR(0, 6325, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6334
 *         return self._request_futures_api('post', 'leverage', True, data=params)
 * 
 *     def futures_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """Change the margin type for a symbol
 * 
 */
  __pyx_codeobj__427 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_change_margin_type, 6334, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__427)) __PYX_ERR(0, 6334, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6342
 *         return self._request_futures_api('post', 'marginType', True, data=params)
 * 
 *     def futures_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */
  __pyx_codeobj__428 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_change_position_margin, 6342, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__428)) __PYX_ERR(0, 6342, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6351
 *         return self._request_futures_api('post', 'positionMargin', True, data=params)
 * 
 *     def futures_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position margin change history
 */
  __pyx_codeobj__429 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_position_margin_history, 6351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__429)) __PYX_ERR(0, 6351, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6360
 *         return self._request_futures_api('get', 'positionMargin/history', True, data=params)
 * 
 *     def futures_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */
  __pyx_codeobj__430 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_position_information, 6360, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__430)) __PYX_ERR(0, 6360, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6369
 *         return self._request_futures_api('get', 'positionRisk', True, data=params)
 * 
 *     def futures_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get trades for the authenticated account and symbol.
 */
  __pyx_codeobj__431 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_account_trades, 6369, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__431)) __PYX_ERR(0, 6369, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6378
 *         return self._request_futures_api('get', 'userTrades', True, data=params)
 * 
 *     def futures_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get income history for authenticated account
 */
  __pyx_codeobj__432 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_income_history, 6378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__432)) __PYX_ERR(0, 6378, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6387
 *         return self._request_futures_api('get', 'income', True, data=params)
 * 
 *     def futures_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change position mode for authenticated account
 */
  __pyx_codeobj__433 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_change_position_mode, 6387, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__433)) __PYX_ERR(0, 6387, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6396
 *         return self._request_futures_api('post', 'positionSide/dual', True, data=params)
 * 
 *     def futures_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position mode for authenticated account
 */
  __pyx_codeobj__434 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_get_position_mode, 6396, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__434)) __PYX_ERR(0, 6396, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6405
 *         return self._request_futures_api('get', 'positionSide/dual', True, data=params)
 * 
 *     def futures_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_codeobj__435 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__311, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_stream_get_listen_key, 6405, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__435)) __PYX_ERR(0, 6405, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6438
 *             return res['listenKey']
 * 
 *     def futures_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a futures data stream to prevent a time out.
 * 
 */
  __pyx_codeobj__436 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_stream_keepalive, 6438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__436)) __PYX_ERR(0, 6438, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6463
 *                                          throw_exception=throw_exception)
 * 
 *     def futures_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a futures data stream.
 * 
 */
  __pyx_codeobj__437 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_stream_close, 6463, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__437)) __PYX_ERR(0, 6463, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6489
 * 
 *     # COIN Futures API
 *     def futures_coin_ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API
 */
  __pyx_codeobj__438 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_ping, 6489, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__438)) __PYX_ERR(0, 6489, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6498
 *         return self._request_futures_coin_api("get", "ping")
 * 
 *     def futures_coin_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */
  __pyx_codeobj__439 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_time, 6498, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__439)) __PYX_ERR(0, 6498, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6507
 *         return self._request_futures_coin_api("get", "time")
 * 
 *     def futures_coin_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Current exchange trading rules and symbol information
 */
  __pyx_codeobj__440 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_exchange_info, 6507, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__440)) __PYX_ERR(0, 6507, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6516
 *         return self._request_futures_coin_api("get", "exchangeInfo")
 * 
 *     def futures_coin_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */
  __pyx_codeobj__441 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_order_book, 6516, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__441)) __PYX_ERR(0, 6516, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6525
 *         return self._request_futures_coin_api("get", "depth", data=params)
 * 
 *     def futures_coin_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */
  __pyx_codeobj__442 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_recent_trades, 6525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__442)) __PYX_ERR(0, 6525, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6533
 *         return self._request_futures_coin_api("get", "trades", data=params)
 * 
 *     def futures_coin_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older market historical trades.
 */
  __pyx_codeobj__443 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_historical_trades, 6533, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__443)) __PYX_ERR(0, 6533, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6542
 *         return self._request_futures_coin_api("get", "historicalTrades", data=params)
 * 
 *     def futures_coin_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 */
  __pyx_codeobj__444 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_aggregate_trades, 6542, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__444)) __PYX_ERR(0, 6542, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6552
 *         return self._request_futures_coin_api("get", "aggTrades", data=params)
 * 
 *     def futures_coin_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */
  __pyx_codeobj__445 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_klines, 6552, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__445)) __PYX_ERR(0, 6552, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6561
 *         return self._request_futures_coin_api("get", "klines", data=params)
 * 
 *     def futures_coin_continous_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a specific contract type. Klines are uniquely identified by their open time.
 */
  __pyx_codeobj__446 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_continous_klines, 6561, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__446)) __PYX_ERR(0, 6561, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6570
 *         return self._request_futures_coin_api("get", "continuousKlines", data=params)
 * 
 *     def futures_coin_index_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */
  __pyx_codeobj__447 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_index_price_klines, 6570, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__447)) __PYX_ERR(0, 6570, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6578
 *         return self._request_futures_coin_api("get", "indexPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */
  __pyx_codeobj__448 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_mark_price_klines, 6578, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__448)) __PYX_ERR(0, 6578, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6586
 *         return self._request_futures_coin_api("get", "markPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get Mark Price and Funding Rate
 */
  __pyx_codeobj__449 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_mark_price, 6586, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__449)) __PYX_ERR(0, 6586, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6595
 *         return self._request_futures_coin_api("get", "premiumIndex", data=params)
 * 
 *     def futures_coin_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */
  __pyx_codeobj__450 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_funding_rate, 6595, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__450)) __PYX_ERR(0, 6595, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6603
 *         return self._request_futures_coin_api("get", "fundingRate", data=params)
 * 
 *     def futures_coin_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         24 hour rolling window price change statistics.
 */
  __pyx_codeobj__451 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_ticker, 6603, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__451)) __PYX_ERR(0, 6603, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6612
 *         return self._request_futures_coin_api("get", "ticker/24hr", data=params)
 * 
 *     def futures_coin_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for a symbol or symbols.
 */
  __pyx_codeobj__452 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_symbol_ticker, 6612, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__452)) __PYX_ERR(0, 6612, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6621
 *         return self._request_futures_coin_api("get", "ticker/price", data=params)
 * 
 *     def futures_coin_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for a symbol or symbols.
 */
  __pyx_codeobj__453 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_orderbook_ticker, 6621, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__453)) __PYX_ERR(0, 6621, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6630
 *         return self._request_futures_coin_api("get", "ticker/bookTicker", data=params)
 * 
 *     def futures_coin_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all liquidation orders
 */
  __pyx_codeobj__454 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_liquidation_orders, 6630, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__454)) __PYX_ERR(0, 6630, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6639
 *         return self._request_futures_coin_api("get", "allForceOrders", data=params)
 * 
 *     def futures_coin_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get present open interest of a specific symbol.
 */
  __pyx_codeobj__455 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_open_interest, 6639, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__455)) __PYX_ERR(0, 6639, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6648
 *         return self._request_futures_coin_api("get", "openInterest", data=params)
 * 
 *     def futures_coin_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get open interest statistics of a specific symbol.
 */
  __pyx_codeobj__456 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_open_interest_hist, 6648, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__456)) __PYX_ERR(0, 6648, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6657
 *         return self._request_futures_coin_data_api("get", "openInterestHist", data=params)
 * 
 *     def futures_coin_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Notional and Leverage Brackets
 */
  __pyx_codeobj__457 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_leverage_bracket, 6657, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__457)) __PYX_ERR(0, 6657, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6668
 *         )
 * 
 *     def new_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get future account transaction history list
 */
  __pyx_codeobj__458 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_new_transfer_history, 6668, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__458)) __PYX_ERR(0, 6668, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6678
 *         # return self._request_margin_api("get", "futures/transfer", True, data=params)
 * 
 *     def universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Unviversal transfer api accross different unicorn_binance_rest_api account types
 */
  __pyx_codeobj__459 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_universal_transfer, 6678, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__459)) __PYX_ERR(0, 6678, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6688
 *         )
 * 
 *     def futures_coin_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Send in a new order.
 */
  __pyx_codeobj__460 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_create_order, 6688, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__460)) __PYX_ERR(0, 6688, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6697
 *         return self._request_futures_coin_api("post", "order", True, data=params)
 * 
 *     def futures_coin_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */
  __pyx_codeobj__461 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__416, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_place_batch_order, 6697, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__461)) __PYX_ERR(0, 6697, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6708
 *         return self._request_futures_coin_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_coin_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */
  __pyx_codeobj__462 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_get_order, 6708, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__462)) __PYX_ERR(0, 6708, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6717
 *         return self._request_futures_coin_api("get", "order", True, data=params)
 * 
 *     def futures_coin_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */
  __pyx_codeobj__463 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_get_open_orders, 6717, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__463)) __PYX_ERR(0, 6717, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6726
 *         return self._request_futures_coin_api("get", "openOrders", True, data=params)
 * 
 *     def futures_coin_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */
  __pyx_codeobj__464 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_get_all_orders, 6726, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__464)) __PYX_ERR(0, 6726, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6737
 *         )
 * 
 *     def futures_coin_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */
  __pyx_codeobj__465 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_cancel_order, 6737, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__465)) __PYX_ERR(0, 6737, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6748
 *         )
 * 
 *     def futures_coin_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */
  __pyx_codeobj__466 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_cancel_all_open_ord, 6748, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__466)) __PYX_ERR(0, 6748, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6759
 *         )
 * 
 *     def futures_coin_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */
  __pyx_codeobj__467 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_cancel_orders, 6759, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__467)) __PYX_ERR(0, 6759, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6770
 *         )
 * 
 *     def futures_coin_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */
  __pyx_codeobj__468 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_account_balance, 6770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__468)) __PYX_ERR(0, 6770, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6781
 *         )
 * 
 *     def futures_coin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */
  __pyx_codeobj__469 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_account, 6781, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__469)) __PYX_ERR(0, 6781, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6792
 *         )
 * 
 *     def futures_coin_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */
  __pyx_codeobj__470 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_change_leverage, 6792, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__470)) __PYX_ERR(0, 6792, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6803
 *         )
 * 
 *     def futures_coin_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the margin type for a symbol
 */
  __pyx_codeobj__471 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_change_margin_type, 6803, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__471)) __PYX_ERR(0, 6803, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6814
 *         )
 * 
 *     def futures_coin_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */
  __pyx_codeobj__472 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_change_position_mar, 6814, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__472)) __PYX_ERR(0, 6814, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6825
 *         )
 * 
 *     def futures_coin_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get position margin change history
 * 
 */
  __pyx_codeobj__473 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_position_margin_his, 6825, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__473)) __PYX_ERR(0, 6825, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6835
 *         )
 * 
 *     def futures_coin_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */
  __pyx_codeobj__474 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_position_informatio, 6835, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__474)) __PYX_ERR(0, 6835, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6844
 *         return self._request_futures_coin_api("get", "positionRisk", True, data=params)
 * 
 *     def futures_coin_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for the authenticated account and symbol.
 * 
 */
  __pyx_codeobj__475 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_account_trades, 6844, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__475)) __PYX_ERR(0, 6844, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6852
 *         return self._request_futures_coin_api("get", "userTrades", True, data=params)
 * 
 *     def futures_coin_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get income history for authenticated account
 * 
 */
  __pyx_codeobj__476 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_income_history, 6852, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__476)) __PYX_ERR(0, 6852, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6860
 *         return self._request_futures_coin_api("get", "income", True, data=params)
 * 
 *     def futures_coin_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */
  __pyx_codeobj__477 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_change_position_mod, 6860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__477)) __PYX_ERR(0, 6860, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6868
 *         return self._request_futures_coin_api("post", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */
  __pyx_codeobj__478 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_get_position_mode, 6868, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__478)) __PYX_ERR(0, 6868, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6877
 *         return self._request_futures_coin_api("get", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new coin futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_codeobj__479 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__311, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_stream_get_listen_k, 6877, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__479)) __PYX_ERR(0, 6877, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6911
 *             return res['listenKey']
 * 
 *     def futures_coin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a coin futures data stream to prevent a time out.
 * 
 */
  __pyx_codeobj__480 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_stream_keepalive, 6911, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__480)) __PYX_ERR(0, 6911, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6936
 *                                               throw_exception=throw_exception)
 * 
 *     def futures_coin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a coin futures data stream.
 * 
 */
  __pyx_codeobj__481 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_futures_coin_stream_close, 6936, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__481)) __PYX_ERR(0, 6936, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":6962
 * 
 * 
 *     def get_all_coins_info(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get information of coins (available for deposit and withdraw) for user.
 */
  __pyx_codeobj__482 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_all_coins_info, 6962, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__482)) __PYX_ERR(0, 6962, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":7038
 *         return self._request_margin_api('get', 'capital/config/getall', True, data=params)
 * 
 *     def get_account_snapshot(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get daily account snapshot of specific type.
 */
  __pyx_codeobj__483 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_get_account_snapshot, 7038, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__483)) __PYX_ERR(0, 7038, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":7154
 *         return self._request_margin_api('get', 'accountSnapshot', True, data=params)
 * 
 *     def disable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Disable Fast Withdraw Switch
 */
  __pyx_codeobj__484 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_disable_fast_withdraw_switch, 7154, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__484)) __PYX_ERR(0, 7154, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":7170
 *         return self._request_margin_api('post', 'disableFastWithdrawSwitch', True, data=params)
 * 
 *     def enable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Enable Fast Withdraw Switch
 */
  __pyx_codeobj__485 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__254, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_enable_fast_withdraw_switch, 7170, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__485)) __PYX_ERR(0, 7170, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":7186
 *         return self._request_margin_api('post', 'enableFastWithdrawSwitch', True, data=params)
 * 
 *     def stop_manager(self, close_api_session=True):             # <<<<<<<<<<<<<<
 *         """
 *         Stop the BinanceRestApiManager
 */
  __pyx_tuple__486 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_close_api_session); if (unlikely(!__pyx_tuple__486)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__486);
  __Pyx_GIVEREF(__pyx_tuple__486);
  __pyx_codeobj__487 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_unicorn_binance_rest_api_manager_2, __pyx_n_s_stop_manager, 7186, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__487)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_get.method_name = &__pyx_n_s_get;
  __pyx_umethod_PyDict_Type_update.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_update.method_name = &__pyx_n_s_update;
  __pyx_umethod_PyString_Type_split.type = (PyObject*)&PyString_Type;
  __pyx_umethod_PyString_Type_split.method_name = &__pyx_n_s_split;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_200 = PyInt_FromLong(200); if (unlikely(!__pyx_int_200)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_300 = PyInt_FromLong(300); if (unlikely(!__pyx_int_300)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_500 = PyInt_FromLong(500); if (unlikely(!__pyx_int_500)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1000 = PyInt_FromLong(1000); if (unlikely(!__pyx_int_1000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3600 = PyInt_FromLong(3600); if (unlikely(!__pyx_int_3600)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3600000 = PyInt_FromLong(3600000L); if (unlikely(!__pyx_int_3600000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_4 = PyInt_FromLong(-4); if (unlikely(!__pyx_int_neg_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr_spec, NULL); if (unlikely(!__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr)) __PYX_ERR(0, 525, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr_spec, __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr) < 0) __PYX_ERR(0, 525, __pyx_L1_error)
  #else
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr = &__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr) < 0) __PYX_ERR(0, 525, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr->tp_dictoffset && __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct__genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter_spec, NULL); if (unlikely(!__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter)) __PYX_ERR(0, 1039, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter_spec, __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter) < 0) __PYX_ERR(0, 1039, __pyx_L1_error)
  #else
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter = &__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter) < 0) __PYX_ERR(0, 1039, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter->tp_dictoffset && __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_1_aggregate_trade_iter->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator_spec, NULL); if (unlikely(!__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator)) __PYX_ERR(0, 1276, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator_spec, __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator) < 0) __PYX_ERR(0, 1276, __pyx_L1_error)
  #else
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator = &__pyx_type_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator) < 0) __PYX_ERR(0, 1276, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator->tp_dictoffset && __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_24unicorn_binance_rest_api_7manager___pyx_scope_struct_2_get_historical_klines_generator->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_manager(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_manager},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "manager",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initmanager(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initmanager(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_manager(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_manager(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_manager(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'manager' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("manager", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to manager pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_manager(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_unicorn_binance_rest_api__manager) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "unicorn_binance_rest_api.manager")) {
      if (unlikely((PyDict_SetItemString(modules, "unicorn_binance_rest_api.manager", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "unicorn_binance_rest_api/manager.py":40
 * # IN THE SOFTWARE.
 * 
 * from lucit_licensing_python.manager import LucitLicensingManager             # <<<<<<<<<<<<<<
 * from operator import itemgetter
 * from typing import Optional
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_LucitLicensingManager);
  __Pyx_GIVEREF(__pyx_n_s_LucitLicensingManager);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_LucitLicensingManager)) __PYX_ERR(0, 40, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_lucit_licensing_python_manager, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_LucitLicensingManager); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LucitLicensingManager, __pyx_t_2) < 0) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":41
 * 
 * from lucit_licensing_python.manager import LucitLicensingManager
 * from operator import itemgetter             # <<<<<<<<<<<<<<
 * from typing import Optional
 * from urllib.parse import urlencode
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_itemgetter);
  __Pyx_GIVEREF(__pyx_n_s_itemgetter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_itemgetter)) __PYX_ERR(0, 41, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_operator, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_itemgetter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_itemgetter, __pyx_t_3) < 0) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":42
 * from lucit_licensing_python.manager import LucitLicensingManager
 * from operator import itemgetter
 * from typing import Optional             # <<<<<<<<<<<<<<
 * from urllib.parse import urlencode
 * from .helpers import date_to_milliseconds, interval_to_milliseconds
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_Optional);
  __Pyx_GIVEREF(__pyx_n_s_Optional);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Optional)) __PYX_ERR(0, 42, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_typing, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Optional, __pyx_t_2) < 0) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":43
 * from operator import itemgetter
 * from typing import Optional
 * from urllib.parse import urlencode             # <<<<<<<<<<<<<<
 * from .helpers import date_to_milliseconds, interval_to_milliseconds
 * from .exceptions import BinanceAPIException, BinanceRequestException, BinanceWithdrawException, UnknownExchange
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_urlencode);
  __Pyx_GIVEREF(__pyx_n_s_urlencode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_urlencode)) __PYX_ERR(0, 43, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_urllib_parse, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_urlencode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_urlencode, __pyx_t_3) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":44
 * from typing import Optional
 * from urllib.parse import urlencode
 * from .helpers import date_to_milliseconds, interval_to_milliseconds             # <<<<<<<<<<<<<<
 * from .exceptions import BinanceAPIException, BinanceRequestException, BinanceWithdrawException, UnknownExchange
 * import colorama
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_date_to_milliseconds);
  __Pyx_GIVEREF(__pyx_n_s_date_to_milliseconds);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_date_to_milliseconds)) __PYX_ERR(0, 44, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_interval_to_milliseconds);
  __Pyx_GIVEREF(__pyx_n_s_interval_to_milliseconds);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_interval_to_milliseconds)) __PYX_ERR(0, 44, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_helpers, __pyx_t_2, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_date_to_milliseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_date_to_milliseconds, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_interval_to_milliseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_interval_to_milliseconds, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "unicorn_binance_rest_api/manager.py":45
 * from urllib.parse import urlencode
 * from .helpers import date_to_milliseconds, interval_to_milliseconds
 * from .exceptions import BinanceAPIException, BinanceRequestException, BinanceWithdrawException, UnknownExchange             # <<<<<<<<<<<<<<
 * import colorama
 * import cython
 */
  __pyx_t_3 = PyList_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_BinanceAPIException);
  __Pyx_GIVEREF(__pyx_n_s_BinanceAPIException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_BinanceAPIException)) __PYX_ERR(0, 45, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_BinanceRequestException);
  __Pyx_GIVEREF(__pyx_n_s_BinanceRequestException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_BinanceRequestException)) __PYX_ERR(0, 45, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_BinanceWithdrawException);
  __Pyx_GIVEREF(__pyx_n_s_BinanceWithdrawException);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_BinanceWithdrawException)) __PYX_ERR(0, 45, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_UnknownExchange);
  __Pyx_GIVEREF(__pyx_n_s_UnknownExchange);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 3, __pyx_n_s_UnknownExchange)) __PYX_ERR(0, 45, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_exceptions, __pyx_t_3, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_BinanceAPIException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BinanceAPIException, __pyx_t_3) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_BinanceRequestException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BinanceRequestException, __pyx_t_3) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_BinanceWithdrawException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BinanceWithdrawException, __pyx_t_3) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_UnknownExchange); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnknownExchange, __pyx_t_3) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":46
 * from .helpers import date_to_milliseconds, interval_to_milliseconds
 * from .exceptions import BinanceAPIException, BinanceRequestException, BinanceWithdrawException, UnknownExchange
 * import colorama             # <<<<<<<<<<<<<<
 * import cython
 * import datetime
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_colorama, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_colorama, __pyx_t_2) < 0) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":48
 * import colorama
 * import cython
 * import datetime             # <<<<<<<<<<<<<<
 * import hashlib
 * import hmac
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_datetime, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_2) < 0) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":49
 * import cython
 * import datetime
 * import hashlib             # <<<<<<<<<<<<<<
 * import hmac
 * import logging
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_hashlib, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_hashlib, __pyx_t_2) < 0) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":50
 * import datetime
 * import hashlib
 * import hmac             # <<<<<<<<<<<<<<
 * import logging
 * import requests
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_hmac, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_hmac, __pyx_t_2) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":51
 * import hashlib
 * import hmac
 * import logging             # <<<<<<<<<<<<<<
 * import requests
 * import platform
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_logging, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_logging, __pyx_t_2) < 0) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":52
 * import hmac
 * import logging
 * import requests             # <<<<<<<<<<<<<<
 * import platform
 * import time
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_requests, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_requests, __pyx_t_2) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":53
 * import logging
 * import requests
 * import platform             # <<<<<<<<<<<<<<
 * import time
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_platform, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_platform, __pyx_t_2) < 0) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":54
 * import requests
 * import platform
 * import time             # <<<<<<<<<<<<<<
 * 
 * logger = logging.getLogger("unicorn_binance_rest_api")
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_time, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_2) < 0) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":56
 * import time
 * 
 * logger = logging.getLogger("unicorn_binance_rest_api")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logging); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getLogger); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__187, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_logger, __pyx_t_2) < 0) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":59
 * 
 * 
 * class BinanceRestApiManager(object):             # <<<<<<<<<<<<<<
 *     """
 *     An unofficial Python API to use the Binance REST API`s (com+testnet, com-margin+testnet,
 */
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_tuple__189); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_3, __pyx_t_2, __pyx_n_s_BinanceRestApiManager, __pyx_n_s_BinanceRestApiManager, (PyObject *) NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_kp_s_An_unofficial_Python_API_to_use); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__pyx_t_2 != __pyx_tuple__189) {
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_tuple__189) < 0))) __PYX_ERR(0, 59, __pyx_L1_error)
  }

  /* "unicorn_binance_rest_api/manager.py":116
 *     """
 * 
 *     API_URL = 'https://api.binance.{}/api'             # <<<<<<<<<<<<<<
 *     MARGIN_API_URL = 'https://api.binance.{}/sapi'
 *     WEBSITE_URL = 'https://www.binance.{}'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_API_URL, __pyx_kp_s_https_api_binance_api) < 0) __PYX_ERR(0, 116, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":117
 * 
 *     API_URL = 'https://api.binance.{}/api'
 *     MARGIN_API_URL = 'https://api.binance.{}/sapi'             # <<<<<<<<<<<<<<
 *     WEBSITE_URL = 'https://www.binance.{}'
 *     FUTURES_URL = 'https://fapi.binance.{}/fapi'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_MARGIN_API_URL, __pyx_kp_s_https_api_binance_sapi) < 0) __PYX_ERR(0, 117, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":118
 *     API_URL = 'https://api.binance.{}/api'
 *     MARGIN_API_URL = 'https://api.binance.{}/sapi'
 *     WEBSITE_URL = 'https://www.binance.{}'             # <<<<<<<<<<<<<<
 *     FUTURES_URL = 'https://fapi.binance.{}/fapi'
 *     FUTURES_DATA_URL = 'https://fapi.binance.{}/futures/data'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_WEBSITE_URL, __pyx_kp_s_https_www_binance) < 0) __PYX_ERR(0, 118, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":119
 *     MARGIN_API_URL = 'https://api.binance.{}/sapi'
 *     WEBSITE_URL = 'https://www.binance.{}'
 *     FUTURES_URL = 'https://fapi.binance.{}/fapi'             # <<<<<<<<<<<<<<
 *     FUTURES_DATA_URL = 'https://fapi.binance.{}/futures/data'
 *     FUTURES_COIN_URL = "https://fapi.binance.{}/fapi"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FUTURES_URL, __pyx_kp_s_https_fapi_binance_fapi) < 0) __PYX_ERR(0, 119, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":120
 *     WEBSITE_URL = 'https://www.binance.{}'
 *     FUTURES_URL = 'https://fapi.binance.{}/fapi'
 *     FUTURES_DATA_URL = 'https://fapi.binance.{}/futures/data'             # <<<<<<<<<<<<<<
 *     FUTURES_COIN_URL = "https://fapi.binance.{}/fapi"
 *     FUTURES_COIN_DATA_URL = "https://dapi.binance.{}/futures/data"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FUTURES_DATA_URL, __pyx_kp_s_https_fapi_binance_futures_data) < 0) __PYX_ERR(0, 120, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":121
 *     FUTURES_URL = 'https://fapi.binance.{}/fapi'
 *     FUTURES_DATA_URL = 'https://fapi.binance.{}/futures/data'
 *     FUTURES_COIN_URL = "https://fapi.binance.{}/fapi"             # <<<<<<<<<<<<<<
 *     FUTURES_COIN_DATA_URL = "https://dapi.binance.{}/futures/data"
 *     PUBLIC_API_VERSION = 'v1'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FUTURES_COIN_URL, __pyx_kp_s_https_fapi_binance_fapi) < 0) __PYX_ERR(0, 121, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":122
 *     FUTURES_DATA_URL = 'https://fapi.binance.{}/futures/data'
 *     FUTURES_COIN_URL = "https://fapi.binance.{}/fapi"
 *     FUTURES_COIN_DATA_URL = "https://dapi.binance.{}/futures/data"             # <<<<<<<<<<<<<<
 *     PUBLIC_API_VERSION = 'v1'
 *     PRIVATE_API_VERSION = 'v3'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FUTURES_COIN_DATA_URL, __pyx_kp_s_https_dapi_binance_futures_data) < 0) __PYX_ERR(0, 122, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":123
 *     FUTURES_COIN_URL = "https://fapi.binance.{}/fapi"
 *     FUTURES_COIN_DATA_URL = "https://dapi.binance.{}/futures/data"
 *     PUBLIC_API_VERSION = 'v1'             # <<<<<<<<<<<<<<
 *     PRIVATE_API_VERSION = 'v3'
 *     MARGIN_API_VERSION = 'v1'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_PUBLIC_API_VERSION, __pyx_n_s_v1) < 0) __PYX_ERR(0, 123, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":124
 *     FUTURES_COIN_DATA_URL = "https://dapi.binance.{}/futures/data"
 *     PUBLIC_API_VERSION = 'v1'
 *     PRIVATE_API_VERSION = 'v3'             # <<<<<<<<<<<<<<
 *     MARGIN_API_VERSION = 'v1'
 *     FUTURES_API_VERSION = 'v1'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_PRIVATE_API_VERSION, __pyx_n_s_v3) < 0) __PYX_ERR(0, 124, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":125
 *     PUBLIC_API_VERSION = 'v1'
 *     PRIVATE_API_VERSION = 'v3'
 *     MARGIN_API_VERSION = 'v1'             # <<<<<<<<<<<<<<
 *     FUTURES_API_VERSION = 'v1'
 *     FUTURES_API_VERSION2 = "v2"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_MARGIN_API_VERSION, __pyx_n_s_v1) < 0) __PYX_ERR(0, 125, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":126
 *     PRIVATE_API_VERSION = 'v3'
 *     MARGIN_API_VERSION = 'v1'
 *     FUTURES_API_VERSION = 'v1'             # <<<<<<<<<<<<<<
 *     FUTURES_API_VERSION2 = "v2"
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FUTURES_API_VERSION, __pyx_n_s_v1) < 0) __PYX_ERR(0, 126, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":127
 *     MARGIN_API_VERSION = 'v1'
 *     FUTURES_API_VERSION = 'v1'
 *     FUTURES_API_VERSION2 = "v2"             # <<<<<<<<<<<<<<
 * 
 *     SYMBOL_TYPE_SPOT = 'SPOT'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FUTURES_API_VERSION2, __pyx_n_s_v2) < 0) __PYX_ERR(0, 127, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":129
 *     FUTURES_API_VERSION2 = "v2"
 * 
 *     SYMBOL_TYPE_SPOT = 'SPOT'             # <<<<<<<<<<<<<<
 * 
 *     ORDER_STATUS_NEW = 'NEW'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SYMBOL_TYPE_SPOT, __pyx_n_s_SPOT) < 0) __PYX_ERR(0, 129, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":131
 *     SYMBOL_TYPE_SPOT = 'SPOT'
 * 
 *     ORDER_STATUS_NEW = 'NEW'             # <<<<<<<<<<<<<<
 *     ORDER_STATUS_PARTIALLY_FILLED = 'PARTIALLY_FILLED'
 *     ORDER_STATUS_FILLED = 'FILLED'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_STATUS_NEW, __pyx_n_s_NEW) < 0) __PYX_ERR(0, 131, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":132
 * 
 *     ORDER_STATUS_NEW = 'NEW'
 *     ORDER_STATUS_PARTIALLY_FILLED = 'PARTIALLY_FILLED'             # <<<<<<<<<<<<<<
 *     ORDER_STATUS_FILLED = 'FILLED'
 *     ORDER_STATUS_CANCELED = 'CANCELED'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_STATUS_PARTIALLY_FILLED, __pyx_n_s_PARTIALLY_FILLED) < 0) __PYX_ERR(0, 132, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":133
 *     ORDER_STATUS_NEW = 'NEW'
 *     ORDER_STATUS_PARTIALLY_FILLED = 'PARTIALLY_FILLED'
 *     ORDER_STATUS_FILLED = 'FILLED'             # <<<<<<<<<<<<<<
 *     ORDER_STATUS_CANCELED = 'CANCELED'
 *     ORDER_STATUS_PENDING_CANCEL = 'PENDING_CANCEL'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_STATUS_FILLED, __pyx_n_s_FILLED) < 0) __PYX_ERR(0, 133, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":134
 *     ORDER_STATUS_PARTIALLY_FILLED = 'PARTIALLY_FILLED'
 *     ORDER_STATUS_FILLED = 'FILLED'
 *     ORDER_STATUS_CANCELED = 'CANCELED'             # <<<<<<<<<<<<<<
 *     ORDER_STATUS_PENDING_CANCEL = 'PENDING_CANCEL'
 *     ORDER_STATUS_REJECTED = 'REJECTED'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_STATUS_CANCELED, __pyx_n_s_CANCELED) < 0) __PYX_ERR(0, 134, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":135
 *     ORDER_STATUS_FILLED = 'FILLED'
 *     ORDER_STATUS_CANCELED = 'CANCELED'
 *     ORDER_STATUS_PENDING_CANCEL = 'PENDING_CANCEL'             # <<<<<<<<<<<<<<
 *     ORDER_STATUS_REJECTED = 'REJECTED'
 *     ORDER_STATUS_EXPIRED = 'EXPIRED'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_STATUS_PENDING_CANCEL, __pyx_n_s_PENDING_CANCEL) < 0) __PYX_ERR(0, 135, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":136
 *     ORDER_STATUS_CANCELED = 'CANCELED'
 *     ORDER_STATUS_PENDING_CANCEL = 'PENDING_CANCEL'
 *     ORDER_STATUS_REJECTED = 'REJECTED'             # <<<<<<<<<<<<<<
 *     ORDER_STATUS_EXPIRED = 'EXPIRED'
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_STATUS_REJECTED, __pyx_n_s_REJECTED) < 0) __PYX_ERR(0, 136, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":137
 *     ORDER_STATUS_PENDING_CANCEL = 'PENDING_CANCEL'
 *     ORDER_STATUS_REJECTED = 'REJECTED'
 *     ORDER_STATUS_EXPIRED = 'EXPIRED'             # <<<<<<<<<<<<<<
 * 
 *     KLINE_INTERVAL_1SECOND = '1s'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_STATUS_EXPIRED, __pyx_n_s_EXPIRED) < 0) __PYX_ERR(0, 137, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":139
 *     ORDER_STATUS_EXPIRED = 'EXPIRED'
 * 
 *     KLINE_INTERVAL_1SECOND = '1s'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_1MINUTE = '1m'
 *     KLINE_INTERVAL_3MINUTE = '3m'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_1SECOND, __pyx_kp_s_1s) < 0) __PYX_ERR(0, 139, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":140
 * 
 *     KLINE_INTERVAL_1SECOND = '1s'
 *     KLINE_INTERVAL_1MINUTE = '1m'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_3MINUTE = '3m'
 *     KLINE_INTERVAL_5MINUTE = '5m'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_1MINUTE, __pyx_kp_s_1m) < 0) __PYX_ERR(0, 140, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":141
 *     KLINE_INTERVAL_1SECOND = '1s'
 *     KLINE_INTERVAL_1MINUTE = '1m'
 *     KLINE_INTERVAL_3MINUTE = '3m'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_5MINUTE = '5m'
 *     KLINE_INTERVAL_15MINUTE = '15m'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_3MINUTE, __pyx_kp_s_3m) < 0) __PYX_ERR(0, 141, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":142
 *     KLINE_INTERVAL_1MINUTE = '1m'
 *     KLINE_INTERVAL_3MINUTE = '3m'
 *     KLINE_INTERVAL_5MINUTE = '5m'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_15MINUTE = '15m'
 *     KLINE_INTERVAL_30MINUTE = '30m'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_5MINUTE, __pyx_kp_s_5m) < 0) __PYX_ERR(0, 142, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":143
 *     KLINE_INTERVAL_3MINUTE = '3m'
 *     KLINE_INTERVAL_5MINUTE = '5m'
 *     KLINE_INTERVAL_15MINUTE = '15m'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_30MINUTE = '30m'
 *     KLINE_INTERVAL_1HOUR = '1h'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_15MINUTE, __pyx_kp_s_15m) < 0) __PYX_ERR(0, 143, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":144
 *     KLINE_INTERVAL_5MINUTE = '5m'
 *     KLINE_INTERVAL_15MINUTE = '15m'
 *     KLINE_INTERVAL_30MINUTE = '30m'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_1HOUR = '1h'
 *     KLINE_INTERVAL_2HOUR = '2h'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_30MINUTE, __pyx_kp_s_30m) < 0) __PYX_ERR(0, 144, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":145
 *     KLINE_INTERVAL_15MINUTE = '15m'
 *     KLINE_INTERVAL_30MINUTE = '30m'
 *     KLINE_INTERVAL_1HOUR = '1h'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_2HOUR = '2h'
 *     KLINE_INTERVAL_4HOUR = '4h'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_1HOUR, __pyx_kp_s_1h) < 0) __PYX_ERR(0, 145, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":146
 *     KLINE_INTERVAL_30MINUTE = '30m'
 *     KLINE_INTERVAL_1HOUR = '1h'
 *     KLINE_INTERVAL_2HOUR = '2h'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_4HOUR = '4h'
 *     KLINE_INTERVAL_6HOUR = '6h'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_2HOUR, __pyx_kp_s_2h) < 0) __PYX_ERR(0, 146, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":147
 *     KLINE_INTERVAL_1HOUR = '1h'
 *     KLINE_INTERVAL_2HOUR = '2h'
 *     KLINE_INTERVAL_4HOUR = '4h'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_6HOUR = '6h'
 *     KLINE_INTERVAL_8HOUR = '8h'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_4HOUR, __pyx_kp_s_4h) < 0) __PYX_ERR(0, 147, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":148
 *     KLINE_INTERVAL_2HOUR = '2h'
 *     KLINE_INTERVAL_4HOUR = '4h'
 *     KLINE_INTERVAL_6HOUR = '6h'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_8HOUR = '8h'
 *     KLINE_INTERVAL_12HOUR = '12h'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_6HOUR, __pyx_kp_s_6h) < 0) __PYX_ERR(0, 148, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":149
 *     KLINE_INTERVAL_4HOUR = '4h'
 *     KLINE_INTERVAL_6HOUR = '6h'
 *     KLINE_INTERVAL_8HOUR = '8h'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_12HOUR = '12h'
 *     KLINE_INTERVAL_1DAY = '1d'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_8HOUR, __pyx_kp_s_8h) < 0) __PYX_ERR(0, 149, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":150
 *     KLINE_INTERVAL_6HOUR = '6h'
 *     KLINE_INTERVAL_8HOUR = '8h'
 *     KLINE_INTERVAL_12HOUR = '12h'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_1DAY = '1d'
 *     KLINE_INTERVAL_3DAY = '3d'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_12HOUR, __pyx_kp_s_12h) < 0) __PYX_ERR(0, 150, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":151
 *     KLINE_INTERVAL_8HOUR = '8h'
 *     KLINE_INTERVAL_12HOUR = '12h'
 *     KLINE_INTERVAL_1DAY = '1d'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_3DAY = '3d'
 *     KLINE_INTERVAL_1WEEK = '1w'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_1DAY, __pyx_kp_s_1d) < 0) __PYX_ERR(0, 151, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":152
 *     KLINE_INTERVAL_12HOUR = '12h'
 *     KLINE_INTERVAL_1DAY = '1d'
 *     KLINE_INTERVAL_3DAY = '3d'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_1WEEK = '1w'
 *     KLINE_INTERVAL_1MONTH = '1M'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_3DAY, __pyx_kp_s_3d) < 0) __PYX_ERR(0, 152, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":153
 *     KLINE_INTERVAL_1DAY = '1d'
 *     KLINE_INTERVAL_3DAY = '3d'
 *     KLINE_INTERVAL_1WEEK = '1w'             # <<<<<<<<<<<<<<
 *     KLINE_INTERVAL_1MONTH = '1M'
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_1WEEK, __pyx_kp_s_1w) < 0) __PYX_ERR(0, 153, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":154
 *     KLINE_INTERVAL_3DAY = '3d'
 *     KLINE_INTERVAL_1WEEK = '1w'
 *     KLINE_INTERVAL_1MONTH = '1M'             # <<<<<<<<<<<<<<
 * 
 *     SIDE_BUY = 'BUY'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_KLINE_INTERVAL_1MONTH, __pyx_kp_s_1M) < 0) __PYX_ERR(0, 154, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":156
 *     KLINE_INTERVAL_1MONTH = '1M'
 * 
 *     SIDE_BUY = 'BUY'             # <<<<<<<<<<<<<<
 *     SIDE_SELL = 'SELL'
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SIDE_BUY, __pyx_n_s_BUY) < 0) __PYX_ERR(0, 156, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":157
 * 
 *     SIDE_BUY = 'BUY'
 *     SIDE_SELL = 'SELL'             # <<<<<<<<<<<<<<
 * 
 *     ORDER_TYPE_LIMIT = 'LIMIT'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SIDE_SELL, __pyx_n_s_SELL) < 0) __PYX_ERR(0, 157, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":159
 *     SIDE_SELL = 'SELL'
 * 
 *     ORDER_TYPE_LIMIT = 'LIMIT'             # <<<<<<<<<<<<<<
 *     ORDER_TYPE_MARKET = 'MARKET'
 *     ORDER_TYPE_STOP_LOSS = 'STOP_LOSS'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_TYPE_LIMIT, __pyx_n_s_LIMIT) < 0) __PYX_ERR(0, 159, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":160
 * 
 *     ORDER_TYPE_LIMIT = 'LIMIT'
 *     ORDER_TYPE_MARKET = 'MARKET'             # <<<<<<<<<<<<<<
 *     ORDER_TYPE_STOP_LOSS = 'STOP_LOSS'
 *     ORDER_TYPE_STOP_LOSS_LIMIT = 'STOP_LOSS_LIMIT'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_TYPE_MARKET, __pyx_n_s_MARKET) < 0) __PYX_ERR(0, 160, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":161
 *     ORDER_TYPE_LIMIT = 'LIMIT'
 *     ORDER_TYPE_MARKET = 'MARKET'
 *     ORDER_TYPE_STOP_LOSS = 'STOP_LOSS'             # <<<<<<<<<<<<<<
 *     ORDER_TYPE_STOP_LOSS_LIMIT = 'STOP_LOSS_LIMIT'
 *     ORDER_TYPE_TAKE_PROFIT = 'TAKE_PROFIT'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_TYPE_STOP_LOSS, __pyx_n_s_STOP_LOSS) < 0) __PYX_ERR(0, 161, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":162
 *     ORDER_TYPE_MARKET = 'MARKET'
 *     ORDER_TYPE_STOP_LOSS = 'STOP_LOSS'
 *     ORDER_TYPE_STOP_LOSS_LIMIT = 'STOP_LOSS_LIMIT'             # <<<<<<<<<<<<<<
 *     ORDER_TYPE_TAKE_PROFIT = 'TAKE_PROFIT'
 *     ORDER_TYPE_TAKE_PROFIT_LIMIT = 'TAKE_PROFIT_LIMIT'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_TYPE_STOP_LOSS_LIMIT, __pyx_n_s_STOP_LOSS_LIMIT) < 0) __PYX_ERR(0, 162, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":163
 *     ORDER_TYPE_STOP_LOSS = 'STOP_LOSS'
 *     ORDER_TYPE_STOP_LOSS_LIMIT = 'STOP_LOSS_LIMIT'
 *     ORDER_TYPE_TAKE_PROFIT = 'TAKE_PROFIT'             # <<<<<<<<<<<<<<
 *     ORDER_TYPE_TAKE_PROFIT_LIMIT = 'TAKE_PROFIT_LIMIT'
 *     ORDER_TYPE_LIMIT_MAKER = 'LIMIT_MAKER'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_TYPE_TAKE_PROFIT, __pyx_n_s_TAKE_PROFIT) < 0) __PYX_ERR(0, 163, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":164
 *     ORDER_TYPE_STOP_LOSS_LIMIT = 'STOP_LOSS_LIMIT'
 *     ORDER_TYPE_TAKE_PROFIT = 'TAKE_PROFIT'
 *     ORDER_TYPE_TAKE_PROFIT_LIMIT = 'TAKE_PROFIT_LIMIT'             # <<<<<<<<<<<<<<
 *     ORDER_TYPE_LIMIT_MAKER = 'LIMIT_MAKER'
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_TYPE_TAKE_PROFIT_LIMIT, __pyx_n_s_TAKE_PROFIT_LIMIT) < 0) __PYX_ERR(0, 164, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":165
 *     ORDER_TYPE_TAKE_PROFIT = 'TAKE_PROFIT'
 *     ORDER_TYPE_TAKE_PROFIT_LIMIT = 'TAKE_PROFIT_LIMIT'
 *     ORDER_TYPE_LIMIT_MAKER = 'LIMIT_MAKER'             # <<<<<<<<<<<<<<
 * 
 *     TIME_IN_FORCE_GTC = 'GTC'  # Good till cancelled
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_TYPE_LIMIT_MAKER, __pyx_n_s_LIMIT_MAKER) < 0) __PYX_ERR(0, 165, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":167
 *     ORDER_TYPE_LIMIT_MAKER = 'LIMIT_MAKER'
 * 
 *     TIME_IN_FORCE_GTC = 'GTC'  # Good till cancelled             # <<<<<<<<<<<<<<
 *     TIME_IN_FORCE_IOC = 'IOC'  # Immediate or cancel
 *     TIME_IN_FORCE_FOK = 'FOK'  # Fill or kill
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_TIME_IN_FORCE_GTC, __pyx_n_s_GTC) < 0) __PYX_ERR(0, 167, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":168
 * 
 *     TIME_IN_FORCE_GTC = 'GTC'  # Good till cancelled
 *     TIME_IN_FORCE_IOC = 'IOC'  # Immediate or cancel             # <<<<<<<<<<<<<<
 *     TIME_IN_FORCE_FOK = 'FOK'  # Fill or kill
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_TIME_IN_FORCE_IOC, __pyx_n_s_IOC) < 0) __PYX_ERR(0, 168, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":169
 *     TIME_IN_FORCE_GTC = 'GTC'  # Good till cancelled
 *     TIME_IN_FORCE_IOC = 'IOC'  # Immediate or cancel
 *     TIME_IN_FORCE_FOK = 'FOK'  # Fill or kill             # <<<<<<<<<<<<<<
 * 
 *     ORDER_RESP_TYPE_ACK = 'ACK'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_TIME_IN_FORCE_FOK, __pyx_n_s_FOK) < 0) __PYX_ERR(0, 169, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":171
 *     TIME_IN_FORCE_FOK = 'FOK'  # Fill or kill
 * 
 *     ORDER_RESP_TYPE_ACK = 'ACK'             # <<<<<<<<<<<<<<
 *     ORDER_RESP_TYPE_RESULT = 'RESULT'
 *     ORDER_RESP_TYPE_FULL = 'FULL'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_RESP_TYPE_ACK, __pyx_n_s_ACK) < 0) __PYX_ERR(0, 171, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":172
 * 
 *     ORDER_RESP_TYPE_ACK = 'ACK'
 *     ORDER_RESP_TYPE_RESULT = 'RESULT'             # <<<<<<<<<<<<<<
 *     ORDER_RESP_TYPE_FULL = 'FULL'
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_RESP_TYPE_RESULT, __pyx_n_s_RESULT) < 0) __PYX_ERR(0, 172, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":173
 *     ORDER_RESP_TYPE_ACK = 'ACK'
 *     ORDER_RESP_TYPE_RESULT = 'RESULT'
 *     ORDER_RESP_TYPE_FULL = 'FULL'             # <<<<<<<<<<<<<<
 * 
 *     # For accessing the data returned by Client.aggregate_trades().
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ORDER_RESP_TYPE_FULL, __pyx_n_s_FULL) < 0) __PYX_ERR(0, 173, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":176
 * 
 *     # For accessing the data returned by Client.aggregate_trades().
 *     AGG_ID = 'a'             # <<<<<<<<<<<<<<
 *     AGG_PRICE = 'p'
 *     AGG_QUANTITY = 'q'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_ID, __pyx_n_s_a) < 0) __PYX_ERR(0, 176, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":177
 *     # For accessing the data returned by Client.aggregate_trades().
 *     AGG_ID = 'a'
 *     AGG_PRICE = 'p'             # <<<<<<<<<<<<<<
 *     AGG_QUANTITY = 'q'
 *     AGG_FIRST_TRADE_ID = 'f'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_PRICE, __pyx_n_s_p) < 0) __PYX_ERR(0, 177, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":178
 *     AGG_ID = 'a'
 *     AGG_PRICE = 'p'
 *     AGG_QUANTITY = 'q'             # <<<<<<<<<<<<<<
 *     AGG_FIRST_TRADE_ID = 'f'
 *     AGG_LAST_TRADE_ID = 'l'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_QUANTITY, __pyx_n_s_q) < 0) __PYX_ERR(0, 178, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":179
 *     AGG_PRICE = 'p'
 *     AGG_QUANTITY = 'q'
 *     AGG_FIRST_TRADE_ID = 'f'             # <<<<<<<<<<<<<<
 *     AGG_LAST_TRADE_ID = 'l'
 *     AGG_TIME = 'T'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_FIRST_TRADE_ID, __pyx_n_s_f) < 0) __PYX_ERR(0, 179, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":180
 *     AGG_QUANTITY = 'q'
 *     AGG_FIRST_TRADE_ID = 'f'
 *     AGG_LAST_TRADE_ID = 'l'             # <<<<<<<<<<<<<<
 *     AGG_TIME = 'T'
 *     AGG_BUYER_MAKES = 'm'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_LAST_TRADE_ID, __pyx_n_s_l) < 0) __PYX_ERR(0, 180, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":181
 *     AGG_FIRST_TRADE_ID = 'f'
 *     AGG_LAST_TRADE_ID = 'l'
 *     AGG_TIME = 'T'             # <<<<<<<<<<<<<<
 *     AGG_BUYER_MAKES = 'm'
 *     AGG_BEST_MATCH = 'M'
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_TIME, __pyx_n_s_T) < 0) __PYX_ERR(0, 181, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":182
 *     AGG_LAST_TRADE_ID = 'l'
 *     AGG_TIME = 'T'
 *     AGG_BUYER_MAKES = 'm'             # <<<<<<<<<<<<<<
 *     AGG_BEST_MATCH = 'M'
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_BUYER_MAKES, __pyx_n_s_m) < 0) __PYX_ERR(0, 182, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":183
 *     AGG_TIME = 'T'
 *     AGG_BUYER_MAKES = 'm'
 *     AGG_BEST_MATCH = 'M'             # <<<<<<<<<<<<<<
 * 
 *     # new asset transfer api enum
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_AGG_BEST_MATCH, __pyx_n_s_M) < 0) __PYX_ERR(0, 183, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":186
 * 
 *     # new asset transfer api enum
 *     SPOT_TO_FIAT = "MAIN_C2C"             # <<<<<<<<<<<<<<
 *     SPOT_TO_USDT_FUTURE = "MAIN_UMFUTURE"
 *     SPOT_TO_COIN_FUTURE = "MAIN_CMFUTURE"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SPOT_TO_FIAT, __pyx_n_s_MAIN_C2C) < 0) __PYX_ERR(0, 186, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":187
 *     # new asset transfer api enum
 *     SPOT_TO_FIAT = "MAIN_C2C"
 *     SPOT_TO_USDT_FUTURE = "MAIN_UMFUTURE"             # <<<<<<<<<<<<<<
 *     SPOT_TO_COIN_FUTURE = "MAIN_CMFUTURE"
 *     SPOT_TO_MARGIN_CROSS = "MAIN_MARGIN"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SPOT_TO_USDT_FUTURE, __pyx_n_s_MAIN_UMFUTURE) < 0) __PYX_ERR(0, 187, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":188
 *     SPOT_TO_FIAT = "MAIN_C2C"
 *     SPOT_TO_USDT_FUTURE = "MAIN_UMFUTURE"
 *     SPOT_TO_COIN_FUTURE = "MAIN_CMFUTURE"             # <<<<<<<<<<<<<<
 *     SPOT_TO_MARGIN_CROSS = "MAIN_MARGIN"
 *     SPOT_TO_MINING = "MAIN_MINING"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SPOT_TO_COIN_FUTURE, __pyx_n_s_MAIN_CMFUTURE) < 0) __PYX_ERR(0, 188, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":189
 *     SPOT_TO_USDT_FUTURE = "MAIN_UMFUTURE"
 *     SPOT_TO_COIN_FUTURE = "MAIN_CMFUTURE"
 *     SPOT_TO_MARGIN_CROSS = "MAIN_MARGIN"             # <<<<<<<<<<<<<<
 *     SPOT_TO_MINING = "MAIN_MINING"
 *     FIAT_TO_SPOT = "C2C_MAIN"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SPOT_TO_MARGIN_CROSS, __pyx_n_s_MAIN_MARGIN) < 0) __PYX_ERR(0, 189, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":190
 *     SPOT_TO_COIN_FUTURE = "MAIN_CMFUTURE"
 *     SPOT_TO_MARGIN_CROSS = "MAIN_MARGIN"
 *     SPOT_TO_MINING = "MAIN_MINING"             # <<<<<<<<<<<<<<
 *     FIAT_TO_SPOT = "C2C_MAIN"
 *     FIAT_TO_USDT_FUTURE = "C2C_UMFUTURE"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_SPOT_TO_MINING, __pyx_n_s_MAIN_MINING) < 0) __PYX_ERR(0, 190, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":191
 *     SPOT_TO_MARGIN_CROSS = "MAIN_MARGIN"
 *     SPOT_TO_MINING = "MAIN_MINING"
 *     FIAT_TO_SPOT = "C2C_MAIN"             # <<<<<<<<<<<<<<
 *     FIAT_TO_USDT_FUTURE = "C2C_UMFUTURE"
 *     FIAT_TO_MINING = "C2C_MINING"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FIAT_TO_SPOT, __pyx_n_s_C2C_MAIN) < 0) __PYX_ERR(0, 191, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":192
 *     SPOT_TO_MINING = "MAIN_MINING"
 *     FIAT_TO_SPOT = "C2C_MAIN"
 *     FIAT_TO_USDT_FUTURE = "C2C_UMFUTURE"             # <<<<<<<<<<<<<<
 *     FIAT_TO_MINING = "C2C_MINING"
 *     USDT_FUTURE_TO_SPOT = "UMFUTURE_MAIN"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FIAT_TO_USDT_FUTURE, __pyx_n_s_C2C_UMFUTURE) < 0) __PYX_ERR(0, 192, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":193
 *     FIAT_TO_SPOT = "C2C_MAIN"
 *     FIAT_TO_USDT_FUTURE = "C2C_UMFUTURE"
 *     FIAT_TO_MINING = "C2C_MINING"             # <<<<<<<<<<<<<<
 *     USDT_FUTURE_TO_SPOT = "UMFUTURE_MAIN"
 *     USDT_FUTURE_TO_FIAT = "UMFUTURE_C2C"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_FIAT_TO_MINING, __pyx_n_s_C2C_MINING) < 0) __PYX_ERR(0, 193, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":194
 *     FIAT_TO_USDT_FUTURE = "C2C_UMFUTURE"
 *     FIAT_TO_MINING = "C2C_MINING"
 *     USDT_FUTURE_TO_SPOT = "UMFUTURE_MAIN"             # <<<<<<<<<<<<<<
 *     USDT_FUTURE_TO_FIAT = "UMFUTURE_C2C"
 *     USDT_FUTURE_TO_MARGIN_CROSS = "UMFUTURE_MARGIN"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_USDT_FUTURE_TO_SPOT, __pyx_n_s_UMFUTURE_MAIN) < 0) __PYX_ERR(0, 194, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":195
 *     FIAT_TO_MINING = "C2C_MINING"
 *     USDT_FUTURE_TO_SPOT = "UMFUTURE_MAIN"
 *     USDT_FUTURE_TO_FIAT = "UMFUTURE_C2C"             # <<<<<<<<<<<<<<
 *     USDT_FUTURE_TO_MARGIN_CROSS = "UMFUTURE_MARGIN"
 *     COIN_FUTURE_TO_SPOT = "CMFUTURE_MAIN"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_USDT_FUTURE_TO_FIAT, __pyx_n_s_UMFUTURE_C2C) < 0) __PYX_ERR(0, 195, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":196
 *     USDT_FUTURE_TO_SPOT = "UMFUTURE_MAIN"
 *     USDT_FUTURE_TO_FIAT = "UMFUTURE_C2C"
 *     USDT_FUTURE_TO_MARGIN_CROSS = "UMFUTURE_MARGIN"             # <<<<<<<<<<<<<<
 *     COIN_FUTURE_TO_SPOT = "CMFUTURE_MAIN"
 *     MARGIN_CROSS_TO_SPOT = "MARGIN_MAIN"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_USDT_FUTURE_TO_MARGIN_CROSS, __pyx_n_s_UMFUTURE_MARGIN) < 0) __PYX_ERR(0, 196, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":197
 *     USDT_FUTURE_TO_FIAT = "UMFUTURE_C2C"
 *     USDT_FUTURE_TO_MARGIN_CROSS = "UMFUTURE_MARGIN"
 *     COIN_FUTURE_TO_SPOT = "CMFUTURE_MAIN"             # <<<<<<<<<<<<<<
 *     MARGIN_CROSS_TO_SPOT = "MARGIN_MAIN"
 *     MARGIN_CROSS_TO_USDT_FUTURE = "MARGIN_UMFUTURE"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_COIN_FUTURE_TO_SPOT, __pyx_n_s_CMFUTURE_MAIN) < 0) __PYX_ERR(0, 197, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":198
 *     USDT_FUTURE_TO_MARGIN_CROSS = "UMFUTURE_MARGIN"
 *     COIN_FUTURE_TO_SPOT = "CMFUTURE_MAIN"
 *     MARGIN_CROSS_TO_SPOT = "MARGIN_MAIN"             # <<<<<<<<<<<<<<
 *     MARGIN_CROSS_TO_USDT_FUTURE = "MARGIN_UMFUTURE"
 *     MINING_TO_SPOT = "MINING_MAIN"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_MARGIN_CROSS_TO_SPOT, __pyx_n_s_MARGIN_MAIN) < 0) __PYX_ERR(0, 198, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":199
 *     COIN_FUTURE_TO_SPOT = "CMFUTURE_MAIN"
 *     MARGIN_CROSS_TO_SPOT = "MARGIN_MAIN"
 *     MARGIN_CROSS_TO_USDT_FUTURE = "MARGIN_UMFUTURE"             # <<<<<<<<<<<<<<
 *     MINING_TO_SPOT = "MINING_MAIN"
 *     MINING_TO_USDT_FUTURE = "MINING_UMFUTURE"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_MARGIN_CROSS_TO_USDT_FUTURE, __pyx_n_s_MARGIN_UMFUTURE) < 0) __PYX_ERR(0, 199, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":200
 *     MARGIN_CROSS_TO_SPOT = "MARGIN_MAIN"
 *     MARGIN_CROSS_TO_USDT_FUTURE = "MARGIN_UMFUTURE"
 *     MINING_TO_SPOT = "MINING_MAIN"             # <<<<<<<<<<<<<<
 *     MINING_TO_USDT_FUTURE = "MINING_UMFUTURE"
 *     MINING_TO_FIAT = "MINING_C2C"
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_MINING_TO_SPOT, __pyx_n_s_MINING_MAIN) < 0) __PYX_ERR(0, 200, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":201
 *     MARGIN_CROSS_TO_USDT_FUTURE = "MARGIN_UMFUTURE"
 *     MINING_TO_SPOT = "MINING_MAIN"
 *     MINING_TO_USDT_FUTURE = "MINING_UMFUTURE"             # <<<<<<<<<<<<<<
 *     MINING_TO_FIAT = "MINING_C2C"
 * 
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_MINING_TO_USDT_FUTURE, __pyx_n_s_MINING_UMFUTURE) < 0) __PYX_ERR(0, 201, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":202
 *     MINING_TO_SPOT = "MINING_MAIN"
 *     MINING_TO_USDT_FUTURE = "MINING_UMFUTURE"
 *     MINING_TO_FIAT = "MINING_C2C"             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self,
 */
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_MINING_TO_FIAT, __pyx_n_s_MINING_C2C) < 0) __PYX_ERR(0, 202, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":204
 *     MINING_TO_FIAT = "MINING_C2C"
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  api_key=None,
 *                  api_secret=None,
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_socks5_proxy_server, __pyx_kp_s_Optional_str) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_socks5_proxy_user, __pyx_kp_s_Optional_str) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_socks5_proxy_pass, __pyx_kp_s_Optional_str) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_socks5_proxy_ssl_verification, __pyx_kp_s_Optional_bool) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_lucit_api_secret, __pyx_n_s_str) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_lucit_license_ini, __pyx_n_s_str) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_lucit_license_profile, __pyx_n_s_str) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_lucit_license_token, __pyx_n_s_str) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_1__init__, 0, __pyx_n_s_BinanceRestApiManager___init, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__191)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__192);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_init_2, __pyx_t_6) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":421
 *             logger.warning(update_msg)
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Entering 'with-context' ...")
 *         return self
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_3__enter__, 0, __pyx_n_s_BinanceRestApiManager___enter, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__194)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_enter, __pyx_t_6) < 0) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":425
 *         return self
 * 
 *     def __exit__(self, exc_type, exc_value, error_traceback):             # <<<<<<<<<<<<<<
 *         logger.debug(f"Leaving 'with-context' ...")
 *         self.stop_manager()
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_5__exit__, 0, __pyx_n_s_BinanceRestApiManager___exit, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__196)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_exit, __pyx_t_6) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":431
 *             logger.critical(f"An exception occurred: {exc_type} - {exc_value} - {error_traceback}")
 * 
 *     def _init_session(self):             # <<<<<<<<<<<<<<
 *         session = requests.session()
 *         session.headers.update({'Accept': 'application/json',
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_7_init_session, 0, __pyx_n_s_BinanceRestApiManager__init_sess, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__198)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_init_session, __pyx_t_6) < 0) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":438
 *         return session
 * 
 *     def _create_api_uri(self, path, signed=True, version=PUBLIC_API_VERSION):             # <<<<<<<<<<<<<<
 *         v = self.PRIVATE_API_VERSION if signed else version
 *         return self.API_URL + '/' + v + '/' + path
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_9_create_api_uri, 0, __pyx_n_s_BinanceRestApiManager__create_ap, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__200)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults), 1)) __PYX_ERR(0, 438, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_PUBLIC_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PUBLIC_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager___defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_api_uri, __pyx_t_6) < 0) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":442
 *         return self.API_URL + '/' + v + '/' + path
 * 
 *     def _create_margin_api_uri(self, path, version=MARGIN_API_VERSION):             # <<<<<<<<<<<<<<
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_11_create_margin_api_uri, 0, __pyx_n_s_BinanceRestApiManager__create_ma, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__202)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults1), 1)) __PYX_ERR(0, 442, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_MARGIN_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_MARGIN_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_2__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_margin_api_uri, __pyx_t_6) < 0) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":445
 *         return self.MARGIN_API_URL + '/' + version + '/' + path
 * 
 *     def _create_website_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.WEBSITE_URL + '/' + path
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_13_create_website_uri, 0, __pyx_n_s_BinanceRestApiManager__create_we, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__204)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_website_uri, __pyx_t_6) < 0) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":448
 *         return self.WEBSITE_URL + '/' + path
 * 
 *     def _create_futures_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_15_create_futures_api_uri, 0, __pyx_n_s_BinanceRestApiManager__create_fu, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__205)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_futures_api_uri, __pyx_t_6) < 0) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":451
 *         return self.FUTURES_URL + '/' + self.FUTURES_API_VERSION + '/' + path
 * 
 *     def _create_futures_data_api_uri(self, path):             # <<<<<<<<<<<<<<
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_17_create_futures_data_api_uri, 0, __pyx_n_s_BinanceRestApiManager__create_fu_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__206)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_futures_data_api_uri, __pyx_t_6) < 0) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":454
 *         return self.FUTURES_DATA_URL + '/' + path
 * 
 *     def _create_futures_coin_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         options = {1: self.FUTURES_API_VERSION, 2: self.FUTURES_API_VERSION2}
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_19_create_futures_coin_api_url, 0, __pyx_n_s_BinanceRestApiManager__create_fu_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__208)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__209);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_futures_coin_api_url, __pyx_t_6) < 0) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":458
 *         return self.FUTURES_COIN_URL + "/" + options[version] + "/" + path
 * 
 *     def _create_futures_coin_data_api_url(self, path, version=1):             # <<<<<<<<<<<<<<
 *         # Todo: version is obsolete?
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_21_create_futures_coin_data_api_url, 0, __pyx_n_s_BinanceRestApiManager__create_fu_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__210)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__209);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_futures_coin_data_api_ur, __pyx_t_6) < 0) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":462
 *         return self.FUTURES_COIN_DATA_URL + "/" + path
 * 
 *     def _generate_signature(self, data):             # <<<<<<<<<<<<<<
 * 
 *         ordered_data = self._order_params(data)
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_23_generate_signature, 0, __pyx_n_s_BinanceRestApiManager__generate, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__212)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_generate_signature, __pyx_t_6) < 0) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":469
 *         return m.hexdigest()
 * 
 *     def _order_params(self, data):             # <<<<<<<<<<<<<<
 *         """
 *         Convert params to list with signature as last element
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_25_order_params, 0, __pyx_n_s_BinanceRestApiManager__order_par, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__214)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_params, __pyx_t_6) < 0) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":490
 *         return params
 * 
 *     def _request(self, method, uri, signed, force_params=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 * 
 *         # set default requests timeout
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_27_request, 0, __pyx_n_s_BinanceRestApiManager__request, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__216)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__217);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request, __pyx_t_6) < 0) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":538
 *         return self._handle_response(throw_exception=throw_exception)
 * 
 *     def _request_api(self, method, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_api_uri(path, signed, version)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_29_request_api, 0, __pyx_n_s_BinanceRestApiManager__request_a, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__219)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults2), 1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_PUBLIC_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PUBLIC_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_4__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request_api, __pyx_t_6) < 0) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":543
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_margin_api(self, method, path, signed=False,             # <<<<<<<<<<<<<<
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):
 *         uri = self._create_margin_api_uri(path, version)
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_31_request_margin_api, 0, __pyx_n_s_BinanceRestApiManager__request_m, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__220)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults3), 1)) __PYX_ERR(0, 543, __pyx_L1_error)

  /* "unicorn_binance_rest_api/manager.py":544
 * 
 *     def _request_margin_api(self, method, path, signed=False,
 *                             version=MARGIN_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_margin_api_uri(path, version)
 * 
 */
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_MARGIN_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_MARGIN_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_6__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request_margin_api, __pyx_t_6) < 0) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":549
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_website(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_website_uri(path)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_33_request_website, 0, __pyx_n_s_BinanceRestApiManager__request_w, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__222)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__217);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request_website, __pyx_t_6) < 0) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":554
 *         return self._request(method, uri, signed, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_api_uri(path)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_35_request_futures_api, 0, __pyx_n_s_BinanceRestApiManager__request_f, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__223)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__217);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request_futures_api, __pyx_t_6) < 0) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":559
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_data_api(self, method, path, signed=False, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_data_api_uri(path)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_37_request_futures_data_api, 0, __pyx_n_s_BinanceRestApiManager__request_f_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__224)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__217);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request_futures_data_api, __pyx_t_6) < 0) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":564
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_api_url(path, version=version)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_39_request_futures_coin_api, 0, __pyx_n_s_BinanceRestApiManager__request_f_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__225)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__226);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request_futures_coin_api, __pyx_t_6) < 0) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":569
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _request_futures_coin_data_api(self, method, path, signed=False, version=1, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         uri = self._create_futures_coin_data_api_url(path, version=version)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_41_request_futures_coin_data_api, 0, __pyx_n_s_BinanceRestApiManager__request_f_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__227)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__226);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_request_futures_coin_data_api, __pyx_t_6) < 0) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":574
 *         return self._request(method, uri, signed, True, throw_exception=throw_exception, **kwargs)
 * 
 *     def _handle_response(self, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """
 *         Internal helper for handling API responses from the Binance server.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_43_handle_response, 0, __pyx_n_s_BinanceRestApiManager__handle_re, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__229)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_handle_response, __pyx_t_6) < 0) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":589
 *             raise BinanceRequestException('Invalid Response: %s' % self.response.text)
 * 
 *     def _get(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_45_get, 0, __pyx_n_s_BinanceRestApiManager__get, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__232)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults4), 1)) __PYX_ERR(0, 589, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_PUBLIC_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PUBLIC_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_8__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_2, __pyx_t_6) < 0) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":592
 *         return self._request_api('get', path, signed, version, **kwargs)
 * 
 *     def _post(self, path, signed=False, version=PUBLIC_API_VERSION, throw_exception=True, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_47_post, 0, __pyx_n_s_BinanceRestApiManager__post, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__234)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults5), 1)) __PYX_ERR(0, 592, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_PUBLIC_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PUBLIC_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_10__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_post_2, __pyx_t_6) < 0) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":595
 *         return self._request_api('post', path, signed, version, throw_exception, **kwargs)
 * 
 *     def _put(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_49_put, 0, __pyx_n_s_BinanceRestApiManager__put, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__235)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults6), 1)) __PYX_ERR(0, 595, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_PUBLIC_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PUBLIC_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_12__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_put_2, __pyx_t_6) < 0) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":598
 *         return self._request_api('put', path, signed, version, **kwargs)
 * 
 *     def _delete(self, path, signed=False, version=PUBLIC_API_VERSION, **kwargs):             # <<<<<<<<<<<<<<
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_51_delete, 0, __pyx_n_s_BinanceRestApiManager__delete, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__236)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults7), 1)) __PYX_ERR(0, 598, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_PUBLIC_API_VERSION);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_PUBLIC_API_VERSION);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_t_6)->__pyx_arg_version = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_14__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_delete_2, __pyx_t_6) < 0) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":601
 *         return self._request_api('delete', path, signed, version, **kwargs)
 * 
 *     def is_update_availabe(self):             # <<<<<<<<<<<<<<
 *         """
 *         Is a new release of this package available?
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_53is_update_availabe, 0, __pyx_n_s_BinanceRestApiManager_is_update, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__238)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_is_update_availabe, __pyx_t_6) < 0) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":617
 *             return True
 * 
 *     def get_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the package/module version
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_55get_version, 0, __pyx_n_s_BinanceRestApiManager_get_versio, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__239)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_version, __pyx_t_6) < 0) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":625
 *         return self.version
 * 
 *     def get_latest_version(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the version of the latest available release (cache time 1 hour)
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_57get_latest_version, 0, __pyx_n_s_BinanceRestApiManager_get_latest, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__240)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_latest_version, __pyx_t_6) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":642
 *             return "unknown"
 * 
 *     def get_latest_release_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get infos about the latest available release
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_59get_latest_release_info, 0, __pyx_n_s_BinanceRestApiManager_get_latest_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__242)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_latest_release_info, __pyx_t_6) < 0) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":661
 *             return False
 * 
 *     def get_user_agent(self):             # <<<<<<<<<<<<<<
 *         """
 *         Get the user_agent string "lib name + lib version + python version"
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_61get_user_agent, 0, __pyx_n_s_BinanceRestApiManager_get_user_a, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__244)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_user_agent, __pyx_t_6) < 0) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":671
 * 
 *     # Exchange Endpoints
 *     def get_products(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return list of products currently listed on Binance
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_63get_products, 0, __pyx_n_s_BinanceRestApiManager_get_produc, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__246)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_products, __pyx_t_6) < 0) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":685
 *         return products
 * 
 *     def get_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return rate limits and list of symbols
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_65get_exchange_info, 0, __pyx_n_s_BinanceRestApiManager_get_exchan, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__247)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_exchange_info, __pyx_t_6) < 0) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":750
 *         return self._get('exchangeInfo', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_info(self, symbol):             # <<<<<<<<<<<<<<
 *         """
 *         Return information about a symbol
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_67get_symbol_info, 0, __pyx_n_s_BinanceRestApiManager_get_symbol, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__249)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_symbol_info, __pyx_t_6) < 0) __PYX_ERR(0, 750, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":802
 *     # General Endpoints
 * 
 *     def ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_69ping, 0, __pyx_n_s_BinanceRestApiManager_ping, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__250)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_ping, __pyx_t_6) < 0) __PYX_ERR(0, 802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":819
 *         return self._get('ping', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_server_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_71get_server_time, 0, __pyx_n_s_BinanceRestApiManager_get_server, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__251)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_server_time, __pyx_t_6) < 0) __PYX_ERR(0, 819, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":840
 *     # Market Data Endpoints
 * 
 *     def get_all_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for all symbols.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_73get_all_tickers, 0, __pyx_n_s_BinanceRestApiManager_get_all_ti, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__252)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_all_tickers, __pyx_t_6) < 0) __PYX_ERR(0, 840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":866
 *         return self._get('ticker/price', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_tickers(self):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for all symbols.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_75get_orderbook_tickers, 0, __pyx_n_s_BinanceRestApiManager_get_orderb, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__253)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_orderbook_tickers, __pyx_t_6) < 0) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":898
 *         return self._get('ticker/bookTicker', version=self.PRIVATE_API_VERSION)
 * 
 *     def get_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_77get_order_book, 0, __pyx_n_s_BinanceRestApiManager_get_order, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__255)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_order_book, __pyx_t_6) < 0) __PYX_ERR(0, 898, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":936
 *         return self._get('depth', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get recent trades (up to last 500).
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_79get_recent_trades, 0, __pyx_n_s_BinanceRestApiManager_get_recent, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__256)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_recent_trades, __pyx_t_6) < 0) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":967
 *         return self._get('trades', data=params)
 * 
 *     def get_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older trades.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_81get_historical_trades, 0, __pyx_n_s_BinanceRestApiManager_get_histor_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__257)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_historical_trades, __pyx_t_6) < 0) __PYX_ERR(0, 967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1000
 *         return self._get('historicalTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time,
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_83get_aggregate_trades, 0, __pyx_n_s_BinanceRestApiManager_get_aggreg, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__258)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_aggregate_trades, __pyx_t_6) < 0) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1039
 *         return self._get('aggTrades', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def aggregate_trade_iter(self, symbol, start_str=None, last_id=None):             # <<<<<<<<<<<<<<
 *         """
 *         Iterate over aggregate trade data from (start_time or last_id) to
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_85aggregate_trade_iter, 0, __pyx_n_s_BinanceRestApiManager_aggregate, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__22)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__260);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_aggregate_trade_iter, __pyx_t_6) < 0) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1128
 *             last_id = trades[-1][self.AGG_ID]
 * 
 *     def get_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_88get_klines, 0, __pyx_n_s_BinanceRestApiManager_get_klines, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__261)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_klines, __pyx_t_6) < 0) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1171
 *         return self._get('klines', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def _get_earliest_valid_timestamp(self, symbol, interval):             # <<<<<<<<<<<<<<
 *         """
 *         Get the earliest valid open timestamp from Binance
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_90_get_earliest_valid_timestamp, 0, __pyx_n_s_BinanceRestApiManager__get_earli, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__263)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_earliest_valid_timestamp, __pyx_t_6) < 0) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1192
 *         return kline[0][0]
 * 
 *     def get_historical_klines(self, symbol, interval, start_str, end_str=None,             # <<<<<<<<<<<<<<
 *                               limit=500):
 *         """
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_92get_historical_klines, 0, __pyx_n_s_BinanceRestApiManager_get_histor_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__265)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__266);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_historical_klines, __pyx_t_6) < 0) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1276
 *         return output_data
 * 
 *     def get_historical_klines_generator(self, symbol, interval, start_str, end_str=None):             # <<<<<<<<<<<<<<
 *         """
 *         Get Historical Klines from Binance
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_94get_historical_klines_generator, 0, __pyx_n_s_BinanceRestApiManager_get_histor, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__26)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__268);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_historical_klines_generator, __pyx_t_6) < 0) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1357
 *                 time.sleep(1)
 * 
 *     def get_avg_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Current average price for a symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_97get_avg_price, 0, __pyx_n_s_BinanceRestApiManager_get_avg_pr, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__269)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_avg_price, __pyx_t_6) < 0) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1376
 *         return self._get('avgPrice', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour price change statistics.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_99get_ticker, 0, __pyx_n_s_BinanceRestApiManager_get_ticker, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__270)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 1376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1437
 *         return self._get('ticker/24hr', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_101get_symbol_ticker, 0, __pyx_n_s_BinanceRestApiManager_get_symbol_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__271)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_symbol_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1474
 *         return self._get('ticker/price', data=params, version=self.PRIVATE_API_VERSION)
 * 
 *     def get_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_103get_orderbook_ticker, 0, __pyx_n_s_BinanceRestApiManager_get_orderb_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_orderbook_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 1474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1522
 *     # Account Endpoints
 * 
 *     def create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_105create_order, 0, __pyx_n_s_BinanceRestApiManager_create_ord, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__273)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_order, __pyx_t_6) < 0) __PYX_ERR(0, 1522, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1640
 *         return self._post('order', True, data=params)
 * 
 *     def order_limit(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_107order_limit, 0, __pyx_n_s_BinanceRestApiManager_order_limi, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__275)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults8), 1)) __PYX_ERR(0, 1640, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_TIME_IN_FORCE_GTC);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_TIME_IN_FORCE_GTC);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_t_6)->__pyx_arg_timeInForce = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_16__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_limit, __pyx_t_6) < 0) __PYX_ERR(0, 1640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1679
 *         return self.create_order(**params)
 * 
 *     def order_limit_buy(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit buy order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_109order_limit_buy, 0, __pyx_n_s_BinanceRestApiManager_order_limi_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__276)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults9), 1)) __PYX_ERR(0, 1679, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_TIME_IN_FORCE_GTC);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_TIME_IN_FORCE_GTC);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_t_6)->__pyx_arg_timeInForce = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_18__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_limit_buy, __pyx_t_6) < 0) __PYX_ERR(0, 1679, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1717
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_limit_sell(self, timeInForce=TIME_IN_FORCE_GTC, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new limit sell order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_111order_limit_sell, 0, __pyx_n_s_BinanceRestApiManager_order_limi_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__277)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_6, sizeof(__pyx_defaults10), 1)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_TIME_IN_FORCE_GTC);
  if (unlikely(!__pyx_t_5)) {
    PyErr_Clear();
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_TIME_IN_FORCE_GTC);
  }
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_t_6)->__pyx_arg_timeInForce = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_6, __pyx_pf_24unicorn_binance_rest_api_7manager_20__defaults__);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_limit_sell, __pyx_t_6) < 0) __PYX_ERR(0, 1717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1753
 *         return self.order_limit(timeInForce=timeInForce, **params)
 * 
 *     def order_market(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_113order_market, 0, __pyx_n_s_BinanceRestApiManager_order_mark, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__278)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_market, __pyx_t_6) < 0) __PYX_ERR(0, 1753, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1786
 *         return self.create_order(**params)
 * 
 *     def order_market_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market buy order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_115order_market_buy, 0, __pyx_n_s_BinanceRestApiManager_order_mark_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__279)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_market_buy, __pyx_t_6) < 0) __PYX_ERR(0, 1786, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1816
 *         return self.order_market(**params)
 * 
 *     def order_market_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new market sell order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_117order_market_sell, 0, __pyx_n_s_BinanceRestApiManager_order_mark_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__280)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_market_sell, __pyx_t_6) < 0) __PYX_ERR(0, 1816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1846
 *         return self.order_market(**params)
 * 
 *     def create_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_119create_oco_order, 0, __pyx_n_s_BinanceRestApiManager_create_oco, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__281)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_oco_order, __pyx_t_6) < 0) __PYX_ERR(0, 1846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1910
 *         return self._post('order/oco', True, data=params)
 * 
 *     def order_oco_buy(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO buy order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_121order_oco_buy, 0, __pyx_n_s_BinanceRestApiManager_order_oco, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_oco_buy, __pyx_t_6) < 0) __PYX_ERR(0, 1910, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1954
 *         return self.create_oco_order(**params)
 * 
 *     def order_oco_sell(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new OCO sell order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_123order_oco_sell, 0, __pyx_n_s_BinanceRestApiManager_order_oco_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__283)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_order_oco_sell, __pyx_t_6) < 0) __PYX_ERR(0, 1954, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":1997
 *         return self.create_oco_order(**params)
 * 
 *     def create_test_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Test new order creation and signature/recvWindow long. Creates and validates a new order but does not send
 *         it into the matching engine.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_125create_test_order, 0, __pyx_n_s_BinanceRestApiManager_create_tes, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__284)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_test_order, __pyx_t_6) < 0) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2038
 *         return self._post('order/test', True, data=params)
 * 
 *     def get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Check an order's status. Either orderId or origClientOrderId must be sent.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_127get_order, 0, __pyx_n_s_BinanceRestApiManager_get_order_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__285)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_order, __pyx_t_6) < 0) __PYX_ERR(0, 2038, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2077
 *         return self._get('order', True, data=params)
 * 
 *     def get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all account orders; active, canceled, or filled.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_129get_all_orders, 0, __pyx_n_s_BinanceRestApiManager_get_all_or, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__286)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_all_orders, __pyx_t_6) < 0) __PYX_ERR(0, 2077, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2118
 *         return self._get('allOrders', True, data=params)
 * 
 *     def cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open orders of a symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_131cancel_all_open_orders, 0, __pyx_n_s_BinanceRestApiManager_cancel_all, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__287)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_cancel_all_open_orders, __pyx_t_6) < 0) __PYX_ERR(0, 2118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2231
 *         return self._delete('openOrders', True, data=params)
 * 
 *     def cancel_all_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel all open margin orders of a symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_133cancel_all_open_margin_orders, 0, __pyx_n_s_BinanceRestApiManager_cancel_all_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__288)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_cancel_all_open_margin_orders, __pyx_t_6) < 0) __PYX_ERR(0, 2231, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2340
 *         return self._request_margin_api('delete', 'margin/openOrders', signed=True, data=params)
 * 
 *     def cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an active order. Either orderId or origClientOrderId must be sent.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_135cancel_order, 0, __pyx_n_s_BinanceRestApiManager_cancel_ord, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__289)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_cancel_order, __pyx_t_6) < 0) __PYX_ERR(0, 2340, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2372
 *         return self._delete('order', True, data=params)
 * 
 *     def get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all open orders on a symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_137get_open_orders, 0, __pyx_n_s_BinanceRestApiManager_get_open_o, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__290)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_open_orders, __pyx_t_6) < 0) __PYX_ERR(0, 2372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2410
 * 
 *     # User Stream Endpoints
 *     def get_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get current account information.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_139get_account, 0, __pyx_n_s_BinanceRestApiManager_get_accoun, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__291)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_account, __pyx_t_6) < 0) __PYX_ERR(0, 2410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2449
 *         return self._get('account', True, data=params)
 * 
 *     def get_asset_balance(self, asset, **params):             # <<<<<<<<<<<<<<
 *         """Get current asset balance.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_141get_asset_balance, 0, __pyx_n_s_BinanceRestApiManager_get_asset, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__293)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_asset_balance, __pyx_t_6) < 0) __PYX_ERR(0, 2449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2480
 *         return None
 * 
 *     def get_my_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for a specific symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_143get_my_trades, 0, __pyx_n_s_BinanceRestApiManager_get_my_tra, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__294)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_my_trades, __pyx_t_6) < 0) __PYX_ERR(0, 2480, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2517
 *         return self._get('myTrades', True, data=params)
 * 
 *     def get_system_status(self):             # <<<<<<<<<<<<<<
 *         """Get system status detail.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_145get_system_status, 0, __pyx_n_s_BinanceRestApiManager_get_system, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__295)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_system_status, __pyx_t_6) < 0) __PYX_ERR(0, 2517, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2536
 *         return self._request_margin_api('get', 'system/status')
 * 
 *     def get_account_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get account status detail.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_147get_account_status, 0, __pyx_n_s_BinanceRestApiManager_get_accoun_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__297)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_account_status, __pyx_t_6) < 0) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2560
 *         return res
 * 
 *     def get_account_api_trading_status(self, **params):             # <<<<<<<<<<<<<<
 *         r"""Fetch account api trading status detail.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_149get_account_api_trading_status, 0, __pyx_n_s_BinanceRestApiManager_get_accoun_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__298)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_account_api_trading_status, __pyx_t_6) < 0) __PYX_ERR(0, 2560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2635
 *         return res
 * 
 *     def get_dust_log(self, **params):             # <<<<<<<<<<<<<<
 *         """Get log of small amounts exchanged for BNB.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_151get_dust_log, 0, __pyx_n_s_BinanceRestApiManager_get_dust_l, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__299)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_dust_log, __pyx_t_6) < 0) __PYX_ERR(0, 2635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2712
 *         return res
 * 
 *     def transfer_dust(self, **params):             # <<<<<<<<<<<<<<
 *         """Convert dust assets to BNB.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_153transfer_dust, 0, __pyx_n_s_BinanceRestApiManager_transfer_d, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__300)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_transfer_dust, __pyx_t_6) < 0) __PYX_ERR(0, 2712, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2751
 *         return self._request_margin_api('post', 'asset/dust', True, data=params)
 * 
 *     def get_asset_dividend_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query asset dividend record.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_155get_asset_dividend_history, 0, __pyx_n_s_BinanceRestApiManager_get_asset_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__301)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_asset_dividend_history, __pyx_t_6) < 0) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2799
 *         return self._request_margin_api('get', 'asset/assetDividend', True, data=params)
 * 
 *     def query_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query User Universal Transfer History
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_157query_universal_transfer_history, 0, __pyx_n_s_BinanceRestApiManager_query_univ, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__302)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_query_universal_transfer_history, __pyx_t_6) < 0) __PYX_ERR(0, 2799, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2854
 *         return self._request_margin_api('get', 'asset/transfer', signed=True, data=params)
 * 
 *     def get_trade_fee(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trade fee.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_159get_trade_fee, 0, __pyx_n_s_BinanceRestApiManager_get_trade, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__303)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_trade_fee, __pyx_t_6) < 0) __PYX_ERR(0, 2854, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2889
 *         return res
 * 
 *     def get_asset_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch details on assets.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_161get_asset_details, 0, __pyx_n_s_BinanceRestApiManager_get_asset_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__304)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_asset_details, __pyx_t_6) < 0) __PYX_ERR(0, 2889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2930
 *     # Withdraw Endpoints
 * 
 *     def withdraw(self, **params):             # <<<<<<<<<<<<<<
 *         """Submit a withdraw request.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_163withdraw, 0, __pyx_n_s_BinanceRestApiManager_withdraw, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__305)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_withdraw, __pyx_t_6) < 0) __PYX_ERR(0, 2930, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":2979
 *         return res
 * 
 *     def get_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch deposit history.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_165get_deposit_history, 0, __pyx_n_s_BinanceRestApiManager_get_deposi, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__306)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_deposit_history, __pyx_t_6) < 0) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3035
 *         return self._request_margin_api('get', 'capital/deposit/hisrec', True, data=params)
 * 
 *     def get_withdraw_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_167get_withdraw_history, 0, __pyx_n_s_BinanceRestApiManager_get_withdr, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__307)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_withdraw_history, __pyx_t_6) < 0) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3091
 *         return self._request_margin_api('get', 'capital/withdraw/history', True, data=params)
 * 
 *     def get_withdraw_history_id(self, withdraw_id, **params):             # <<<<<<<<<<<<<<
 *         """Fetch withdraw history.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_169get_withdraw_history_id, 0, __pyx_n_s_BinanceRestApiManager_get_withdr_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__309)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_withdraw_history_id, __pyx_t_6) < 0) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3137
 *         raise Exception("There is no entry with withdraw id", result)
 * 
 *     def get_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch a deposit address for a symbol
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_171get_deposit_address, 0, __pyx_n_s_BinanceRestApiManager_get_deposi_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__310)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_deposit_address, __pyx_t_6) < 0) __PYX_ERR(0, 3137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3167
 *     # User Stream Endpoints
 * 
 *     def stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new user data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_173stream_get_listen_key, 0, __pyx_n_s_BinanceRestApiManager_stream_get, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__312)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__313);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_stream_get_listen_key, __pyx_t_6) < 0) __PYX_ERR(0, 3167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3201
 *             return res['listenKey']
 * 
 *     def stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a user data stream to prevent a time out.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_175stream_keepalive, 0, __pyx_n_s_BinanceRestApiManager_stream_kee, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__315)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_stream_keepalive, __pyx_t_6) < 0) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3226
 *                          throw_exception=throw_exception)
 * 
 *     def stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a user data stream.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_177stream_close, 0, __pyx_n_s_BinanceRestApiManager_stream_clo, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__316)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_stream_close, __pyx_t_6) < 0) __PYX_ERR(0, 3226, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3253
 *     # Margin Trading Endpoints
 * 
 *     def get_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin account details
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_179get_margin_account, 0, __pyx_n_s_BinanceRestApiManager_get_margin, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__317)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_account, __pyx_t_6) < 0) __PYX_ERR(0, 3253, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3311
 *         return self._request_margin_api('get', 'margin/account', True, data=params)
 * 
 *     def get_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin account details
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_181get_isolated_margin_account, 0, __pyx_n_s_BinanceRestApiManager_get_isolat, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__318)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_isolated_margin_account, __pyx_t_6) < 0) __PYX_ERR(0, 3311, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3422
 *         return self._request_margin_api('get', 'margin/isolated/account', True, data=params)
 * 
 *     def get_margin_asset(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin asset
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_183get_margin_asset, 0, __pyx_n_s_BinanceRestApiManager_get_margin_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__319)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_asset, __pyx_t_6) < 0) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3453
 *         return self._request_margin_api('get', 'margin/asset', data=params)
 * 
 *     def get_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query cross-margin symbol info
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_185get_margin_symbol, 0, __pyx_n_s_BinanceRestApiManager_get_margin_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__320)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_symbol, __pyx_t_6) < 0) __PYX_ERR(0, 3453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3485
 *         return self._request_margin_api('get', 'margin/pair', data=params)
 * 
 *     def create_isolated_margin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Create isolated margin account for symbol
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_187create_isolated_margin_account, 0, __pyx_n_s_BinanceRestApiManager_create_iso, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__321)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_isolated_margin_account, __pyx_t_6) < 0) __PYX_ERR(0, 3485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3515
 * 
 * 
 *     def get_isolated_margin_symbol(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_189get_isolated_margin_symbol, 0, __pyx_n_s_BinanceRestApiManager_get_isolat_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__322)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_isolated_margin_symbol, __pyx_t_6) < 0) __PYX_ERR(0, 3515, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3546
 *         return self._request_margin_api('get', 'margin/isolated/pair', signed=True, data=params)
 * 
 *     def get_all_isolated_margin_symbols(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin symbol info for all pairs
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_191get_all_isolated_margin_symbols, 0, __pyx_n_s_BinanceRestApiManager_get_all_is, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__323)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_all_isolated_margin_symbols, __pyx_t_6) < 0) __PYX_ERR(0, 3546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3584
 *         return self._request_margin_api('get', 'margin/isolated/allPairs', signed=True, data=params)
 * 
 *     def toggle_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Toggle BNB Burn On Spot Trade And Margin Interest
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_193toggle_bnb_burn_spot_margin, 0, __pyx_n_s_BinanceRestApiManager_toggle_bnb, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__324)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_toggle_bnb_burn_spot_margin, __pyx_t_6) < 0) __PYX_ERR(0, 3584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3613
 *         return self._request_margin_api('post', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_bnb_burn_spot_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Get BNB Burn Status
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_195get_bnb_burn_spot_margin, 0, __pyx_n_s_BinanceRestApiManager_get_bnb_bu, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__325)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_bnb_burn_spot_margin, __pyx_t_6) < 0) __PYX_ERR(0, 3613, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3637
 *         return self._request_margin_api('get', 'bnbBurn', signed=True, data=params)
 * 
 *     def get_margin_price_index(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin priceIndex
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_197get_margin_price_index, 0, __pyx_n_s_BinanceRestApiManager_get_margin_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__326)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_price_index, __pyx_t_6) < 0) __PYX_ERR(0, 3637, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3664
 *         return self._request_margin_api('get', 'margin/priceIndex', data=params)
 * 
 *     def transfer_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between cross-margin account and spot account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_199transfer_margin_to_spot, 0, __pyx_n_s_BinanceRestApiManager_transfer_m, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__327)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_transfer_margin_to_spot, __pyx_t_6) < 0) __PYX_ERR(0, 3664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3695
 *         return self._request_margin_api('post', 'margin/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and cross-margin account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_201transfer_spot_to_margin, 0, __pyx_n_s_BinanceRestApiManager_transfer_s, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__328)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_transfer_spot_to_margin, __pyx_t_6) < 0) __PYX_ERR(0, 3695, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3727
 * 
 * 
 *     def transfer_isolated_margin_to_spot(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between isolated margin account and spot account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_203transfer_isolated_margin_to_spot, 0, __pyx_n_s_BinanceRestApiManager_transfer_i, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__329)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_transfer_isolated_margin_to_spot, __pyx_t_6) < 0) __PYX_ERR(0, 3727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3762
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def transfer_spot_to_isolated_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and isolated margin account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_205transfer_spot_to_isolated_margin, 0, __pyx_n_s_BinanceRestApiManager_transfer_s_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__330)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_transfer_spot_to_isolated_margin, __pyx_t_6) < 0) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3797
 *         return self._request_margin_api('post', 'margin/isolated/transfer', signed=True, data=params)
 * 
 *     def create_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Apply for a loan in cross-margin or isolated-margin account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_207create_margin_loan, 0, __pyx_n_s_BinanceRestApiManager_create_mar, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__331)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_margin_loan, __pyx_t_6) < 0) __PYX_ERR(0, 3797, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3834
 *         return self._request_margin_api('post', 'margin/loan', signed=True, data=params)
 * 
 *     def repay_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Repay loan in cross-margin or isolated-margin account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_209repay_margin_loan, 0, __pyx_n_s_BinanceRestApiManager_repay_marg, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__332)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_repay_margin_loan, __pyx_t_6) < 0) __PYX_ERR(0, 3834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3876
 *     # Margin OCO
 * 
 *     def create_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new OCO trade for margin account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_211create_margin_oco_order, 0, __pyx_n_s_BinanceRestApiManager_create_mar_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__333)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_margin_oco_order, __pyx_t_6) < 0) __PYX_ERR(0, 3876, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":3985
 *         return self._request_margin_api('post', 'margin/order/oco', signed=True, data=params)
 * 
 *     def cancel_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Cancel an entire Order List for a margin account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_213cancel_margin_oco_order, 0, __pyx_n_s_BinanceRestApiManager_cancel_mar, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__334)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_cancel_margin_oco_order, __pyx_t_6) < 0) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4066
 *         return self._request_margin_api('delete', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_margin_oco_order(self, **params):             # <<<<<<<<<<<<<<
 *         """ Retrieves a specific OCO based on provided optional parameters
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_215get_margin_oco_order, 0, __pyx_n_s_BinanceRestApiManager_get_margin_5, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__335)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_oco_order, __pyx_t_6) < 0) __PYX_ERR(0, 4066, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4112
 *         return self._request_margin_api('get', 'margin/orderList', signed=True, data=params)
 * 
 *     def get_open_margin_oco_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Retrieves open OCO trades
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_217get_open_margin_oco_orders, 0, __pyx_n_s_BinanceRestApiManager_get_open_m, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__336)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_open_margin_oco_orders, __pyx_t_6) < 0) __PYX_ERR(0, 4112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4185
 *         return self._request_margin_api('get', 'margin/allOrderList', signed=True, data=params)
 * 
 *     def create_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Post a new order for margin account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_219create_margin_order, 0, __pyx_n_s_BinanceRestApiManager_create_mar_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__337)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_margin_order, __pyx_t_6) < 0) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4306
 *         return self._request_margin_api('post', 'margin/order', signed=True, data=params)
 * 
 *     def cancel_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active order for margin account.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_221cancel_margin_order, 0, __pyx_n_s_BinanceRestApiManager_cancel_mar_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__338)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_cancel_margin_order, __pyx_t_6) < 0) __PYX_ERR(0, 4306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4353
 *         return self._request_margin_api('delete', 'margin/order', signed=True, data=params)
 * 
 *     def get_margin_loan_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query loan record
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_223get_margin_loan_details, 0, __pyx_n_s_BinanceRestApiManager_get_margin_6, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__339)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_loan_details, __pyx_t_6) < 0) __PYX_ERR(0, 4353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4400
 *         return self._request_margin_api('get', 'margin/loan', signed=True, data=params)
 * 
 *     def get_margin_repay_details(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Query repay record
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_225get_margin_repay_details, 0, __pyx_n_s_BinanceRestApiManager_get_margin_7, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__340)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_repay_details, __pyx_t_6) < 0) __PYX_ERR(0, 4400, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4453
 *         return self._request_margin_api('get', 'margin/repay', signed=True, data=params)
 * 
 *     def get_margin_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts order
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_227get_margin_order, 0, __pyx_n_s_BinanceRestApiManager_get_margin_8, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__341)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_order, __pyx_t_6) < 0) __PYX_ERR(0, 4453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4501
 *         return self._request_margin_api('get', 'margin/order', signed=True, data=params)
 * 
 *     def get_open_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts open orders
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_229get_open_margin_orders, 0, __pyx_n_s_BinanceRestApiManager_get_open_m_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__342)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_open_margin_orders, __pyx_t_6) < 0) __PYX_ERR(0, 4501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4551
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_open_isolated_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query isolated margin accounts open orders
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_231get_open_isolated_margin_orders, 0, __pyx_n_s_BinanceRestApiManager_get_open_i, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__343)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_open_isolated_margin_orders, __pyx_t_6) < 0) __PYX_ERR(0, 4551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4601
 *         return self._request_margin_api('get', 'margin/openOrders', signed=True, data=params)
 * 
 *     def get_all_margin_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Query all margin accounts orders
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_233get_all_margin_orders, 0, __pyx_n_s_BinanceRestApiManager_get_all_ma, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__344)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_all_margin_orders, __pyx_t_6) < 0) __PYX_ERR(0, 4601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4662
 *         return self._request_margin_api('get', 'margin/allOrders', signed=True, data=params)
 * 
 *     def get_margin_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Query margin accounts trades
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_235get_margin_trades, 0, __pyx_n_s_BinanceRestApiManager_get_margin_9, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__345)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_margin_trades, __pyx_t_6) < 0) __PYX_ERR(0, 4662, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4722
 *         return self._request_margin_api('get', 'margin/myTrades', signed=True, data=params)
 * 
 *     def get_max_margin_loan(self, **params):             # <<<<<<<<<<<<<<
 *         """Query max borrow amount for an asset
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_237get_max_margin_loan, 0, __pyx_n_s_BinanceRestApiManager_get_max_ma, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__346)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_max_margin_loan, __pyx_t_6) < 0) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4747
 *         return self._request_margin_api('get', 'margin/maxBorrowable', signed=True, data=params)
 * 
 *     def get_max_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         r"""
 *         Query max transfer-out amount
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_239get_max_margin_transfer, 0, __pyx_n_s_BinanceRestApiManager_get_max_ma_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__347)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_max_margin_transfer, __pyx_t_6) < 0) __PYX_ERR(0, 4747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4775
 *     # Cross-margin
 * 
 *     def margin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new cross-margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_241margin_stream_get_listen_key, 0, __pyx_n_s_BinanceRestApiManager_margin_str, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__348)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__313);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_margin_stream_get_listen_key, __pyx_t_6) < 0) __PYX_ERR(0, 4775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4808
 *             return res['listenKey']
 * 
 *     def margin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a cross-margin data stream to prevent a time out.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_243margin_stream_keepalive, 0, __pyx_n_s_BinanceRestApiManager_margin_str_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__349)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_margin_stream_keepalive, __pyx_t_6) < 0) __PYX_ERR(0, 4808, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4833
 *                                         throw_exception=throw_exception)
 * 
 *     def margin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a cross-margin data stream.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_245margin_stream_close, 0, __pyx_n_s_BinanceRestApiManager_margin_str_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__350)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_margin_stream_close, __pyx_t_6) < 0) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4860
 *     # Isolated margin
 * 
 *     def isolated_margin_stream_get_listen_key(self, symbol, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new isolated margin data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_247isolated_margin_stream_get_listen_key, 0, __pyx_n_s_BinanceRestApiManager_isolated_m, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__352)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__313);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_isolated_margin_stream_get_liste, __pyx_t_6) < 0) __PYX_ERR(0, 4860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4900
 *             return res['listenKey']
 * 
 *     def isolated_margin_stream_keepalive(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING an isolated margin data stream to prevent a time out.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_249isolated_margin_stream_keepalive, 0, __pyx_n_s_BinanceRestApiManager_isolated_m_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__354)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_isolated_margin_stream_keepalive, __pyx_t_6) < 0) __PYX_ERR(0, 4900, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4928
 *                                         throw_exception=throw_exception)
 * 
 *     def isolated_margin_stream_close(self, symbol, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out an isolated margin data stream.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_251isolated_margin_stream_close, 0, __pyx_n_s_BinanceRestApiManager_isolated_m_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__355)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_isolated_margin_stream_close, __pyx_t_6) < 0) __PYX_ERR(0, 4928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4958
 *     # Lending Endpoints
 * 
 *     def get_lending_product_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Product List
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_253get_lending_product_list, 0, __pyx_n_s_BinanceRestApiManager_get_lendin, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__356)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_product_list, __pyx_t_6) < 0) __PYX_ERR(0, 4958, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4966
 *         return self._request_margin_api('get', 'lending/daily/product/list', signed=True, data=params)
 * 
 *     def get_lending_daily_quota_left(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Purchase Quota of Flexible Product.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_255get_lending_daily_quota_left, 0, __pyx_n_s_BinanceRestApiManager_get_lendin_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__357)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_daily_quota_left, __pyx_t_6) < 0) __PYX_ERR(0, 4966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4974
 *         return self._request_margin_api('get', 'lending/daily/userLeftQuota', signed=True, data=params)
 * 
 *     def purchase_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Purchase Flexible Product
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_257purchase_lending_product, 0, __pyx_n_s_BinanceRestApiManager_purchase_l, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__358)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_purchase_lending_product, __pyx_t_6) < 0) __PYX_ERR(0, 4974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4982
 *         return self._request_margin_api('post', 'lending/daily/purchase', signed=True, data=params)
 * 
 *     def get_lending_daily_redemption_quota(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Left Daily Redemption Quota of Flexible Product
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_259get_lending_daily_redemption_quota, 0, __pyx_n_s_BinanceRestApiManager_get_lendin_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__359)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_daily_redemption_quo, __pyx_t_6) < 0) __PYX_ERR(0, 4982, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4990
 *         return self._request_margin_api('get', 'lending/daily/userRedemptionQuota', signed=True, data=params)
 * 
 *     def redeem_lending_product(self, **params):             # <<<<<<<<<<<<<<
 *         """Redeem Flexible Product
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_261redeem_lending_product, 0, __pyx_n_s_BinanceRestApiManager_redeem_len, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__360)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_redeem_lending_product, __pyx_t_6) < 0) __PYX_ERR(0, 4990, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":4998
 *         return self._request_margin_api('post', 'lending/daily/redeem', signed=True, data=params)
 * 
 *     def get_lending_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Flexible Product Position
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_263get_lending_position, 0, __pyx_n_s_BinanceRestApiManager_get_lendin_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__361)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_position, __pyx_t_6) < 0) __PYX_ERR(0, 4998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5006
 *         return self._request_margin_api('get', 'lending/daily/token/position', signed=True, data=params)
 * 
 *     def get_fixed_activity_project_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Fixed and Activity Project List
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_265get_fixed_activity_project_list, 0, __pyx_n_s_BinanceRestApiManager_get_fixed, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__362)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_fixed_activity_project_list, __pyx_t_6) < 0) __PYX_ERR(0, 5006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5056
 *         return self._request_margin_api('get', 'lending/project/list', signed=True, data=params)
 * 
 *     def get_lending_account(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Account Details
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_267get_lending_account, 0, __pyx_n_s_BinanceRestApiManager_get_lendin_5, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__363)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_account, __pyx_t_6) < 0) __PYX_ERR(0, 5056, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5064
 *         return self._request_margin_api('get', 'lending/union/account', signed=True, data=params)
 * 
 *     def get_lending_purchase_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Purchase History
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_269get_lending_purchase_history, 0, __pyx_n_s_BinanceRestApiManager_get_lendin_6, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__364)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_purchase_history, __pyx_t_6) < 0) __PYX_ERR(0, 5064, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5072
 *         return self._request_margin_api('get', 'lending/union/purchaseRecord', signed=True, data=params)
 * 
 *     def get_lending_redemption_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Redemption History
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_271get_lending_redemption_history, 0, __pyx_n_s_BinanceRestApiManager_get_lendin_7, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__365)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_redemption_history, __pyx_t_6) < 0) __PYX_ERR(0, 5072, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5080
 *         return self._request_margin_api('get', 'lending/union/redemptionRecord', signed=True, data=params)
 * 
 *     def get_lending_interest_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Lending Interest History
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_273get_lending_interest_history, 0, __pyx_n_s_BinanceRestApiManager_get_lendin_8, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__366)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_lending_interest_history, __pyx_t_6) < 0) __PYX_ERR(0, 5080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5088
 *         return self._request_margin_api('get', 'lending/union/interestHistory', signed=True, data=params)
 * 
 *     def change_fixed_activity_to_daily_position(self, **params):             # <<<<<<<<<<<<<<
 *         """Change Fixed/Activity Position to Daily Position
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_275change_fixed_activity_to_daily_position, 0, __pyx_n_s_BinanceRestApiManager_change_fix, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__367)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_change_fixed_activity_to_daily_p, __pyx_t_6) < 0) __PYX_ERR(0, 5088, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5098
 *     # Sub Accounts
 * 
 *     def get_sub_account_list(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account List.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_277get_sub_account_list, 0, __pyx_n_s_BinanceRestApiManager_get_sub_ac, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__368)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_sub_account_list, __pyx_t_6) < 0) __PYX_ERR(0, 5098, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5137
 *         return self._request_margin_api('get', 'sub-account/list', True, data=params)
 * 
 *     def get_sub_account_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Transfer History.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_279get_sub_account_transfer_history, 0, __pyx_n_s_BinanceRestApiManager_get_sub_ac_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__369)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_sub_account_transfer_history, __pyx_t_6) < 0) __PYX_ERR(0, 5137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5187
 *         return self._request_margin_api('get', 'sub-account/sub/transfer/history', True, data=params)
 * 
 *     def get_sub_account_futures_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Futures Transfer History.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_281get_sub_account_futures_transfer_history, 0, __pyx_n_s_BinanceRestApiManager_get_sub_ac_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__370)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_sub_account_futures_transfer, __pyx_t_6) < 0) __PYX_ERR(0, 5187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5237
 *         return self._request_margin_api('get', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def create_sub_account_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute sub-account Futures transfer
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_283create_sub_account_futures_transfer, 0, __pyx_n_s_BinanceRestApiManager_create_sub, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__371)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_create_sub_account_futures_trans, __pyx_t_6) < 0) __PYX_ERR(0, 5237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5269
 *         return self._request_margin_api('post', 'sub-account/futures/internalTransfer', True, data=params)
 * 
 *     def get_sub_account_assets(self, **params):             # <<<<<<<<<<<<<<
 *         """Fetch sub-account assets
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_285get_sub_account_assets, 0, __pyx_n_s_BinanceRestApiManager_get_sub_ac_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__372)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_sub_account_assets, __pyx_t_6) < 0) __PYX_ERR(0, 5269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5318
 *         return self._request_margin_api('get', 'sub-account/assets', True, data=params, version='v3')
 * 
 *     def query_subaccount_spot_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Query Sub-account Spot Assets Summary (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_287query_subaccount_spot_summary, 0, __pyx_n_s_BinanceRestApiManager_query_suba, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__373)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_query_subaccount_spot_summary, __pyx_t_6) < 0) __PYX_ERR(0, 5318, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5356
 *         return self._request_margin_api('get', 'sub-account/spotSummary', True, data=params)
 * 
 *     def get_subaccount_deposit_address(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit Address (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_289get_subaccount_deposit_address, 0, __pyx_n_s_BinanceRestApiManager_get_subacc, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__374)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_deposit_address, __pyx_t_6) < 0) __PYX_ERR(0, 5356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5386
 *         return self._request_margin_api('get', 'capital/deposit/subAddress', True, data=params)
 * 
 *     def get_subaccount_deposit_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account Deposit History (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_291get_subaccount_deposit_history, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__375)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_deposit_history, __pyx_t_6) < 0) __PYX_ERR(0, 5386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5444
 *         return self._request_margin_api('get', 'capital/deposit/subHisrec', True, data=params)
 * 
 *     def get_subaccount_futures_margin_status(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Sub-account's Status on Margin/Futures (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_293get_subaccount_futures_margin_status, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__376)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_futures_margin_st, __pyx_t_6) < 0) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5475
 *         return self._request_margin_api('get', 'sub-account/status', True, data=params)
 * 
 *     def enable_subaccount_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Margin for Sub-account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_295enable_subaccount_margin, 0, __pyx_n_s_BinanceRestApiManager_enable_sub, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__377)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_enable_subaccount_margin, __pyx_t_6) < 0) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5502
 *         return self._request_margin_api('post', 'sub-account/margin/enable', True, data=params)
 * 
 *     def get_subaccount_margin_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Margin Account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_297get_subaccount_margin_details, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__378)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_margin_details, __pyx_t_6) < 0) __PYX_ERR(0, 5502, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5569
 *         return self._request_margin_api('get', 'sub-account/margin/account', True, data=params)
 * 
 *     def get_subaccount_margin_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Margin Account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_299get_subaccount_margin_summary, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_5, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__379)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_margin_summary, __pyx_t_6) < 0) __PYX_ERR(0, 5569, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5606
 *         return self._request_margin_api('get', 'sub-account/margin/accountSummary', True, data=params)
 * 
 *     def enable_subaccount_futures(self, **params):             # <<<<<<<<<<<<<<
 *         """Enable Futures for Sub-account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_301enable_subaccount_futures, 0, __pyx_n_s_BinanceRestApiManager_enable_sub_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__380)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_enable_subaccount_futures, __pyx_t_6) < 0) __PYX_ERR(0, 5606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5633
 *         return self._request_margin_api('post', 'sub-account/futures/enable', True, data=params)
 * 
 *     def get_subaccount_futures_details(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Detail on Sub-account's Futures Account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_303get_subaccount_futures_details, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_6, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__381)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_futures_details, __pyx_t_6) < 0) __PYX_ERR(0, 5633, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5683
 *         return self._request_margin_api('get', 'sub-account/futures/account', True, data=params)
 * 
 *     def get_subaccount_futures_summary(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Summary of Sub-account's Futures Account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_305get_subaccount_futures_summary, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_7, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__382)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_futures_summary, __pyx_t_6) < 0) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5735
 *         return self._request_margin_api('get', 'sub-account/futures/accountSummary', True, data=params)
 * 
 *     def get_subaccount_futures_positionrisk(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Futures Position-Risk of Sub-account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_307get_subaccount_futures_positionrisk, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_8, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__383)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_futures_positionr, __pyx_t_6) < 0) __PYX_ERR(0, 5735, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5767
 *         return self._request_margin_api('get', 'sub-account/futures/positionRisk', True, data=params)
 * 
 *     def make_subaccount_futures_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Futures Transfer for Sub-account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_309make_subaccount_futures_transfer, 0, __pyx_n_s_BinanceRestApiManager_make_subac, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__384)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_make_subaccount_futures_transfer, __pyx_t_6) < 0) __PYX_ERR(0, 5767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5797
 *         return self._request_margin_api('post', 'sub-account/futures/transfer', True, data=params)
 * 
 *     def make_subaccount_margin_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Margin Transfer for Sub-account (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_311make_subaccount_margin_transfer, 0, __pyx_n_s_BinanceRestApiManager_make_subac_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__385)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_make_subaccount_margin_transfer, __pyx_t_6) < 0) __PYX_ERR(0, 5797, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5825
 *         return self._request_margin_api('post', 'sub-account/margin/transfer', True, data=params)
 * 
 *     def make_subaccount_to_subaccount_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Sub-account of Same Master (For Sub-account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_313make_subaccount_to_subaccount_transfer, 0, __pyx_n_s_BinanceRestApiManager_make_subac_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__386)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_make_subaccount_to_subaccount_tr, __pyx_t_6) < 0) __PYX_ERR(0, 5825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5852
 *         return self._request_margin_api('post', 'sub-account/transfer/subToSub', True, data=params)
 * 
 *     def make_subaccount_to_master_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Transfer to Master (For Sub-account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_315make_subaccount_to_master_transfer, 0, __pyx_n_s_BinanceRestApiManager_make_subac_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__387)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_make_subaccount_to_master_transf, __pyx_t_6) < 0) __PYX_ERR(0, 5852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5877
 *         return self._request_margin_api('post', 'sub-account/transfer/subToMaster', True, data=params)
 * 
 *     def get_subaccount_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Subaccount Transfer History (For Sub-account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_317get_subaccount_transfer_history, 0, __pyx_n_s_BinanceRestApiManager_get_subacc_9, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__388)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_subaccount_transfer_history, __pyx_t_6) < 0) __PYX_ERR(0, 5877, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5927
 *         return self._request_margin_api('get', 'sub-account/transfer/subUserHistory', True, data=params)
 * 
 *     def make_universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_319make_universal_transfer, 0, __pyx_n_s_BinanceRestApiManager_make_unive, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__389)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_make_universal_transfer, __pyx_t_6) < 0) __PYX_ERR(0, 5927, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":5960
 *         return self._request_margin_api('post', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_universal_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Universal Transfer (For Master Account)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_321get_universal_transfer_history, 0, __pyx_n_s_BinanceRestApiManager_get_univer, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__390)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_universal_transfer_history, __pyx_t_6) < 0) __PYX_ERR(0, 5960, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6014
 *         return self._request_margin_api('get', 'sub-account/universalTransfer', True, data=params)
 * 
 *     def get_used_weight(self, make_new_request=False):             # <<<<<<<<<<<<<<
 *         """Get the used weight from Binance endpoints
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_323get_used_weight, 0, __pyx_n_s_BinanceRestApiManager_get_used_w, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__392)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__393);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_used_weight, __pyx_t_6) < 0) __PYX_ERR(0, 6014, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6047
 *     # Futures API
 * 
 *     def futures_ping(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_325futures_ping, 0, __pyx_n_s_BinanceRestApiManager_futures_pi, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__394)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_ping, __pyx_t_6) < 0) __PYX_ERR(0, 6047, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6055
 *         return self._request_futures_api('get', 'ping')
 * 
 *     def futures_time(self):             # <<<<<<<<<<<<<<
 *         """Test connectivity to the Rest API and get the current server time.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_327futures_time, 0, __pyx_n_s_BinanceRestApiManager_futures_ti, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__395)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_time, __pyx_t_6) < 0) __PYX_ERR(0, 6055, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6063
 *         return self._request_futures_api('get', 'time')
 * 
 *     def futures_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """Current exchange trading rules and symbol information
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_329futures_exchange_info, 0, __pyx_n_s_BinanceRestApiManager_futures_ex, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__396)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_exchange_info, __pyx_t_6) < 0) __PYX_ERR(0, 6063, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6071
 *         return self._request_futures_api('get', 'exchangeInfo')
 * 
 *     def futures_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """Get the Order Book for the market
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_331futures_order_book, 0, __pyx_n_s_BinanceRestApiManager_futures_or, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__397)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_order_book, __pyx_t_6) < 0) __PYX_ERR(0, 6071, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6079
 *         return self._request_futures_api('get', 'depth', data=params)
 * 
 *     def futures_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_333futures_recent_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_re, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__398)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_recent_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6079, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6087
 *         return self._request_futures_api('get', 'trades', data=params)
 * 
 *     def futures_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get older market historical trades.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_335futures_historical_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_hi, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__399)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_historical_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6087, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6095
 *         return self._request_futures_api('get', 'historicalTrades', data=params)
 * 
 *     def futures_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 *         price will have the quantity aggregated.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_337futures_aggregate_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_ag, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__400)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_aggregate_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6104
 *         return self._request_futures_api('get', 'aggTrades', data=params)
 * 
 *     def futures_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_339futures_klines, 0, __pyx_n_s_BinanceRestApiManager_futures_kl, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__401)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_klines, __pyx_t_6) < 0) __PYX_ERR(0, 6104, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6112
 *         return self._request_futures_api('get', 'klines', data=params)
 * 
 *     def futures_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """Get Mark Price and Funding Rate
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_341futures_mark_price, 0, __pyx_n_s_BinanceRestApiManager_futures_ma, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__402)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_mark_price, __pyx_t_6) < 0) __PYX_ERR(0, 6112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6120
 *         return self._request_futures_api('get', 'premiumIndex', data=params)
 * 
 *     def futures_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_343futures_funding_rate, 0, __pyx_n_s_BinanceRestApiManager_futures_fu, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__403)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_funding_rate, __pyx_t_6) < 0) __PYX_ERR(0, 6120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6128
 *         return self._request_futures_api('get', 'fundingRate', data=params)
 * 
 *     def futures_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """24 hour rolling window price change statistics.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_345futures_ticker, 0, __pyx_n_s_BinanceRestApiManager_futures_ti_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__404)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 6128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6136
 *         return self._request_futures_api('get', 'ticker/24hr', data=params)
 * 
 *     def futures_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Latest price for a symbol or symbols.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_347futures_symbol_ticker, 0, __pyx_n_s_BinanceRestApiManager_futures_sy, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__405)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_symbol_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 6136, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6144
 *         return self._request_futures_api('get', 'ticker/price', data=params)
 * 
 *     def futures_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """Best price/qty on the order book for a symbol or symbols.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_349futures_orderbook_ticker, 0, __pyx_n_s_BinanceRestApiManager_futures_or_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__406)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_orderbook_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 6144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6152
 *         return self._request_futures_api('get', 'ticker/bookTicker', data=params)
 * 
 *     def futures_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """Get all liquidation orders
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_351futures_liquidation_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_li, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__407)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_liquidation_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6160
 *         return self._request_futures_api('get', 'ticker/allForceOrders', data=params)
 * 
 *     def futures_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """Get present open interest of a specific symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_353futures_open_interest, 0, __pyx_n_s_BinanceRestApiManager_futures_op, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__408)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_open_interest, __pyx_t_6) < 0) __PYX_ERR(0, 6160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6168
 *         return self._request_futures_api('get', 'ticker/openInterest', data=params)
 * 
 *     def futures_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """Get open interest statistics of a specific symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_355futures_open_interest_hist, 0, __pyx_n_s_BinanceRestApiManager_futures_op_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__409)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_open_interest_hist, __pyx_t_6) < 0) __PYX_ERR(0, 6168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6176
 *         return self._request_futures_data_api('get', 'openInterestHist', data=params)
 * 
 *     def futures_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """Notional and Leverage Brackets
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_357futures_leverage_bracket, 0, __pyx_n_s_BinanceRestApiManager_futures_le, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__410)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_leverage_bracket, __pyx_t_6) < 0) __PYX_ERR(0, 6176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6184
 *         return self._request_futures_api('get', 'leverageBracket', True, data=params)
 * 
 *     def futures_account_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """Execute transfer between spot account and futures account.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_359futures_account_transfer, 0, __pyx_n_s_BinanceRestApiManager_futures_ac, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__411)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_account_transfer, __pyx_t_6) < 0) __PYX_ERR(0, 6184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6192
 *         return self._request_margin_api('post', 'futures/transfer', True, data=params)
 * 
 *     def futures_auto_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open orders of the specified symbol at the end of the specified countdown.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_361futures_auto_cancel_all_open_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_au, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__412)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_auto_cancel_all_open_ord, __pyx_t_6) < 0) __PYX_ERR(0, 6192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6218
 *         return self._request_futures_api('post', 'countdownCancelAll', True, data=params)
 * 
 *     def futures_commission_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get commission rate (user data)
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_363futures_commission_rate, 0, __pyx_n_s_BinanceRestApiManager_futures_co, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__413)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_commission_rate, __pyx_t_6) < 0) __PYX_ERR(0, 6218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6226
 *         return self._request_futures_coin_api("get", "commissionRate", version=1, signed=True, data=params)
 * 
 *     def transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get future account transaction history list
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_365transfer_history, 0, __pyx_n_s_BinanceRestApiManager_transfer_h, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__414)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_transfer_history, __pyx_t_6) < 0) __PYX_ERR(0, 6226, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6234
 *         return self._request_margin_api('get', 'futures/transfer', True, data=params)
 * 
 *     def futures_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in a new order.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_367futures_create_order, 0, __pyx_n_s_BinanceRestApiManager_futures_cr, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__415)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_create_order, __pyx_t_6) < 0) __PYX_ERR(0, 6234, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6242
 *         return self._request_futures_api('post', 'order', True, data=params)
 * 
 *     def futures_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_369futures_place_batch_order, 0, __pyx_n_s_BinanceRestApiManager_futures_pl, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__417)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_place_batch_order, __pyx_t_6) < 0) __PYX_ERR(0, 6242, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6253
 *         return self._request_futures_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_371futures_get_order, 0, __pyx_n_s_BinanceRestApiManager_futures_ge, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__418)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_get_order, __pyx_t_6) < 0) __PYX_ERR(0, 6253, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6262
 *         return self._request_futures_api('get', 'order', True, data=params)
 * 
 *     def futures_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_373futures_get_open_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_ge_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__419)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_get_open_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6271
 *         return self._request_futures_api('get', 'openOrders', True, data=params)
 * 
 *     def futures_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_375futures_get_all_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_ge_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__420)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_get_all_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6280
 *         return self._request_futures_api('get', 'allOrders', True, data=params)
 * 
 *     def futures_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_377futures_cancel_order, 0, __pyx_n_s_BinanceRestApiManager_futures_ca, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__421)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_cancel_order, __pyx_t_6) < 0) __PYX_ERR(0, 6280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6289
 *         return self._request_futures_api('delete', 'order', True, data=params)
 * 
 *     def futures_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_379futures_cancel_all_open_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_ca_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__422)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_cancel_all_open_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6289, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6298
 *         return self._request_futures_api('delete', 'allOpenOrders', True, data=params)
 * 
 *     def futures_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_381futures_cancel_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_ca_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__423)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_cancel_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6298, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6307
 *         return self._request_futures_api('delete', 'batchOrders', True, data=params)
 * 
 *     def futures_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_383futures_account_balance, 0, __pyx_n_s_BinanceRestApiManager_futures_ac_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__424)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_account_balance, __pyx_t_6) < 0) __PYX_ERR(0, 6307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6316
 *         return self._request_futures_api('get', 'balance', True, data=params)
 * 
 *     def futures_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_385futures_account, 0, __pyx_n_s_BinanceRestApiManager_futures_ac_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__425)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_account, __pyx_t_6) < 0) __PYX_ERR(0, 6316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6325
 *         return self._request_futures_api('get', 'account', True, data=params)
 * 
 *     def futures_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_387futures_change_leverage, 0, __pyx_n_s_BinanceRestApiManager_futures_ch, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__426)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_change_leverage, __pyx_t_6) < 0) __PYX_ERR(0, 6325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6334
 *         return self._request_futures_api('post', 'leverage', True, data=params)
 * 
 *     def futures_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """Change the margin type for a symbol
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_389futures_change_margin_type, 0, __pyx_n_s_BinanceRestApiManager_futures_ch_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__427)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_change_margin_type, __pyx_t_6) < 0) __PYX_ERR(0, 6334, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6342
 *         return self._request_futures_api('post', 'marginType', True, data=params)
 * 
 *     def futures_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_391futures_change_position_margin, 0, __pyx_n_s_BinanceRestApiManager_futures_ch_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__428)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_change_position_margin, __pyx_t_6) < 0) __PYX_ERR(0, 6342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6351
 *         return self._request_futures_api('post', 'positionMargin', True, data=params)
 * 
 *     def futures_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position margin change history
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_393futures_position_margin_history, 0, __pyx_n_s_BinanceRestApiManager_futures_po, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__429)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_position_margin_history, __pyx_t_6) < 0) __PYX_ERR(0, 6351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6360
 *         return self._request_futures_api('get', 'positionMargin/history', True, data=params)
 * 
 *     def futures_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_395futures_position_information, 0, __pyx_n_s_BinanceRestApiManager_futures_po_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__430)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_position_information, __pyx_t_6) < 0) __PYX_ERR(0, 6360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6369
 *         return self._request_futures_api('get', 'positionRisk', True, data=params)
 * 
 *     def futures_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get trades for the authenticated account and symbol.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_397futures_account_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_ac_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_account_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6378
 *         return self._request_futures_api('get', 'userTrades', True, data=params)
 * 
 *     def futures_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get income history for authenticated account
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_399futures_income_history, 0, __pyx_n_s_BinanceRestApiManager_futures_in, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__432)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_income_history, __pyx_t_6) < 0) __PYX_ERR(0, 6378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6387
 *         return self._request_futures_api('get', 'income', True, data=params)
 * 
 *     def futures_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change position mode for authenticated account
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_401futures_change_position_mode, 0, __pyx_n_s_BinanceRestApiManager_futures_ch_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__433)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_change_position_mode, __pyx_t_6) < 0) __PYX_ERR(0, 6387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6396
 *         return self._request_futures_api('post', 'positionSide/dual', True, data=params)
 * 
 *     def futures_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position mode for authenticated account
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_403futures_get_position_mode, 0, __pyx_n_s_BinanceRestApiManager_futures_ge_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__434)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_get_position_mode, __pyx_t_6) < 0) __PYX_ERR(0, 6396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6405
 *         return self._request_futures_api('get', 'positionSide/dual', True, data=params)
 * 
 *     def futures_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_405futures_stream_get_listen_key, 0, __pyx_n_s_BinanceRestApiManager_futures_st, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__435)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__313);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_stream_get_listen_key, __pyx_t_6) < 0) __PYX_ERR(0, 6405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6438
 *             return res['listenKey']
 * 
 *     def futures_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a futures data stream to prevent a time out.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_407futures_stream_keepalive, 0, __pyx_n_s_BinanceRestApiManager_futures_st_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__436)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_stream_keepalive, __pyx_t_6) < 0) __PYX_ERR(0, 6438, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6463
 *                                          throw_exception=throw_exception)
 * 
 *     def futures_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a futures data stream.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_409futures_stream_close, 0, __pyx_n_s_BinanceRestApiManager_futures_st_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__437)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_stream_close, __pyx_t_6) < 0) __PYX_ERR(0, 6463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6489
 * 
 *     # COIN Futures API
 *     def futures_coin_ping(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_411futures_coin_ping, 0, __pyx_n_s_BinanceRestApiManager_futures_co_2, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__438)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_ping, __pyx_t_6) < 0) __PYX_ERR(0, 6489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6498
 *         return self._request_futures_coin_api("get", "ping")
 * 
 *     def futures_coin_time(self):             # <<<<<<<<<<<<<<
 *         """
 *         Test connectivity to the Rest API and get the current server time.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_413futures_coin_time, 0, __pyx_n_s_BinanceRestApiManager_futures_co_3, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__439)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_time, __pyx_t_6) < 0) __PYX_ERR(0, 6498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6507
 *         return self._request_futures_coin_api("get", "time")
 * 
 *     def futures_coin_exchange_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Current exchange trading rules and symbol information
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_415futures_coin_exchange_info, 0, __pyx_n_s_BinanceRestApiManager_futures_co_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__440)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_exchange_info, __pyx_t_6) < 0) __PYX_ERR(0, 6507, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6516
 *         return self._request_futures_coin_api("get", "exchangeInfo")
 * 
 *     def futures_coin_order_book(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get the Order Book for the market
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_417futures_coin_order_book, 0, __pyx_n_s_BinanceRestApiManager_futures_co_5, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__441)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_order_book, __pyx_t_6) < 0) __PYX_ERR(0, 6516, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6525
 *         return self._request_futures_coin_api("get", "depth", data=params)
 * 
 *     def futures_coin_recent_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get recent trades (up to last 500).
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_419futures_coin_recent_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_co_6, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__442)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_recent_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6533
 *         return self._request_futures_coin_api("get", "trades", data=params)
 * 
 *     def futures_coin_historical_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get older market historical trades.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_421futures_coin_historical_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_co_7, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__443)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_historical_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6542
 *         return self._request_futures_coin_api("get", "historicalTrades", data=params)
 * 
 *     def futures_coin_aggregate_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get compressed, aggregate trades. Trades that fill at the time, from the same order, with the same
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_423futures_coin_aggregate_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_co_8, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__444)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_aggregate_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6542, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6552
 *         return self._request_futures_coin_api("get", "aggTrades", data=params)
 * 
 *     def futures_coin_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_425futures_coin_klines, 0, __pyx_n_s_BinanceRestApiManager_futures_co_9, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__445)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_klines, __pyx_t_6) < 0) __PYX_ERR(0, 6552, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6561
 *         return self._request_futures_coin_api("get", "klines", data=params)
 * 
 *     def futures_coin_continous_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Kline/candlestick bars for a specific contract type. Klines are uniquely identified by their open time.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_427futures_coin_continous_klines, 0, __pyx_n_s_BinanceRestApiManager_futures_co_10, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__446)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_continous_klines, __pyx_t_6) < 0) __PYX_ERR(0, 6561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6570
 *         return self._request_futures_coin_api("get", "continuousKlines", data=params)
 * 
 *     def futures_coin_index_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_429futures_coin_index_price_klines, 0, __pyx_n_s_BinanceRestApiManager_futures_co_11, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_index_price_klines, __pyx_t_6) < 0) __PYX_ERR(0, 6570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6578
 *         return self._request_futures_coin_api("get", "indexPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price_klines(self, **params):             # <<<<<<<<<<<<<<
 *         """Kline/candlestick bars for the index price of a pair..
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_431futures_coin_mark_price_klines, 0, __pyx_n_s_BinanceRestApiManager_futures_co_12, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__448)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_mark_price_klines, __pyx_t_6) < 0) __PYX_ERR(0, 6578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6586
 *         return self._request_futures_coin_api("get", "markPriceKlines", data=params)
 * 
 *     def futures_coin_mark_price(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get Mark Price and Funding Rate
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_433futures_coin_mark_price, 0, __pyx_n_s_BinanceRestApiManager_futures_co_13, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__449)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_mark_price, __pyx_t_6) < 0) __PYX_ERR(0, 6586, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6595
 *         return self._request_futures_coin_api("get", "premiumIndex", data=params)
 * 
 *     def futures_coin_funding_rate(self, **params):             # <<<<<<<<<<<<<<
 *         """Get funding rate history
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_435futures_coin_funding_rate, 0, __pyx_n_s_BinanceRestApiManager_futures_co_14, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__450)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_funding_rate, __pyx_t_6) < 0) __PYX_ERR(0, 6595, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6603
 *         return self._request_futures_coin_api("get", "fundingRate", data=params)
 * 
 *     def futures_coin_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         24 hour rolling window price change statistics.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_437futures_coin_ticker, 0, __pyx_n_s_BinanceRestApiManager_futures_co_15, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__451)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 6603, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6612
 *         return self._request_futures_coin_api("get", "ticker/24hr", data=params)
 * 
 *     def futures_coin_symbol_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Latest price for a symbol or symbols.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_439futures_coin_symbol_ticker, 0, __pyx_n_s_BinanceRestApiManager_futures_co_16, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__452)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_symbol_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 6612, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6621
 *         return self._request_futures_coin_api("get", "ticker/price", data=params)
 * 
 *     def futures_coin_orderbook_ticker(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Best price/qty on the order book for a symbol or symbols.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_441futures_coin_orderbook_ticker, 0, __pyx_n_s_BinanceRestApiManager_futures_co_17, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__453)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_orderbook_ticker, __pyx_t_6) < 0) __PYX_ERR(0, 6621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6630
 *         return self._request_futures_coin_api("get", "ticker/bookTicker", data=params)
 * 
 *     def futures_coin_liquidation_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all liquidation orders
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_443futures_coin_liquidation_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_co_18, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__454)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_liquidation_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6639
 *         return self._request_futures_coin_api("get", "allForceOrders", data=params)
 * 
 *     def futures_coin_open_interest(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get present open interest of a specific symbol.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_445futures_coin_open_interest, 0, __pyx_n_s_BinanceRestApiManager_futures_co_19, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__455)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_open_interest, __pyx_t_6) < 0) __PYX_ERR(0, 6639, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6648
 *         return self._request_futures_coin_api("get", "openInterest", data=params)
 * 
 *     def futures_coin_open_interest_hist(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get open interest statistics of a specific symbol.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_447futures_coin_open_interest_hist, 0, __pyx_n_s_BinanceRestApiManager_futures_co_20, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__456)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_open_interest_hist, __pyx_t_6) < 0) __PYX_ERR(0, 6648, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6657
 *         return self._request_futures_coin_data_api("get", "openInterestHist", data=params)
 * 
 *     def futures_coin_leverage_bracket(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Notional and Leverage Brackets
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_449futures_coin_leverage_bracket, 0, __pyx_n_s_BinanceRestApiManager_futures_co_21, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__457)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_leverage_bracket, __pyx_t_6) < 0) __PYX_ERR(0, 6657, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6668
 *         )
 * 
 *     def new_transfer_history(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get future account transaction history list
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_451new_transfer_history, 0, __pyx_n_s_BinanceRestApiManager_new_transf, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__458)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_new_transfer_history, __pyx_t_6) < 0) __PYX_ERR(0, 6668, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6678
 *         # return self._request_margin_api("get", "futures/transfer", True, data=params)
 * 
 *     def universal_transfer(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Unviversal transfer api accross different unicorn_binance_rest_api account types
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_453universal_transfer, 0, __pyx_n_s_BinanceRestApiManager_universal, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__459)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_universal_transfer, __pyx_t_6) < 0) __PYX_ERR(0, 6678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6688
 *         )
 * 
 *     def futures_coin_create_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Send in a new order.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_455futures_coin_create_order, 0, __pyx_n_s_BinanceRestApiManager_futures_co_22, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__460)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_create_order, __pyx_t_6) < 0) __PYX_ERR(0, 6688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6697
 *         return self._request_futures_coin_api("post", "order", True, data=params)
 * 
 *     def futures_coin_place_batch_order(self, **params):             # <<<<<<<<<<<<<<
 *         """Send in new orders.
 *         https://binance-docs.github.io/apidocs/delivery/en/#place-multiple-orders-trade
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_457futures_coin_place_batch_order, 0, __pyx_n_s_BinanceRestApiManager_futures_co_23, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__461)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_place_batch_order, __pyx_t_6) < 0) __PYX_ERR(0, 6697, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6708
 *         return self._request_futures_coin_api('post', 'batchOrders', True, data=params)
 * 
 *     def futures_coin_get_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Check an order's status.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_459futures_coin_get_order, 0, __pyx_n_s_BinanceRestApiManager_futures_co_24, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_get_order, __pyx_t_6) < 0) __PYX_ERR(0, 6708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6717
 *         return self._request_futures_coin_api("get", "order", True, data=params)
 * 
 *     def futures_coin_get_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all open orders on a symbol.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_461futures_coin_get_open_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_co_25, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__463)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_get_open_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6726
 *         return self._request_futures_coin_api("get", "openOrders", True, data=params)
 * 
 *     def futures_coin_get_all_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get all futures account orders; active, canceled, or filled.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_463futures_coin_get_all_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_co_26, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__464)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_get_all_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6737
 *         )
 * 
 *     def futures_coin_cancel_order(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel an active futures order.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_465futures_coin_cancel_order, 0, __pyx_n_s_BinanceRestApiManager_futures_co_27, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__465)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_cancel_order, __pyx_t_6) < 0) __PYX_ERR(0, 6737, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6748
 *         )
 * 
 *     def futures_coin_cancel_all_open_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel all open futures orders
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_467futures_coin_cancel_all_open_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_co_28, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__466)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_cancel_all_open_ord, __pyx_t_6) < 0) __PYX_ERR(0, 6748, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6759
 *         )
 * 
 *     def futures_coin_cancel_orders(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Cancel multiple futures orders
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_469futures_coin_cancel_orders, 0, __pyx_n_s_BinanceRestApiManager_futures_co_29, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__467)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_cancel_orders, __pyx_t_6) < 0) __PYX_ERR(0, 6759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6770
 *         )
 * 
 *     def futures_coin_account_balance(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get futures account balance
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_471futures_coin_account_balance, 0, __pyx_n_s_BinanceRestApiManager_futures_co_30, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__468)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_account_balance, __pyx_t_6) < 0) __PYX_ERR(0, 6770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6781
 *         )
 * 
 *     def futures_coin_account(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get current account information.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_473futures_coin_account, 0, __pyx_n_s_BinanceRestApiManager_futures_co_31, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__469)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_account, __pyx_t_6) < 0) __PYX_ERR(0, 6781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6792
 *         )
 * 
 *     def futures_coin_change_leverage(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's initial leverage of specific symbol market
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_475futures_coin_change_leverage, 0, __pyx_n_s_BinanceRestApiManager_futures_co_32, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__470)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_change_leverage, __pyx_t_6) < 0) __PYX_ERR(0, 6792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6803
 *         )
 * 
 *     def futures_coin_change_margin_type(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the margin type for a symbol
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_477futures_coin_change_margin_type, 0, __pyx_n_s_BinanceRestApiManager_futures_co_33, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__471)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_change_margin_type, __pyx_t_6) < 0) __PYX_ERR(0, 6803, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6814
 *         )
 * 
 *     def futures_coin_change_position_margin(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change the position margin for a symbol
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_479futures_coin_change_position_margin, 0, __pyx_n_s_BinanceRestApiManager_futures_co_34, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__472)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_change_position_mar, __pyx_t_6) < 0) __PYX_ERR(0, 6814, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6825
 *         )
 * 
 *     def futures_coin_position_margin_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get position margin change history
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_481futures_coin_position_margin_history, 0, __pyx_n_s_BinanceRestApiManager_futures_co_35, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__473)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_position_margin_his, __pyx_t_6) < 0) __PYX_ERR(0, 6825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6835
 *         )
 * 
 *     def futures_coin_position_information(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get position information
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_483futures_coin_position_information, 0, __pyx_n_s_BinanceRestApiManager_futures_co_36, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__474)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_position_informatio, __pyx_t_6) < 0) __PYX_ERR(0, 6835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6844
 *         return self._request_futures_coin_api("get", "positionRisk", True, data=params)
 * 
 *     def futures_coin_account_trades(self, **params):             # <<<<<<<<<<<<<<
 *         """Get trades for the authenticated account and symbol.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_485futures_coin_account_trades, 0, __pyx_n_s_BinanceRestApiManager_futures_co_37, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__475)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_account_trades, __pyx_t_6) < 0) __PYX_ERR(0, 6844, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6852
 *         return self._request_futures_coin_api("get", "userTrades", True, data=params)
 * 
 *     def futures_coin_income_history(self, **params):             # <<<<<<<<<<<<<<
 *         """Get income history for authenticated account
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_487futures_coin_income_history, 0, __pyx_n_s_BinanceRestApiManager_futures_co_38, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__476)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_income_history, __pyx_t_6) < 0) __PYX_ERR(0, 6852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6860
 *         return self._request_futures_coin_api("get", "income", True, data=params)
 * 
 *     def futures_coin_change_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Change user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_489futures_coin_change_position_mode, 0, __pyx_n_s_BinanceRestApiManager_futures_co_39, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_change_position_mod, __pyx_t_6) < 0) __PYX_ERR(0, 6860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6868
 *         return self._request_futures_coin_api("post", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_get_position_mode(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get user's position mode (Hedge Mode or One-way Mode ) on EVERY symbol
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_491futures_coin_get_position_mode, 0, __pyx_n_s_BinanceRestApiManager_futures_co_40, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__478)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_get_position_mode, __pyx_t_6) < 0) __PYX_ERR(0, 6868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6877
 *         return self._request_futures_coin_api("get", "positionSide/dual", True, data=params)
 * 
 *     def futures_coin_stream_get_listen_key(self, output="value", throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Start a new coin futures data stream and return the listen key
 *         If a stream already exists it should return the same key.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_493futures_coin_stream_get_listen_key, 0, __pyx_n_s_BinanceRestApiManager_futures_co_41, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__479)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__313);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_stream_get_listen_k, __pyx_t_6) < 0) __PYX_ERR(0, 6877, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6911
 *             return res['listenKey']
 * 
 *     def futures_coin_stream_keepalive(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """PING a coin futures data stream to prevent a time out.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_495futures_coin_stream_keepalive, 0, __pyx_n_s_BinanceRestApiManager_futures_co_42, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__480)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_stream_keepalive, __pyx_t_6) < 0) __PYX_ERR(0, 6911, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6936
 *                                               throw_exception=throw_exception)
 * 
 *     def futures_coin_stream_close(self, listenKey, throw_exception=True):             # <<<<<<<<<<<<<<
 *         """Close out a coin futures data stream.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_497futures_coin_stream_close, 0, __pyx_n_s_BinanceRestApiManager_futures_co_43, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__481)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_futures_coin_stream_close, __pyx_t_6) < 0) __PYX_ERR(0, 6936, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":6962
 * 
 * 
 *     def get_all_coins_info(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get information of coins (available for deposit and withdraw) for user.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_499get_all_coins_info, 0, __pyx_n_s_BinanceRestApiManager_get_all_co, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__482)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 6962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_all_coins_info, __pyx_t_6) < 0) __PYX_ERR(0, 6962, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":7038
 *         return self._request_margin_api('get', 'capital/config/getall', True, data=params)
 * 
 *     def get_account_snapshot(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Get daily account snapshot of specific type.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_501get_account_snapshot, 0, __pyx_n_s_BinanceRestApiManager_get_accoun_4, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__483)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_get_account_snapshot, __pyx_t_6) < 0) __PYX_ERR(0, 7038, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":7154
 *         return self._request_margin_api('get', 'accountSnapshot', True, data=params)
 * 
 *     def disable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Disable Fast Withdraw Switch
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_503disable_fast_withdraw_switch, 0, __pyx_n_s_BinanceRestApiManager_disable_fa, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__484)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_disable_fast_withdraw_switch, __pyx_t_6) < 0) __PYX_ERR(0, 7154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":7170
 *         return self._request_margin_api('post', 'disableFastWithdrawSwitch', True, data=params)
 * 
 *     def enable_fast_withdraw_switch(self, **params):             # <<<<<<<<<<<<<<
 *         """
 *         Enable Fast Withdraw Switch
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_505enable_fast_withdraw_switch, 0, __pyx_n_s_BinanceRestApiManager_enable_fas, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__485)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_enable_fast_withdraw_switch, __pyx_t_6) < 0) __PYX_ERR(0, 7170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":7186
 *         return self._request_margin_api('post', 'enableFastWithdrawSwitch', True, data=params)
 * 
 *     def stop_manager(self, close_api_session=True):             # <<<<<<<<<<<<<<
 *         """
 *         Stop the BinanceRestApiManager
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_24unicorn_binance_rest_api_7manager_21BinanceRestApiManager_507stop_manager, 0, __pyx_n_s_BinanceRestApiManager_stop_manag, NULL, __pyx_n_s_unicorn_binance_rest_api_manager, __pyx_d, ((PyObject *)__pyx_codeobj__487)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__230);
  if (__Pyx_SetNameInClass(__pyx_t_4, __pyx_n_s_stop_manager, __pyx_t_6) < 0) __PYX_ERR(0, 7186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "unicorn_binance_rest_api/manager.py":59
 * 
 * 
 * class BinanceRestApiManager(object):             # <<<<<<<<<<<<<<
 *     """
 *     An unofficial Python API to use the Binance REST API`s (com+testnet, com-margin+testnet,
 */
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_3, __pyx_n_s_BinanceRestApiManager, __pyx_t_2, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BinanceRestApiManager, __pyx_t_6) < 0) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "unicorn_binance_rest_api/manager.py":1
 * #!/usr/bin/env python3             # <<<<<<<<<<<<<<
 * # -*- coding: utf-8 -*-
 * #
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init unicorn_binance_rest_api.manager", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init unicorn_binance_rest_api.manager");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;  // error
            return kwvalues[i];
        }
    }
    return NULL;  // not found (no exception set)
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
static CYTHON_UNUSED PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value); // transfer ownership of value to values
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;  // ownership transferred to values
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL; // ownership transferred to values
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* UnpackUnboundCMethod */
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    PyObject *result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!__Pyx_CyOrPyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    PyObject* exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        
#ifdef HAVE_LONG_LONG
            if (sizeof(PY_LONG_LONG) > sizeof(long)) {
                PY_LONG_LONG result = (PY_LONG_LONG)a * (PY_LONG_LONG)b;
                return (result >= LONG_MIN && result <= LONG_MAX) ?
                    PyInt_FromLong((long)result) : PyLong_FromLongLong(result);
            }
#endif
#if CYTHON_USE_TYPE_SLOTS
            return PyInt_Type.tp_as_number->nb_multiply(op1, op2);
#else
            return PyNumber_Multiply(op1, op2);
#endif
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
            }
        }
                CYTHON_UNUSED_VAR(a);
                CYTHON_UNUSED_VAR(b);
                #ifdef HAVE_LONG_LONG
                lla = a;
                goto long_long;
                #else
                return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
                #endif
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("multiply", return NULL)
            result = ((double)a) * (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
#if !(CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2)
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_GetMethod;
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* StringJoin */
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    (void) __Pyx_PyObject_CallMethod1;
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION < 3
    return _PyString_Join(sep, values);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    return _PyBytes_Join(sep, values);
#else
    return __Pyx_PyObject_CallMethod1(sep, __pyx_n_s_join, values);
#endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc;
    __Pyx_PyThreadState_declare
    #ifdef __Pyx_StopAsyncIteration_USED
    int is_async_stopiteration = 0;
    #endif
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    cur_exc = PyErr_Occurred();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        #ifdef __Pyx_StopAsyncIteration_USED
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, __Pyx_PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else
        #endif
            return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(val);
    Py_XDECREF(tb);
    PyErr_SetString(PyExc_RuntimeError,
        #ifdef __Pyx_StopAsyncIteration_USED
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        #endif
        "generator raised StopIteration");
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* MergeKeywords */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping) {
    PyObject *iter, *key = NULL, *value = NULL;
    int source_is_dict, result;
    Py_ssize_t orig_length, ppos = 0;
    iter = __Pyx_dict_iterator(source_mapping, 0, __pyx_n_s_items, &orig_length, &source_is_dict);
    if (unlikely(!iter)) {
        PyObject *args;
        if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError))) goto bad;
        PyErr_Clear();
        args = PyTuple_Pack(1, source_mapping);
        if (likely(args)) {
            PyObject *fallback = PyObject_Call((PyObject*)&PyDict_Type, args, NULL);
            Py_DECREF(args);
            if (likely(fallback)) {
                iter = __Pyx_dict_iterator(fallback, 1, __pyx_n_s_items, &orig_length, &source_is_dict);
                Py_DECREF(fallback);
            }
        }
        if (unlikely(!iter)) goto bad;
    }
    while (1) {
        result = __Pyx_dict_iter_next(iter, orig_length, &ppos, &key, &value, NULL, source_is_dict);
        if (unlikely(result < 0)) goto bad;
        if (!result) break;
        if (unlikely(PyDict_Contains(kwdict, key))) {
            __Pyx_RaiseDoubleKeywordsError("function", key);
            result = -1;
        } else {
            result = PyDict_SetItem(kwdict, key, value);
        }
        Py_DECREF(key);
        Py_DECREF(value);
        if (unlikely(result < 0)) goto bad;
    }
    Py_XDECREF(iter);
    return 0;
bad:
    Py_XDECREF(iter);
    return -1;
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_RemainderObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = a % b;
            x += ((x != 0) & ((x ^ b) < 0)) * b;
            return PyInt_FromLong(x);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_remainder(op1, op2);
            }
        }
                x = a % b;
                x += ((x != 0) & ((x ^ b) < 0)) * b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla % llb;
                llx += ((llx != 0) & ((llx ^ llb) < 0)) * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceRemainder : PyNumber_Remainder)(op1, op2);
}
#endif

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a == b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#if !CYTHON_USE_TYPE_SLOTS
        if (dictoffset == 0) {
            PyErr_Format(PyExc_TypeError,
                "extension type '%s.200s': "
                "unable to validate whether bases have a __dict__ "
                "when CYTHON_USE_TYPE_SLOTS is off "
                "(likely because you are building in the limited API). "
                "Therefore, all extension types with multiple bases "
                "must add 'cdef dict __dict__' in this compilation mode",
                type_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#else
        if (dictoffset == 0 && b->tp_dictoffset)
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "extension type '%.200s' has no __dict__ slot, "
                "but base type '" __Pyx_FMT_TYPENAME "' has: "
                "either add 'cdef dict __dict__' to the extension type "
                "or add '__slots__ = [...]' to the base type",
                type_name, b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__185);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__186;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base, *meth, *new_base, *result, *new_bases = NULL;
    size_bases = PyTuple_GET_SIZE(bases);
    for (i = 0; i < size_bases; i++) {
        base  = PyTuple_GET_ITEM(bases, i);
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_n_s_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                base = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base);
                Py_INCREF(base);
            }
        }
        j = PyList_GET_SIZE(new_bases);
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
    return result;
error:
    Py_XDECREF(new_bases);
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_MACROS
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__488);
    }
    return name;
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* CoroutineBase */
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(PyObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body(self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(PyObject* gen, PyObject *retval) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval))
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    gen->is_running = 0;
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        Py_TYPE(gen)->tp_del(self);
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (likely(--self->ob_refcnt == 0)) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context)
{
    PyObject *frame = self->gi_frame;
    CYTHON_UNUSED_VAR(context);
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (unlikely(!module)) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) __Pyx_PyObject_GenericGetAttrNoDict},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    __pyx_GeneratorType_slots
};
#else
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_Generator_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_GeneratorType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
#endif
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
